(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    536509,      13899]*)
(*NotebookOutlinePosition[    537159,      13922]*)
(*  CellTagsIndexPosition[    537115,      13918]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[BoxData[{
    \(<< NumericalMath`ListIntegrate`\), "\[IndentingNewLine]", 
    \(<< Statistics`DataSmoothing`\), "\[IndentingNewLine]", 
    \(<< NumericalMath`PolynomialFit`\), "\[IndentingNewLine]", 
    \(<< Statistics`NormalDistribution`\), "\[IndentingNewLine]", 
    \(<< Statistics`DiscreteDistributions`\), "\[IndentingNewLine]", 
    \(hide = DisplayFunction \[Rule] Identity\), "\[IndentingNewLine]", 
    \(SetDirectory["\</afs/cern.ch/user/a/afabich/public/MERIT\>"]\), "\n", 
    \(<< "\<prolog.m\>"\)}], "Input"],

Cell[BoxData[
    \(DisplayFunction \[Rule] Identity\)], "Output"],

Cell[BoxData[
    \("/afs/cern.ch/user/a/afabich/public/MERIT"\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\( (*\ 
      PS\ beam\ information\ from\ CPS\ *) \)\(\[IndentingNewLine]\)\(\
\[IndentingNewLine]\)\(\(PSbct = 
        ReadList["\</afs/cern.ch/user/a/afabich/public/MERIT/BeamLog_\
CompactForm.txt\>", String];\)\[IndentingNewLine]
    PSbct[\([1]\)]\[IndentingNewLine]
    \(PSbct = 
        Transpose[Map[StringSplit, Drop[PSbct, 1]]];\)\[IndentingNewLine]
    \(PSbct = 
        ToExpression[{PSbct[\([1]\)], PSbct[\([\(-3\)]\)], 
            PSbct[\([\(-2\)]\)], PSbct[\([\(-1\)]\)]}];\)\[IndentingNewLine]
    \)\)\)], "Input"],

Cell[BoxData[
    \("Run\tDate\tTime (Beam Log)"\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \("\<Every shot with index smaller than 4014 has a two times lower \
attenuation, the signal is twice higher for the same intensity.\>"\), "\
\[IndentingNewLine]", 
    \(corr[x_] := 
      Join[Take[x, {1, 8}], 
        Take[x, {9, 24}]/If[1042 < x[\([1]\)] < 4014, 2, 1], 
        Take[x, {25, 41}]]\), "\[IndentingNewLine]", 
    \(\(repH8 = 
        ReadList["\</afs/cern.ch/user/a/afabich/public/MERIT/transformer8.dat\
\>", Table[Number, {41}]];\)\), "\[IndentingNewLine]", 
    \(\(repH8 = Map[corr, repH8];\)\), "\[IndentingNewLine]", 
    \(\(repH16 = 
        Select[ReadList["\</afs/cern.ch/user/a/afabich/public/MERIT/\
transformerWithSaturation.dat\>", Table[Number, {41}]], 
          IntegerPart[#[\([1]\)]/1000] \[NotEqual] 
              20 &];\)\), "\[IndentingNewLine]", 
    \(\(repH16 = Map[corr, repH16];\)\), "\[IndentingNewLine]", 
    \(Export["\</afs/cern.ch/user/a/afabich/public/MERIT/transformerAll.dat\>\
", report = Sort[Join[repH8, repH16]]]\), "\[IndentingNewLine]", 
    \(\(report = Select[report, #[\([\(-1\)]\)] \[Equal] 0 &];\)\)}], "Input"],

Cell[BoxData[
    \("Every shot with index smaller than 4014 has a two times lower \
attenuation, the signal is twice higher for the same intensity."\)], "Output"],

Cell[BoxData[
    \("/afs/cern.ch/user/a/afabich/public/MERIT/transformerAll.dat"\)], \
"Output"]
}, Open  ]],

Cell[BoxData[{
    \(\(TotBctH16 = 
        Transpose[{\(Transpose[repH16]\)[\([1]\)], 
            Map[Total, 
              Transpose[
                Take[Transpose[repH16], {9, 
                    24}]]]}];\)\), "\[IndentingNewLine]", 
    \(\(TotBctH16 = 
        Transpose[{\(Transpose[report]\)[\([1]\)], 
            Map[Total, 
              Transpose[Take[Transpose[report], {9, 24}]]]}];\)\)}], "Input"],

Cell[BoxData[
    \(\(\(sel[x_] := 
      Flatten[Join[
          Select[Transpose[
              PSbct], #[\([1]\)] \[Equal] 
                x[\([1]\)] &], {x[\([2]\)]}]]\[IndentingNewLine]
    result = 
      Select[PSbctSel = Map[sel, TotBctH16], Length[#] \[Equal] 5 &]; \  (*\ 
      remove\ runs\ with\ no\ data\ in\ PS\ bct\ *) \[IndentingNewLine]result \
= Select[result, #[\([5]\)]/#[\([3]\)] > 100 &]; \  (*\ 
      remove\ runs\ with\ strange\ MERIT\ BCT\ data\ \
*) \[IndentingNewLine]result = 
      Select[result, #[\([1]\)] > 1999 &];\)\(\ \)\( (*\ 
      remove\ runs\ earlier\ then\ 2000\ *) \)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(indexFull = 
        Transpose[{Table[
              m, {m, Length[\(Transpose[
                      result]\)[\([1]\)]]}]\[IndentingNewLine], \(Transpose[
                result]\)[\([1]\)]}];\)\), "\n", 
    \(\(indexRed = {{indexFull[\([1, 1]\)], 
            IntegerPart[indexFull[\([1, 2]\)]/1000]}};\)\), "\n", 
    \(Do[\[IndentingNewLine]If[
        IntegerPart[indexFull[\([m, 2]\)]/1000] - 
            indexRed[\([\(-1\), 2]\)] \[GreaterEqual] 1, 
        AppendTo[
          indexRed, {indexFull[\([m, 1]\)], 
            IntegerPart[
              indexFull[\([m, 2]\)]/1000]}]]\[IndentingNewLine], {m, 2, 
        Length[indexFull]}]\), "\n", 
    \(indexRed\)}], "Input"],

Cell[BoxData[
    \({{1, 2}, {18, 3}, {41, 4}, {68, 5}, {87, 6}, {105, 7}, {124, 8}, {163, 
        9}, {182, 10}, {193, 11}, {208, 12}, {234, 13}, {247, 14}, {283, 
        15}, {324, 16}, {331, 17}}\)], "Output"]
}, Open  ]],

Cell[BoxData[{
    \(\(buf = \(\(Transpose[result]\)[\([5]\)]/\(Transpose[
                result]\)[\([2]\)]\)/
          Mean[\(Transpose[result]\)[\([5]\)]/\(Transpose[
                  result]\)[\([3]\)]];\)\), "\[IndentingNewLine]", 
    \(\(buf2 = \(\(Transpose[result]\)[\([5]\)]/\(Transpose[
                result]\)[\([3]\)]\)/
          Mean[\(Transpose[result]\)[\([5]\)]/\(Transpose[
                  result]\)[\([3]\)]];\)\), "\[IndentingNewLine]", 
    \(sel[x_] := 
      If[Abs[x[\([1]\)] - 1] < Abs[x[\([2]\)] - 1], x[\([1]\)], 
        x[\([1]\)]]\), "\n", 
    \(\(bufX = 
        Map[sel, Transpose[{buf, buf2}]]/0.904;\)\), "\[IndentingNewLine]", 
    \( (*\ \(bufX = bufX/Mean[bufX];\)\ *) \)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Export["\</afs/cern.ch/user/a/afabich/public/MERIT/PicDisplayAllRuns.\
eps\>", \[IndentingNewLine]Show[
        GraphicsArray[{\[IndentingNewLine]Histogram[bufX, 
              HistogramCategories -> 
                Table[m, {m, Floor[Min[bufX] 10]/10, \n
                    Ceiling[Max[bufX] 10]/10, 0.005}], Frame \[Rule] True, 
              FrameLabel \[Rule] {"\<ratio MCT/PSCT\>", "\<entries\>"}, 
              hide], \[IndentingNewLine]MultipleListPlot[\[IndentingNewLine]\
bufX, \[IndentingNewLine]\(\(Transpose[result]\)[\([2]\)]/
                  Mean[\(Transpose[result]\)[\([2]\)]]\)/
                2, \[IndentingNewLine]\(\(Transpose[result]\)[\([3]\)]/
                  Mean[\(Transpose[result]\)[\([3]\)]]\)/
                2, \[IndentingNewLine]PlotRange \[Rule] {All, {0.0, 2}}, 
              FrameTicks \[Rule] {indexRed, True, False, False}, hide, 
              FrameLabel \[Rule] {"\<Run index (day)\>", "\<ratio \
MCT/PSCT\>"}, PlotJoined \[Rule] {False, True, True}, 
              SymbolShape \[Rule] {PlotSymbol[Box], None, None}, 
              PlotStyle \[Rule] {RGBColor[0, 0, 0], RGBColor[1, 0, 0], 
                  RGBColor[0, 1, 0], RGBColor[0, 1, 1], 
                  RGBColor[0, 0, 1]}]\[IndentingNewLine]}], 
        ImageSize \[Rule] 1100]\[IndentingNewLine]]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2943 
%%ImageSize: 1100 323.732 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00700719 0.47619 [
[ 0 0 0 0 ]
[ 1 .2943 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .2943 L
0 .2943 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00700719 0.477324 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0932642 1.03627 0.0147151 0.0159082 [
[.11399 -0.0125 -9 -9 ]
[.11399 -0.0125 9 0 ]
[.32124 -0.0125 -9 -9 ]
[.32124 -0.0125 9 0 ]
[.5285 -0.0125 -9 -9 ]
[.5285 -0.0125 9 0 ]
[.73575 -0.0125 -9 -9 ]
[.73575 -0.0125 9 0 ]
[.94301 -0.0125 -3 -9 ]
[.94301 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -44 -19.125 ]
[.5 -0.0125 44 -9 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .09426 -6 -4.5 ]
[-0.0125 .09426 0 4.5 ]
[-0.0125 .1738 -12 -4.5 ]
[-0.0125 .1738 0 4.5 ]
[-0.0125 .25334 -12 -4.5 ]
[-0.0125 .25334 0 4.5 ]
[-0.0125 .33288 -12 -4.5 ]
[-0.0125 .33288 0 4.5 ]
[-0.0125 .41242 -12 -4.5 ]
[-0.0125 .41242 0 4.5 ]
[-0.0125 .49196 -12 -4.5 ]
[-0.0125 .49196 0 4.5 ]
[-0.0125 .5715 -12 -4.5 ]
[-0.0125 .5715 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -22.125 -23 ]
[-0.01875 .30902 -12 23 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11399 0 m
.11399 .00625 L
s
[(0.2)] .11399 -0.0125 0 1 Mshowa
.32124 0 m
.32124 .00625 L
s
[(0.4)] .32124 -0.0125 0 1 Mshowa
.5285 0 m
.5285 .00625 L
s
[(0.6)] .5285 -0.0125 0 1 Mshowa
.73575 0 m
.73575 .00625 L
s
[(0.8)] .73575 -0.0125 0 1 Mshowa
.94301 0 m
.94301 .00625 L
s
[(1)] .94301 -0.0125 0 1 Mshowa
.125 Mabswid
.1658 0 m
.1658 .00375 L
s
.21762 0 m
.21762 .00375 L
s
.26943 0 m
.26943 .00375 L
s
.37306 0 m
.37306 .00375 L
s
.42487 0 m
.42487 .00375 L
s
.47668 0 m
.47668 .00375 L
s
.58031 0 m
.58031 .00375 L
s
.63212 0 m
.63212 .00375 L
s
.68394 0 m
.68394 .00375 L
s
.78756 0 m
.78756 .00375 L
s
.83938 0 m
.83938 .00375 L
s
.89119 0 m
.89119 .00375 L
s
.06218 0 m
.06218 .00375 L
s
.01036 0 m
.01036 .00375 L
s
.99482 0 m
.99482 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -105 -23.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ratio) show
99.000 11.562 moveto
(MCT) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 11.562 moveto
(\\220) show
123.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(PSCT) show
147.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .09426 m
.00625 .09426 L
s
[(5)] -0.0125 .09426 1 0 Mshowa
0 .1738 m
.00625 .1738 L
s
[(10)] -0.0125 .1738 1 0 Mshowa
0 .25334 m
.00625 .25334 L
s
[(15)] -0.0125 .25334 1 0 Mshowa
0 .33288 m
.00625 .33288 L
s
[(20)] -0.0125 .33288 1 0 Mshowa
0 .41242 m
.00625 .41242 L
s
[(25)] -0.0125 .41242 1 0 Mshowa
0 .49196 m
.00625 .49196 L
s
[(30)] -0.0125 .49196 1 0 Mshowa
0 .5715 m
.00625 .5715 L
s
[(35)] -0.0125 .5715 1 0 Mshowa
.125 Mabswid
0 .03062 m
.00375 .03062 L
s
0 .04653 m
.00375 .04653 L
s
0 .06244 m
.00375 .06244 L
s
0 .07835 m
.00375 .07835 L
s
0 .11016 m
.00375 .11016 L
s
0 .12607 m
.00375 .12607 L
s
0 .14198 m
.00375 .14198 L
s
0 .15789 m
.00375 .15789 L
s
0 .18971 m
.00375 .18971 L
s
0 .20561 m
.00375 .20561 L
s
0 .22152 m
.00375 .22152 L
s
0 .23743 m
.00375 .23743 L
s
0 .26925 m
.00375 .26925 L
s
0 .28515 m
.00375 .28515 L
s
0 .30106 m
.00375 .30106 L
s
0 .31697 m
.00375 .31697 L
s
0 .34879 m
.00375 .34879 L
s
0 .3647 m
.00375 .3647 L
s
0 .3806 m
.00375 .3806 L
s
0 .39651 m
.00375 .39651 L
s
0 .42833 m
.00375 .42833 L
s
0 .44424 m
.00375 .44424 L
s
0 .46014 m
.00375 .46014 L
s
0 .47605 m
.00375 .47605 L
s
0 .50787 m
.00375 .50787 L
s
0 .52378 m
.00375 .52378 L
s
0 .53969 m
.00375 .53969 L
s
0 .55559 m
.00375 .55559 L
s
0 .58741 m
.00375 .58741 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -101.062 -9.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
84 9.0625 translate
90 rotate
-84 -9.0625 translate
0 18.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(entries) show
105.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11399 .61178 m
.11399 .61803 L
s
.32124 .61178 m
.32124 .61803 L
s
.5285 .61178 m
.5285 .61803 L
s
.73575 .61178 m
.73575 .61803 L
s
.94301 .61178 m
.94301 .61803 L
s
.125 Mabswid
.1658 .61428 m
.1658 .61803 L
s
.21762 .61428 m
.21762 .61803 L
s
.26943 .61428 m
.26943 .61803 L
s
.37306 .61428 m
.37306 .61803 L
s
.42487 .61428 m
.42487 .61803 L
s
.47668 .61428 m
.47668 .61803 L
s
.58031 .61428 m
.58031 .61803 L
s
.63212 .61428 m
.63212 .61803 L
s
.68394 .61428 m
.68394 .61803 L
s
.78756 .61428 m
.78756 .61803 L
s
.83938 .61428 m
.83938 .61803 L
s
.89119 .61428 m
.89119 .61803 L
s
.06218 .61428 m
.06218 .61803 L
s
.01036 .61428 m
.01036 .61803 L
s
.99482 .61428 m
.99482 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .09426 m
1 .09426 L
s
.99375 .1738 m
1 .1738 L
s
.99375 .25334 m
1 .25334 L
s
.99375 .33288 m
1 .33288 L
s
.99375 .41242 m
1 .41242 L
s
.99375 .49196 m
1 .49196 L
s
.99375 .5715 m
1 .5715 L
s
.125 Mabswid
.99625 .03062 m
1 .03062 L
s
.99625 .04653 m
1 .04653 L
s
.99625 .06244 m
1 .06244 L
s
.99625 .07835 m
1 .07835 L
s
.99625 .11016 m
1 .11016 L
s
.99625 .12607 m
1 .12607 L
s
.99625 .14198 m
1 .14198 L
s
.99625 .15789 m
1 .15789 L
s
.99625 .18971 m
1 .18971 L
s
.99625 .20561 m
1 .20561 L
s
.99625 .22152 m
1 .22152 L
s
.99625 .23743 m
1 .23743 L
s
.99625 .26925 m
1 .26925 L
s
.99625 .28515 m
1 .28515 L
s
.99625 .30106 m
1 .30106 L
s
.99625 .31697 m
1 .31697 L
s
.99625 .34879 m
1 .34879 L
s
.99625 .3647 m
1 .3647 L
s
.99625 .3806 m
1 .3806 L
s
.99625 .39651 m
1 .39651 L
s
.99625 .42833 m
1 .42833 L
s
.99625 .44424 m
1 .44424 L
s
.99625 .46014 m
1 .46014 L
s
.99625 .47605 m
1 .47605 L
s
.99625 .50787 m
1 .50787 L
s
.99625 .52378 m
1 .52378 L
s
.99625 .53969 m
1 .53969 L
s
.99625 .55559 m
1 .55559 L
s
.99625 .58741 m
1 .58741 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .03062 L
.00518 .03062 L
.00518 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .03062 L
.00518 .03062 L
.00518 .01472 L
0 .01472 L
s
1 0 0 r
.00518 .01472 m
.00518 .01472 L
.01036 .01472 L
.01036 .01472 L
F
0 g
.00518 .01472 m
.00518 .01472 L
.01036 .01472 L
.01036 .01472 L
.00518 .01472 L
s
1 0 0 r
.01036 .01472 m
.01036 .01472 L
.01554 .01472 L
.01554 .01472 L
F
0 g
.01036 .01472 m
.01036 .01472 L
.01554 .01472 L
.01554 .01472 L
.01036 .01472 L
s
1 0 0 r
.01554 .01472 m
.01554 .01472 L
.02073 .01472 L
.02073 .01472 L
F
0 g
.01554 .01472 m
.01554 .01472 L
.02073 .01472 L
.02073 .01472 L
.01554 .01472 L
s
1 0 0 r
.02073 .01472 m
.02073 .03062 L
.02591 .03062 L
.02591 .01472 L
F
0 g
.02073 .01472 m
.02073 .03062 L
.02591 .03062 L
.02591 .01472 L
.02073 .01472 L
s
1 0 0 r
.02591 .01472 m
.02591 .01472 L
.03109 .01472 L
.03109 .01472 L
F
0 g
.02591 .01472 m
.02591 .01472 L
.03109 .01472 L
.03109 .01472 L
.02591 .01472 L
s
1 0 0 r
.03109 .01472 m
.03109 .06244 L
.03627 .06244 L
.03627 .01472 L
F
0 g
.03109 .01472 m
.03109 .06244 L
.03627 .06244 L
.03627 .01472 L
.03109 .01472 L
s
1 0 0 r
.03627 .01472 m
.03627 .03062 L
.04145 .03062 L
.04145 .01472 L
F
0 g
.03627 .01472 m
.03627 .03062 L
.04145 .03062 L
.04145 .01472 L
.03627 .01472 L
s
1 0 0 r
.04145 .01472 m
.04145 .04653 L
.04663 .04653 L
.04663 .01472 L
F
0 g
.04145 .01472 m
.04145 .04653 L
.04663 .04653 L
.04663 .01472 L
.04145 .01472 L
s
1 0 0 r
.04663 .01472 m
.04663 .01472 L
.05181 .01472 L
.05181 .01472 L
F
0 g
.04663 .01472 m
.04663 .01472 L
.05181 .01472 L
.05181 .01472 L
.04663 .01472 L
s
1 0 0 r
.05181 .01472 m
.05181 .01472 L
.05699 .01472 L
.05699 .01472 L
F
0 g
.05181 .01472 m
.05181 .01472 L
.05699 .01472 L
.05699 .01472 L
.05181 .01472 L
s
1 0 0 r
.05699 .01472 m
.05699 .01472 L
.06218 .01472 L
.06218 .01472 L
F
0 g
.05699 .01472 m
.05699 .01472 L
.06218 .01472 L
.06218 .01472 L
.05699 .01472 L
s
1 0 0 r
.06218 .01472 m
.06218 .01472 L
.06736 .01472 L
.06736 .01472 L
F
0 g
.06218 .01472 m
.06218 .01472 L
.06736 .01472 L
.06736 .01472 L
.06218 .01472 L
s
1 0 0 r
.06736 .01472 m
.06736 .01472 L
.07254 .01472 L
.07254 .01472 L
F
0 g
.06736 .01472 m
.06736 .01472 L
.07254 .01472 L
.07254 .01472 L
.06736 .01472 L
s
1 0 0 r
.07254 .01472 m
.07254 .01472 L
.07772 .01472 L
.07772 .01472 L
F
0 g
.07254 .01472 m
.07254 .01472 L
.07772 .01472 L
.07772 .01472 L
.07254 .01472 L
s
1 0 0 r
.07772 .01472 m
.07772 .01472 L
.0829 .01472 L
.0829 .01472 L
F
0 g
.07772 .01472 m
.07772 .01472 L
.0829 .01472 L
.0829 .01472 L
.07772 .01472 L
s
1 0 0 r
.0829 .01472 m
.0829 .01472 L
.08808 .01472 L
.08808 .01472 L
F
0 g
.0829 .01472 m
.0829 .01472 L
.08808 .01472 L
.08808 .01472 L
.0829 .01472 L
s
1 0 0 r
.08808 .01472 m
.08808 .01472 L
.09326 .01472 L
.09326 .01472 L
F
0 g
.08808 .01472 m
.08808 .01472 L
.09326 .01472 L
.09326 .01472 L
.08808 .01472 L
s
1 0 0 r
.09326 .01472 m
.09326 .01472 L
.09845 .01472 L
.09845 .01472 L
F
0 g
.09326 .01472 m
.09326 .01472 L
.09845 .01472 L
.09845 .01472 L
.09326 .01472 L
s
1 0 0 r
.09845 .01472 m
.09845 .01472 L
.10363 .01472 L
.10363 .01472 L
F
0 g
.09845 .01472 m
.09845 .01472 L
.10363 .01472 L
.10363 .01472 L
.09845 .01472 L
s
1 0 0 r
.10363 .01472 m
.10363 .01472 L
.10881 .01472 L
.10881 .01472 L
F
0 g
.10363 .01472 m
.10363 .01472 L
.10881 .01472 L
.10881 .01472 L
.10363 .01472 L
s
1 0 0 r
.10881 .01472 m
.10881 .01472 L
.11399 .01472 L
.11399 .01472 L
F
0 g
.10881 .01472 m
.10881 .01472 L
.11399 .01472 L
.11399 .01472 L
.10881 .01472 L
s
1 0 0 r
.11399 .01472 m
.11399 .01472 L
.11917 .01472 L
.11917 .01472 L
F
0 g
.11399 .01472 m
.11399 .01472 L
.11917 .01472 L
.11917 .01472 L
.11399 .01472 L
s
1 0 0 r
.11917 .01472 m
.11917 .01472 L
.12435 .01472 L
.12435 .01472 L
F
0 g
.11917 .01472 m
.11917 .01472 L
.12435 .01472 L
.12435 .01472 L
.11917 .01472 L
s
1 0 0 r
.12435 .01472 m
.12435 .01472 L
.12953 .01472 L
.12953 .01472 L
F
0 g
.12435 .01472 m
.12435 .01472 L
.12953 .01472 L
.12953 .01472 L
.12435 .01472 L
s
1 0 0 r
.12953 .01472 m
.12953 .03062 L
.13472 .03062 L
.13472 .01472 L
F
0 g
.12953 .01472 m
.12953 .03062 L
.13472 .03062 L
.13472 .01472 L
.12953 .01472 L
s
1 0 0 r
.13472 .01472 m
.13472 .01472 L
.1399 .01472 L
.1399 .01472 L
F
0 g
.13472 .01472 m
.13472 .01472 L
.1399 .01472 L
.1399 .01472 L
.13472 .01472 L
s
1 0 0 r
.1399 .01472 m
.1399 .01472 L
.14508 .01472 L
.14508 .01472 L
F
0 g
.1399 .01472 m
.1399 .01472 L
.14508 .01472 L
.14508 .01472 L
.1399 .01472 L
s
1 0 0 r
.14508 .01472 m
.14508 .01472 L
.15026 .01472 L
.15026 .01472 L
F
0 g
.14508 .01472 m
.14508 .01472 L
.15026 .01472 L
.15026 .01472 L
.14508 .01472 L
s
1 0 0 r
.15026 .01472 m
.15026 .01472 L
.15544 .01472 L
.15544 .01472 L
F
0 g
.15026 .01472 m
.15026 .01472 L
.15544 .01472 L
.15544 .01472 L
.15026 .01472 L
s
1 0 0 r
.15544 .01472 m
.15544 .03062 L
.16062 .03062 L
.16062 .01472 L
F
0 g
.15544 .01472 m
.15544 .03062 L
.16062 .03062 L
.16062 .01472 L
.15544 .01472 L
s
1 0 0 r
.16062 .01472 m
.16062 .1738 L
.1658 .1738 L
.1658 .01472 L
F
0 g
.16062 .01472 m
.16062 .1738 L
.1658 .1738 L
.1658 .01472 L
.16062 .01472 L
s
1 0 0 r
.1658 .01472 m
.1658 .39651 L
.17098 .39651 L
.17098 .01472 L
F
0 g
.1658 .01472 m
.1658 .39651 L
.17098 .39651 L
.17098 .01472 L
.1658 .01472 L
s
1 0 0 r
.17098 .01472 m
.17098 .3806 L
.17617 .3806 L
.17617 .01472 L
F
0 g
.17098 .01472 m
.17098 .3806 L
.17617 .3806 L
.17617 .01472 L
.17098 .01472 L
s
1 0 0 r
.17617 .01472 m
.17617 .12607 L
.18135 .12607 L
.18135 .01472 L
F
0 g
.17617 .01472 m
.17617 .12607 L
.18135 .12607 L
.18135 .01472 L
.17617 .01472 L
s
1 0 0 r
.18135 .01472 m
.18135 .03062 L
.18653 .03062 L
.18653 .01472 L
F
0 g
.18135 .01472 m
.18135 .03062 L
.18653 .03062 L
.18653 .01472 L
.18135 .01472 L
s
1 0 0 r
.18653 .01472 m
.18653 .03062 L
.19171 .03062 L
.19171 .01472 L
F
0 g
.18653 .01472 m
.18653 .03062 L
.19171 .03062 L
.19171 .01472 L
.18653 .01472 L
s
1 0 0 r
.19171 .01472 m
.19171 .01472 L
.19689 .01472 L
.19689 .01472 L
F
0 g
.19171 .01472 m
.19171 .01472 L
.19689 .01472 L
.19689 .01472 L
.19171 .01472 L
s
1 0 0 r
.19689 .01472 m
.19689 .01472 L
.20207 .01472 L
.20207 .01472 L
F
0 g
.19689 .01472 m
.19689 .01472 L
.20207 .01472 L
.20207 .01472 L
.19689 .01472 L
s
1 0 0 r
.20207 .01472 m
.20207 .01472 L
.20725 .01472 L
.20725 .01472 L
F
0 g
.20207 .01472 m
.20207 .01472 L
.20725 .01472 L
.20725 .01472 L
.20207 .01472 L
s
1 0 0 r
.20725 .01472 m
.20725 .01472 L
.21244 .01472 L
.21244 .01472 L
F
0 g
.20725 .01472 m
.20725 .01472 L
.21244 .01472 L
.21244 .01472 L
.20725 .01472 L
s
1 0 0 r
.21244 .01472 m
.21244 .01472 L
.21762 .01472 L
.21762 .01472 L
F
0 g
.21244 .01472 m
.21244 .01472 L
.21762 .01472 L
.21762 .01472 L
.21244 .01472 L
s
1 0 0 r
.21762 .01472 m
.21762 .01472 L
.2228 .01472 L
.2228 .01472 L
F
0 g
.21762 .01472 m
.21762 .01472 L
.2228 .01472 L
.2228 .01472 L
.21762 .01472 L
s
1 0 0 r
.2228 .01472 m
.2228 .01472 L
.22798 .01472 L
.22798 .01472 L
F
0 g
.2228 .01472 m
.2228 .01472 L
.22798 .01472 L
.22798 .01472 L
.2228 .01472 L
s
1 0 0 r
.22798 .01472 m
.22798 .01472 L
.23316 .01472 L
.23316 .01472 L
F
0 g
.22798 .01472 m
.22798 .01472 L
.23316 .01472 L
.23316 .01472 L
.22798 .01472 L
s
1 0 0 r
.23316 .01472 m
.23316 .01472 L
.23834 .01472 L
.23834 .01472 L
F
0 g
.23316 .01472 m
.23316 .01472 L
.23834 .01472 L
.23834 .01472 L
.23316 .01472 L
s
1 0 0 r
.23834 .01472 m
.23834 .01472 L
.24352 .01472 L
.24352 .01472 L
F
0 g
.23834 .01472 m
.23834 .01472 L
.24352 .01472 L
.24352 .01472 L
.23834 .01472 L
s
1 0 0 r
.24352 .01472 m
.24352 .01472 L
.2487 .01472 L
.2487 .01472 L
F
0 g
.24352 .01472 m
.24352 .01472 L
.2487 .01472 L
.2487 .01472 L
.24352 .01472 L
s
1 0 0 r
.2487 .01472 m
.2487 .01472 L
.25389 .01472 L
.25389 .01472 L
F
0 g
.2487 .01472 m
.2487 .01472 L
.25389 .01472 L
.25389 .01472 L
.2487 .01472 L
s
1 0 0 r
.25389 .01472 m
.25389 .01472 L
.25907 .01472 L
.25907 .01472 L
F
0 g
.25389 .01472 m
.25389 .01472 L
.25907 .01472 L
.25907 .01472 L
.25389 .01472 L
s
1 0 0 r
.25907 .01472 m
.25907 .01472 L
.26425 .01472 L
.26425 .01472 L
F
0 g
.25907 .01472 m
.25907 .01472 L
.26425 .01472 L
.26425 .01472 L
.25907 .01472 L
s
1 0 0 r
.26425 .01472 m
.26425 .01472 L
.26943 .01472 L
.26943 .01472 L
F
0 g
.26425 .01472 m
.26425 .01472 L
.26943 .01472 L
.26943 .01472 L
.26425 .01472 L
s
1 0 0 r
.26943 .01472 m
.26943 .01472 L
.27461 .01472 L
.27461 .01472 L
F
0 g
.26943 .01472 m
.26943 .01472 L
.27461 .01472 L
.27461 .01472 L
.26943 .01472 L
s
1 0 0 r
.27461 .01472 m
.27461 .01472 L
.27979 .01472 L
.27979 .01472 L
F
0 g
.27461 .01472 m
.27461 .01472 L
.27979 .01472 L
.27979 .01472 L
.27461 .01472 L
s
1 0 0 r
.27979 .01472 m
.27979 .01472 L
.28497 .01472 L
.28497 .01472 L
F
0 g
.27979 .01472 m
.27979 .01472 L
.28497 .01472 L
.28497 .01472 L
.27979 .01472 L
s
1 0 0 r
.28497 .01472 m
.28497 .01472 L
.29016 .01472 L
.29016 .01472 L
F
0 g
.28497 .01472 m
.28497 .01472 L
.29016 .01472 L
.29016 .01472 L
.28497 .01472 L
s
1 0 0 r
.29016 .01472 m
.29016 .01472 L
.29534 .01472 L
.29534 .01472 L
F
0 g
.29016 .01472 m
.29016 .01472 L
.29534 .01472 L
.29534 .01472 L
.29016 .01472 L
s
1 0 0 r
.29534 .01472 m
.29534 .01472 L
.30052 .01472 L
.30052 .01472 L
F
0 g
.29534 .01472 m
.29534 .01472 L
.30052 .01472 L
.30052 .01472 L
.29534 .01472 L
s
1 0 0 r
.30052 .01472 m
.30052 .01472 L
.3057 .01472 L
.3057 .01472 L
F
0 g
.30052 .01472 m
.30052 .01472 L
.3057 .01472 L
.3057 .01472 L
.30052 .01472 L
s
1 0 0 r
.3057 .01472 m
.3057 .01472 L
.31088 .01472 L
.31088 .01472 L
F
0 g
.3057 .01472 m
.3057 .01472 L
.31088 .01472 L
.31088 .01472 L
.3057 .01472 L
s
1 0 0 r
.31088 .01472 m
.31088 .01472 L
.31606 .01472 L
.31606 .01472 L
F
0 g
.31088 .01472 m
.31088 .01472 L
.31606 .01472 L
.31606 .01472 L
.31088 .01472 L
s
1 0 0 r
.31606 .01472 m
.31606 .01472 L
.32124 .01472 L
.32124 .01472 L
F
0 g
.31606 .01472 m
.31606 .01472 L
.32124 .01472 L
.32124 .01472 L
.31606 .01472 L
s
1 0 0 r
.32124 .01472 m
.32124 .01472 L
.32642 .01472 L
.32642 .01472 L
F
0 g
.32124 .01472 m
.32124 .01472 L
.32642 .01472 L
.32642 .01472 L
.32124 .01472 L
s
1 0 0 r
.32642 .01472 m
.32642 .01472 L
.33161 .01472 L
.33161 .01472 L
F
0 g
.32642 .01472 m
.32642 .01472 L
.33161 .01472 L
.33161 .01472 L
.32642 .01472 L
s
1 0 0 r
.33161 .01472 m
.33161 .01472 L
.33679 .01472 L
.33679 .01472 L
F
0 g
.33161 .01472 m
.33161 .01472 L
.33679 .01472 L
.33679 .01472 L
.33161 .01472 L
s
1 0 0 r
.33679 .01472 m
.33679 .01472 L
.34197 .01472 L
.34197 .01472 L
F
0 g
.33679 .01472 m
.33679 .01472 L
.34197 .01472 L
.34197 .01472 L
.33679 .01472 L
s
1 0 0 r
.34197 .01472 m
.34197 .01472 L
.34715 .01472 L
.34715 .01472 L
F
0 g
.34197 .01472 m
.34197 .01472 L
.34715 .01472 L
.34715 .01472 L
.34197 .01472 L
s
1 0 0 r
.34715 .01472 m
.34715 .01472 L
.35233 .01472 L
.35233 .01472 L
F
0 g
.34715 .01472 m
.34715 .01472 L
.35233 .01472 L
.35233 .01472 L
.34715 .01472 L
s
1 0 0 r
.35233 .01472 m
.35233 .01472 L
.35751 .01472 L
.35751 .01472 L
F
0 g
.35233 .01472 m
.35233 .01472 L
.35751 .01472 L
.35751 .01472 L
.35233 .01472 L
s
1 0 0 r
.35751 .01472 m
.35751 .01472 L
.36269 .01472 L
.36269 .01472 L
F
0 g
.35751 .01472 m
.35751 .01472 L
.36269 .01472 L
.36269 .01472 L
.35751 .01472 L
s
1 0 0 r
.36269 .01472 m
.36269 .01472 L
.36788 .01472 L
.36788 .01472 L
F
0 g
.36269 .01472 m
.36269 .01472 L
.36788 .01472 L
.36788 .01472 L
.36269 .01472 L
s
1 0 0 r
.36788 .01472 m
.36788 .01472 L
.37306 .01472 L
.37306 .01472 L
F
0 g
.36788 .01472 m
.36788 .01472 L
.37306 .01472 L
.37306 .01472 L
.36788 .01472 L
s
1 0 0 r
.37306 .01472 m
.37306 .01472 L
.37824 .01472 L
.37824 .01472 L
F
0 g
.37306 .01472 m
.37306 .01472 L
.37824 .01472 L
.37824 .01472 L
.37306 .01472 L
s
1 0 0 r
.37824 .01472 m
.37824 .01472 L
.38342 .01472 L
.38342 .01472 L
F
0 g
.37824 .01472 m
.37824 .01472 L
.38342 .01472 L
.38342 .01472 L
.37824 .01472 L
s
1 0 0 r
.38342 .01472 m
.38342 .01472 L
.3886 .01472 L
.3886 .01472 L
F
0 g
.38342 .01472 m
.38342 .01472 L
.3886 .01472 L
.3886 .01472 L
.38342 .01472 L
s
1 0 0 r
.3886 .01472 m
.3886 .01472 L
.39378 .01472 L
.39378 .01472 L
F
0 g
.3886 .01472 m
.3886 .01472 L
.39378 .01472 L
.39378 .01472 L
.3886 .01472 L
s
1 0 0 r
.39378 .01472 m
.39378 .01472 L
.39896 .01472 L
.39896 .01472 L
F
0 g
.39378 .01472 m
.39378 .01472 L
.39896 .01472 L
.39896 .01472 L
.39378 .01472 L
s
1 0 0 r
.39896 .01472 m
.39896 .01472 L
.40415 .01472 L
.40415 .01472 L
F
0 g
.39896 .01472 m
.39896 .01472 L
.40415 .01472 L
.40415 .01472 L
.39896 .01472 L
s
1 0 0 r
.40415 .01472 m
.40415 .04653 L
.40933 .04653 L
.40933 .01472 L
F
0 g
.40415 .01472 m
.40415 .04653 L
.40933 .04653 L
.40933 .01472 L
.40415 .01472 L
s
1 0 0 r
.40933 .01472 m
.40933 .06244 L
.41451 .06244 L
.41451 .01472 L
F
0 g
.40933 .01472 m
.40933 .06244 L
.41451 .06244 L
.41451 .01472 L
.40933 .01472 L
s
1 0 0 r
.41451 .01472 m
.41451 .04653 L
.41969 .04653 L
.41969 .01472 L
F
0 g
.41451 .01472 m
.41451 .04653 L
.41969 .04653 L
.41969 .01472 L
.41451 .01472 L
s
1 0 0 r
.41969 .01472 m
.41969 .04653 L
.42487 .04653 L
.42487 .01472 L
F
0 g
.41969 .01472 m
.41969 .04653 L
.42487 .04653 L
.42487 .01472 L
.41969 .01472 L
s
1 0 0 r
.42487 .01472 m
.42487 .04653 L
.43005 .04653 L
.43005 .01472 L
F
0 g
.42487 .01472 m
.42487 .04653 L
.43005 .04653 L
.43005 .01472 L
.42487 .01472 L
s
1 0 0 r
.43005 .01472 m
.43005 .07835 L
.43523 .07835 L
.43523 .01472 L
F
0 g
.43005 .01472 m
.43005 .07835 L
.43523 .07835 L
.43523 .01472 L
.43005 .01472 L
s
1 0 0 r
.43523 .01472 m
.43523 .01472 L
.44041 .01472 L
.44041 .01472 L
F
0 g
.43523 .01472 m
.43523 .01472 L
.44041 .01472 L
.44041 .01472 L
.43523 .01472 L
s
1 0 0 r
.44041 .01472 m
.44041 .01472 L
.4456 .01472 L
.4456 .01472 L
F
0 g
.44041 .01472 m
.44041 .01472 L
.4456 .01472 L
.4456 .01472 L
.44041 .01472 L
s
1 0 0 r
.4456 .01472 m
.4456 .01472 L
.45078 .01472 L
.45078 .01472 L
F
0 g
.4456 .01472 m
.4456 .01472 L
.45078 .01472 L
.45078 .01472 L
.4456 .01472 L
s
1 0 0 r
.45078 .01472 m
.45078 .01472 L
.45596 .01472 L
.45596 .01472 L
F
0 g
.45078 .01472 m
.45078 .01472 L
.45596 .01472 L
.45596 .01472 L
.45078 .01472 L
s
1 0 0 r
.45596 .01472 m
.45596 .01472 L
.46114 .01472 L
.46114 .01472 L
F
0 g
.45596 .01472 m
.45596 .01472 L
.46114 .01472 L
.46114 .01472 L
.45596 .01472 L
s
1 0 0 r
.46114 .01472 m
.46114 .01472 L
.46632 .01472 L
.46632 .01472 L
F
0 g
.46114 .01472 m
.46114 .01472 L
.46632 .01472 L
.46632 .01472 L
.46114 .01472 L
s
1 0 0 r
.46632 .01472 m
.46632 .01472 L
.4715 .01472 L
.4715 .01472 L
F
0 g
.46632 .01472 m
.46632 .01472 L
.4715 .01472 L
.4715 .01472 L
.46632 .01472 L
s
1 0 0 r
.4715 .01472 m
.4715 .01472 L
.47668 .01472 L
.47668 .01472 L
F
0 g
.4715 .01472 m
.4715 .01472 L
.47668 .01472 L
.47668 .01472 L
.4715 .01472 L
s
1 0 0 r
.47668 .01472 m
.47668 .01472 L
.48187 .01472 L
.48187 .01472 L
F
0 g
.47668 .01472 m
.47668 .01472 L
.48187 .01472 L
.48187 .01472 L
.47668 .01472 L
s
1 0 0 r
.48187 .01472 m
.48187 .01472 L
.48705 .01472 L
.48705 .01472 L
F
0 g
.48187 .01472 m
.48187 .01472 L
.48705 .01472 L
.48705 .01472 L
.48187 .01472 L
s
1 0 0 r
.48705 .01472 m
.48705 .01472 L
.49223 .01472 L
.49223 .01472 L
F
0 g
.48705 .01472 m
.48705 .01472 L
.49223 .01472 L
.49223 .01472 L
.48705 .01472 L
s
1 0 0 r
.49223 .01472 m
.49223 .01472 L
.49741 .01472 L
.49741 .01472 L
F
0 g
.49223 .01472 m
.49223 .01472 L
.49741 .01472 L
.49741 .01472 L
.49223 .01472 L
s
1 0 0 r
.49741 .01472 m
.49741 .01472 L
.50259 .01472 L
.50259 .01472 L
F
0 g
.49741 .01472 m
.49741 .01472 L
.50259 .01472 L
.50259 .01472 L
.49741 .01472 L
s
1 0 0 r
.50259 .01472 m
.50259 .01472 L
.50777 .01472 L
.50777 .01472 L
F
0 g
.50259 .01472 m
.50259 .01472 L
.50777 .01472 L
.50777 .01472 L
.50259 .01472 L
s
1 0 0 r
.50777 .01472 m
.50777 .01472 L
.51295 .01472 L
.51295 .01472 L
F
0 g
.50777 .01472 m
.50777 .01472 L
.51295 .01472 L
.51295 .01472 L
.50777 .01472 L
s
1 0 0 r
.51295 .01472 m
.51295 .01472 L
.51813 .01472 L
.51813 .01472 L
F
0 g
.51295 .01472 m
.51295 .01472 L
.51813 .01472 L
.51813 .01472 L
.51295 .01472 L
s
1 0 0 r
.51813 .01472 m
.51813 .01472 L
.52332 .01472 L
.52332 .01472 L
F
0 g
.51813 .01472 m
.51813 .01472 L
.52332 .01472 L
.52332 .01472 L
.51813 .01472 L
s
1 0 0 r
.52332 .01472 m
.52332 .01472 L
.5285 .01472 L
.5285 .01472 L
F
0 g
.52332 .01472 m
.52332 .01472 L
.5285 .01472 L
.5285 .01472 L
.52332 .01472 L
s
1 0 0 r
.5285 .01472 m
.5285 .01472 L
.53368 .01472 L
.53368 .01472 L
F
0 g
.5285 .01472 m
.5285 .01472 L
.53368 .01472 L
.53368 .01472 L
.5285 .01472 L
s
1 0 0 r
.53368 .01472 m
.53368 .04653 L
.53886 .04653 L
.53886 .01472 L
F
0 g
.53368 .01472 m
.53368 .04653 L
.53886 .04653 L
.53886 .01472 L
.53368 .01472 L
s
1 0 0 r
.53886 .01472 m
.53886 .01472 L
.54404 .01472 L
.54404 .01472 L
F
0 g
.53886 .01472 m
.53886 .01472 L
.54404 .01472 L
.54404 .01472 L
.53886 .01472 L
s
1 0 0 r
.54404 .01472 m
.54404 .01472 L
.54922 .01472 L
.54922 .01472 L
F
0 g
.54404 .01472 m
.54404 .01472 L
.54922 .01472 L
.54922 .01472 L
.54404 .01472 L
s
1 0 0 r
.54922 .01472 m
.54922 .01472 L
.5544 .01472 L
.5544 .01472 L
F
0 g
.54922 .01472 m
.54922 .01472 L
.5544 .01472 L
.5544 .01472 L
.54922 .01472 L
s
1 0 0 r
.5544 .01472 m
.5544 .03062 L
.55959 .03062 L
.55959 .01472 L
F
0 g
.5544 .01472 m
.5544 .03062 L
.55959 .03062 L
.55959 .01472 L
.5544 .01472 L
s
1 0 0 r
.55959 .01472 m
.55959 .01472 L
.56477 .01472 L
.56477 .01472 L
F
0 g
.55959 .01472 m
.55959 .01472 L
.56477 .01472 L
.56477 .01472 L
.55959 .01472 L
s
1 0 0 r
.56477 .01472 m
.56477 .01472 L
.56995 .01472 L
.56995 .01472 L
F
0 g
.56477 .01472 m
.56477 .01472 L
.56995 .01472 L
.56995 .01472 L
.56477 .01472 L
s
1 0 0 r
.56995 .01472 m
.56995 .01472 L
.57513 .01472 L
.57513 .01472 L
F
0 g
.56995 .01472 m
.56995 .01472 L
.57513 .01472 L
.57513 .01472 L
.56995 .01472 L
s
1 0 0 r
.57513 .01472 m
.57513 .01472 L
.58031 .01472 L
.58031 .01472 L
F
0 g
.57513 .01472 m
.57513 .01472 L
.58031 .01472 L
.58031 .01472 L
.57513 .01472 L
s
1 0 0 r
.58031 .01472 m
.58031 .01472 L
.58549 .01472 L
.58549 .01472 L
F
0 g
.58031 .01472 m
.58031 .01472 L
.58549 .01472 L
.58549 .01472 L
.58031 .01472 L
s
1 0 0 r
.58549 .01472 m
.58549 .01472 L
.59067 .01472 L
.59067 .01472 L
F
0 g
.58549 .01472 m
.58549 .01472 L
.59067 .01472 L
.59067 .01472 L
.58549 .01472 L
s
1 0 0 r
.59067 .01472 m
.59067 .01472 L
.59585 .01472 L
.59585 .01472 L
F
0 g
.59067 .01472 m
.59067 .01472 L
.59585 .01472 L
.59585 .01472 L
.59067 .01472 L
s
1 0 0 r
.59585 .01472 m
.59585 .01472 L
.60104 .01472 L
.60104 .01472 L
F
0 g
.59585 .01472 m
.59585 .01472 L
.60104 .01472 L
.60104 .01472 L
.59585 .01472 L
s
1 0 0 r
.60104 .01472 m
.60104 .01472 L
.60622 .01472 L
.60622 .01472 L
F
0 g
.60104 .01472 m
.60104 .01472 L
.60622 .01472 L
.60622 .01472 L
.60104 .01472 L
s
1 0 0 r
.60622 .01472 m
.60622 .01472 L
.6114 .01472 L
.6114 .01472 L
F
0 g
.60622 .01472 m
.60622 .01472 L
.6114 .01472 L
.6114 .01472 L
.60622 .01472 L
s
1 0 0 r
.6114 .01472 m
.6114 .01472 L
.61658 .01472 L
.61658 .01472 L
F
0 g
.6114 .01472 m
.6114 .01472 L
.61658 .01472 L
.61658 .01472 L
.6114 .01472 L
s
1 0 0 r
.61658 .01472 m
.61658 .01472 L
.62176 .01472 L
.62176 .01472 L
F
0 g
.61658 .01472 m
.61658 .01472 L
.62176 .01472 L
.62176 .01472 L
.61658 .01472 L
s
1 0 0 r
.62176 .01472 m
.62176 .03062 L
.62694 .03062 L
.62694 .01472 L
F
0 g
.62176 .01472 m
.62176 .03062 L
.62694 .03062 L
.62694 .01472 L
.62176 .01472 L
s
1 0 0 r
.62694 .01472 m
.62694 .01472 L
.63212 .01472 L
.63212 .01472 L
F
0 g
.62694 .01472 m
.62694 .01472 L
.63212 .01472 L
.63212 .01472 L
.62694 .01472 L
s
1 0 0 r
.63212 .01472 m
.63212 .03062 L
.63731 .03062 L
.63731 .01472 L
F
0 g
.63212 .01472 m
.63212 .03062 L
.63731 .03062 L
.63731 .01472 L
.63212 .01472 L
s
1 0 0 r
.63731 .01472 m
.63731 .01472 L
.64249 .01472 L
.64249 .01472 L
F
0 g
.63731 .01472 m
.63731 .01472 L
.64249 .01472 L
.64249 .01472 L
.63731 .01472 L
s
1 0 0 r
.64249 .01472 m
.64249 .03062 L
.64767 .03062 L
.64767 .01472 L
F
0 g
.64249 .01472 m
.64249 .03062 L
.64767 .03062 L
.64767 .01472 L
.64249 .01472 L
s
1 0 0 r
.64767 .01472 m
.64767 .01472 L
.65285 .01472 L
.65285 .01472 L
F
0 g
.64767 .01472 m
.64767 .01472 L
.65285 .01472 L
.65285 .01472 L
.64767 .01472 L
s
1 0 0 r
.65285 .01472 m
.65285 .03062 L
.65803 .03062 L
.65803 .01472 L
F
0 g
.65285 .01472 m
.65285 .03062 L
.65803 .03062 L
.65803 .01472 L
.65285 .01472 L
s
1 0 0 r
.65803 .01472 m
.65803 .03062 L
.66321 .03062 L
.66321 .01472 L
F
0 g
.65803 .01472 m
.65803 .03062 L
.66321 .03062 L
.66321 .01472 L
.65803 .01472 L
s
1 0 0 r
.66321 .01472 m
.66321 .03062 L
.66839 .03062 L
.66839 .01472 L
F
0 g
.66321 .01472 m
.66321 .03062 L
.66839 .03062 L
.66839 .01472 L
.66321 .01472 L
s
1 0 0 r
.66839 .01472 m
.66839 .01472 L
.67358 .01472 L
.67358 .01472 L
F
0 g
.66839 .01472 m
.66839 .01472 L
.67358 .01472 L
.67358 .01472 L
.66839 .01472 L
s
1 0 0 r
.67358 .01472 m
.67358 .03062 L
.67876 .03062 L
.67876 .01472 L
F
0 g
.67358 .01472 m
.67358 .03062 L
.67876 .03062 L
.67876 .01472 L
.67358 .01472 L
s
1 0 0 r
.67876 .01472 m
.67876 .01472 L
.68394 .01472 L
.68394 .01472 L
F
0 g
.67876 .01472 m
.67876 .01472 L
.68394 .01472 L
.68394 .01472 L
.67876 .01472 L
s
1 0 0 r
.68394 .01472 m
.68394 .01472 L
.68912 .01472 L
.68912 .01472 L
F
0 g
.68394 .01472 m
.68394 .01472 L
.68912 .01472 L
.68912 .01472 L
.68394 .01472 L
s
1 0 0 r
.68912 .01472 m
.68912 .01472 L
.6943 .01472 L
.6943 .01472 L
F
0 g
.68912 .01472 m
.68912 .01472 L
.6943 .01472 L
.6943 .01472 L
.68912 .01472 L
s
1 0 0 r
.6943 .01472 m
.6943 .01472 L
.69948 .01472 L
.69948 .01472 L
F
0 g
.6943 .01472 m
.6943 .01472 L
.69948 .01472 L
.69948 .01472 L
.6943 .01472 L
s
1 0 0 r
.69948 .01472 m
.69948 .01472 L
.70466 .01472 L
.70466 .01472 L
F
0 g
.69948 .01472 m
.69948 .01472 L
.70466 .01472 L
.70466 .01472 L
.69948 .01472 L
s
1 0 0 r
.70466 .01472 m
.70466 .01472 L
.70984 .01472 L
.70984 .01472 L
F
0 g
.70466 .01472 m
.70466 .01472 L
.70984 .01472 L
.70984 .01472 L
.70466 .01472 L
s
1 0 0 r
.70984 .01472 m
.70984 .01472 L
.71503 .01472 L
.71503 .01472 L
F
0 g
.70984 .01472 m
.70984 .01472 L
.71503 .01472 L
.71503 .01472 L
.70984 .01472 L
s
1 0 0 r
.71503 .01472 m
.71503 .01472 L
.72021 .01472 L
.72021 .01472 L
F
0 g
.71503 .01472 m
.71503 .01472 L
.72021 .01472 L
.72021 .01472 L
.71503 .01472 L
s
1 0 0 r
.72021 .01472 m
.72021 .01472 L
.72539 .01472 L
.72539 .01472 L
F
0 g
.72021 .01472 m
.72021 .01472 L
.72539 .01472 L
.72539 .01472 L
.72021 .01472 L
s
1 0 0 r
.72539 .01472 m
.72539 .01472 L
.73057 .01472 L
.73057 .01472 L
F
0 g
.72539 .01472 m
.72539 .01472 L
.73057 .01472 L
.73057 .01472 L
.72539 .01472 L
s
1 0 0 r
.73057 .01472 m
.73057 .01472 L
.73575 .01472 L
.73575 .01472 L
F
0 g
.73057 .01472 m
.73057 .01472 L
.73575 .01472 L
.73575 .01472 L
.73057 .01472 L
s
1 0 0 r
.73575 .01472 m
.73575 .01472 L
.74093 .01472 L
.74093 .01472 L
F
0 g
.73575 .01472 m
.73575 .01472 L
.74093 .01472 L
.74093 .01472 L
.73575 .01472 L
s
1 0 0 r
.74093 .01472 m
.74093 .01472 L
.74611 .01472 L
.74611 .01472 L
F
0 g
.74093 .01472 m
.74093 .01472 L
.74611 .01472 L
.74611 .01472 L
.74093 .01472 L
s
1 0 0 r
.74611 .01472 m
.74611 .01472 L
.7513 .01472 L
.7513 .01472 L
F
0 g
.74611 .01472 m
.74611 .01472 L
.7513 .01472 L
.7513 .01472 L
.74611 .01472 L
s
1 0 0 r
.7513 .01472 m
.7513 .03062 L
.75648 .03062 L
.75648 .01472 L
F
0 g
.7513 .01472 m
.7513 .03062 L
.75648 .03062 L
.75648 .01472 L
.7513 .01472 L
s
1 0 0 r
.75648 .01472 m
.75648 .01472 L
.76166 .01472 L
.76166 .01472 L
F
0 g
.75648 .01472 m
.75648 .01472 L
.76166 .01472 L
.76166 .01472 L
.75648 .01472 L
s
1 0 0 r
.76166 .01472 m
.76166 .01472 L
.76684 .01472 L
.76684 .01472 L
F
0 g
.76166 .01472 m
.76166 .01472 L
.76684 .01472 L
.76684 .01472 L
.76166 .01472 L
s
1 0 0 r
.76684 .01472 m
.76684 .03062 L
.77202 .03062 L
.77202 .01472 L
F
0 g
.76684 .01472 m
.76684 .03062 L
.77202 .03062 L
.77202 .01472 L
.76684 .01472 L
s
1 0 0 r
.77202 .01472 m
.77202 .03062 L
.7772 .03062 L
.7772 .01472 L
F
0 g
.77202 .01472 m
.77202 .03062 L
.7772 .03062 L
.7772 .01472 L
.77202 .01472 L
s
1 0 0 r
.7772 .01472 m
.7772 .04653 L
.78238 .04653 L
.78238 .01472 L
F
0 g
.7772 .01472 m
.7772 .04653 L
.78238 .04653 L
.78238 .01472 L
.7772 .01472 L
s
1 0 0 r
.78238 .01472 m
.78238 .03062 L
.78756 .03062 L
.78756 .01472 L
F
0 g
.78238 .01472 m
.78238 .03062 L
.78756 .03062 L
.78756 .01472 L
.78238 .01472 L
s
1 0 0 r
.78756 .01472 m
.78756 .03062 L
.79275 .03062 L
.79275 .01472 L
F
0 g
.78756 .01472 m
.78756 .03062 L
.79275 .03062 L
.79275 .01472 L
.78756 .01472 L
s
1 0 0 r
.79275 .01472 m
.79275 .06244 L
.79793 .06244 L
.79793 .01472 L
F
0 g
.79275 .01472 m
.79275 .06244 L
.79793 .06244 L
.79793 .01472 L
.79275 .01472 L
s
1 0 0 r
.79793 .01472 m
.79793 .04653 L
.80311 .04653 L
.80311 .01472 L
F
0 g
.79793 .01472 m
.79793 .04653 L
.80311 .04653 L
.80311 .01472 L
.79793 .01472 L
s
1 0 0 r
.80311 .01472 m
.80311 .03062 L
.80829 .03062 L
.80829 .01472 L
F
0 g
.80311 .01472 m
.80311 .03062 L
.80829 .03062 L
.80829 .01472 L
.80311 .01472 L
s
1 0 0 r
.80829 .01472 m
.80829 .01472 L
.81347 .01472 L
.81347 .01472 L
F
0 g
.80829 .01472 m
.80829 .01472 L
.81347 .01472 L
.81347 .01472 L
.80829 .01472 L
s
1 0 0 r
.81347 .01472 m
.81347 .01472 L
.81865 .01472 L
.81865 .01472 L
F
0 g
.81347 .01472 m
.81347 .01472 L
.81865 .01472 L
.81865 .01472 L
.81347 .01472 L
s
1 0 0 r
.81865 .01472 m
.81865 .01472 L
.82383 .01472 L
.82383 .01472 L
F
0 g
.81865 .01472 m
.81865 .01472 L
.82383 .01472 L
.82383 .01472 L
.81865 .01472 L
s
1 0 0 r
.82383 .01472 m
.82383 .01472 L
.82902 .01472 L
.82902 .01472 L
F
0 g
.82383 .01472 m
.82383 .01472 L
.82902 .01472 L
.82902 .01472 L
.82383 .01472 L
s
1 0 0 r
.82902 .01472 m
.82902 .01472 L
.8342 .01472 L
.8342 .01472 L
F
0 g
.82902 .01472 m
.82902 .01472 L
.8342 .01472 L
.8342 .01472 L
.82902 .01472 L
s
1 0 0 r
.8342 .01472 m
.8342 .03062 L
.83938 .03062 L
.83938 .01472 L
F
0 g
.8342 .01472 m
.8342 .03062 L
.83938 .03062 L
.83938 .01472 L
.8342 .01472 L
s
1 0 0 r
.83938 .01472 m
.83938 .03062 L
.84456 .03062 L
.84456 .01472 L
F
0 g
.83938 .01472 m
.83938 .03062 L
.84456 .03062 L
.84456 .01472 L
.83938 .01472 L
s
1 0 0 r
.84456 .01472 m
.84456 .03062 L
.84974 .03062 L
.84974 .01472 L
F
0 g
.84456 .01472 m
.84456 .03062 L
.84974 .03062 L
.84974 .01472 L
.84456 .01472 L
s
1 0 0 r
.84974 .01472 m
.84974 .03062 L
.85492 .03062 L
.85492 .01472 L
F
0 g
.84974 .01472 m
.84974 .03062 L
.85492 .03062 L
.85492 .01472 L
.84974 .01472 L
s
1 0 0 r
.85492 .01472 m
.85492 .04653 L
.8601 .04653 L
.8601 .01472 L
F
0 g
.85492 .01472 m
.85492 .04653 L
.8601 .04653 L
.8601 .01472 L
.85492 .01472 L
s
1 0 0 r
.8601 .01472 m
.8601 .06244 L
.86528 .06244 L
.86528 .01472 L
F
0 g
.8601 .01472 m
.8601 .06244 L
.86528 .06244 L
.86528 .01472 L
.8601 .01472 L
s
1 0 0 r
.86528 .01472 m
.86528 .04653 L
.87047 .04653 L
.87047 .01472 L
F
0 g
.86528 .01472 m
.86528 .04653 L
.87047 .04653 L
.87047 .01472 L
.86528 .01472 L
s
1 0 0 r
.87047 .01472 m
.87047 .04653 L
.87565 .04653 L
.87565 .01472 L
F
0 g
.87047 .01472 m
.87047 .04653 L
.87565 .04653 L
.87565 .01472 L
.87047 .01472 L
s
1 0 0 r
.87565 .01472 m
.87565 .09426 L
.88083 .09426 L
.88083 .01472 L
F
0 g
.87565 .01472 m
.87565 .09426 L
.88083 .09426 L
.88083 .01472 L
.87565 .01472 L
s
1 0 0 r
.88083 .01472 m
.88083 .06244 L
.88601 .06244 L
.88601 .01472 L
F
0 g
.88083 .01472 m
.88083 .06244 L
.88601 .06244 L
.88601 .01472 L
.88083 .01472 L
s
1 0 0 r
.88601 .01472 m
.88601 .11016 L
.89119 .11016 L
.89119 .01472 L
F
0 g
.88601 .01472 m
.88601 .11016 L
.89119 .11016 L
.89119 .01472 L
.88601 .01472 L
s
1 0 0 r
.89119 .01472 m
.89119 .07835 L
.89637 .07835 L
.89637 .01472 L
F
0 g
.89119 .01472 m
.89119 .07835 L
.89637 .07835 L
.89637 .01472 L
.89119 .01472 L
s
1 0 0 r
.89637 .01472 m
.89637 .03062 L
.90155 .03062 L
.90155 .01472 L
F
0 g
.89637 .01472 m
.89637 .03062 L
.90155 .03062 L
.90155 .01472 L
.89637 .01472 L
s
1 0 0 r
.90155 .01472 m
.90155 .06244 L
.90674 .06244 L
.90674 .01472 L
F
0 g
.90155 .01472 m
.90155 .06244 L
.90674 .06244 L
.90674 .01472 L
.90155 .01472 L
s
1 0 0 r
.90674 .01472 m
.90674 .15789 L
.91192 .15789 L
.91192 .01472 L
F
0 g
.90674 .01472 m
.90674 .15789 L
.91192 .15789 L
.91192 .01472 L
.90674 .01472 L
s
1 0 0 r
.91192 .01472 m
.91192 .25334 L
.9171 .25334 L
.9171 .01472 L
F
0 g
.91192 .01472 m
.91192 .25334 L
.9171 .25334 L
.9171 .01472 L
.91192 .01472 L
s
1 0 0 r
.9171 .01472 m
.9171 .18971 L
.92228 .18971 L
.92228 .01472 L
F
0 g
.9171 .01472 m
.9171 .18971 L
.92228 .18971 L
.92228 .01472 L
.9171 .01472 L
s
1 0 0 r
.92228 .01472 m
.92228 .31697 L
.92746 .31697 L
.92746 .01472 L
F
0 g
.92228 .01472 m
.92228 .31697 L
.92746 .31697 L
.92746 .01472 L
.92228 .01472 L
s
1 0 0 r
.92746 .01472 m
.92746 .3806 L
.93264 .3806 L
.93264 .01472 L
F
0 g
.92746 .01472 m
.92746 .3806 L
.93264 .3806 L
.93264 .01472 L
.92746 .01472 L
s
1 0 0 r
.93264 .01472 m
.93264 .47605 L
.93782 .47605 L
.93782 .01472 L
F
0 g
.93264 .01472 m
.93264 .47605 L
.93782 .47605 L
.93782 .01472 L
.93264 .01472 L
s
1 0 0 r
.93782 .01472 m
.93782 .60332 L
.94301 .60332 L
.94301 .01472 L
F
0 g
.93782 .01472 m
.93782 .60332 L
.94301 .60332 L
.94301 .01472 L
.93782 .01472 L
s
1 0 0 r
.94301 .01472 m
.94301 .44424 L
.94819 .44424 L
.94819 .01472 L
F
0 g
.94301 .01472 m
.94301 .44424 L
.94819 .44424 L
.94819 .01472 L
.94301 .01472 L
s
1 0 0 r
.94819 .01472 m
.94819 .33288 L
.95337 .33288 L
.95337 .01472 L
F
0 g
.94819 .01472 m
.94819 .33288 L
.95337 .33288 L
.95337 .01472 L
.94819 .01472 L
s
1 0 0 r
.95337 .01472 m
.95337 .22152 L
.95855 .22152 L
.95855 .01472 L
F
0 g
.95337 .01472 m
.95337 .22152 L
.95855 .22152 L
.95855 .01472 L
.95337 .01472 L
s
1 0 0 r
.95855 .01472 m
.95855 .15789 L
.96373 .15789 L
.96373 .01472 L
F
0 g
.95855 .01472 m
.95855 .15789 L
.96373 .15789 L
.96373 .01472 L
.95855 .01472 L
s
1 0 0 r
.96373 .01472 m
.96373 .07835 L
.96891 .07835 L
.96891 .01472 L
F
0 g
.96373 .01472 m
.96373 .07835 L
.96891 .07835 L
.96891 .01472 L
.96373 .01472 L
s
1 0 0 r
.96891 .01472 m
.96891 .06244 L
.97409 .06244 L
.97409 .01472 L
F
0 g
.96891 .01472 m
.96891 .06244 L
.97409 .06244 L
.97409 .01472 L
.96891 .01472 L
s
1 0 0 r
.97409 .01472 m
.97409 .03062 L
.97927 .03062 L
.97927 .01472 L
F
0 g
.97409 .01472 m
.97409 .03062 L
.97927 .03062 L
.97927 .01472 L
.97409 .01472 L
s
1 0 0 r
.97927 .01472 m
.97927 .06244 L
.98446 .06244 L
.98446 .01472 L
F
0 g
.97927 .01472 m
.97927 .06244 L
.98446 .06244 L
.98446 .01472 L
.97927 .01472 L
s
1 0 0 r
.98446 .01472 m
.98446 .03062 L
.98964 .03062 L
.98964 .01472 L
F
0 g
.98446 .01472 m
.98446 .03062 L
.98964 .03062 L
.98964 .01472 L
.98446 .01472 L
s
1 0 0 r
.98964 .01472 m
.98964 .01472 L
.99482 .01472 L
.99482 .01472 L
F
0 g
.98964 .01472 m
.98964 .01472 L
.99482 .01472 L
.99482 .01472 L
.98964 .01472 L
s
1 0 0 r
.99482 .01472 m
.99482 .03062 L
1 .03062 L
1 .01472 L
F
0 g
.99482 .01472 m
.99482 .03062 L
1 .03062 L
1 .01472 L
.99482 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00700719 0.97619 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0212562 0.0025533 0 0.309017 [
[.02381 -0.0125 -8 -17.6875 ]
[.02381 -0.0125 8 0 ]
[.06722 -0.0125 -8 -17.6875 ]
[.06722 -0.0125 8 0 ]
[.12594 -0.0125 -8 -17.6875 ]
[.12594 -0.0125 8 0 ]
[.19488 -0.0125 -8 -17.6875 ]
[.19488 -0.0125 8 0 ]
[.24339 -0.0125 -8 -17.6875 ]
[.24339 -0.0125 8 0 ]
[.28935 -0.0125 -8 -17.6875 ]
[.28935 -0.0125 8 0 ]
[.33787 -0.0125 -8 -17.6875 ]
[.33787 -0.0125 8 0 ]
[.43744 -0.0125 -8 -17.6875 ]
[.43744 -0.0125 8 0 ]
[.48596 -0.0125 -14 -17.6875 ]
[.48596 -0.0125 14 0 ]
[.51404 -0.0125 -14 -17.6875 ]
[.51404 -0.0125 14 0 ]
[.55234 -0.0125 -14 -17.6875 ]
[.55234 -0.0125 14 0 ]
[.61873 -0.0125 -14 -17.6875 ]
[.61873 -0.0125 14 0 ]
[.65192 -0.0125 -14 -17.6875 ]
[.65192 -0.0125 14 0 ]
[.74384 -0.0125 -14 -17.6875 ]
[.74384 -0.0125 14 0 ]
[.84853 -0.0125 -14 -17.6875 ]
[.84853 -0.0125 14 0 ]
[.8664 -0.0125 -14 -17.6875 ]
[.8664 -0.0125 14 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -92 -36.5 ]
[.5 -0.0125 92 -17.6875 ]
[-0.0125 .07725 -52 -8.84375 ]
[-0.0125 .07725 0 8.84375 ]
[-0.0125 .15451 -40 -8.84375 ]
[-0.0125 .15451 0 8.84375 ]
[-0.0125 .23176 -52 -8.84375 ]
[-0.0125 .23176 0 8.84375 ]
[-0.0125 .30902 -16 -8.84375 ]
[-0.0125 .30902 0 8.84375 ]
[-0.0125 .38627 -52 -8.84375 ]
[-0.0125 .38627 0 8.84375 ]
[-0.0125 .46353 -40 -8.84375 ]
[-0.0125 .46353 0 8.84375 ]
[-0.0125 .54078 -52 -8.84375 ]
[-0.0125 .54078 0 8.84375 ]
[-0.0125 .61803 -16 -8.84375 ]
[-0.0125 .61803 0 8.84375 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -70.25 -86 ]
[-0.01875 .30902 -52 86 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -69 -21.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.06722 0 m
.06722 .00625 L
s
gsave
.06722 -0.0125 -69 -21.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.12594 0 m
.12594 .00625 L
s
gsave
.12594 -0.0125 -69 -21.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.19488 0 m
.19488 .00625 L
s
gsave
.19488 -0.0125 -69 -21.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.24339 0 m
.24339 .00625 L
s
gsave
.24339 -0.0125 -69 -21.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.28935 0 m
.28935 .00625 L
s
gsave
.28935 -0.0125 -69 -21.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
1.000 setlinewidth
grestore
.33787 0 m
.33787 .00625 L
s
gsave
.33787 -0.0125 -69 -21.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.43744 0 m
.43744 .00625 L
s
gsave
.43744 -0.0125 -69 -21.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9) show
1.000 setlinewidth
grestore
.48596 0 m
.48596 .00625 L
s
gsave
.48596 -0.0125 -75 -21.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.51404 0 m
.51404 .00625 L
s
gsave
.51404 -0.0125 -75 -21.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
1.000 setlinewidth
grestore
.55234 0 m
.55234 .00625 L
s
gsave
.55234 -0.0125 -75 -21.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.61873 0 m
.61873 .00625 L
s
gsave
.61873 -0.0125 -75 -21.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13) show
1.000 setlinewidth
grestore
.65192 0 m
.65192 .00625 L
s
gsave
.65192 -0.0125 -75 -21.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(14) show
1.000 setlinewidth
grestore
.74384 0 m
.74384 .00625 L
s
gsave
.74384 -0.0125 -75 -21.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.84853 0 m
.84853 .00625 L
s
gsave
.84853 -0.0125 -75 -21.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(16) show
1.000 setlinewidth
grestore
.8664 0 m
.8664 .00625 L
s
gsave
.8664 -0.0125 -75 -21.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(17) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
.5 -0.0125 -153 -40.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 18.125 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 18.125 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Run) show
111.000 18.125 moveto
(index) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
183.000 18.125 moveto
(H) show
195.000 18.125 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(day) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
231.000 18.125 moveto
(L) show
243.000 18.125 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .07725 m
.00625 .07725 L
s
gsave
-0.0125 .07725 -113 -12.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
0 .15451 m
.00625 .15451 L
s
gsave
-0.0125 .15451 -101 -12.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .23176 m
.00625 .23176 L
s
gsave
-0.0125 .23176 -113 -12.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
0 .30902 m
.00625 .30902 L
s
gsave
-0.0125 .30902 -77 -12.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .38627 m
.00625 .38627 L
s
gsave
-0.0125 .38627 -113 -12.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.25) show
1.000 setlinewidth
grestore
0 .46353 m
.00625 .46353 L
s
gsave
-0.0125 .46353 -101 -12.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
0 .54078 m
.00625 .54078 L
s
gsave
-0.0125 .54078 -113 -12.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.75) show
1.000 setlinewidth
grestore
0 .61803 m
.00625 .61803 L
s
gsave
-0.0125 .61803 -77 -12.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -208.125 -13.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
147 13.125 translate
90 rotate
-147 -13.125 translate
0 26.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 18.125 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 18.125 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ratio) show
135.000 18.125 moveto
(MCT) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
171.000 18.125 moveto
(\\220) show
183.000 18.125 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(PSCT) show
231.000 18.125 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0001 w
.02381 .07937 -2.5 2.5 Mabsadd m
.02381 .07937 2.5 2.5 Mabsadd L
.02381 .07937 2.5 -2.5 Mabsadd L
.02381 .07937 -2.5 -2.5 Mabsadd L
.02381 .07937 -2.5 2.5 Mabsadd L closepath F
.02636 .08107 -2.5 2.5 Mabsadd m
.02636 .08107 2.5 2.5 Mabsadd L
.02636 .08107 2.5 -2.5 Mabsadd L
.02636 .08107 -2.5 -2.5 Mabsadd L
.02636 .08107 -2.5 2.5 Mabsadd L closepath F
.02892 .0797 -2.5 2.5 Mabsadd m
.02892 .0797 2.5 2.5 Mabsadd L
.02892 .0797 2.5 -2.5 Mabsadd L
.02892 .0797 -2.5 -2.5 Mabsadd L
.02892 .0797 -2.5 2.5 Mabsadd L closepath F
.03147 .08084 -2.5 2.5 Mabsadd m
.03147 .08084 2.5 2.5 Mabsadd L
.03147 .08084 2.5 -2.5 Mabsadd L
.03147 .08084 -2.5 -2.5 Mabsadd L
.03147 .08084 -2.5 2.5 Mabsadd L closepath F
.03402 .07804 -2.5 2.5 Mabsadd m
.03402 .07804 2.5 2.5 Mabsadd L
.03402 .07804 2.5 -2.5 Mabsadd L
.03402 .07804 -2.5 -2.5 Mabsadd L
.03402 .07804 -2.5 2.5 Mabsadd L closepath F
.03658 .07932 -2.5 2.5 Mabsadd m
.03658 .07932 2.5 2.5 Mabsadd L
.03658 .07932 2.5 -2.5 Mabsadd L
.03658 .07932 -2.5 -2.5 Mabsadd L
.03658 .07932 -2.5 2.5 Mabsadd L closepath F
.03913 .04136 -2.5 2.5 Mabsadd m
.03913 .04136 2.5 2.5 Mabsadd L
.03913 .04136 2.5 -2.5 Mabsadd L
.03913 .04136 -2.5 -2.5 Mabsadd L
.03913 .04136 -2.5 2.5 Mabsadd L closepath F
.04168 .07838 -2.5 2.5 Mabsadd m
.04168 .07838 2.5 2.5 Mabsadd L
.04168 .07838 2.5 -2.5 Mabsadd L
.04168 .07838 -2.5 -2.5 Mabsadd L
.04168 .07838 -2.5 2.5 Mabsadd L closepath F
.04424 .07884 -2.5 2.5 Mabsadd m
.04424 .07884 2.5 2.5 Mabsadd L
.04424 .07884 2.5 -2.5 Mabsadd L
.04424 .07884 -2.5 -2.5 Mabsadd L
.04424 .07884 -2.5 2.5 Mabsadd L closepath F
.04679 .07901 -2.5 2.5 Mabsadd m
.04679 .07901 2.5 2.5 Mabsadd L
.04679 .07901 2.5 -2.5 Mabsadd L
.04679 .07901 -2.5 -2.5 Mabsadd L
.04679 .07901 -2.5 2.5 Mabsadd L closepath F
.04934 .07849 -2.5 2.5 Mabsadd m
.04934 .07849 2.5 2.5 Mabsadd L
.04934 .07849 2.5 -2.5 Mabsadd L
.04934 .07849 -2.5 -2.5 Mabsadd L
.04934 .07849 -2.5 2.5 Mabsadd L closepath F
.0519 .07863 -2.5 2.5 Mabsadd m
.0519 .07863 2.5 2.5 Mabsadd L
.0519 .07863 2.5 -2.5 Mabsadd L
.0519 .07863 -2.5 -2.5 Mabsadd L
.0519 .07863 -2.5 2.5 Mabsadd L closepath F
.05445 .07724 -2.5 2.5 Mabsadd m
.05445 .07724 2.5 2.5 Mabsadd L
.05445 .07724 2.5 -2.5 Mabsadd L
.05445 .07724 -2.5 -2.5 Mabsadd L
.05445 .07724 -2.5 2.5 Mabsadd L closepath F
.057 .07693 -2.5 2.5 Mabsadd m
.057 .07693 2.5 2.5 Mabsadd L
.057 .07693 2.5 -2.5 Mabsadd L
.057 .07693 -2.5 -2.5 Mabsadd L
.057 .07693 -2.5 2.5 Mabsadd L closepath F
.05956 .07714 -2.5 2.5 Mabsadd m
.05956 .07714 2.5 2.5 Mabsadd L
.05956 .07714 2.5 -2.5 Mabsadd L
.05956 .07714 -2.5 -2.5 Mabsadd L
.05956 .07714 -2.5 2.5 Mabsadd L closepath F
.06211 .07891 -2.5 2.5 Mabsadd m
.06211 .07891 2.5 2.5 Mabsadd L
.06211 .07891 2.5 -2.5 Mabsadd L
.06211 .07891 -2.5 -2.5 Mabsadd L
.06211 .07891 -2.5 2.5 Mabsadd L closepath F
.06466 .07792 -2.5 2.5 Mabsadd m
.06466 .07792 2.5 2.5 Mabsadd L
.06466 .07792 2.5 -2.5 Mabsadd L
.06466 .07792 -2.5 -2.5 Mabsadd L
.06466 .07792 -2.5 2.5 Mabsadd L closepath F
.06722 .14943 -2.5 2.5 Mabsadd m
.06722 .14943 2.5 2.5 Mabsadd L
.06722 .14943 2.5 -2.5 Mabsadd L
.06722 .14943 -2.5 -2.5 Mabsadd L
.06722 .14943 -2.5 2.5 Mabsadd L closepath F
.06977 .14858 -2.5 2.5 Mabsadd m
.06977 .14858 2.5 2.5 Mabsadd L
.06977 .14858 2.5 -2.5 Mabsadd L
.06977 .14858 -2.5 -2.5 Mabsadd L
.06977 .14858 -2.5 2.5 Mabsadd L closepath F
.07232 .15113 -2.5 2.5 Mabsadd m
.07232 .15113 2.5 2.5 Mabsadd L
.07232 .15113 2.5 -2.5 Mabsadd L
.07232 .15113 -2.5 -2.5 Mabsadd L
.07232 .15113 -2.5 2.5 Mabsadd L closepath F
.07488 .15138 -2.5 2.5 Mabsadd m
.07488 .15138 2.5 2.5 Mabsadd L
.07488 .15138 2.5 -2.5 Mabsadd L
.07488 .15138 -2.5 -2.5 Mabsadd L
.07488 .15138 -2.5 2.5 Mabsadd L closepath F
.07743 .31223 -2.5 2.5 Mabsadd m
.07743 .31223 2.5 2.5 Mabsadd L
.07743 .31223 2.5 -2.5 Mabsadd L
.07743 .31223 -2.5 -2.5 Mabsadd L
.07743 .31223 -2.5 2.5 Mabsadd L closepath F
.07998 .31114 -2.5 2.5 Mabsadd m
.07998 .31114 2.5 2.5 Mabsadd L
.07998 .31114 2.5 -2.5 Mabsadd L
.07998 .31114 -2.5 -2.5 Mabsadd L
.07998 .31114 -2.5 2.5 Mabsadd L closepath F
.08254 .30922 -2.5 2.5 Mabsadd m
.08254 .30922 2.5 2.5 Mabsadd L
.08254 .30922 2.5 -2.5 Mabsadd L
.08254 .30922 -2.5 -2.5 Mabsadd L
.08254 .30922 -2.5 2.5 Mabsadd L closepath F
.08509 .31195 -2.5 2.5 Mabsadd m
.08509 .31195 2.5 2.5 Mabsadd L
.08509 .31195 2.5 -2.5 Mabsadd L
.08509 .31195 -2.5 -2.5 Mabsadd L
.08509 .31195 -2.5 2.5 Mabsadd L closepath F
.08764 .31034 -2.5 2.5 Mabsadd m
.08764 .31034 2.5 2.5 Mabsadd L
.08764 .31034 2.5 -2.5 Mabsadd L
.08764 .31034 -2.5 -2.5 Mabsadd L
.08764 .31034 -2.5 2.5 Mabsadd L closepath F
.0902 .3088 -2.5 2.5 Mabsadd m
.0902 .3088 2.5 2.5 Mabsadd L
.0902 .3088 2.5 -2.5 Mabsadd L
.0902 .3088 -2.5 -2.5 Mabsadd L
.0902 .3088 -2.5 2.5 Mabsadd L closepath F
.09275 .30806 -2.5 2.5 Mabsadd m
.09275 .30806 2.5 2.5 Mabsadd L
.09275 .30806 2.5 -2.5 Mabsadd L
.09275 .30806 -2.5 -2.5 Mabsadd L
.09275 .30806 -2.5 2.5 Mabsadd L closepath F
.0953 .07815 -2.5 2.5 Mabsadd m
.0953 .07815 2.5 2.5 Mabsadd L
.0953 .07815 2.5 -2.5 Mabsadd L
.0953 .07815 -2.5 -2.5 Mabsadd L
.0953 .07815 -2.5 2.5 Mabsadd L closepath F
.09786 .07888 -2.5 2.5 Mabsadd m
.09786 .07888 2.5 2.5 Mabsadd L
.09786 .07888 2.5 -2.5 Mabsadd L
.09786 .07888 -2.5 -2.5 Mabsadd L
.09786 .07888 -2.5 2.5 Mabsadd L closepath F
.10041 .07753 -2.5 2.5 Mabsadd m
.10041 .07753 2.5 2.5 Mabsadd L
.10041 .07753 2.5 -2.5 Mabsadd L
.10041 .07753 -2.5 -2.5 Mabsadd L
.10041 .07753 -2.5 2.5 Mabsadd L closepath F
.10296 .07834 -2.5 2.5 Mabsadd m
.10296 .07834 2.5 2.5 Mabsadd L
.10296 .07834 2.5 -2.5 Mabsadd L
.10296 .07834 -2.5 -2.5 Mabsadd L
.10296 .07834 -2.5 2.5 Mabsadd L closepath F
.10552 .07697 -2.5 2.5 Mabsadd m
.10552 .07697 2.5 2.5 Mabsadd L
.10552 .07697 2.5 -2.5 Mabsadd L
.10552 .07697 -2.5 -2.5 Mabsadd L
.10552 .07697 -2.5 2.5 Mabsadd L closepath F
.10807 .08017 -2.5 2.5 Mabsadd m
.10807 .08017 2.5 2.5 Mabsadd L
.10807 .08017 2.5 -2.5 Mabsadd L
.10807 .08017 -2.5 -2.5 Mabsadd L
.10807 .08017 -2.5 2.5 Mabsadd L closepath F
.11062 .07787 -2.5 2.5 Mabsadd m
.11062 .07787 2.5 2.5 Mabsadd L
.11062 .07787 2.5 -2.5 Mabsadd L
.11062 .07787 -2.5 -2.5 Mabsadd L
.11062 .07787 -2.5 2.5 Mabsadd L closepath F
.11318 .08048 -2.5 2.5 Mabsadd m
.11318 .08048 2.5 2.5 Mabsadd L
.11318 .08048 2.5 -2.5 Mabsadd L
.11318 .08048 -2.5 -2.5 Mabsadd L
.11318 .08048 -2.5 2.5 Mabsadd L closepath F
.11573 .07851 -2.5 2.5 Mabsadd m
.11573 .07851 2.5 2.5 Mabsadd L
.11573 .07851 2.5 -2.5 Mabsadd L
.11573 .07851 -2.5 -2.5 Mabsadd L
.11573 .07851 -2.5 2.5 Mabsadd L closepath F
.11828 .07848 -2.5 2.5 Mabsadd m
.11828 .07848 2.5 2.5 Mabsadd L
.11828 .07848 2.5 -2.5 Mabsadd L
.11828 .07848 -2.5 -2.5 Mabsadd L
.11828 .07848 -2.5 2.5 Mabsadd L closepath F
.12083 .0773 -2.5 2.5 Mabsadd m
.12083 .0773 2.5 2.5 Mabsadd L
.12083 .0773 2.5 -2.5 Mabsadd L
.12083 .0773 -2.5 -2.5 Mabsadd L
.12083 .0773 -2.5 2.5 Mabsadd L closepath F
.12339 .07749 -2.5 2.5 Mabsadd m
.12339 .07749 2.5 2.5 Mabsadd L
.12339 .07749 2.5 -2.5 Mabsadd L
.12339 .07749 -2.5 -2.5 Mabsadd L
.12339 .07749 -2.5 2.5 Mabsadd L closepath F
.12594 .07836 -2.5 2.5 Mabsadd m
.12594 .07836 2.5 2.5 Mabsadd L
.12594 .07836 2.5 -2.5 Mabsadd L
.12594 .07836 -2.5 -2.5 Mabsadd L
.12594 .07836 -2.5 2.5 Mabsadd L closepath F
.12849 .07835 -2.5 2.5 Mabsadd m
.12849 .07835 2.5 2.5 Mabsadd L
.12849 .07835 2.5 -2.5 Mabsadd L
.12849 .07835 -2.5 -2.5 Mabsadd L
.12849 .07835 -2.5 2.5 Mabsadd L closepath F
.13105 .076 -2.5 2.5 Mabsadd m
.13105 .076 2.5 2.5 Mabsadd L
.13105 .076 2.5 -2.5 Mabsadd L
.13105 .076 -2.5 -2.5 Mabsadd L
.13105 .076 -2.5 2.5 Mabsadd L closepath F
.1336 .07889 -2.5 2.5 Mabsadd m
.1336 .07889 2.5 2.5 Mabsadd L
.1336 .07889 2.5 -2.5 Mabsadd L
.1336 .07889 -2.5 -2.5 Mabsadd L
.1336 .07889 -2.5 2.5 Mabsadd L closepath F
.13615 .07844 -2.5 2.5 Mabsadd m
.13615 .07844 2.5 2.5 Mabsadd L
.13615 .07844 2.5 -2.5 Mabsadd L
.13615 .07844 -2.5 -2.5 Mabsadd L
.13615 .07844 -2.5 2.5 Mabsadd L closepath F
.13871 .07689 -2.5 2.5 Mabsadd m
.13871 .07689 2.5 2.5 Mabsadd L
.13871 .07689 2.5 -2.5 Mabsadd L
.13871 .07689 -2.5 -2.5 Mabsadd L
.13871 .07689 -2.5 2.5 Mabsadd L closepath F
.14126 .07587 -2.5 2.5 Mabsadd m
.14126 .07587 2.5 2.5 Mabsadd L
.14126 .07587 2.5 -2.5 Mabsadd L
.14126 .07587 -2.5 -2.5 Mabsadd L
.14126 .07587 -2.5 2.5 Mabsadd L closepath F
.14381 .07811 -2.5 2.5 Mabsadd m
.14381 .07811 2.5 2.5 Mabsadd L
.14381 .07811 2.5 -2.5 Mabsadd L
.14381 .07811 -2.5 -2.5 Mabsadd L
.14381 .07811 -2.5 2.5 Mabsadd L closepath F
.14637 .07747 -2.5 2.5 Mabsadd m
.14637 .07747 2.5 2.5 Mabsadd L
.14637 .07747 2.5 -2.5 Mabsadd L
.14637 .07747 -2.5 -2.5 Mabsadd L
.14637 .07747 -2.5 2.5 Mabsadd L closepath F
.14892 .07731 -2.5 2.5 Mabsadd m
.14892 .07731 2.5 2.5 Mabsadd L
.14892 .07731 2.5 -2.5 Mabsadd L
.14892 .07731 -2.5 -2.5 Mabsadd L
.14892 .07731 -2.5 2.5 Mabsadd L closepath F
.15147 .07683 -2.5 2.5 Mabsadd m
.15147 .07683 2.5 2.5 Mabsadd L
.15147 .07683 2.5 -2.5 Mabsadd L
.15147 .07683 -2.5 -2.5 Mabsadd L
.15147 .07683 -2.5 2.5 Mabsadd L closepath F
.15403 .0672 -2.5 2.5 Mabsadd m
.15403 .0672 2.5 2.5 Mabsadd L
.15403 .0672 2.5 -2.5 Mabsadd L
.15403 .0672 -2.5 -2.5 Mabsadd L
.15403 .0672 -2.5 2.5 Mabsadd L closepath F
.15658 .07648 -2.5 2.5 Mabsadd m
.15658 .07648 2.5 2.5 Mabsadd L
.15658 .07648 2.5 -2.5 Mabsadd L
.15658 .07648 -2.5 -2.5 Mabsadd L
.15658 .07648 -2.5 2.5 Mabsadd L closepath F
.15913 .30118 -2.5 2.5 Mabsadd m
.15913 .30118 2.5 2.5 Mabsadd L
.15913 .30118 2.5 -2.5 Mabsadd L
.15913 .30118 -2.5 -2.5 Mabsadd L
.15913 .30118 -2.5 2.5 Mabsadd L closepath F
.16169 .3004 -2.5 2.5 Mabsadd m
.16169 .3004 2.5 2.5 Mabsadd L
.16169 .3004 2.5 -2.5 Mabsadd L
.16169 .3004 -2.5 -2.5 Mabsadd L
.16169 .3004 -2.5 2.5 Mabsadd L closepath F
.16424 .30094 -2.5 2.5 Mabsadd m
.16424 .30094 2.5 2.5 Mabsadd L
.16424 .30094 2.5 -2.5 Mabsadd L
.16424 .30094 -2.5 -2.5 Mabsadd L
.16424 .30094 -2.5 2.5 Mabsadd L closepath F
.16679 .30059 -2.5 2.5 Mabsadd m
.16679 .30059 2.5 2.5 Mabsadd L
.16679 .30059 2.5 -2.5 Mabsadd L
.16679 .30059 -2.5 -2.5 Mabsadd L
.16679 .30059 -2.5 2.5 Mabsadd L closepath F
.16935 .15517 -2.5 2.5 Mabsadd m
.16935 .15517 2.5 2.5 Mabsadd L
.16935 .15517 2.5 -2.5 Mabsadd L
.16935 .15517 -2.5 -2.5 Mabsadd L
.16935 .15517 -2.5 2.5 Mabsadd L closepath F
.1719 .15676 -2.5 2.5 Mabsadd m
.1719 .15676 2.5 2.5 Mabsadd L
.1719 .15676 2.5 -2.5 Mabsadd L
.1719 .15676 -2.5 -2.5 Mabsadd L
.1719 .15676 -2.5 2.5 Mabsadd L closepath F
.17445 .15617 -2.5 2.5 Mabsadd m
.17445 .15617 2.5 2.5 Mabsadd L
.17445 .15617 2.5 -2.5 Mabsadd L
.17445 .15617 -2.5 -2.5 Mabsadd L
.17445 .15617 -2.5 2.5 Mabsadd L closepath F
.17701 .15704 -2.5 2.5 Mabsadd m
.17701 .15704 2.5 2.5 Mabsadd L
.17701 .15704 2.5 -2.5 Mabsadd L
.17701 .15704 -2.5 -2.5 Mabsadd L
.17701 .15704 -2.5 2.5 Mabsadd L closepath F
.17956 .15544 -2.5 2.5 Mabsadd m
.17956 .15544 2.5 2.5 Mabsadd L
.17956 .15544 2.5 -2.5 Mabsadd L
.17956 .15544 -2.5 -2.5 Mabsadd L
.17956 .15544 -2.5 2.5 Mabsadd L closepath F
.18211 .15673 -2.5 2.5 Mabsadd m
.18211 .15673 2.5 2.5 Mabsadd L
.18211 .15673 2.5 -2.5 Mabsadd L
.18211 .15673 -2.5 -2.5 Mabsadd L
.18211 .15673 -2.5 2.5 Mabsadd L closepath F
.18467 .30818 -2.5 2.5 Mabsadd m
.18467 .30818 2.5 2.5 Mabsadd L
.18467 .30818 2.5 -2.5 Mabsadd L
.18467 .30818 -2.5 -2.5 Mabsadd L
.18467 .30818 -2.5 2.5 Mabsadd L closepath F
.18722 .31061 -2.5 2.5 Mabsadd m
.18722 .31061 2.5 2.5 Mabsadd L
.18722 .31061 2.5 -2.5 Mabsadd L
.18722 .31061 -2.5 -2.5 Mabsadd L
.18722 .31061 -2.5 2.5 Mabsadd L closepath F
.18977 .30536 -2.5 2.5 Mabsadd m
.18977 .30536 2.5 2.5 Mabsadd L
.18977 .30536 2.5 -2.5 Mabsadd L
.18977 .30536 -2.5 -2.5 Mabsadd L
.18977 .30536 -2.5 2.5 Mabsadd L closepath F
.19233 .30451 -2.5 2.5 Mabsadd m
.19233 .30451 2.5 2.5 Mabsadd L
.19233 .30451 2.5 -2.5 Mabsadd L
.19233 .30451 -2.5 -2.5 Mabsadd L
.19233 .30451 -2.5 2.5 Mabsadd L closepath F
.19488 .30199 -2.5 2.5 Mabsadd m
.19488 .30199 2.5 2.5 Mabsadd L
.19488 .30199 2.5 -2.5 Mabsadd L
.19488 .30199 -2.5 -2.5 Mabsadd L
.19488 .30199 -2.5 2.5 Mabsadd L closepath F
.19743 .30321 -2.5 2.5 Mabsadd m
.19743 .30321 2.5 2.5 Mabsadd L
.19743 .30321 2.5 -2.5 Mabsadd L
.19743 .30321 -2.5 -2.5 Mabsadd L
.19743 .30321 -2.5 2.5 Mabsadd L closepath F
.19999 .30435 -2.5 2.5 Mabsadd m
.19999 .30435 2.5 2.5 Mabsadd L
.19999 .30435 2.5 -2.5 Mabsadd L
.19999 .30435 -2.5 -2.5 Mabsadd L
.19999 .30435 -2.5 2.5 Mabsadd L closepath F
.20254 .3047 -2.5 2.5 Mabsadd m
.20254 .3047 2.5 2.5 Mabsadd L
.20254 .3047 2.5 -2.5 Mabsadd L
.20254 .3047 -2.5 -2.5 Mabsadd L
.20254 .3047 -2.5 2.5 Mabsadd L closepath F
.20509 .30165 -2.5 2.5 Mabsadd m
.20509 .30165 2.5 2.5 Mabsadd L
.20509 .30165 2.5 -2.5 Mabsadd L
.20509 .30165 -2.5 -2.5 Mabsadd L
.20509 .30165 -2.5 2.5 Mabsadd L closepath F
.20765 .30436 -2.5 2.5 Mabsadd m
.20765 .30436 2.5 2.5 Mabsadd L
.20765 .30436 2.5 -2.5 Mabsadd L
.20765 .30436 -2.5 -2.5 Mabsadd L
.20765 .30436 -2.5 2.5 Mabsadd L closepath F
.2102 .30552 -2.5 2.5 Mabsadd m
.2102 .30552 2.5 2.5 Mabsadd L
.2102 .30552 2.5 -2.5 Mabsadd L
.2102 .30552 -2.5 -2.5 Mabsadd L
.2102 .30552 -2.5 2.5 Mabsadd L closepath F
.21275 .30395 -2.5 2.5 Mabsadd m
.21275 .30395 2.5 2.5 Mabsadd L
.21275 .30395 2.5 -2.5 Mabsadd L
.21275 .30395 -2.5 -2.5 Mabsadd L
.21275 .30395 -2.5 2.5 Mabsadd L closepath F
.21531 .30443 -2.5 2.5 Mabsadd m
.21531 .30443 2.5 2.5 Mabsadd L
.21531 .30443 2.5 -2.5 Mabsadd L
.21531 .30443 -2.5 -2.5 Mabsadd L
.21531 .30443 -2.5 2.5 Mabsadd L closepath F
.21786 .30568 -2.5 2.5 Mabsadd m
.21786 .30568 2.5 2.5 Mabsadd L
.21786 .30568 2.5 -2.5 Mabsadd L
.21786 .30568 -2.5 -2.5 Mabsadd L
.21786 .30568 -2.5 2.5 Mabsadd L closepath F
.22041 .30485 -2.5 2.5 Mabsadd m
.22041 .30485 2.5 2.5 Mabsadd L
.22041 .30485 2.5 -2.5 Mabsadd L
.22041 .30485 -2.5 -2.5 Mabsadd L
.22041 .30485 -2.5 2.5 Mabsadd L closepath F
.22297 .30927 -2.5 2.5 Mabsadd m
.22297 .30927 2.5 2.5 Mabsadd L
.22297 .30927 2.5 -2.5 Mabsadd L
.22297 .30927 -2.5 -2.5 Mabsadd L
.22297 .30927 -2.5 2.5 Mabsadd L closepath F
.22552 .3034 -2.5 2.5 Mabsadd m
.22552 .3034 2.5 2.5 Mabsadd L
.22552 .3034 2.5 -2.5 Mabsadd L
.22552 .3034 -2.5 -2.5 Mabsadd L
.22552 .3034 -2.5 2.5 Mabsadd L closepath F
.22807 .30412 -2.5 2.5 Mabsadd m
.22807 .30412 2.5 2.5 Mabsadd L
.22807 .30412 2.5 -2.5 Mabsadd L
.22807 .30412 -2.5 -2.5 Mabsadd L
.22807 .30412 -2.5 2.5 Mabsadd L closepath F
.23063 .30423 -2.5 2.5 Mabsadd m
.23063 .30423 2.5 2.5 Mabsadd L
.23063 .30423 2.5 -2.5 Mabsadd L
.23063 .30423 -2.5 -2.5 Mabsadd L
.23063 .30423 -2.5 2.5 Mabsadd L closepath F
.23318 .29946 -2.5 2.5 Mabsadd m
.23318 .29946 2.5 2.5 Mabsadd L
.23318 .29946 2.5 -2.5 Mabsadd L
.23318 .29946 -2.5 -2.5 Mabsadd L
.23318 .29946 -2.5 2.5 Mabsadd L closepath F
.23573 .30579 -2.5 2.5 Mabsadd m
.23573 .30579 2.5 2.5 Mabsadd L
.23573 .30579 2.5 -2.5 Mabsadd L
.23573 .30579 -2.5 -2.5 Mabsadd L
.23573 .30579 -2.5 2.5 Mabsadd L closepath F
.23829 .30343 -2.5 2.5 Mabsadd m
.23829 .30343 2.5 2.5 Mabsadd L
.23829 .30343 2.5 -2.5 Mabsadd L
.23829 .30343 -2.5 -2.5 Mabsadd L
.23829 .30343 -2.5 2.5 Mabsadd L closepath F
.24084 .30123 -2.5 2.5 Mabsadd m
.24084 .30123 2.5 2.5 Mabsadd L
.24084 .30123 2.5 -2.5 Mabsadd L
.24084 .30123 -2.5 -2.5 Mabsadd L
.24084 .30123 -2.5 2.5 Mabsadd L closepath F
.24339 .30908 -2.5 2.5 Mabsadd m
.24339 .30908 2.5 2.5 Mabsadd L
.24339 .30908 2.5 -2.5 Mabsadd L
.24339 .30908 -2.5 -2.5 Mabsadd L
.24339 .30908 -2.5 2.5 Mabsadd L closepath F
.24595 .30617 -2.5 2.5 Mabsadd m
.24595 .30617 2.5 2.5 Mabsadd L
.24595 .30617 2.5 -2.5 Mabsadd L
.24595 .30617 -2.5 -2.5 Mabsadd L
.24595 .30617 -2.5 2.5 Mabsadd L closepath F
.2485 .30533 -2.5 2.5 Mabsadd m
.2485 .30533 2.5 2.5 Mabsadd L
.2485 .30533 2.5 -2.5 Mabsadd L
.2485 .30533 -2.5 -2.5 Mabsadd L
.2485 .30533 -2.5 2.5 Mabsadd L closepath F
.25105 .30599 -2.5 2.5 Mabsadd m
.25105 .30599 2.5 2.5 Mabsadd L
.25105 .30599 2.5 -2.5 Mabsadd L
.25105 .30599 -2.5 -2.5 Mabsadd L
.25105 .30599 -2.5 2.5 Mabsadd L closepath F
.25361 .30597 -2.5 2.5 Mabsadd m
.25361 .30597 2.5 2.5 Mabsadd L
.25361 .30597 2.5 -2.5 Mabsadd L
.25361 .30597 -2.5 -2.5 Mabsadd L
.25361 .30597 -2.5 2.5 Mabsadd L closepath F
.25616 .30643 -2.5 2.5 Mabsadd m
.25616 .30643 2.5 2.5 Mabsadd L
.25616 .30643 2.5 -2.5 Mabsadd L
.25616 .30643 -2.5 -2.5 Mabsadd L
.25616 .30643 -2.5 2.5 Mabsadd L closepath F
.25871 .30481 -2.5 2.5 Mabsadd m
.25871 .30481 2.5 2.5 Mabsadd L
.25871 .30481 2.5 -2.5 Mabsadd L
.25871 .30481 -2.5 -2.5 Mabsadd L
.25871 .30481 -2.5 2.5 Mabsadd L closepath F
.26127 .30408 -2.5 2.5 Mabsadd m
.26127 .30408 2.5 2.5 Mabsadd L
.26127 .30408 2.5 -2.5 Mabsadd L
.26127 .30408 -2.5 -2.5 Mabsadd L
.26127 .30408 -2.5 2.5 Mabsadd L closepath F
.26382 .3038 -2.5 2.5 Mabsadd m
.26382 .3038 2.5 2.5 Mabsadd L
.26382 .3038 2.5 -2.5 Mabsadd L
.26382 .3038 -2.5 -2.5 Mabsadd L
.26382 .3038 -2.5 2.5 Mabsadd L closepath F
.26637 .30576 -2.5 2.5 Mabsadd m
.26637 .30576 2.5 2.5 Mabsadd L
.26637 .30576 2.5 -2.5 Mabsadd L
.26637 .30576 -2.5 -2.5 Mabsadd L
.26637 .30576 -2.5 2.5 Mabsadd L closepath F
.26893 .07839 -2.5 2.5 Mabsadd m
.26893 .07839 2.5 2.5 Mabsadd L
.26893 .07839 2.5 -2.5 Mabsadd L
.26893 .07839 -2.5 -2.5 Mabsadd L
.26893 .07839 -2.5 2.5 Mabsadd L closepath F
.27148 .07827 -2.5 2.5 Mabsadd m
.27148 .07827 2.5 2.5 Mabsadd L
.27148 .07827 2.5 -2.5 Mabsadd L
.27148 .07827 -2.5 -2.5 Mabsadd L
.27148 .07827 -2.5 2.5 Mabsadd L closepath F
.27403 .07922 -2.5 2.5 Mabsadd m
.27403 .07922 2.5 2.5 Mabsadd L
.27403 .07922 2.5 -2.5 Mabsadd L
.27403 .07922 -2.5 -2.5 Mabsadd L
.27403 .07922 -2.5 2.5 Mabsadd L closepath F
.27659 .07927 -2.5 2.5 Mabsadd m
.27659 .07927 2.5 2.5 Mabsadd L
.27659 .07927 2.5 -2.5 Mabsadd L
.27659 .07927 -2.5 -2.5 Mabsadd L
.27659 .07927 -2.5 2.5 Mabsadd L closepath F
.27914 .08004 -2.5 2.5 Mabsadd m
.27914 .08004 2.5 2.5 Mabsadd L
.27914 .08004 2.5 -2.5 Mabsadd L
.27914 .08004 -2.5 -2.5 Mabsadd L
.27914 .08004 -2.5 2.5 Mabsadd L closepath F
.28169 .07936 -2.5 2.5 Mabsadd m
.28169 .07936 2.5 2.5 Mabsadd L
.28169 .07936 2.5 -2.5 Mabsadd L
.28169 .07936 -2.5 -2.5 Mabsadd L
.28169 .07936 -2.5 2.5 Mabsadd L closepath F
.28425 .07572 -2.5 2.5 Mabsadd m
.28425 .07572 2.5 2.5 Mabsadd L
.28425 .07572 2.5 -2.5 Mabsadd L
.28425 .07572 -2.5 -2.5 Mabsadd L
.28425 .07572 -2.5 2.5 Mabsadd L closepath F
.2868 .07959 -2.5 2.5 Mabsadd m
.2868 .07959 2.5 2.5 Mabsadd L
.2868 .07959 2.5 -2.5 Mabsadd L
.2868 .07959 -2.5 -2.5 Mabsadd L
.2868 .07959 -2.5 2.5 Mabsadd L closepath F
.28935 .30744 -2.5 2.5 Mabsadd m
.28935 .30744 2.5 2.5 Mabsadd L
.28935 .30744 2.5 -2.5 Mabsadd L
.28935 .30744 -2.5 -2.5 Mabsadd L
.28935 .30744 -2.5 2.5 Mabsadd L closepath F
.29191 .3101 -2.5 2.5 Mabsadd m
.29191 .3101 2.5 2.5 Mabsadd L
.29191 .3101 2.5 -2.5 Mabsadd L
.29191 .3101 -2.5 -2.5 Mabsadd L
.29191 .3101 -2.5 2.5 Mabsadd L closepath F
.29446 .07901 -2.5 2.5 Mabsadd m
.29446 .07901 2.5 2.5 Mabsadd L
.29446 .07901 2.5 -2.5 Mabsadd L
.29446 .07901 -2.5 -2.5 Mabsadd L
.29446 .07901 -2.5 2.5 Mabsadd L closepath F
.29701 .07892 -2.5 2.5 Mabsadd m
.29701 .07892 2.5 2.5 Mabsadd L
.29701 .07892 2.5 -2.5 Mabsadd L
.29701 .07892 -2.5 -2.5 Mabsadd L
.29701 .07892 -2.5 2.5 Mabsadd L closepath F
.29957 .08049 -2.5 2.5 Mabsadd m
.29957 .08049 2.5 2.5 Mabsadd L
.29957 .08049 2.5 -2.5 Mabsadd L
.29957 .08049 -2.5 -2.5 Mabsadd L
.29957 .08049 -2.5 2.5 Mabsadd L closepath F
.30212 .08108 -2.5 2.5 Mabsadd m
.30212 .08108 2.5 2.5 Mabsadd L
.30212 .08108 2.5 -2.5 Mabsadd L
.30212 .08108 -2.5 -2.5 Mabsadd L
.30212 .08108 -2.5 2.5 Mabsadd L closepath F
.30467 .07996 -2.5 2.5 Mabsadd m
.30467 .07996 2.5 2.5 Mabsadd L
.30467 .07996 2.5 -2.5 Mabsadd L
.30467 .07996 -2.5 -2.5 Mabsadd L
.30467 .07996 -2.5 2.5 Mabsadd L closepath F
.30723 .07772 -2.5 2.5 Mabsadd m
.30723 .07772 2.5 2.5 Mabsadd L
.30723 .07772 2.5 -2.5 Mabsadd L
.30723 .07772 -2.5 -2.5 Mabsadd L
.30723 .07772 -2.5 2.5 Mabsadd L closepath F
.30978 .07815 -2.5 2.5 Mabsadd m
.30978 .07815 2.5 2.5 Mabsadd L
.30978 .07815 2.5 -2.5 Mabsadd L
.30978 .07815 -2.5 -2.5 Mabsadd L
.30978 .07815 -2.5 2.5 Mabsadd L closepath F
.31233 .0799 -2.5 2.5 Mabsadd m
.31233 .0799 2.5 2.5 Mabsadd L
.31233 .0799 2.5 -2.5 Mabsadd L
.31233 .0799 -2.5 -2.5 Mabsadd L
.31233 .0799 -2.5 2.5 Mabsadd L closepath F
.31489 .07952 -2.5 2.5 Mabsadd m
.31489 .07952 2.5 2.5 Mabsadd L
.31489 .07952 2.5 -2.5 Mabsadd L
.31489 .07952 -2.5 -2.5 Mabsadd L
.31489 .07952 -2.5 2.5 Mabsadd L closepath F
.31744 .30868 -2.5 2.5 Mabsadd m
.31744 .30868 2.5 2.5 Mabsadd L
.31744 .30868 2.5 -2.5 Mabsadd L
.31744 .30868 -2.5 -2.5 Mabsadd L
.31744 .30868 -2.5 2.5 Mabsadd L closepath F
.31999 .30861 -2.5 2.5 Mabsadd m
.31999 .30861 2.5 2.5 Mabsadd L
.31999 .30861 2.5 -2.5 Mabsadd L
.31999 .30861 -2.5 -2.5 Mabsadd L
.31999 .30861 -2.5 2.5 Mabsadd L closepath F
.32255 .30291 -2.5 2.5 Mabsadd m
.32255 .30291 2.5 2.5 Mabsadd L
.32255 .30291 2.5 -2.5 Mabsadd L
.32255 .30291 -2.5 -2.5 Mabsadd L
.32255 .30291 -2.5 2.5 Mabsadd L closepath F
.3251 .3033 -2.5 2.5 Mabsadd m
.3251 .3033 2.5 2.5 Mabsadd L
.3251 .3033 2.5 -2.5 Mabsadd L
.3251 .3033 -2.5 -2.5 Mabsadd L
.3251 .3033 -2.5 2.5 Mabsadd L closepath F
.32765 .30964 -2.5 2.5 Mabsadd m
.32765 .30964 2.5 2.5 Mabsadd L
.32765 .30964 2.5 -2.5 Mabsadd L
.32765 .30964 -2.5 -2.5 Mabsadd L
.32765 .30964 -2.5 2.5 Mabsadd L closepath F
.33021 .30524 -2.5 2.5 Mabsadd m
.33021 .30524 2.5 2.5 Mabsadd L
.33021 .30524 2.5 -2.5 Mabsadd L
.33021 .30524 -2.5 -2.5 Mabsadd L
.33021 .30524 -2.5 2.5 Mabsadd L closepath F
.33276 .30865 -2.5 2.5 Mabsadd m
.33276 .30865 2.5 2.5 Mabsadd L
.33276 .30865 2.5 -2.5 Mabsadd L
.33276 .30865 -2.5 -2.5 Mabsadd L
.33276 .30865 -2.5 2.5 Mabsadd L closepath F
.33531 .30893 -2.5 2.5 Mabsadd m
.33531 .30893 2.5 2.5 Mabsadd L
.33531 .30893 2.5 -2.5 Mabsadd L
.33531 .30893 -2.5 -2.5 Mabsadd L
.33531 .30893 -2.5 2.5 Mabsadd L closepath F
.33787 .30652 -2.5 2.5 Mabsadd m
.33787 .30652 2.5 2.5 Mabsadd L
.33787 .30652 2.5 -2.5 Mabsadd L
.33787 .30652 -2.5 -2.5 Mabsadd L
.33787 .30652 -2.5 2.5 Mabsadd L closepath F
.34042 .30742 -2.5 2.5 Mabsadd m
.34042 .30742 2.5 2.5 Mabsadd L
.34042 .30742 2.5 -2.5 Mabsadd L
.34042 .30742 -2.5 -2.5 Mabsadd L
.34042 .30742 -2.5 2.5 Mabsadd L closepath F
.34297 .30763 -2.5 2.5 Mabsadd m
.34297 .30763 2.5 2.5 Mabsadd L
.34297 .30763 2.5 -2.5 Mabsadd L
.34297 .30763 -2.5 -2.5 Mabsadd L
.34297 .30763 -2.5 2.5 Mabsadd L closepath F
.34553 .30949 -2.5 2.5 Mabsadd m
.34553 .30949 2.5 2.5 Mabsadd L
.34553 .30949 2.5 -2.5 Mabsadd L
.34553 .30949 -2.5 -2.5 Mabsadd L
.34553 .30949 -2.5 2.5 Mabsadd L closepath F
.34808 .3087 -2.5 2.5 Mabsadd m
.34808 .3087 2.5 2.5 Mabsadd L
.34808 .3087 2.5 -2.5 Mabsadd L
.34808 .3087 -2.5 -2.5 Mabsadd L
.34808 .3087 -2.5 2.5 Mabsadd L closepath F
.35063 .31024 -2.5 2.5 Mabsadd m
.35063 .31024 2.5 2.5 Mabsadd L
.35063 .31024 2.5 -2.5 Mabsadd L
.35063 .31024 -2.5 -2.5 Mabsadd L
.35063 .31024 -2.5 2.5 Mabsadd L closepath F
.35319 .30821 -2.5 2.5 Mabsadd m
.35319 .30821 2.5 2.5 Mabsadd L
.35319 .30821 2.5 -2.5 Mabsadd L
.35319 .30821 -2.5 -2.5 Mabsadd L
.35319 .30821 -2.5 2.5 Mabsadd L closepath F
.35574 .3114 -2.5 2.5 Mabsadd m
.35574 .3114 2.5 2.5 Mabsadd L
.35574 .3114 2.5 -2.5 Mabsadd L
.35574 .3114 -2.5 -2.5 Mabsadd L
.35574 .3114 -2.5 2.5 Mabsadd L closepath F
.35829 .30578 -2.5 2.5 Mabsadd m
.35829 .30578 2.5 2.5 Mabsadd L
.35829 .30578 2.5 -2.5 Mabsadd L
.35829 .30578 -2.5 -2.5 Mabsadd L
.35829 .30578 -2.5 2.5 Mabsadd L closepath F
.36085 .3084 -2.5 2.5 Mabsadd m
.36085 .3084 2.5 2.5 Mabsadd L
.36085 .3084 2.5 -2.5 Mabsadd L
.36085 .3084 -2.5 -2.5 Mabsadd L
.36085 .3084 -2.5 2.5 Mabsadd L closepath F
.3634 .31234 -2.5 2.5 Mabsadd m
.3634 .31234 2.5 2.5 Mabsadd L
.3634 .31234 2.5 -2.5 Mabsadd L
.3634 .31234 -2.5 -2.5 Mabsadd L
.3634 .31234 -2.5 2.5 Mabsadd L closepath F
.36595 .30865 -2.5 2.5 Mabsadd m
.36595 .30865 2.5 2.5 Mabsadd L
.36595 .30865 2.5 -2.5 Mabsadd L
.36595 .30865 -2.5 -2.5 Mabsadd L
.36595 .30865 -2.5 2.5 Mabsadd L closepath F
.36851 .31014 -2.5 2.5 Mabsadd m
.36851 .31014 2.5 2.5 Mabsadd L
.36851 .31014 2.5 -2.5 Mabsadd L
.36851 .31014 -2.5 -2.5 Mabsadd L
.36851 .31014 -2.5 2.5 Mabsadd L closepath F
.37106 .3115 -2.5 2.5 Mabsadd m
.37106 .3115 2.5 2.5 Mabsadd L
.37106 .3115 2.5 -2.5 Mabsadd L
.37106 .3115 -2.5 -2.5 Mabsadd L
.37106 .3115 -2.5 2.5 Mabsadd L closepath F
.37361 .31293 -2.5 2.5 Mabsadd m
.37361 .31293 2.5 2.5 Mabsadd L
.37361 .31293 2.5 -2.5 Mabsadd L
.37361 .31293 -2.5 -2.5 Mabsadd L
.37361 .31293 -2.5 2.5 Mabsadd L closepath F
.37616 .30777 -2.5 2.5 Mabsadd m
.37616 .30777 2.5 2.5 Mabsadd L
.37616 .30777 2.5 -2.5 Mabsadd L
.37616 .30777 -2.5 -2.5 Mabsadd L
.37616 .30777 -2.5 2.5 Mabsadd L closepath F
.37872 .31288 -2.5 2.5 Mabsadd m
.37872 .31288 2.5 2.5 Mabsadd L
.37872 .31288 2.5 -2.5 Mabsadd L
.37872 .31288 -2.5 -2.5 Mabsadd L
.37872 .31288 -2.5 2.5 Mabsadd L closepath F
.38127 .31107 -2.5 2.5 Mabsadd m
.38127 .31107 2.5 2.5 Mabsadd L
.38127 .31107 2.5 -2.5 Mabsadd L
.38127 .31107 -2.5 -2.5 Mabsadd L
.38127 .31107 -2.5 2.5 Mabsadd L closepath F
.38382 .31434 -2.5 2.5 Mabsadd m
.38382 .31434 2.5 2.5 Mabsadd L
.38382 .31434 2.5 -2.5 Mabsadd L
.38382 .31434 -2.5 -2.5 Mabsadd L
.38382 .31434 -2.5 2.5 Mabsadd L closepath F
.38638 .3077 -2.5 2.5 Mabsadd m
.38638 .3077 2.5 2.5 Mabsadd L
.38638 .3077 2.5 -2.5 Mabsadd L
.38638 .3077 -2.5 -2.5 Mabsadd L
.38638 .3077 -2.5 2.5 Mabsadd L closepath F
.38893 .31034 -2.5 2.5 Mabsadd m
.38893 .31034 2.5 2.5 Mabsadd L
.38893 .31034 2.5 -2.5 Mabsadd L
.38893 .31034 -2.5 -2.5 Mabsadd L
.38893 .31034 -2.5 2.5 Mabsadd L closepath F
.39148 .07972 -2.5 2.5 Mabsadd m
.39148 .07972 2.5 2.5 Mabsadd L
.39148 .07972 2.5 -2.5 Mabsadd L
.39148 .07972 -2.5 -2.5 Mabsadd L
.39148 .07972 -2.5 2.5 Mabsadd L closepath F
.39404 .08098 -2.5 2.5 Mabsadd m
.39404 .08098 2.5 2.5 Mabsadd L
.39404 .08098 2.5 -2.5 Mabsadd L
.39404 .08098 -2.5 -2.5 Mabsadd L
.39404 .08098 -2.5 2.5 Mabsadd L closepath F
.39659 .08016 -2.5 2.5 Mabsadd m
.39659 .08016 2.5 2.5 Mabsadd L
.39659 .08016 2.5 -2.5 Mabsadd L
.39659 .08016 -2.5 -2.5 Mabsadd L
.39659 .08016 -2.5 2.5 Mabsadd L closepath F
.39914 .15134 -2.5 2.5 Mabsadd m
.39914 .15134 2.5 2.5 Mabsadd L
.39914 .15134 2.5 -2.5 Mabsadd L
.39914 .15134 -2.5 -2.5 Mabsadd L
.39914 .15134 -2.5 2.5 Mabsadd L closepath F
.4017 .1534 -2.5 2.5 Mabsadd m
.4017 .1534 2.5 2.5 Mabsadd L
.4017 .1534 2.5 -2.5 Mabsadd L
.4017 .1534 -2.5 -2.5 Mabsadd L
.4017 .1534 -2.5 2.5 Mabsadd L closepath F
.40425 .15166 -2.5 2.5 Mabsadd m
.40425 .15166 2.5 2.5 Mabsadd L
.40425 .15166 2.5 -2.5 Mabsadd L
.40425 .15166 -2.5 -2.5 Mabsadd L
.40425 .15166 -2.5 2.5 Mabsadd L closepath F
.4068 .30835 -2.5 2.5 Mabsadd m
.4068 .30835 2.5 2.5 Mabsadd L
.4068 .30835 2.5 -2.5 Mabsadd L
.4068 .30835 -2.5 -2.5 Mabsadd L
.4068 .30835 -2.5 2.5 Mabsadd L closepath F
.40936 .30805 -2.5 2.5 Mabsadd m
.40936 .30805 2.5 2.5 Mabsadd L
.40936 .30805 2.5 -2.5 Mabsadd L
.40936 .30805 -2.5 -2.5 Mabsadd L
.40936 .30805 -2.5 2.5 Mabsadd L closepath F
.41191 .31066 -2.5 2.5 Mabsadd m
.41191 .31066 2.5 2.5 Mabsadd L
.41191 .31066 2.5 -2.5 Mabsadd L
.41191 .31066 -2.5 -2.5 Mabsadd L
.41191 .31066 -2.5 2.5 Mabsadd L closepath F
.41446 .30863 -2.5 2.5 Mabsadd m
.41446 .30863 2.5 2.5 Mabsadd L
.41446 .30863 2.5 -2.5 Mabsadd L
.41446 .30863 -2.5 -2.5 Mabsadd L
.41446 .30863 -2.5 2.5 Mabsadd L closepath F
.41702 .31232 -2.5 2.5 Mabsadd m
.41702 .31232 2.5 2.5 Mabsadd L
.41702 .31232 2.5 -2.5 Mabsadd L
.41702 .31232 -2.5 -2.5 Mabsadd L
.41702 .31232 -2.5 2.5 Mabsadd L closepath F
.41957 .29596 -2.5 2.5 Mabsadd m
.41957 .29596 2.5 2.5 Mabsadd L
.41957 .29596 2.5 -2.5 Mabsadd L
.41957 .29596 -2.5 -2.5 Mabsadd L
.41957 .29596 -2.5 2.5 Mabsadd L closepath F
.42212 .29495 -2.5 2.5 Mabsadd m
.42212 .29495 2.5 2.5 Mabsadd L
.42212 .29495 2.5 -2.5 Mabsadd L
.42212 .29495 -2.5 -2.5 Mabsadd L
.42212 .29495 -2.5 2.5 Mabsadd L closepath F
.42468 .29292 -2.5 2.5 Mabsadd m
.42468 .29292 2.5 2.5 Mabsadd L
.42468 .29292 2.5 -2.5 Mabsadd L
.42468 .29292 -2.5 -2.5 Mabsadd L
.42468 .29292 -2.5 2.5 Mabsadd L closepath F
.42723 .30035 -2.5 2.5 Mabsadd m
.42723 .30035 2.5 2.5 Mabsadd L
.42723 .30035 2.5 -2.5 Mabsadd L
.42723 .30035 -2.5 -2.5 Mabsadd L
.42723 .30035 -2.5 2.5 Mabsadd L closepath F
.42978 .29747 -2.5 2.5 Mabsadd m
.42978 .29747 2.5 2.5 Mabsadd L
.42978 .29747 2.5 -2.5 Mabsadd L
.42978 .29747 -2.5 -2.5 Mabsadd L
.42978 .29747 -2.5 2.5 Mabsadd L closepath F
.43234 .29207 -2.5 2.5 Mabsadd m
.43234 .29207 2.5 2.5 Mabsadd L
.43234 .29207 2.5 -2.5 Mabsadd L
.43234 .29207 -2.5 -2.5 Mabsadd L
.43234 .29207 -2.5 2.5 Mabsadd L closepath F
.43489 .29978 -2.5 2.5 Mabsadd m
.43489 .29978 2.5 2.5 Mabsadd L
.43489 .29978 2.5 -2.5 Mabsadd L
.43489 .29978 -2.5 -2.5 Mabsadd L
.43489 .29978 -2.5 2.5 Mabsadd L closepath F
.43744 .08013 -2.5 2.5 Mabsadd m
.43744 .08013 2.5 2.5 Mabsadd L
.43744 .08013 2.5 -2.5 Mabsadd L
.43744 .08013 -2.5 -2.5 Mabsadd L
.43744 .08013 -2.5 2.5 Mabsadd L closepath F
.44 .07876 -2.5 2.5 Mabsadd m
.44 .07876 2.5 2.5 Mabsadd L
.44 .07876 2.5 -2.5 Mabsadd L
.44 .07876 -2.5 -2.5 Mabsadd L
.44 .07876 -2.5 2.5 Mabsadd L closepath F
.44255 .08022 -2.5 2.5 Mabsadd m
.44255 .08022 2.5 2.5 Mabsadd L
.44255 .08022 2.5 -2.5 Mabsadd L
.44255 .08022 -2.5 -2.5 Mabsadd L
.44255 .08022 -2.5 2.5 Mabsadd L closepath F
.4451 .31341 -2.5 2.5 Mabsadd m
.4451 .31341 2.5 2.5 Mabsadd L
.4451 .31341 2.5 -2.5 Mabsadd L
.4451 .31341 -2.5 -2.5 Mabsadd L
.4451 .31341 -2.5 2.5 Mabsadd L closepath F
.44766 .31023 -2.5 2.5 Mabsadd m
.44766 .31023 2.5 2.5 Mabsadd L
.44766 .31023 2.5 -2.5 Mabsadd L
.44766 .31023 -2.5 -2.5 Mabsadd L
.44766 .31023 -2.5 2.5 Mabsadd L closepath F
.45021 .30941 -2.5 2.5 Mabsadd m
.45021 .30941 2.5 2.5 Mabsadd L
.45021 .30941 2.5 -2.5 Mabsadd L
.45021 .30941 -2.5 -2.5 Mabsadd L
.45021 .30941 -2.5 2.5 Mabsadd L closepath F
.45276 .30924 -2.5 2.5 Mabsadd m
.45276 .30924 2.5 2.5 Mabsadd L
.45276 .30924 2.5 -2.5 Mabsadd L
.45276 .30924 -2.5 -2.5 Mabsadd L
.45276 .30924 -2.5 2.5 Mabsadd L closepath F
.45532 .31146 -2.5 2.5 Mabsadd m
.45532 .31146 2.5 2.5 Mabsadd L
.45532 .31146 2.5 -2.5 Mabsadd L
.45532 .31146 -2.5 -2.5 Mabsadd L
.45532 .31146 -2.5 2.5 Mabsadd L closepath F
.45787 .30465 -2.5 2.5 Mabsadd m
.45787 .30465 2.5 2.5 Mabsadd L
.45787 .30465 2.5 -2.5 Mabsadd L
.45787 .30465 -2.5 -2.5 Mabsadd L
.45787 .30465 -2.5 2.5 Mabsadd L closepath F
.46042 .25324 -2.5 2.5 Mabsadd m
.46042 .25324 2.5 2.5 Mabsadd L
.46042 .25324 2.5 -2.5 Mabsadd L
.46042 .25324 -2.5 -2.5 Mabsadd L
.46042 .25324 -2.5 2.5 Mabsadd L closepath F
.46298 .25788 -2.5 2.5 Mabsadd m
.46298 .25788 2.5 2.5 Mabsadd L
.46298 .25788 2.5 -2.5 Mabsadd L
.46298 .25788 -2.5 -2.5 Mabsadd L
.46298 .25788 -2.5 2.5 Mabsadd L closepath F
.46553 .29012 -2.5 2.5 Mabsadd m
.46553 .29012 2.5 2.5 Mabsadd L
.46553 .29012 2.5 -2.5 Mabsadd L
.46553 .29012 -2.5 -2.5 Mabsadd L
.46553 .29012 -2.5 2.5 Mabsadd L closepath F
.46808 .31403 -2.5 2.5 Mabsadd m
.46808 .31403 2.5 2.5 Mabsadd L
.46808 .31403 2.5 -2.5 Mabsadd L
.46808 .31403 -2.5 -2.5 Mabsadd L
.46808 .31403 -2.5 2.5 Mabsadd L closepath F
.47064 .31225 -2.5 2.5 Mabsadd m
.47064 .31225 2.5 2.5 Mabsadd L
.47064 .31225 2.5 -2.5 Mabsadd L
.47064 .31225 -2.5 -2.5 Mabsadd L
.47064 .31225 -2.5 2.5 Mabsadd L closepath F
.47319 .31153 -2.5 2.5 Mabsadd m
.47319 .31153 2.5 2.5 Mabsadd L
.47319 .31153 2.5 -2.5 Mabsadd L
.47319 .31153 -2.5 -2.5 Mabsadd L
.47319 .31153 -2.5 2.5 Mabsadd L closepath F
.47574 .31236 -2.5 2.5 Mabsadd m
.47574 .31236 2.5 2.5 Mabsadd L
.47574 .31236 2.5 -2.5 Mabsadd L
.47574 .31236 -2.5 -2.5 Mabsadd L
.47574 .31236 -2.5 2.5 Mabsadd L closepath F
.4783 .30696 -2.5 2.5 Mabsadd m
.4783 .30696 2.5 2.5 Mabsadd L
.4783 .30696 2.5 -2.5 Mabsadd L
.4783 .30696 -2.5 -2.5 Mabsadd L
.4783 .30696 -2.5 2.5 Mabsadd L closepath F
.48085 .30968 -2.5 2.5 Mabsadd m
.48085 .30968 2.5 2.5 Mabsadd L
.48085 .30968 2.5 -2.5 Mabsadd L
.48085 .30968 -2.5 -2.5 Mabsadd L
.48085 .30968 -2.5 2.5 Mabsadd L closepath F
.4834 .30635 -2.5 2.5 Mabsadd m
.4834 .30635 2.5 2.5 Mabsadd L
.4834 .30635 2.5 -2.5 Mabsadd L
.4834 .30635 -2.5 -2.5 Mabsadd L
.4834 .30635 -2.5 2.5 Mabsadd L closepath F
.48596 .31546 -2.5 2.5 Mabsadd m
.48596 .31546 2.5 2.5 Mabsadd L
.48596 .31546 2.5 -2.5 Mabsadd L
.48596 .31546 -2.5 -2.5 Mabsadd L
.48596 .31546 -2.5 2.5 Mabsadd L closepath F
.48851 .31704 -2.5 2.5 Mabsadd m
.48851 .31704 2.5 2.5 Mabsadd L
.48851 .31704 2.5 -2.5 Mabsadd L
.48851 .31704 -2.5 -2.5 Mabsadd L
.48851 .31704 -2.5 2.5 Mabsadd L closepath F
.49106 .31085 -2.5 2.5 Mabsadd m
.49106 .31085 2.5 2.5 Mabsadd L
.49106 .31085 2.5 -2.5 Mabsadd L
.49106 .31085 -2.5 -2.5 Mabsadd L
.49106 .31085 -2.5 2.5 Mabsadd L closepath F
.49362 .31067 -2.5 2.5 Mabsadd m
.49362 .31067 2.5 2.5 Mabsadd L
.49362 .31067 2.5 -2.5 Mabsadd L
.49362 .31067 -2.5 -2.5 Mabsadd L
.49362 .31067 -2.5 2.5 Mabsadd L closepath F
.49617 .31527 -2.5 2.5 Mabsadd m
.49617 .31527 2.5 2.5 Mabsadd L
.49617 .31527 2.5 -2.5 Mabsadd L
.49617 .31527 -2.5 -2.5 Mabsadd L
.49617 .31527 -2.5 2.5 Mabsadd L closepath F
.49872 .31324 -2.5 2.5 Mabsadd m
.49872 .31324 2.5 2.5 Mabsadd L
.49872 .31324 2.5 -2.5 Mabsadd L
.49872 .31324 -2.5 -2.5 Mabsadd L
.49872 .31324 -2.5 2.5 Mabsadd L closepath F
.50128 .30938 -2.5 2.5 Mabsadd m
.50128 .30938 2.5 2.5 Mabsadd L
.50128 .30938 2.5 -2.5 Mabsadd L
.50128 .30938 -2.5 -2.5 Mabsadd L
.50128 .30938 -2.5 2.5 Mabsadd L closepath F
.50383 .31029 -2.5 2.5 Mabsadd m
.50383 .31029 2.5 2.5 Mabsadd L
.50383 .31029 2.5 -2.5 Mabsadd L
.50383 .31029 -2.5 -2.5 Mabsadd L
.50383 .31029 -2.5 2.5 Mabsadd L closepath F
.50638 .31329 -2.5 2.5 Mabsadd m
.50638 .31329 2.5 2.5 Mabsadd L
.50638 .31329 2.5 -2.5 Mabsadd L
.50638 .31329 -2.5 -2.5 Mabsadd L
.50638 .31329 -2.5 2.5 Mabsadd L closepath F
.50894 .30762 -2.5 2.5 Mabsadd m
.50894 .30762 2.5 2.5 Mabsadd L
.50894 .30762 2.5 -2.5 Mabsadd L
.50894 .30762 -2.5 -2.5 Mabsadd L
.50894 .30762 -2.5 2.5 Mabsadd L closepath F
.51149 .31065 -2.5 2.5 Mabsadd m
.51149 .31065 2.5 2.5 Mabsadd L
.51149 .31065 2.5 -2.5 Mabsadd L
.51149 .31065 -2.5 -2.5 Mabsadd L
.51149 .31065 -2.5 2.5 Mabsadd L closepath F
.51404 .30505 -2.5 2.5 Mabsadd m
.51404 .30505 2.5 2.5 Mabsadd L
.51404 .30505 2.5 -2.5 Mabsadd L
.51404 .30505 -2.5 -2.5 Mabsadd L
.51404 .30505 -2.5 2.5 Mabsadd L closepath F
.5166 .31185 -2.5 2.5 Mabsadd m
.5166 .31185 2.5 2.5 Mabsadd L
.5166 .31185 2.5 -2.5 Mabsadd L
.5166 .31185 -2.5 -2.5 Mabsadd L
.5166 .31185 -2.5 2.5 Mabsadd L closepath F
.51915 .31454 -2.5 2.5 Mabsadd m
.51915 .31454 2.5 2.5 Mabsadd L
.51915 .31454 2.5 -2.5 Mabsadd L
.51915 .31454 -2.5 -2.5 Mabsadd L
.51915 .31454 -2.5 2.5 Mabsadd L closepath F
.5217 .08171 -2.5 2.5 Mabsadd m
.5217 .08171 2.5 2.5 Mabsadd L
.5217 .08171 2.5 -2.5 Mabsadd L
.5217 .08171 -2.5 -2.5 Mabsadd L
.5217 .08171 -2.5 2.5 Mabsadd L closepath F
.52426 .31098 -2.5 2.5 Mabsadd m
.52426 .31098 2.5 2.5 Mabsadd L
.52426 .31098 2.5 -2.5 Mabsadd L
.52426 .31098 -2.5 -2.5 Mabsadd L
.52426 .31098 -2.5 2.5 Mabsadd L closepath F
.52681 .30912 -2.5 2.5 Mabsadd m
.52681 .30912 2.5 2.5 Mabsadd L
.52681 .30912 2.5 -2.5 Mabsadd L
.52681 .30912 -2.5 -2.5 Mabsadd L
.52681 .30912 -2.5 2.5 Mabsadd L closepath F
.52936 .08348 -2.5 2.5 Mabsadd m
.52936 .08348 2.5 2.5 Mabsadd L
.52936 .08348 2.5 -2.5 Mabsadd L
.52936 .08348 -2.5 -2.5 Mabsadd L
.52936 .08348 -2.5 2.5 Mabsadd L closepath F
.53192 .08281 -2.5 2.5 Mabsadd m
.53192 .08281 2.5 2.5 Mabsadd L
.53192 .08281 2.5 -2.5 Mabsadd L
.53192 .08281 -2.5 -2.5 Mabsadd L
.53192 .08281 -2.5 2.5 Mabsadd L closepath F
.53447 .15435 -2.5 2.5 Mabsadd m
.53447 .15435 2.5 2.5 Mabsadd L
.53447 .15435 2.5 -2.5 Mabsadd L
.53447 .15435 -2.5 -2.5 Mabsadd L
.53447 .15435 -2.5 2.5 Mabsadd L closepath F
.53702 .1515 -2.5 2.5 Mabsadd m
.53702 .1515 2.5 2.5 Mabsadd L
.53702 .1515 2.5 -2.5 Mabsadd L
.53702 .1515 -2.5 -2.5 Mabsadd L
.53702 .1515 -2.5 2.5 Mabsadd L closepath F
.53958 .22594 -2.5 2.5 Mabsadd m
.53958 .22594 2.5 2.5 Mabsadd L
.53958 .22594 2.5 -2.5 Mabsadd L
.53958 .22594 -2.5 -2.5 Mabsadd L
.53958 .22594 -2.5 2.5 Mabsadd L closepath F
.54213 .22913 -2.5 2.5 Mabsadd m
.54213 .22913 2.5 2.5 Mabsadd L
.54213 .22913 2.5 -2.5 Mabsadd L
.54213 .22913 -2.5 -2.5 Mabsadd L
.54213 .22913 -2.5 2.5 Mabsadd L closepath F
.54468 .18724 -2.5 2.5 Mabsadd m
.54468 .18724 2.5 2.5 Mabsadd L
.54468 .18724 2.5 -2.5 Mabsadd L
.54468 .18724 -2.5 -2.5 Mabsadd L
.54468 .18724 -2.5 2.5 Mabsadd L closepath F
.54724 .26706 -2.5 2.5 Mabsadd m
.54724 .26706 2.5 2.5 Mabsadd L
.54724 .26706 2.5 -2.5 Mabsadd L
.54724 .26706 -2.5 -2.5 Mabsadd L
.54724 .26706 -2.5 2.5 Mabsadd L closepath F
.54979 .30685 -2.5 2.5 Mabsadd m
.54979 .30685 2.5 2.5 Mabsadd L
.54979 .30685 2.5 -2.5 Mabsadd L
.54979 .30685 -2.5 -2.5 Mabsadd L
.54979 .30685 -2.5 2.5 Mabsadd L closepath F
.55234 .30539 -2.5 2.5 Mabsadd m
.55234 .30539 2.5 2.5 Mabsadd L
.55234 .30539 2.5 -2.5 Mabsadd L
.55234 .30539 -2.5 -2.5 Mabsadd L
.55234 .30539 -2.5 2.5 Mabsadd L closepath F
.5549 .28714 -2.5 2.5 Mabsadd m
.5549 .28714 2.5 2.5 Mabsadd L
.5549 .28714 2.5 -2.5 Mabsadd L
.5549 .28714 -2.5 -2.5 Mabsadd L
.5549 .28714 -2.5 2.5 Mabsadd L closepath F
.55745 .21638 -2.5 2.5 Mabsadd m
.55745 .21638 2.5 2.5 Mabsadd L
.55745 .21638 2.5 -2.5 Mabsadd L
.55745 .21638 -2.5 -2.5 Mabsadd L
.55745 .21638 -2.5 2.5 Mabsadd L closepath F
.56 .26082 -2.5 2.5 Mabsadd m
.56 .26082 2.5 2.5 Mabsadd L
.56 .26082 2.5 -2.5 Mabsadd L
.56 .26082 -2.5 -2.5 Mabsadd L
.56 .26082 -2.5 2.5 Mabsadd L closepath F
.56256 .26728 -2.5 2.5 Mabsadd m
.56256 .26728 2.5 2.5 Mabsadd L
.56256 .26728 2.5 -2.5 Mabsadd L
.56256 .26728 -2.5 -2.5 Mabsadd L
.56256 .26728 -2.5 2.5 Mabsadd L closepath F
.56511 .26814 -2.5 2.5 Mabsadd m
.56511 .26814 2.5 2.5 Mabsadd L
.56511 .26814 2.5 -2.5 Mabsadd L
.56511 .26814 -2.5 -2.5 Mabsadd L
.56511 .26814 -2.5 2.5 Mabsadd L closepath F
.56766 .25947 -2.5 2.5 Mabsadd m
.56766 .25947 2.5 2.5 Mabsadd L
.56766 .25947 2.5 -2.5 Mabsadd L
.56766 .25947 -2.5 -2.5 Mabsadd L
.56766 .25947 -2.5 2.5 Mabsadd L closepath F
.57022 .26469 -2.5 2.5 Mabsadd m
.57022 .26469 2.5 2.5 Mabsadd L
.57022 .26469 2.5 -2.5 Mabsadd L
.57022 .26469 -2.5 -2.5 Mabsadd L
.57022 .26469 -2.5 2.5 Mabsadd L closepath F
.57277 .26474 -2.5 2.5 Mabsadd m
.57277 .26474 2.5 2.5 Mabsadd L
.57277 .26474 2.5 -2.5 Mabsadd L
.57277 .26474 -2.5 -2.5 Mabsadd L
.57277 .26474 -2.5 2.5 Mabsadd L closepath F
.57532 .26477 -2.5 2.5 Mabsadd m
.57532 .26477 2.5 2.5 Mabsadd L
.57532 .26477 2.5 -2.5 Mabsadd L
.57532 .26477 -2.5 -2.5 Mabsadd L
.57532 .26477 -2.5 2.5 Mabsadd L closepath F
.57788 .26117 -2.5 2.5 Mabsadd m
.57788 .26117 2.5 2.5 Mabsadd L
.57788 .26117 2.5 -2.5 Mabsadd L
.57788 .26117 -2.5 -2.5 Mabsadd L
.57788 .26117 -2.5 2.5 Mabsadd L closepath F
.58043 .2607 -2.5 2.5 Mabsadd m
.58043 .2607 2.5 2.5 Mabsadd L
.58043 .2607 2.5 -2.5 Mabsadd L
.58043 .2607 -2.5 -2.5 Mabsadd L
.58043 .2607 -2.5 2.5 Mabsadd L closepath F
.58298 .26407 -2.5 2.5 Mabsadd m
.58298 .26407 2.5 2.5 Mabsadd L
.58298 .26407 2.5 -2.5 Mabsadd L
.58298 .26407 -2.5 -2.5 Mabsadd L
.58298 .26407 -2.5 2.5 Mabsadd L closepath F
.58554 .07461 -2.5 2.5 Mabsadd m
.58554 .07461 2.5 2.5 Mabsadd L
.58554 .07461 2.5 -2.5 Mabsadd L
.58554 .07461 -2.5 -2.5 Mabsadd L
.58554 .07461 -2.5 2.5 Mabsadd L closepath F
.58809 .03924 -2.5 2.5 Mabsadd m
.58809 .03924 2.5 2.5 Mabsadd L
.58809 .03924 2.5 -2.5 Mabsadd L
.58809 .03924 -2.5 -2.5 Mabsadd L
.58809 .03924 -2.5 2.5 Mabsadd L closepath F
.59064 .03788 -2.5 2.5 Mabsadd m
.59064 .03788 2.5 2.5 Mabsadd L
.59064 .03788 2.5 -2.5 Mabsadd L
.59064 .03788 -2.5 -2.5 Mabsadd L
.59064 .03788 -2.5 2.5 Mabsadd L closepath F
.5932 .03745 -2.5 2.5 Mabsadd m
.5932 .03745 2.5 2.5 Mabsadd L
.5932 .03745 2.5 -2.5 Mabsadd L
.5932 .03745 -2.5 -2.5 Mabsadd L
.5932 .03745 -2.5 2.5 Mabsadd L closepath F
.59575 .03533 -2.5 2.5 Mabsadd m
.59575 .03533 2.5 2.5 Mabsadd L
.59575 .03533 2.5 -2.5 Mabsadd L
.59575 .03533 -2.5 -2.5 Mabsadd L
.59575 .03533 -2.5 2.5 Mabsadd L closepath F
.5983 .03818 -2.5 2.5 Mabsadd m
.5983 .03818 2.5 2.5 Mabsadd L
.5983 .03818 2.5 -2.5 Mabsadd L
.5983 .03818 -2.5 -2.5 Mabsadd L
.5983 .03818 -2.5 2.5 Mabsadd L closepath F
.60086 .04099 -2.5 2.5 Mabsadd m
.60086 .04099 2.5 2.5 Mabsadd L
.60086 .04099 2.5 -2.5 Mabsadd L
.60086 .04099 -2.5 -2.5 Mabsadd L
.60086 .04099 -2.5 2.5 Mabsadd L closepath F
.60341 .02861 -2.5 2.5 Mabsadd m
.60341 .02861 2.5 2.5 Mabsadd L
.60341 .02861 2.5 -2.5 Mabsadd L
.60341 .02861 -2.5 -2.5 Mabsadd L
.60341 .02861 -2.5 2.5 Mabsadd L closepath F
.60596 .2935 -2.5 2.5 Mabsadd m
.60596 .2935 2.5 2.5 Mabsadd L
.60596 .2935 2.5 -2.5 Mabsadd L
.60596 .2935 -2.5 -2.5 Mabsadd L
.60596 .2935 -2.5 2.5 Mabsadd L closepath F
.60852 .29441 -2.5 2.5 Mabsadd m
.60852 .29441 2.5 2.5 Mabsadd L
.60852 .29441 2.5 -2.5 Mabsadd L
.60852 .29441 -2.5 -2.5 Mabsadd L
.60852 .29441 -2.5 2.5 Mabsadd L closepath F
.61107 .3081 -2.5 2.5 Mabsadd m
.61107 .3081 2.5 2.5 Mabsadd L
.61107 .3081 2.5 -2.5 Mabsadd L
.61107 .3081 -2.5 -2.5 Mabsadd L
.61107 .3081 -2.5 2.5 Mabsadd L closepath F
.61362 .29732 -2.5 2.5 Mabsadd m
.61362 .29732 2.5 2.5 Mabsadd L
.61362 .29732 2.5 -2.5 Mabsadd L
.61362 .29732 -2.5 -2.5 Mabsadd L
.61362 .29732 -2.5 2.5 Mabsadd L closepath F
.61618 .29878 -2.5 2.5 Mabsadd m
.61618 .29878 2.5 2.5 Mabsadd L
.61618 .29878 2.5 -2.5 Mabsadd L
.61618 .29878 -2.5 -2.5 Mabsadd L
.61618 .29878 -2.5 2.5 Mabsadd L closepath F
.61873 .30029 -2.5 2.5 Mabsadd m
.61873 .30029 2.5 2.5 Mabsadd L
.61873 .30029 2.5 -2.5 Mabsadd L
.61873 .30029 -2.5 -2.5 Mabsadd L
.61873 .30029 -2.5 2.5 Mabsadd L closepath F
.62128 .30607 -2.5 2.5 Mabsadd m
.62128 .30607 2.5 2.5 Mabsadd L
.62128 .30607 2.5 -2.5 Mabsadd L
.62128 .30607 -2.5 -2.5 Mabsadd L
.62128 .30607 -2.5 2.5 Mabsadd L closepath F
.62384 .30077 -2.5 2.5 Mabsadd m
.62384 .30077 2.5 2.5 Mabsadd L
.62384 .30077 2.5 -2.5 Mabsadd L
.62384 .30077 -2.5 -2.5 Mabsadd L
.62384 .30077 -2.5 2.5 Mabsadd L closepath F
.62639 .29965 -2.5 2.5 Mabsadd m
.62639 .29965 2.5 2.5 Mabsadd L
.62639 .29965 2.5 -2.5 Mabsadd L
.62639 .29965 -2.5 -2.5 Mabsadd L
.62639 .29965 -2.5 2.5 Mabsadd L closepath F
.62894 .29852 -2.5 2.5 Mabsadd m
.62894 .29852 2.5 2.5 Mabsadd L
.62894 .29852 2.5 -2.5 Mabsadd L
.62894 .29852 -2.5 -2.5 Mabsadd L
.62894 .29852 -2.5 2.5 Mabsadd L closepath F
.63149 .30161 -2.5 2.5 Mabsadd m
.63149 .30161 2.5 2.5 Mabsadd L
.63149 .30161 2.5 -2.5 Mabsadd L
.63149 .30161 -2.5 -2.5 Mabsadd L
.63149 .30161 -2.5 2.5 Mabsadd L closepath F
.63405 .30017 -2.5 2.5 Mabsadd m
.63405 .30017 2.5 2.5 Mabsadd L
.63405 .30017 2.5 -2.5 Mabsadd L
.63405 .30017 -2.5 -2.5 Mabsadd L
.63405 .30017 -2.5 2.5 Mabsadd L closepath F
.6366 .30095 -2.5 2.5 Mabsadd m
.6366 .30095 2.5 2.5 Mabsadd L
.6366 .30095 2.5 -2.5 Mabsadd L
.6366 .30095 -2.5 -2.5 Mabsadd L
.6366 .30095 -2.5 2.5 Mabsadd L closepath F
.63915 .30173 -2.5 2.5 Mabsadd m
.63915 .30173 2.5 2.5 Mabsadd L
.63915 .30173 2.5 -2.5 Mabsadd L
.63915 .30173 -2.5 -2.5 Mabsadd L
.63915 .30173 -2.5 2.5 Mabsadd L closepath F
.64171 .30006 -2.5 2.5 Mabsadd m
.64171 .30006 2.5 2.5 Mabsadd L
.64171 .30006 2.5 -2.5 Mabsadd L
.64171 .30006 -2.5 -2.5 Mabsadd L
.64171 .30006 -2.5 2.5 Mabsadd L closepath F
.64426 .3011 -2.5 2.5 Mabsadd m
.64426 .3011 2.5 2.5 Mabsadd L
.64426 .3011 2.5 -2.5 Mabsadd L
.64426 .3011 -2.5 -2.5 Mabsadd L
.64426 .3011 -2.5 2.5 Mabsadd L closepath F
.64681 .30336 -2.5 2.5 Mabsadd m
.64681 .30336 2.5 2.5 Mabsadd L
.64681 .30336 2.5 -2.5 Mabsadd L
.64681 .30336 -2.5 -2.5 Mabsadd L
.64681 .30336 -2.5 2.5 Mabsadd L closepath F
.64937 .29985 -2.5 2.5 Mabsadd m
.64937 .29985 2.5 2.5 Mabsadd L
.64937 .29985 2.5 -2.5 Mabsadd L
.64937 .29985 -2.5 -2.5 Mabsadd L
.64937 .29985 -2.5 2.5 Mabsadd L closepath F
.65192 .31091 -2.5 2.5 Mabsadd m
.65192 .31091 2.5 2.5 Mabsadd L
.65192 .31091 2.5 -2.5 Mabsadd L
.65192 .31091 -2.5 -2.5 Mabsadd L
.65192 .31091 -2.5 2.5 Mabsadd L closepath F
.65447 .309 -2.5 2.5 Mabsadd m
.65447 .309 2.5 2.5 Mabsadd L
.65447 .309 2.5 -2.5 Mabsadd L
.65447 .309 -2.5 -2.5 Mabsadd L
.65447 .309 -2.5 2.5 Mabsadd L closepath F
.65703 .30736 -2.5 2.5 Mabsadd m
.65703 .30736 2.5 2.5 Mabsadd L
.65703 .30736 2.5 -2.5 Mabsadd L
.65703 .30736 -2.5 -2.5 Mabsadd L
.65703 .30736 -2.5 2.5 Mabsadd L closepath F
.65958 .30768 -2.5 2.5 Mabsadd m
.65958 .30768 2.5 2.5 Mabsadd L
.65958 .30768 2.5 -2.5 Mabsadd L
.65958 .30768 -2.5 -2.5 Mabsadd L
.65958 .30768 -2.5 2.5 Mabsadd L closepath F
.66213 .30812 -2.5 2.5 Mabsadd m
.66213 .30812 2.5 2.5 Mabsadd L
.66213 .30812 2.5 -2.5 Mabsadd L
.66213 .30812 -2.5 -2.5 Mabsadd L
.66213 .30812 -2.5 2.5 Mabsadd L closepath F
.66469 .30951 -2.5 2.5 Mabsadd m
.66469 .30951 2.5 2.5 Mabsadd L
.66469 .30951 2.5 -2.5 Mabsadd L
.66469 .30951 -2.5 -2.5 Mabsadd L
.66469 .30951 -2.5 2.5 Mabsadd L closepath F
.66724 .30556 -2.5 2.5 Mabsadd m
.66724 .30556 2.5 2.5 Mabsadd L
.66724 .30556 2.5 -2.5 Mabsadd L
.66724 .30556 -2.5 -2.5 Mabsadd L
.66724 .30556 -2.5 2.5 Mabsadd L closepath F
.66979 .30832 -2.5 2.5 Mabsadd m
.66979 .30832 2.5 2.5 Mabsadd L
.66979 .30832 2.5 -2.5 Mabsadd L
.66979 .30832 -2.5 -2.5 Mabsadd L
.66979 .30832 -2.5 2.5 Mabsadd L closepath F
.67235 .30488 -2.5 2.5 Mabsadd m
.67235 .30488 2.5 2.5 Mabsadd L
.67235 .30488 2.5 -2.5 Mabsadd L
.67235 .30488 -2.5 -2.5 Mabsadd L
.67235 .30488 -2.5 2.5 Mabsadd L closepath F
.6749 .30628 -2.5 2.5 Mabsadd m
.6749 .30628 2.5 2.5 Mabsadd L
.6749 .30628 2.5 -2.5 Mabsadd L
.6749 .30628 -2.5 -2.5 Mabsadd L
.6749 .30628 -2.5 2.5 Mabsadd L closepath F
.67745 .30392 -2.5 2.5 Mabsadd m
.67745 .30392 2.5 2.5 Mabsadd L
.67745 .30392 2.5 -2.5 Mabsadd L
.67745 .30392 -2.5 -2.5 Mabsadd L
.67745 .30392 -2.5 2.5 Mabsadd L closepath F
.68001 .30728 -2.5 2.5 Mabsadd m
.68001 .30728 2.5 2.5 Mabsadd L
.68001 .30728 2.5 -2.5 Mabsadd L
.68001 .30728 -2.5 -2.5 Mabsadd L
.68001 .30728 -2.5 2.5 Mabsadd L closepath F
.68256 .30303 -2.5 2.5 Mabsadd m
.68256 .30303 2.5 2.5 Mabsadd L
.68256 .30303 2.5 -2.5 Mabsadd L
.68256 .30303 -2.5 -2.5 Mabsadd L
.68256 .30303 -2.5 2.5 Mabsadd L closepath F
.68511 .30819 -2.5 2.5 Mabsadd m
.68511 .30819 2.5 2.5 Mabsadd L
.68511 .30819 2.5 -2.5 Mabsadd L
.68511 .30819 -2.5 -2.5 Mabsadd L
.68511 .30819 -2.5 2.5 Mabsadd L closepath F
.68767 .30399 -2.5 2.5 Mabsadd m
.68767 .30399 2.5 2.5 Mabsadd L
.68767 .30399 2.5 -2.5 Mabsadd L
.68767 .30399 -2.5 -2.5 Mabsadd L
.68767 .30399 -2.5 2.5 Mabsadd L closepath F
.69022 .29855 -2.5 2.5 Mabsadd m
.69022 .29855 2.5 2.5 Mabsadd L
.69022 .29855 2.5 -2.5 Mabsadd L
.69022 .29855 -2.5 -2.5 Mabsadd L
.69022 .29855 -2.5 2.5 Mabsadd L closepath F
.69277 .29368 -2.5 2.5 Mabsadd m
.69277 .29368 2.5 2.5 Mabsadd L
.69277 .29368 2.5 -2.5 Mabsadd L
.69277 .29368 -2.5 -2.5 Mabsadd L
.69277 .29368 -2.5 2.5 Mabsadd L closepath F
.69533 .29963 -2.5 2.5 Mabsadd m
.69533 .29963 2.5 2.5 Mabsadd L
.69533 .29963 2.5 -2.5 Mabsadd L
.69533 .29963 -2.5 -2.5 Mabsadd L
.69533 .29963 -2.5 2.5 Mabsadd L closepath F
.69788 .30528 -2.5 2.5 Mabsadd m
.69788 .30528 2.5 2.5 Mabsadd L
.69788 .30528 2.5 -2.5 Mabsadd L
.69788 .30528 -2.5 -2.5 Mabsadd L
.69788 .30528 -2.5 2.5 Mabsadd L closepath F
.70043 .30864 -2.5 2.5 Mabsadd m
.70043 .30864 2.5 2.5 Mabsadd L
.70043 .30864 2.5 -2.5 Mabsadd L
.70043 .30864 -2.5 -2.5 Mabsadd L
.70043 .30864 -2.5 2.5 Mabsadd L closepath F
.70299 .2774 -2.5 2.5 Mabsadd m
.70299 .2774 2.5 2.5 Mabsadd L
.70299 .2774 2.5 -2.5 Mabsadd L
.70299 .2774 -2.5 -2.5 Mabsadd L
.70299 .2774 -2.5 2.5 Mabsadd L closepath F
.70554 .30728 -2.5 2.5 Mabsadd m
.70554 .30728 2.5 2.5 Mabsadd L
.70554 .30728 2.5 -2.5 Mabsadd L
.70554 .30728 -2.5 -2.5 Mabsadd L
.70554 .30728 -2.5 2.5 Mabsadd L closepath F
.70809 .30715 -2.5 2.5 Mabsadd m
.70809 .30715 2.5 2.5 Mabsadd L
.70809 .30715 2.5 -2.5 Mabsadd L
.70809 .30715 -2.5 -2.5 Mabsadd L
.70809 .30715 -2.5 2.5 Mabsadd L closepath F
.71065 .30691 -2.5 2.5 Mabsadd m
.71065 .30691 2.5 2.5 Mabsadd L
.71065 .30691 2.5 -2.5 Mabsadd L
.71065 .30691 -2.5 -2.5 Mabsadd L
.71065 .30691 -2.5 2.5 Mabsadd L closepath F
.7132 .30622 -2.5 2.5 Mabsadd m
.7132 .30622 2.5 2.5 Mabsadd L
.7132 .30622 2.5 -2.5 Mabsadd L
.7132 .30622 -2.5 -2.5 Mabsadd L
.7132 .30622 -2.5 2.5 Mabsadd L closepath F
.71575 .30799 -2.5 2.5 Mabsadd m
.71575 .30799 2.5 2.5 Mabsadd L
.71575 .30799 2.5 -2.5 Mabsadd L
.71575 .30799 -2.5 -2.5 Mabsadd L
.71575 .30799 -2.5 2.5 Mabsadd L closepath F
.71831 .30912 -2.5 2.5 Mabsadd m
.71831 .30912 2.5 2.5 Mabsadd L
.71831 .30912 2.5 -2.5 Mabsadd L
.71831 .30912 -2.5 -2.5 Mabsadd L
.71831 .30912 -2.5 2.5 Mabsadd L closepath F
.72086 .30842 -2.5 2.5 Mabsadd m
.72086 .30842 2.5 2.5 Mabsadd L
.72086 .30842 2.5 -2.5 Mabsadd L
.72086 .30842 -2.5 -2.5 Mabsadd L
.72086 .30842 -2.5 2.5 Mabsadd L closepath F
.72341 .31337 -2.5 2.5 Mabsadd m
.72341 .31337 2.5 2.5 Mabsadd L
.72341 .31337 2.5 -2.5 Mabsadd L
.72341 .31337 -2.5 -2.5 Mabsadd L
.72341 .31337 -2.5 2.5 Mabsadd L closepath F
.72597 .31198 -2.5 2.5 Mabsadd m
.72597 .31198 2.5 2.5 Mabsadd L
.72597 .31198 2.5 -2.5 Mabsadd L
.72597 .31198 -2.5 -2.5 Mabsadd L
.72597 .31198 -2.5 2.5 Mabsadd L closepath F
.72852 .30647 -2.5 2.5 Mabsadd m
.72852 .30647 2.5 2.5 Mabsadd L
.72852 .30647 2.5 -2.5 Mabsadd L
.72852 .30647 -2.5 -2.5 Mabsadd L
.72852 .30647 -2.5 2.5 Mabsadd L closepath F
.73107 .30208 -2.5 2.5 Mabsadd m
.73107 .30208 2.5 2.5 Mabsadd L
.73107 .30208 2.5 -2.5 Mabsadd L
.73107 .30208 -2.5 -2.5 Mabsadd L
.73107 .30208 -2.5 2.5 Mabsadd L closepath F
.73363 .30417 -2.5 2.5 Mabsadd m
.73363 .30417 2.5 2.5 Mabsadd L
.73363 .30417 2.5 -2.5 Mabsadd L
.73363 .30417 -2.5 -2.5 Mabsadd L
.73363 .30417 -2.5 2.5 Mabsadd L closepath F
.73618 .30693 -2.5 2.5 Mabsadd m
.73618 .30693 2.5 2.5 Mabsadd L
.73618 .30693 2.5 -2.5 Mabsadd L
.73618 .30693 -2.5 -2.5 Mabsadd L
.73618 .30693 -2.5 2.5 Mabsadd L closepath F
.73873 .31104 -2.5 2.5 Mabsadd m
.73873 .31104 2.5 2.5 Mabsadd L
.73873 .31104 2.5 -2.5 Mabsadd L
.73873 .31104 -2.5 -2.5 Mabsadd L
.73873 .31104 -2.5 2.5 Mabsadd L closepath F
.74129 .30482 -2.5 2.5 Mabsadd m
.74129 .30482 2.5 2.5 Mabsadd L
.74129 .30482 2.5 -2.5 Mabsadd L
.74129 .30482 -2.5 -2.5 Mabsadd L
.74129 .30482 -2.5 2.5 Mabsadd L closepath F
.74384 .30771 -2.5 2.5 Mabsadd m
.74384 .30771 2.5 2.5 Mabsadd L
.74384 .30771 2.5 -2.5 Mabsadd L
.74384 .30771 -2.5 -2.5 Mabsadd L
.74384 .30771 -2.5 2.5 Mabsadd L closepath F
.74639 .30842 -2.5 2.5 Mabsadd m
.74639 .30842 2.5 2.5 Mabsadd L
.74639 .30842 2.5 -2.5 Mabsadd L
.74639 .30842 -2.5 -2.5 Mabsadd L
.74639 .30842 -2.5 2.5 Mabsadd L closepath F
.74895 .30182 -2.5 2.5 Mabsadd m
.74895 .30182 2.5 2.5 Mabsadd L
.74895 .30182 2.5 -2.5 Mabsadd L
.74895 .30182 -2.5 -2.5 Mabsadd L
.74895 .30182 -2.5 2.5 Mabsadd L closepath F
.7515 .30864 -2.5 2.5 Mabsadd m
.7515 .30864 2.5 2.5 Mabsadd L
.7515 .30864 2.5 -2.5 Mabsadd L
.7515 .30864 -2.5 -2.5 Mabsadd L
.7515 .30864 -2.5 2.5 Mabsadd L closepath F
.75405 .30922 -2.5 2.5 Mabsadd m
.75405 .30922 2.5 2.5 Mabsadd L
.75405 .30922 2.5 -2.5 Mabsadd L
.75405 .30922 -2.5 -2.5 Mabsadd L
.75405 .30922 -2.5 2.5 Mabsadd L closepath F
.75661 .30962 -2.5 2.5 Mabsadd m
.75661 .30962 2.5 2.5 Mabsadd L
.75661 .30962 2.5 -2.5 Mabsadd L
.75661 .30962 -2.5 -2.5 Mabsadd L
.75661 .30962 -2.5 2.5 Mabsadd L closepath F
.75916 .30266 -2.5 2.5 Mabsadd m
.75916 .30266 2.5 2.5 Mabsadd L
.75916 .30266 2.5 -2.5 Mabsadd L
.75916 .30266 -2.5 -2.5 Mabsadd L
.75916 .30266 -2.5 2.5 Mabsadd L closepath F
.76171 .31058 -2.5 2.5 Mabsadd m
.76171 .31058 2.5 2.5 Mabsadd L
.76171 .31058 2.5 -2.5 Mabsadd L
.76171 .31058 -2.5 -2.5 Mabsadd L
.76171 .31058 -2.5 2.5 Mabsadd L closepath F
.76427 .30642 -2.5 2.5 Mabsadd m
.76427 .30642 2.5 2.5 Mabsadd L
.76427 .30642 2.5 -2.5 Mabsadd L
.76427 .30642 -2.5 -2.5 Mabsadd L
.76427 .30642 -2.5 2.5 Mabsadd L closepath F
.76682 .30683 -2.5 2.5 Mabsadd m
.76682 .30683 2.5 2.5 Mabsadd L
.76682 .30683 2.5 -2.5 Mabsadd L
.76682 .30683 -2.5 -2.5 Mabsadd L
.76682 .30683 -2.5 2.5 Mabsadd L closepath F
.76937 .30324 -2.5 2.5 Mabsadd m
.76937 .30324 2.5 2.5 Mabsadd L
.76937 .30324 2.5 -2.5 Mabsadd L
.76937 .30324 -2.5 -2.5 Mabsadd L
.76937 .30324 -2.5 2.5 Mabsadd L closepath F
.77193 .30513 -2.5 2.5 Mabsadd m
.77193 .30513 2.5 2.5 Mabsadd L
.77193 .30513 2.5 -2.5 Mabsadd L
.77193 .30513 -2.5 -2.5 Mabsadd L
.77193 .30513 -2.5 2.5 Mabsadd L closepath F
.77448 .30247 -2.5 2.5 Mabsadd m
.77448 .30247 2.5 2.5 Mabsadd L
.77448 .30247 2.5 -2.5 Mabsadd L
.77448 .30247 -2.5 -2.5 Mabsadd L
.77448 .30247 -2.5 2.5 Mabsadd L closepath F
.77703 .30961 -2.5 2.5 Mabsadd m
.77703 .30961 2.5 2.5 Mabsadd L
.77703 .30961 2.5 -2.5 Mabsadd L
.77703 .30961 -2.5 -2.5 Mabsadd L
.77703 .30961 -2.5 2.5 Mabsadd L closepath F
.77959 .30721 -2.5 2.5 Mabsadd m
.77959 .30721 2.5 2.5 Mabsadd L
.77959 .30721 2.5 -2.5 Mabsadd L
.77959 .30721 -2.5 -2.5 Mabsadd L
.77959 .30721 -2.5 2.5 Mabsadd L closepath F
.78214 .28811 -2.5 2.5 Mabsadd m
.78214 .28811 2.5 2.5 Mabsadd L
.78214 .28811 2.5 -2.5 Mabsadd L
.78214 .28811 -2.5 -2.5 Mabsadd L
.78214 .28811 -2.5 2.5 Mabsadd L closepath F
.78469 .30779 -2.5 2.5 Mabsadd m
.78469 .30779 2.5 2.5 Mabsadd L
.78469 .30779 2.5 -2.5 Mabsadd L
.78469 .30779 -2.5 -2.5 Mabsadd L
.78469 .30779 -2.5 2.5 Mabsadd L closepath F
.78725 .30687 -2.5 2.5 Mabsadd m
.78725 .30687 2.5 2.5 Mabsadd L
.78725 .30687 2.5 -2.5 Mabsadd L
.78725 .30687 -2.5 -2.5 Mabsadd L
.78725 .30687 -2.5 2.5 Mabsadd L closepath F
.7898 .30219 -2.5 2.5 Mabsadd m
.7898 .30219 2.5 2.5 Mabsadd L
.7898 .30219 2.5 -2.5 Mabsadd L
.7898 .30219 -2.5 -2.5 Mabsadd L
.7898 .30219 -2.5 2.5 Mabsadd L closepath F
.79235 .30718 -2.5 2.5 Mabsadd m
.79235 .30718 2.5 2.5 Mabsadd L
.79235 .30718 2.5 -2.5 Mabsadd L
.79235 .30718 -2.5 -2.5 Mabsadd L
.79235 .30718 -2.5 2.5 Mabsadd L closepath F
.79491 .30258 -2.5 2.5 Mabsadd m
.79491 .30258 2.5 2.5 Mabsadd L
.79491 .30258 2.5 -2.5 Mabsadd L
.79491 .30258 -2.5 -2.5 Mabsadd L
.79491 .30258 -2.5 2.5 Mabsadd L closepath F
.79746 .29939 -2.5 2.5 Mabsadd m
.79746 .29939 2.5 2.5 Mabsadd L
.79746 .29939 2.5 -2.5 Mabsadd L
.79746 .29939 -2.5 -2.5 Mabsadd L
.79746 .29939 -2.5 2.5 Mabsadd L closepath F
.80001 .30087 -2.5 2.5 Mabsadd m
.80001 .30087 2.5 2.5 Mabsadd L
.80001 .30087 2.5 -2.5 Mabsadd L
.80001 .30087 -2.5 -2.5 Mabsadd L
.80001 .30087 -2.5 2.5 Mabsadd L closepath F
.80257 .29913 -2.5 2.5 Mabsadd m
.80257 .29913 2.5 2.5 Mabsadd L
.80257 .29913 2.5 -2.5 Mabsadd L
.80257 .29913 -2.5 -2.5 Mabsadd L
.80257 .29913 -2.5 2.5 Mabsadd L closepath F
.80512 .30622 -2.5 2.5 Mabsadd m
.80512 .30622 2.5 2.5 Mabsadd L
.80512 .30622 2.5 -2.5 Mabsadd L
.80512 .30622 -2.5 -2.5 Mabsadd L
.80512 .30622 -2.5 2.5 Mabsadd L closepath F
.80767 .29671 -2.5 2.5 Mabsadd m
.80767 .29671 2.5 2.5 Mabsadd L
.80767 .29671 2.5 -2.5 Mabsadd L
.80767 .29671 -2.5 -2.5 Mabsadd L
.80767 .29671 -2.5 2.5 Mabsadd L closepath F
.81023 .30777 -2.5 2.5 Mabsadd m
.81023 .30777 2.5 2.5 Mabsadd L
.81023 .30777 2.5 -2.5 Mabsadd L
.81023 .30777 -2.5 -2.5 Mabsadd L
.81023 .30777 -2.5 2.5 Mabsadd L closepath F
.81278 .30795 -2.5 2.5 Mabsadd m
.81278 .30795 2.5 2.5 Mabsadd L
.81278 .30795 2.5 -2.5 Mabsadd L
.81278 .30795 -2.5 -2.5 Mabsadd L
.81278 .30795 -2.5 2.5 Mabsadd L closepath F
.81533 .30969 -2.5 2.5 Mabsadd m
.81533 .30969 2.5 2.5 Mabsadd L
.81533 .30969 2.5 -2.5 Mabsadd L
.81533 .30969 -2.5 -2.5 Mabsadd L
.81533 .30969 -2.5 2.5 Mabsadd L closepath F
.81789 .30988 -2.5 2.5 Mabsadd m
.81789 .30988 2.5 2.5 Mabsadd L
.81789 .30988 2.5 -2.5 Mabsadd L
.81789 .30988 -2.5 -2.5 Mabsadd L
.81789 .30988 -2.5 2.5 Mabsadd L closepath F
.82044 .30729 -2.5 2.5 Mabsadd m
.82044 .30729 2.5 2.5 Mabsadd L
.82044 .30729 2.5 -2.5 Mabsadd L
.82044 .30729 -2.5 -2.5 Mabsadd L
.82044 .30729 -2.5 2.5 Mabsadd L closepath F
.82299 .31175 -2.5 2.5 Mabsadd m
.82299 .31175 2.5 2.5 Mabsadd L
.82299 .31175 2.5 -2.5 Mabsadd L
.82299 .31175 -2.5 -2.5 Mabsadd L
.82299 .31175 -2.5 2.5 Mabsadd L closepath F
.82555 .30836 -2.5 2.5 Mabsadd m
.82555 .30836 2.5 2.5 Mabsadd L
.82555 .30836 2.5 -2.5 Mabsadd L
.82555 .30836 -2.5 -2.5 Mabsadd L
.82555 .30836 -2.5 2.5 Mabsadd L closepath F
.8281 .30896 -2.5 2.5 Mabsadd m
.8281 .30896 2.5 2.5 Mabsadd L
.8281 .30896 2.5 -2.5 Mabsadd L
.8281 .30896 -2.5 -2.5 Mabsadd L
.8281 .30896 -2.5 2.5 Mabsadd L closepath F
.83065 .30718 -2.5 2.5 Mabsadd m
.83065 .30718 2.5 2.5 Mabsadd L
.83065 .30718 2.5 -2.5 Mabsadd L
.83065 .30718 -2.5 -2.5 Mabsadd L
.83065 .30718 -2.5 2.5 Mabsadd L closepath F
.83321 .30765 -2.5 2.5 Mabsadd m
.83321 .30765 2.5 2.5 Mabsadd L
.83321 .30765 2.5 -2.5 Mabsadd L
.83321 .30765 -2.5 -2.5 Mabsadd L
.83321 .30765 -2.5 2.5 Mabsadd L closepath F
.83576 .30932 -2.5 2.5 Mabsadd m
.83576 .30932 2.5 2.5 Mabsadd L
.83576 .30932 2.5 -2.5 Mabsadd L
.83576 .30932 -2.5 -2.5 Mabsadd L
.83576 .30932 -2.5 2.5 Mabsadd L closepath F
.83831 .30867 -2.5 2.5 Mabsadd m
.83831 .30867 2.5 2.5 Mabsadd L
.83831 .30867 2.5 -2.5 Mabsadd L
.83831 .30867 -2.5 -2.5 Mabsadd L
.83831 .30867 -2.5 2.5 Mabsadd L closepath F
.84087 .30935 -2.5 2.5 Mabsadd m
.84087 .30935 2.5 2.5 Mabsadd L
.84087 .30935 2.5 -2.5 Mabsadd L
.84087 .30935 -2.5 -2.5 Mabsadd L
.84087 .30935 -2.5 2.5 Mabsadd L closepath F
.84342 .30903 -2.5 2.5 Mabsadd m
.84342 .30903 2.5 2.5 Mabsadd L
.84342 .30903 2.5 -2.5 Mabsadd L
.84342 .30903 -2.5 -2.5 Mabsadd L
.84342 .30903 -2.5 2.5 Mabsadd L closepath F
.84597 .29442 -2.5 2.5 Mabsadd m
.84597 .29442 2.5 2.5 Mabsadd L
.84597 .29442 2.5 -2.5 Mabsadd L
.84597 .29442 -2.5 -2.5 Mabsadd L
.84597 .29442 -2.5 2.5 Mabsadd L closepath F
.84853 .30252 -2.5 2.5 Mabsadd m
.84853 .30252 2.5 2.5 Mabsadd L
.84853 .30252 2.5 -2.5 Mabsadd L
.84853 .30252 -2.5 -2.5 Mabsadd L
.84853 .30252 -2.5 2.5 Mabsadd L closepath F
.85108 .30355 -2.5 2.5 Mabsadd m
.85108 .30355 2.5 2.5 Mabsadd L
.85108 .30355 2.5 -2.5 Mabsadd L
.85108 .30355 -2.5 -2.5 Mabsadd L
.85108 .30355 -2.5 2.5 Mabsadd L closepath F
.85363 .3052 -2.5 2.5 Mabsadd m
.85363 .3052 2.5 2.5 Mabsadd L
.85363 .3052 2.5 -2.5 Mabsadd L
.85363 .3052 -2.5 -2.5 Mabsadd L
.85363 .3052 -2.5 2.5 Mabsadd L closepath F
.85619 .22296 -2.5 2.5 Mabsadd m
.85619 .22296 2.5 2.5 Mabsadd L
.85619 .22296 2.5 -2.5 Mabsadd L
.85619 .22296 -2.5 -2.5 Mabsadd L
.85619 .22296 -2.5 2.5 Mabsadd L closepath F
.85874 .2252 -2.5 2.5 Mabsadd m
.85874 .2252 2.5 2.5 Mabsadd L
.85874 .2252 2.5 -2.5 Mabsadd L
.85874 .2252 -2.5 -2.5 Mabsadd L
.85874 .2252 -2.5 2.5 Mabsadd L closepath F
.86129 .29294 -2.5 2.5 Mabsadd m
.86129 .29294 2.5 2.5 Mabsadd L
.86129 .29294 2.5 -2.5 Mabsadd L
.86129 .29294 -2.5 -2.5 Mabsadd L
.86129 .29294 -2.5 2.5 Mabsadd L closepath F
.86385 .30639 -2.5 2.5 Mabsadd m
.86385 .30639 2.5 2.5 Mabsadd L
.86385 .30639 2.5 -2.5 Mabsadd L
.86385 .30639 -2.5 -2.5 Mabsadd L
.86385 .30639 -2.5 2.5 Mabsadd L closepath F
.8664 .29081 -2.5 2.5 Mabsadd m
.8664 .29081 2.5 2.5 Mabsadd L
.8664 .29081 2.5 -2.5 Mabsadd L
.8664 .29081 -2.5 -2.5 Mabsadd L
.8664 .29081 -2.5 2.5 Mabsadd L closepath F
.86895 .31472 -2.5 2.5 Mabsadd m
.86895 .31472 2.5 2.5 Mabsadd L
.86895 .31472 2.5 -2.5 Mabsadd L
.86895 .31472 -2.5 -2.5 Mabsadd L
.86895 .31472 -2.5 2.5 Mabsadd L closepath F
.87151 .29217 -2.5 2.5 Mabsadd m
.87151 .29217 2.5 2.5 Mabsadd L
.87151 .29217 2.5 -2.5 Mabsadd L
.87151 .29217 -2.5 -2.5 Mabsadd L
.87151 .29217 -2.5 2.5 Mabsadd L closepath F
.87406 .31458 -2.5 2.5 Mabsadd m
.87406 .31458 2.5 2.5 Mabsadd L
.87406 .31458 2.5 -2.5 Mabsadd L
.87406 .31458 -2.5 -2.5 Mabsadd L
.87406 .31458 -2.5 2.5 Mabsadd L closepath F
.87661 .29001 -2.5 2.5 Mabsadd m
.87661 .29001 2.5 2.5 Mabsadd L
.87661 .29001 2.5 -2.5 Mabsadd L
.87661 .29001 -2.5 -2.5 Mabsadd L
.87661 .29001 -2.5 2.5 Mabsadd L closepath F
.87917 .31461 -2.5 2.5 Mabsadd m
.87917 .31461 2.5 2.5 Mabsadd L
.87917 .31461 2.5 -2.5 Mabsadd L
.87917 .31461 -2.5 -2.5 Mabsadd L
.87917 .31461 -2.5 2.5 Mabsadd L closepath F
.88172 .28873 -2.5 2.5 Mabsadd m
.88172 .28873 2.5 2.5 Mabsadd L
.88172 .28873 2.5 -2.5 Mabsadd L
.88172 .28873 -2.5 -2.5 Mabsadd L
.88172 .28873 -2.5 2.5 Mabsadd L closepath F
.88427 .31481 -2.5 2.5 Mabsadd m
.88427 .31481 2.5 2.5 Mabsadd L
.88427 .31481 2.5 -2.5 Mabsadd L
.88427 .31481 -2.5 -2.5 Mabsadd L
.88427 .31481 -2.5 2.5 Mabsadd L closepath F
.88682 .28972 -2.5 2.5 Mabsadd m
.88682 .28972 2.5 2.5 Mabsadd L
.88682 .28972 2.5 -2.5 Mabsadd L
.88682 .28972 -2.5 -2.5 Mabsadd L
.88682 .28972 -2.5 2.5 Mabsadd L closepath F
.88938 .31512 -2.5 2.5 Mabsadd m
.88938 .31512 2.5 2.5 Mabsadd L
.88938 .31512 2.5 -2.5 Mabsadd L
.88938 .31512 -2.5 -2.5 Mabsadd L
.88938 .31512 -2.5 2.5 Mabsadd L closepath F
.89193 .2903 -2.5 2.5 Mabsadd m
.89193 .2903 2.5 2.5 Mabsadd L
.89193 .2903 2.5 -2.5 Mabsadd L
.89193 .2903 -2.5 -2.5 Mabsadd L
.89193 .2903 -2.5 2.5 Mabsadd L closepath F
.89448 .31425 -2.5 2.5 Mabsadd m
.89448 .31425 2.5 2.5 Mabsadd L
.89448 .31425 2.5 -2.5 Mabsadd L
.89448 .31425 -2.5 -2.5 Mabsadd L
.89448 .31425 -2.5 2.5 Mabsadd L closepath F
.89704 .28913 -2.5 2.5 Mabsadd m
.89704 .28913 2.5 2.5 Mabsadd L
.89704 .28913 2.5 -2.5 Mabsadd L
.89704 .28913 -2.5 -2.5 Mabsadd L
.89704 .28913 -2.5 2.5 Mabsadd L closepath F
.89959 .31288 -2.5 2.5 Mabsadd m
.89959 .31288 2.5 2.5 Mabsadd L
.89959 .31288 2.5 -2.5 Mabsadd L
.89959 .31288 -2.5 -2.5 Mabsadd L
.89959 .31288 -2.5 2.5 Mabsadd L closepath F
.90214 .2919 -2.5 2.5 Mabsadd m
.90214 .2919 2.5 2.5 Mabsadd L
.90214 .2919 2.5 -2.5 Mabsadd L
.90214 .2919 -2.5 -2.5 Mabsadd L
.90214 .2919 -2.5 2.5 Mabsadd L closepath F
.9047 .31349 -2.5 2.5 Mabsadd m
.9047 .31349 2.5 2.5 Mabsadd L
.9047 .31349 2.5 -2.5 Mabsadd L
.9047 .31349 -2.5 -2.5 Mabsadd L
.9047 .31349 -2.5 2.5 Mabsadd L closepath F
.90725 .18761 -2.5 2.5 Mabsadd m
.90725 .18761 2.5 2.5 Mabsadd L
.90725 .18761 2.5 -2.5 Mabsadd L
.90725 .18761 -2.5 -2.5 Mabsadd L
.90725 .18761 -2.5 2.5 Mabsadd L closepath F
.9098 .21413 -2.5 2.5 Mabsadd m
.9098 .21413 2.5 2.5 Mabsadd L
.9098 .21413 2.5 -2.5 Mabsadd L
.9098 .21413 -2.5 -2.5 Mabsadd L
.9098 .21413 -2.5 2.5 Mabsadd L closepath F
.91236 .19452 -2.5 2.5 Mabsadd m
.91236 .19452 2.5 2.5 Mabsadd L
.91236 .19452 2.5 -2.5 Mabsadd L
.91236 .19452 -2.5 -2.5 Mabsadd L
.91236 .19452 -2.5 2.5 Mabsadd L closepath F
.91491 .21949 -2.5 2.5 Mabsadd m
.91491 .21949 2.5 2.5 Mabsadd L
.91491 .21949 2.5 -2.5 Mabsadd L
.91491 .21949 -2.5 -2.5 Mabsadd L
.91491 .21949 -2.5 2.5 Mabsadd L closepath F
.91746 .28076 -2.5 2.5 Mabsadd m
.91746 .28076 2.5 2.5 Mabsadd L
.91746 .28076 2.5 -2.5 Mabsadd L
.91746 .28076 -2.5 -2.5 Mabsadd L
.91746 .28076 -2.5 2.5 Mabsadd L closepath F
.92002 .32124 -2.5 2.5 Mabsadd m
.92002 .32124 2.5 2.5 Mabsadd L
.92002 .32124 2.5 -2.5 Mabsadd L
.92002 .32124 -2.5 -2.5 Mabsadd L
.92002 .32124 -2.5 2.5 Mabsadd L closepath F
.92257 .28193 -2.5 2.5 Mabsadd m
.92257 .28193 2.5 2.5 Mabsadd L
.92257 .28193 2.5 -2.5 Mabsadd L
.92257 .28193 -2.5 -2.5 Mabsadd L
.92257 .28193 -2.5 2.5 Mabsadd L closepath F
.92512 .31771 -2.5 2.5 Mabsadd m
.92512 .31771 2.5 2.5 Mabsadd L
.92512 .31771 2.5 -2.5 Mabsadd L
.92512 .31771 -2.5 -2.5 Mabsadd L
.92512 .31771 -2.5 2.5 Mabsadd L closepath F
.92768 .28285 -2.5 2.5 Mabsadd m
.92768 .28285 2.5 2.5 Mabsadd L
.92768 .28285 2.5 -2.5 Mabsadd L
.92768 .28285 -2.5 -2.5 Mabsadd L
.92768 .28285 -2.5 2.5 Mabsadd L closepath F
.93023 .31919 -2.5 2.5 Mabsadd m
.93023 .31919 2.5 2.5 Mabsadd L
.93023 .31919 2.5 -2.5 Mabsadd L
.93023 .31919 -2.5 -2.5 Mabsadd L
.93023 .31919 -2.5 2.5 Mabsadd L closepath F
.93278 .28573 -2.5 2.5 Mabsadd m
.93278 .28573 2.5 2.5 Mabsadd L
.93278 .28573 2.5 -2.5 Mabsadd L
.93278 .28573 -2.5 -2.5 Mabsadd L
.93278 .28573 -2.5 2.5 Mabsadd L closepath F
.93534 .32172 -2.5 2.5 Mabsadd m
.93534 .32172 2.5 2.5 Mabsadd L
.93534 .32172 2.5 -2.5 Mabsadd L
.93534 .32172 -2.5 -2.5 Mabsadd L
.93534 .32172 -2.5 2.5 Mabsadd L closepath F
.93789 .29853 -2.5 2.5 Mabsadd m
.93789 .29853 2.5 2.5 Mabsadd L
.93789 .29853 2.5 -2.5 Mabsadd L
.93789 .29853 -2.5 -2.5 Mabsadd L
.93789 .29853 -2.5 2.5 Mabsadd L closepath F
.94044 .32125 -2.5 2.5 Mabsadd m
.94044 .32125 2.5 2.5 Mabsadd L
.94044 .32125 2.5 -2.5 Mabsadd L
.94044 .32125 -2.5 -2.5 Mabsadd L
.94044 .32125 -2.5 2.5 Mabsadd L closepath F
.943 .28358 -2.5 2.5 Mabsadd m
.943 .28358 2.5 2.5 Mabsadd L
.943 .28358 2.5 -2.5 Mabsadd L
.943 .28358 -2.5 -2.5 Mabsadd L
.943 .28358 -2.5 2.5 Mabsadd L closepath F
.94555 .31715 -2.5 2.5 Mabsadd m
.94555 .31715 2.5 2.5 Mabsadd L
.94555 .31715 2.5 -2.5 Mabsadd L
.94555 .31715 -2.5 -2.5 Mabsadd L
.94555 .31715 -2.5 2.5 Mabsadd L closepath F
.9481 .28643 -2.5 2.5 Mabsadd m
.9481 .28643 2.5 2.5 Mabsadd L
.9481 .28643 2.5 -2.5 Mabsadd L
.9481 .28643 -2.5 -2.5 Mabsadd L
.9481 .28643 -2.5 2.5 Mabsadd L closepath F
.95066 .32484 -2.5 2.5 Mabsadd m
.95066 .32484 2.5 2.5 Mabsadd L
.95066 .32484 2.5 -2.5 Mabsadd L
.95066 .32484 -2.5 -2.5 Mabsadd L
.95066 .32484 -2.5 2.5 Mabsadd L closepath F
.95321 .28466 -2.5 2.5 Mabsadd m
.95321 .28466 2.5 2.5 Mabsadd L
.95321 .28466 2.5 -2.5 Mabsadd L
.95321 .28466 -2.5 -2.5 Mabsadd L
.95321 .28466 -2.5 2.5 Mabsadd L closepath F
.95576 .32053 -2.5 2.5 Mabsadd m
.95576 .32053 2.5 2.5 Mabsadd L
.95576 .32053 2.5 -2.5 Mabsadd L
.95576 .32053 -2.5 -2.5 Mabsadd L
.95576 .32053 -2.5 2.5 Mabsadd L closepath F
.95832 .29145 -2.5 2.5 Mabsadd m
.95832 .29145 2.5 2.5 Mabsadd L
.95832 .29145 2.5 -2.5 Mabsadd L
.95832 .29145 -2.5 -2.5 Mabsadd L
.95832 .29145 -2.5 2.5 Mabsadd L closepath F
.96087 .31617 -2.5 2.5 Mabsadd m
.96087 .31617 2.5 2.5 Mabsadd L
.96087 .31617 2.5 -2.5 Mabsadd L
.96087 .31617 -2.5 -2.5 Mabsadd L
.96087 .31617 -2.5 2.5 Mabsadd L closepath F
.96342 .29285 -2.5 2.5 Mabsadd m
.96342 .29285 2.5 2.5 Mabsadd L
.96342 .29285 2.5 -2.5 Mabsadd L
.96342 .29285 -2.5 -2.5 Mabsadd L
.96342 .29285 -2.5 2.5 Mabsadd L closepath F
.96598 .31579 -2.5 2.5 Mabsadd m
.96598 .31579 2.5 2.5 Mabsadd L
.96598 .31579 2.5 -2.5 Mabsadd L
.96598 .31579 -2.5 -2.5 Mabsadd L
.96598 .31579 -2.5 2.5 Mabsadd L closepath F
.96853 .28578 -2.5 2.5 Mabsadd m
.96853 .28578 2.5 2.5 Mabsadd L
.96853 .28578 2.5 -2.5 Mabsadd L
.96853 .28578 -2.5 -2.5 Mabsadd L
.96853 .28578 -2.5 2.5 Mabsadd L closepath F
.97108 .31076 -2.5 2.5 Mabsadd m
.97108 .31076 2.5 2.5 Mabsadd L
.97108 .31076 2.5 -2.5 Mabsadd L
.97108 .31076 -2.5 -2.5 Mabsadd L
.97108 .31076 -2.5 2.5 Mabsadd L closepath F
.97364 .27876 -2.5 2.5 Mabsadd m
.97364 .27876 2.5 2.5 Mabsadd L
.97364 .27876 2.5 -2.5 Mabsadd L
.97364 .27876 -2.5 -2.5 Mabsadd L
.97364 .27876 -2.5 2.5 Mabsadd L closepath F
.97619 .30502 -2.5 2.5 Mabsadd m
.97619 .30502 2.5 2.5 Mabsadd L
.97619 .30502 2.5 -2.5 Mabsadd L
.97619 .30502 -2.5 -2.5 Mabsadd L
.97619 .30502 -2.5 2.5 Mabsadd L closepath F
1 0 0 r
.001 w
.02381 .02506 m
.02636 .02489 L
.02892 .02506 L
.03147 .02495 L
.03402 .02582 L
.03658 .02473 L
.03913 .02549 L
.04168 .02424 L
.04424 .02569 L
.04679 .02541 L
.04934 .0256 L
.0519 .02536 L
.05445 .02549 L
.057 .0247 L
.05956 .02547 L
.06211 .02547 L
.06466 .02552 L
.06722 .02519 L
.06977 .02495 L
.07232 .02536 L
.07488 .02544 L
.07743 .09349 L
.07998 .09131 L
.08254 .09568 L
.08509 .09295 L
.08764 .09404 L
.0902 .09459 L
.09275 .09623 L
.0953 .02498 L
.09786 .02498 L
.10041 .02549 L
.10296 .02555 L
.10552 .02468 L
.10807 .02509 L
.11062 .02514 L
.11318 .02528 L
.11573 .02487 L
.11828 .02509 L
.12083 .0256 L
.12339 .02555 L
.12594 .02448 L
.12849 .02511 L
.13105 .02544 L
.1336 .02585 L
.13615 .025 L
.13871 .02539 L
.14126 .02536 L
.14381 .02528 L
.14637 .02484 L
.14892 .02544 L
Mistroke
.15147 .025 L
.15403 .02522 L
.15658 .02536 L
.15913 .22963 L
.16169 .22908 L
.16424 .22526 L
.16679 .23291 L
.16935 .02492 L
.1719 .02541 L
.17445 .02558 L
.17701 .02468 L
.17956 .02539 L
.18211 .02588 L
.18467 .2258 L
.18722 .22252 L
.18977 .22198 L
.19233 .22416 L
.19488 .02703 L
.19743 .02667 L
.19999 .21268 L
.20254 .02675 L
.20509 .02498 L
.20765 .23455 L
.2102 .22854 L
.21275 .1509 L
.21531 .11427 L
.21786 .117 L
.22041 .22635 L
.22297 .02328 L
.22552 .32859 L
.22807 .34991 L
.23063 .34171 L
.23318 .45871 L
.23573 .43302 L
.23829 .43466 L
.24084 .45543 L
.24339 .09076 L
.24595 .22198 L
.2485 .21651 L
.25105 .234 L
.25361 .234 L
.25616 .23182 L
.25871 .23236 L
.26127 .22963 L
.26382 .23346 L
.26637 .2258 L
.26893 .02273 L
.27148 .02366 L
.27403 .02298 L
.27659 .02241 L
Mistroke
.27914 .0223 L
.28169 .02314 L
.28425 .0226 L
.2868 .02254 L
.28935 .09076 L
.29191 .09623 L
.29446 .02134 L
.29701 .02099 L
.29957 .02183 L
.30212 .02211 L
.30467 .02213 L
.30723 .02235 L
.30978 .02161 L
.31233 .02194 L
.31489 .02293 L
.31744 .09513 L
.31999 .08802 L
.32255 .02227 L
.3251 .02219 L
.32765 .08966 L
.33021 .08912 L
.33276 .08638 L
.33531 .08857 L
.33787 .09623 L
.34042 .09623 L
.34297 .09459 L
.34553 .09732 L
.34808 .09623 L
.35063 .09732 L
.35319 .09295 L
.35574 .09349 L
.35829 .09732 L
.36085 .09295 L
.3634 .09568 L
.36595 .09732 L
.36851 .09732 L
.37106 .09568 L
.37361 .09349 L
.37616 .09568 L
.37872 .09568 L
.38127 .09459 L
.38382 .09623 L
.38638 .09677 L
.38893 .09732 L
.39148 .02172 L
.39404 .0217 L
.39659 .02126 L
.39914 .02186 L
.4017 .02181 L
.40425 .02202 L
Mistroke
.4068 .0924 L
.40936 .09623 L
.41191 .09404 L
.41446 .09404 L
.41702 .09349 L
.41957 .45981 L
.42212 .4609 L
.42468 .44832 L
.42723 .44832 L
.42978 .44832 L
.43234 .45653 L
.43489 .44723 L
.43744 .02347 L
.44 .02375 L
.44255 .02405 L
.4451 .09295 L
.44766 .09951 L
.45021 .10115 L
.45276 .09951 L
.45532 .07381 L
.45787 .04927 L
.46042 .07381 L
.46298 .07381 L
.46553 .07272 L
.46808 .07545 L
.47064 .13122 L
.47319 .10005 L
.47574 .07436 L
.4783 .00443 L
.48085 .08474 L
.4834 .11427 L
.48596 .10224 L
.48851 .10552 L
.49106 .10115 L
.49362 .10115 L
.49617 .10388 L
.49872 .10279 L
.50128 .2094 L
.50383 .13286 L
.50638 .13559 L
.50894 .13395 L
.51149 .13231 L
.51404 .02743 L
.5166 .13778 L
.51915 .13942 L
.5217 .02347 L
.52426 .07928 L
.52681 .08256 L
.52936 .0194 L
.53192 .02025 L
Mistroke
.53447 .01454 L
.53702 .01951 L
.53958 .01358 L
.54213 .02055 L
.54468 .04552 L
.54724 .04733 L
.54979 .04345 L
.55234 .10716 L
.5549 .1088 L
.55745 .10716 L
.56 .08966 L
.56256 .08748 L
.56511 .08748 L
.56766 .08966 L
.57022 .08912 L
.57277 .09076 L
.57532 .09021 L
.57788 .09021 L
.58043 .09295 L
.58298 .09185 L
.58554 .02593 L
.58809 .05085 L
.59064 .05303 L
.5932 .05085 L
.59575 .05522 L
.5983 .04975 L
.60086 .04419 L
.60341 .04386 L
.60596 .05085 L
.60852 .05194 L
.61107 .05031 L
.61362 .0405 L
.61618 .23291 L
.61873 .04949 L
.62128 .11755 L
.62384 .11481 L
.62639 .18534 L
.62894 .18753 L
.63149 .36631 L
.63405 .36139 L
.6366 .36686 L
.63915 .3685 L
.64171 .37124 L
.64426 .36686 L
.64681 .36413 L
.64937 .36741 L
.65192 .13723 L
.65447 .13778 L
.65703 .0223 L
.65958 .02172 L
Mistroke
.66213 .13504 L
.66469 .14215 L
.66724 .23728 L
.66979 .22635 L
.67235 .2258 L
.6749 .21979 L
.67745 .23947 L
.68001 .23346 L
.68256 .35921 L
.68511 .36194 L
.68767 .36249 L
.69022 .3685 L
.69277 .35921 L
.69533 .35921 L
.69788 .35866 L
.70043 .35264 L
.70299 .3018 L
.70554 .35264 L
.70809 .35428 L
.71065 .35483 L
.7132 .35866 L
.71575 .36467 L
.71831 .35155 L
.72086 .35319 L
.72341 .09295 L
.72597 .09021 L
.72852 .01541 L
.73107 .0153 L
.73363 .20503 L
.73618 .21049 L
.73873 .20503 L
.74129 .01806 L
.74384 .3603 L
.74639 .35428 L
.74895 .35647 L
.7515 .35593 L
.75405 .35046 L
.75661 .34718 L
.75916 .36085 L
.76171 .35374 L
.76427 .35866 L
.76682 .35811 L
.76937 .37178 L
.77193 .36686 L
.77448 .36467 L
.77703 .35319 L
.77959 .35046 L
.78214 .36522 L
.78469 .3439 L
.78725 .36085 L
Mistroke
.7898 .35538 L
.79235 .35264 L
.79491 .35593 L
.79746 .36194 L
.80001 .35538 L
.80257 .34991 L
.80512 .35593 L
.80767 .35593 L
.81023 .13723 L
.81278 .13996 L
.81533 .13887 L
.81789 .13996 L
.82044 .13723 L
.82299 .13668 L
.82555 .13887 L
.8281 .13832 L
.83065 .13887 L
.83321 .22362 L
.83576 .17933 L
.83831 .17824 L
.84087 .13614 L
.84342 .13668 L
.84597 .12575 L
.84853 .28813 L
.85108 .2843 L
.85363 .28048 L
.85619 .27993 L
.85874 .28157 L
.86129 .27938 L
.86385 .27938 L
.8664 .13887 L
.86895 .13887 L
.87151 .17496 L
.87406 .17496 L
.87661 .13723 L
.87917 .13723 L
.88172 .13996 L
.88427 .13996 L
.88682 .1345 L
.88938 .1345 L
.89193 .13559 L
.89448 .13559 L
.89704 .09459 L
.89959 .09459 L
.90214 .18753 L
.9047 .18753 L
.90725 .18316 L
.9098 .18316 L
.91236 .18698 L
.91491 .18698 L
Mistroke
.91746 .18316 L
.92002 .18316 L
.92257 .17004 L
.92512 .17004 L
.92768 .18316 L
.93023 .18316 L
.93278 .1684 L
.93534 .1684 L
.93789 .1919 L
.94044 .1919 L
.943 .18534 L
.94555 .18534 L
.9481 .09185 L
.95066 .09185 L
.95321 .1427 L
.95576 .1427 L
.95832 .3357 L
.96087 .3357 L
.96342 .33843 L
.96598 .33843 L
Mfstroke
.96598 .33843 m
.96826 .61803 L
s
0 1 0 r
.02381 .00738 m
.02636 .00722 L
.02892 .00725 L
.03147 .00743 L
.03402 .00748 L
.03658 .00697 L
.03913 .00733 L
.04168 .00699 L
.04424 .00733 L
.04679 .00717 L
.04934 .00728 L
.0519 .00725 L
.05445 .0072 L
.057 .00702 L
.05956 .00725 L
.06211 .00738 L
.06466 .00717 L
.06722 .00658 L
.06977 .00651 L
.07232 .00679 L
.07488 .00679 L
.07743 .0299 L
.07998 .03218 L
.08254 .03356 L
.08509 .02872 L
.08764 .03041 L
.0902 .03284 L
.09275 .03587 L
.0953 .0071 L
.09786 .0072 L
.10041 .0072 L
.10296 .00725 L
.10552 .00715 L
.10807 .00735 L
.11062 .00712 L
.11318 .00751 L
.11573 .00699 L
.11828 .0072 L
.12083 .00717 L
.12339 .00722 L
.12594 .00712 L
.12849 .00728 L
.13105 .00694 L
.1336 .00743 L
.13615 .00725 L
.13871 .00712 L
.14126 .00725 L
.14381 .00717 L
.14637 .0071 L
.14892 .00738 L
Mistroke
.15147 .0071 L
.15403 .00658 L
.15658 .00712 L
.15913 .27438 L
.16169 .26573 L
.16424 .26228 L
.16679 .26977 L
.16935 .01409 L
.1719 .01458 L
.17445 .0146 L
.17701 .01409 L
.17956 .01442 L
.18211 .01473 L
.18467 .25882 L
.18722 .25478 L
.18977 .2617 L
.19233 .25709 L
.19488 .03018 L
.19743 .02972 L
.19999 .24383 L
.20254 .02967 L
.20509 .02775 L
.20765 .26631 L
.2102 .26228 L
.21275 .17639 L
.21531 .14295 L
.21786 .13661 L
.22041 .26055 L
.22297 .026 L
.22552 .37641 L
.22807 .39889 L
.23063 .38967 L
.23318 .51994 L
.23573 .494 L
.23829 .49458 L
.24084 .51648 L
.24339 .11183 L
.24595 .25651 L
.2485 .24614 L
.25105 .27208 L
.25361 .26804 L
.25616 .26516 L
.25871 .26631 L
.26127 .26804 L
.26382 .2715 L
.26637 .25997 L
.26893 .00638 L
.27148 .00669 L
.27403 .00658 L
.27659 .00635 L
Mistroke
.27914 .00651 L
.28169 .00661 L
.28425 .00612 L
.2868 .00648 L
.28935 .10779 L
.29191 .11356 L
.29446 .0061 L
.29701 .00594 L
.29957 .0064 L
.30212 .00638 L
.30467 .00643 L
.30723 .00633 L
.30978 .00607 L
.31233 .0064 L
.31489 .00661 L
.31744 .11471 L
.31999 .10376 L
.32255 .02488 L
.3251 .02472 L
.32765 .10779 L
.33021 .10606 L
.33276 .1026 L
.33531 .10549 L
.33787 .11644 L
.34042 .11413 L
.34297 .11298 L
.34553 .11586 L
.34808 .11471 L
.35063 .12393 L
.35319 .1124 L
.35574 .11183 L
.35829 .11644 L
.36085 .11183 L
.3634 .11932 L
.36595 .12566 L
.36851 .11529 L
.37106 .11471 L
.37361 .11183 L
.37616 .11471 L
.37872 .11817 L
.38127 .1124 L
.38382 .11471 L
.38638 .11586 L
.38893 .11586 L
.39148 .00628 L
.39404 .00633 L
.39659 .00623 L
.39914 .01217 L
.4017 .01222 L
.40425 .0123 L
Mistroke
.4068 .11586 L
.40936 .11413 L
.41191 .11067 L
.41446 .11356 L
.41702 .11529 L
.41957 .52571 L
.42212 .52974 L
.42468 .39255 L
.42723 .38217 L
.42978 .51245 L
.43234 .38909 L
.43489 .37814 L
.43744 .00669 L
.44 .00669 L
.44255 .00679 L
.4451 .11529 L
.44766 .11586 L
.45021 .11759 L
.45276 .11644 L
.45532 .08877 L
.45787 .06225 L
.46042 .07205 L
.46298 .07494 L
.46553 .08877 L
.46808 .0905 L
.47064 .15045 L
.47319 .11759 L
.47574 .09396 L
.4783 .00502 L
.48085 .09972 L
.4834 .13085 L
.48596 .11932 L
.48851 .12509 L
.49106 .1199 L
.49362 .11759 L
.49617 .12278 L
.49872 .11817 L
.50128 .2398 L
.50383 .15275 L
.50638 .15506 L
.50894 .15794 L
.51149 .1516 L
.51404 .03056 L
.5166 .16025 L
.51915 .1614 L
.5217 .00684 L
.52426 .09799 L
.52681 .09742 L
.52936 .00571 L
.53192 .00589 L
Mistroke
.53447 .0081 L
.53702 .01081 L
.53958 .01127 L
.54213 .01734 L
.54468 .03023 L
.54724 .04304 L
.54979 .04729 L
.55234 .12854 L
.5549 .13027 L
.55745 .12509 L
.56 .10491 L
.56256 .10376 L
.56511 .10549 L
.56766 .10549 L
.57022 .10318 L
.57277 .10606 L
.57532 .10433 L
.57788 .10433 L
.58043 .11067 L
.58298 .10722 L
.58554 .00635 L
.58809 .0061 L
.59064 .00515 L
.5932 .00676 L
.59575 .00479 L
.5983 .00582 L
.60086 .00571 L
.60341 .0053 L
.60596 .05995 L
.60852 .06514 L
.61107 .06456 L
.61362 .04419 L
.61618 .26689 L
.61873 .06802 L
.62128 .1395 L
.62384 .13604 L
.62639 .21328 L
.62894 .21731 L
.63149 .31416 L
.63405 .30781 L
.6366 .313 L
.63915 .32107 L
.64171 .32107 L
.64426 .31185 L
.64681 .31185 L
.64937 .31473 L
.65192 .16082 L
.65447 .1614 L
.65703 .0249 L
.65958 .02411 L
Mistroke
.66213 .16313 L
.66469 .17005 L
.66724 .2715 L
.66979 .25882 L
.67235 .25824 L
.6749 .25363 L
.67745 .27208 L
.68001 .26804 L
.68256 .30551 L
.68511 .3107 L
.68767 .30897 L
.69022 .31934 L
.69277 .31473 L
.69533 .30609 L
.69788 .30666 L
.70043 .30493 L
.70299 .31358 L
.70554 .30724 L
.70809 .30436 L
.71065 .30263 L
.7132 .30954 L
.71575 .31416 L
.71831 .30609 L
.72086 .30493 L
.72341 .08819 L
.72597 .11702 L
.72852 .01704 L
.73107 .01693 L
.73363 .24152 L
.73618 .24441 L
.73873 .24037 L
.74129 .01888 L
.74384 .31416 L
.74639 .30897 L
.74895 .30781 L
.7515 .30609 L
.75405 .29917 L
.75661 .30263 L
.75916 .31358 L
.76171 .31243 L
.76427 .31012 L
.76682 .31416 L
.76937 .33087 L
.77193 .31819 L
.77448 .31358 L
.77703 .3107 L
.77959 .29974 L
.78214 .31646 L
.78469 .29283 L
.78725 .41618 L
Mistroke
.7898 .40869 L
.79235 .40811 L
.79491 .41042 L
.79746 .41791 L
.80001 .411 L
.80257 .40235 L
.80512 .41503 L
.80767 .411 L
.81023 .16371 L
.81278 .16717 L
.81533 .1614 L
.81789 .16371 L
.82044 .16313 L
.82299 .16486 L
.82555 .16198 L
.8281 .16544 L
.83065 .17005 L
.83321 .25766 L
.83576 .20809 L
.83831 .20867 L
.84087 .16601 L
.84342 .16025 L
.84597 .1493 L
.84853 .3303 L
.85108 .32684 L
.85363 .3228 L
.85619 .16198 L
.85874 .16486 L
.86129 .16198 L
.86385 .16198 L
.8664 .16486 L
.86895 .16486 L
.87151 .20463 L
.87406 .20463 L
.87661 .1614 L
.87917 .1614 L
.88172 .16544 L
.88427 .16544 L
.88682 .16255 L
.88938 .16255 L
.89193 .16082 L
.89448 .16082 L
.89704 .11702 L
.89959 .11702 L
.90214 .22308 L
.9047 .22308 L
.90725 .10664 L
.9098 .10664 L
.91236 .11067 L
.91491 .11067 L
Mistroke
.91746 .10491 L
.92002 .10491 L
.92257 .09915 L
.92512 .09915 L
.92768 .10664 L
.93023 .10664 L
.93278 .10549 L
.93534 .10549 L
.93789 .22077 L
.94044 .22077 L
.943 .21731 L
.94555 .21731 L
.9481 .11298 L
.95066 .11298 L
.95321 .16544 L
.95576 .16544 L
.95832 .39024 L
.96087 .39024 L
.96342 .38851 L
.96598 .38851 L
Mfstroke
.96598 .38851 m
.96766 .61803 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{1100, 323.688},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000A<0001@b000`400000o`00o`00o`00o`3ooooo
0?ooool0ooooo`3ooom@0?ooo`00o`3ooooo0?ooool0ooooo`3ooom@0?ooo`00o`3ooooo0?ooool0
ooooo`3ooom@0?ooo`00o`3ooooo0?ooool0ooooo`3ooom@0?ooo`00o`3ooooo0?ooool0ooooo`3o
oom@0?ooo`00o`3ooooo0?ooool0ooooo`3ooom@0?ooo`00o`3ooooo0?ooool0ooooo`3ooom@0?oo
o`00o`3ooooo0?ooool0ooooo`3ooom@0?ooo`00o`3ooooo0?ooool0ooooo`3ooom@0?ooo`00o`3o
oooo0?ooool0ooooQ`3oool00`000000oooo0?ooo`0H0?ooo`@00000Z@3oool00?l0oooo<@3oool0
0`000000oooo0?ooo`3o0?ooool0ooooDP3oool00`000000oooo0?ooo`0I0?ooo`@00000303oool0
0`000000oooo0?ooo`2J0?ooo`00nP3oool4000000<0oooo0P0000000`3oool000000?ooo`020?oo
o`8000000P3oool500000080oooo0P0000080?ooo`80000000<0oooo0000000000000`3oool20000
00<0oooo0`0000030?ooo`030000003oool0oooo0080oooo0`0000040?ooo`<00000103oool20000
00<0oooo0`00003o0?ooool0oooo>P3oool00`000000oooo0?ooo`0M0?ooo`8000002P3oool00`00
0000oooo0?ooo`2J0?ooo`00n`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
00<0oooo00@000000?ooo`3oool000000`3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
00000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooocP0oooo00<000000?ooo`3oool07P3oool2000000/0oooo00<00000
0?ooo`3oool0V@3oool00?/0oooo00<000000?ooo`3oool00`3oool3000000<0oooo00<000000?oo
o`3oool0103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01@3oool0
1@000000oooo0000003oool000000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0080oooo0`0000060?ooo`040000003oool0oooo000000H0oooo
00<000000?ooo`3oool0o`3ooonh0?ooo`H00000103oool2000000@0oooo100000020?ooo`P00000
0P3oool4000000h0oooo400000020?ooo`@00000103oool400000080oooo0P0000040?ooo`H00000
0P3oool400000080oooo1000000E0?ooo`030000003oool0oooo00H0oooo100000020?ooo`800000
103oool400000080oooo0P0000040?ooo`@000002@3oool00`000000oooo0?ooo`2I0?ooo`00n`3o
ool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`0000001P3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool01@3oool01@000000oooo0000003oool00000
0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo
0?ooo`0000000P3oool010000000oooo0?ooo`3oool2000000<0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`3o0?oookP0oooo1P0000040?ooo`800000103oool400000080oooo2000
00020?ooo`@000003P3oool@00000080oooo100000040?ooo`@000000P3oool2000000@0oooo1P00
00020?ooo`@000000P3oool4000001@0oooo00<000000?ooo`3oool01`3oool400000080oooo0P00
00040?ooo`@000000P3oool2000000@0oooo1000000:0?ooo`030000003oool0oooo09P0oooo003j
0?ooo`030000003oool00000008000000P3oool2000000<0oooo100000030?ooo`800000103oool2
000000P0oooo0P0000000`3oool00000000000020?ooo`0:0000003oool0oooo0000003oool00000
0?ooo`000000oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0
oooo000000D0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool00000o`3ooonj
0?ooo`800000103oool2000000@0oooo0P0000040?ooo`800000103oool2000000@0oooo0P00000D
0?ooo`8000001P3oool2000000@0oooo0P0000040?ooo`800000103oool2000000@0oooo0P00000:
0?ooo`8000000P3oool2000001H0oooo00<000000?ooo`3oool01@3oool2000000@0oooo0P000004
0?ooo`800000103oool2000000@0oooo0P0000040?ooo`800000203oool00`000000oooo0?ooo`2H
0?ooo`00o`3oool80?ooo`030000003oool0oooo01<0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`8000000P3oool5000000D0oooo00<000000?ooo`0000000`0000040?ooo`<000000`3oool2
00000080oooo1@00003o0?oookX0oooo0P0000040?ooo`800000103oool2000000@0oooo0P000004
0?ooo`800000103oool2000001@0oooo0P0000060?ooo`800000103oool2000000@0oooo0P000004
0?ooo`800000103oool2000000X0oooo0P0000020?ooo`8000005P3oool00`000000oooo0?ooo`05
0?ooo`800000103oool2000000@0oooo0P0000040?ooo`800000103oool2000000@0oooo0P000008
0?ooo`030000003oool0oooo09P0oooo003o0?ooo`P0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`3o0?ooooD0oooo1P0000060?ooo`800000103oool2000000@0oooo0P0000040?oo
o`800000503oool2000000H0oooo0P0000040?ooo`800000103oool2000000@0oooo0P0000040?oo
o`H00000203oool2000001P0oooo00<000000?ooo`3oool01@3oool2000000@0oooo0P0000060?oo
o`H00000103oool2000000@0oooo0P0000080?ooo`030000003oool0oooo09P0oooo003o0?ooool0
ooooo`3oool80?ooo`H000001P3oool2000000@0oooo0P0000040?ooo`800000103oool2000001@0
oooo0P0000060?ooo`800000103oool2000000@0oooo0P0000040?ooo`800000103oool6000000P0
oooo0P00000H0?ooo`030000003oool0oooo00D0oooo0P0000040?ooo`8000001P3oool6000000@0
oooo0P0000040?ooo`800000203oool00`000000oooo0?ooo`2H0?ooo`00o`3ooooo0?ooool0oooo
203oool2000000@0oooo0P0000040?ooo`800000103oool2000000@0oooo0P0000040?ooo`800000
503oool2000000H0oooo0P0000040?ooo`800000103oool2000000@0oooo0P0000040?ooo`800000
103oool2000000@0oooo0P0000020?ooo`8000005P3oool00`000000oooo0?ooo`050?ooo`800000
103oool2000000X0oooo0P0000040?ooo`800000103oool2000000P0oooo00<000000?ooo`3oool0
V03oool006/0oooo0P0000040?ooo`030000003oool0oooo0080oooo1000001@0?ooo`800000103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo04l0oooo0P0000040?ooo`030000003o
ool0oooo00<0oooo0P00001A0?ooo`800000103oool00`000000oooo0?ooo`030?ooo`800000E@3o
ool400000?l0oooo5`3oool2000000@0oooo0P0000040?ooo`800000103oool2000000@0oooo0P00
00040?ooo`800000503oool2000000H0oooo0P0000040?ooo`800000103oool2000000@0oooo0P00
00040?ooo`800000103oool2000000@0oooo0P0000020?ooo`8000005P3oool00`000000oooo0?oo
o`050?ooo`800000103oool2000000X0oooo0P0000040?ooo`800000103oool2000000P0oooo00<0
00000?ooo`3oool0V03oool006X0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?oo
o`1@0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0CP3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000004l0oooo00@000000?ooo`3oool00000203oool0
10000000oooo0?ooo`00001F0?ooo`030000003oool0oooo0?l0oooo5P3oool2000000@0oooo0P00
00020?ooo`@000000P3oool400000080oooo0P0000020?ooo`@00000503oool4000000@0oooo0P00
00020?ooo`@00000203oool6000000H0oooo100000040?ooo`@000000P3oool4000001D0oooo00<0
00000?ooo`3oool01P3oool6000000H0oooo100000040?ooo`@000000P3oool4000000L0oooo00<0
00000?ooo`3oool0V@3oool006X0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?oo
o`1?0?ooo`040000003oool0oooo000000L0oooo1@00001?0?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool00000C`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0
oooo000005H0oooo00<000000?ooo`3oool0o`3ooolF0?ooo`800000103oool200000080oooo1000
00020?ooo`@000000P3oool200000080oooo1000000D0?ooo`@00000103oool200000080oooo1000
00080?ooo`H000001P3oool4000000@0oooo100000020?ooo`@000005@3oool00`000000oooo0?oo
o`060?ooo`H000001P3oool4000000@0oooo100000020?ooo`@000001`3oool00`000000oooo0?oo
o`2I0?ooo`00JP3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo04h0oooo00@0
00000?ooo`3oool000001`3oool010000000oooo0?ooo`00001@0?ooo`040000003oool0oooo0000
00P0oooo0`00001@0?ooo`040000003oool0oooo000000T0oooo0P00001G0?ooo`030000003oool0
oooo0?l0oooo503oool8000004P0oooo0P00000^0?ooo`030000003oool0oooo00T0oooo0P00000N
0?ooo`030000003oool0oooo09X0oooo001Z0?ooo`040000003oool0oooo000000/0oooo00<00000
0?ooo`3oool0C@3oool010000000oooo0?ooo`0000080?ooo`030000003oool000000500oooo00@0
00000?ooo`3oool00000203oool00`000000oooo0?ooo`1@0?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool00000EP3oool00`000000oooo0?ooo`3o0?oooa@0oooo200000180?oo
o`800000;P3oool00`000000oooo0?ooo`090?ooo`8000007P3oool00`000000oooo0?ooo`2J0?oo
o`00JP3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000004l0oooo00@00000
0?ooo`3oool000002@3oool200000500oooo00@000000?ooo`3oool00000203oool00`000000oooo
0?ooo`1@0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000E03oool30000
0?l0ooooC03oool2000001H0oooo1000000_0?ooo`030000003oool0oooo00H0oooo1000002k0?oo
o`00J`3oool2000000X0oooo0P00001A0?ooo`8000002`3oool00`000000oooo0?ooo`1?0?ooo`80
00002P3oool300000500oooo0P00000:0?ooo`800000E`3oool00`000000oooo0?ooo`3o0?ooodX0
oooo0P00000F0?ooo`@00000>03oool400000;/0oooo003o0?ooool0ooooo`3ooooo0?oooe00oooo
003o0?ooool0ooooo`3ooooo0?oooe00oooo003o0?ooool0ooooo`3ooooo0?oooe00oooo003o0?oo
ool0ooooo`3ooooo0?oooe00oooo003o0?ooool0ooooUP3oool8000000`0oooo1000000F0?ooo`80
00005`3oool600000100oooo1000000?0?ooo`8000004P3oool4000002<0oooo1P0000090?ooo`P0
00000`3oool8000000@0oooo300000040?ooo`P00000203oool8000000H0oooo200000080?ooo`80
0000503oool8000000@0oooo1P00000I0?oooa800000103oool200000500oooo000n0?ooool00000
b`00002<0?ooo`P00000303oool4000001H0oooo0P00000G0?ooo`H00000403oool4000000l0oooo
0P00000B0?ooo`@000008`3oool6000000T0oooo200000030?ooo`P00000103oool<000000@0oooo
200000080?ooo`P000001P3oool8000000P0oooo0P00000D0?ooo`P00000103oool6000001T0oooo
4P0000040?ooo`800000D03oool003h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0000008`0oooo0P00000@0?ooo`800000103oool2000001@0oooo0P00
000M0?ooo`800000303oool2000000@0oooo0P00000=0?ooo`800000403oool2000000@0oooo0P00
000W0?ooo`8000002`3oool2000000H0oooo0P000000103oool000000000003oool2000000L0oooo
0P0000020?ooo`8000001P3oool200000180oooo0P0000060?ooo`800000103oool2000000X0oooo
0P00000H0?ooo`800000303oool2000001/0oooo0P0000060?ooo`800000103oool200000080oooo
0P00001@0?ooo`00?P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`000000S03oool200000100oooo0P0000040?ooo`800000503oool2000001d0oooo0P00
000<0?ooo`800000103oool2000000d0oooo0P00000@0?ooo`800000103oool2000002L0oooo0P00
000;0?ooo`8000001P3oool2000000040?ooo`00000000000?ooo`8000001`3oool200000080oooo
0P0000060?ooo`8000004P3oool2000000H0oooo0P0000040?ooo`8000002P3oool2000001P0oooo
0P00000<0?ooo`8000006`3oool2000000H0oooo0P0000040?ooo`8000000P3oool200000500oooo
000n0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0G03oool00`000000oooo0?oo
o`1L0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo08`0oooo0P00000D0?ooo`8000003P3oool:000001/0oooo0P00
000<0?ooo`800000103oool2000000l0oooo0P00000>0?ooo`800000103oool2000002L0oooo0P00
000;0?ooo`8000001P3oool2000000040?ooo`00000000000?ooo`8000001`3oool200000080oooo
0P0000080?ooo`800000403oool2000000`0oooo0P0000040?ooo`X000005P3oool2000000`0oooo
0P00000K0?ooo`8000001P3oool2000000@0oooo0P0000040?ooo`800000CP3oool003h0oooo00<0
00000?ooo`3oool0o`3oooo70?ooo`030000003oool0oooo08`0oooo0P00000D0?ooo`8000003P3o
ool:000001/0oooo0P00000<0?ooo`800000103oool2000000l0oooo0P00000>0?ooo`800000103o
ool2000002L0oooo0P00000;0?ooo`8000001P3oool2000000040?ooo`00000000000?ooo`800000
1`3oool200000080oooo0P0000080?ooo`800000403oool2000000`0oooo0P0000040?ooo`X00000
5P3oool2000000`0oooo0P00000K0?ooo`8000001P3oool2000000@0oooo0P0000040?ooo`800000
CP3oool003@0oooo0P0000080?ooo`030000003oool0oooo0?l0ooooa`3oool00`000000oooo0?oo
o`2>0?ooo`8000003P3oool400000100oooo0P0000040?ooo`8000005`3oool6000000h0oooo1P00
000A0?ooo`800000403oool4000002D0oooo1P00000;0?ooo`8000001P3oool2000000040?ooo`00
000000000?ooo`8000001`3oool200000080oooo0P00000:0?ooo`8000003P3oool2000000P0oooo
1P0000040?ooo`800000103oool2000001P0oooo0P0000060?ooo`H000007@3oool2000000H0oooo
1P0000060?ooo`800000CP3oool003<0oooo00@000000?ooo`3oool000001`3oool00`000000oooo
0?ooo`3o0?ooolL0oooo00<000000?ooo`3oool0SP3oool2000000h0oooo1000000@0?ooo`800000
103oool2000001L0oooo1P00000>0?ooo`H000004@3oool200000100oooo1000000U0?ooo`H00000
2`3oool2000000H0oooo0P000000103oool000000000003oool2000000L0oooo0P0000020?ooo`80
00002P3oool2000000h0oooo0P0000080?ooo`H00000103oool2000000@0oooo0P00000H0?ooo`80
00001P3oool6000001d0oooo0P0000060?ooo`H000001P3oool2000004h0oooo000c0?ooo`040000
003oool0oooo000000L0ooooo`00003;00000980oooo0P00000@0?ooo`800000403oool200000080
oooo0P00000G0?ooo`8000004P3oool2000001L0oooo0P00000<0?ooo`800000103oool200000240
oooo0P0000040?ooo`8000002`3oool2000000H0oooo0P000000103oool000000000003oool20000
00L0oooo0P0000020?ooo`800000303oool2000000`0oooo0P00000<0?ooo`8000001P3oool20000
0080oooo0P00000H0?ooo`8000001P3oool200000240oooo0P0000060?ooo`800000303oool20000
04`0oooo000c0?ooo`040000003oool0oooo000000L0oooo00@000000000o`000?l000001P3oool0
1@000000003o0000003oool000000080003o00<000000000o`0000000P000?l00`000000oooo0?oo
o`0R0?ooo`04000000000?l0003o000000P0oooo00P000000000o`000?l000000000o`000000003o
00000080003o00D000000000o`000000003o000000020000o`030000003oool0oooo05h0oooo00<0
00000000o`0000000P000?l01@000000003o000000000?l000000080003o00<000000000o`000000
;03oool010000000003o0000o`0000060?ooo`03000000000?l0000001/0oooo00H000000000o`00
0?l000000?ooo`0000020000o`050000003oool000000000o`0000000P3oool01@000000003o0000
00000?l000000080003o00<000000?ooo`0000000P000?l00`000000oooo0?ooo`0N0?ooo`030000
00000?l0000000@0oooo00<000000000o`0000000P000?l01@000000003o000000000?l000000080
003o00D000000000o`000000003o000000020000o`030000003oool0oooo00T0oooo00D000000000
o`000000003o000000020000o`05000000000?l000000000o`0000000P000?l00`000000003o0000
00020000o`05000000000?l000000000o`0000000P000?l01@000000003o000000000?l000000080
003o00D000000000o`000000003o000000020000o`03000000000?l000000080003o00D000000000
o`000000003o000000020000o`05000000000?l000000000o`0000000P000?l00`000000003o0000
00020000o`05000000000?l000000000o`0000000P000?l01@000000oooo000000000?l000000980
oooo0P00000@0?ooo`800000403oool200000080oooo0P00000G0?ooo`8000004P3oool2000001L0
oooo0P00000<0?ooo`800000103oool200000240oooo0P0000040?ooo`8000002`3oool2000000H0
oooo0P000000103oool000000000003oool2000000L0oooo0P0000020?ooo`800000303oool20000
00`0oooo0P00000<0?ooo`8000001P3oool200000080oooo0P00000H0?ooo`8000001P3oool20000
0240oooo0P0000060?ooo`800000303oool2000004`0oooo000c0?ooo`040000003oool0oooo0000
00L0oooo00@000000000o`000?l000001P3oool01@000000003o0000003oool000000080003o00<0
00000000o`0000000P000?l00`000000oooo0?ooo`0R0?ooo`04000000000?l0003o000000P0oooo
00P000000000o`000?l000000000o`000000003o00000080003o00D000000000o`000000003o0000
00020000o`030000003oool0oooo05h0oooo00<000000000o`0000000P000?l01@000000003o0000
00000?l000000080003o00<000000000o`000000;03oool010000000003o0000o`0000060?ooo`03
000000000?l0000001/0oooo00H000000000o`000?l000000?ooo`0000020000o`050000003oool0
00000000o`0000000P3oool01@000000003o000000000?l000000080003o00<000000?ooo`000000
0P000?l00`000000oooo0?ooo`0N0?ooo`03000000000?l0000000@0oooo00<000000000o`000000
0P000?l01@000000003o000000000?l000000080003o00D000000000o`000000003o000000020000
o`030000003oool0oooo00T0oooo00D000000000o`000000003o000000020000o`05000000000?l0
00000000o`0000000P000?l00`000000003o000000020000o`05000000000?l000000000o`000000
0P000?l01@000000003o000000000?l000000080003o00D000000000o`000000003o000000020000
o`03000000000?l000000080003o00D000000000o`000000003o000000020000o`05000000000?l0
00000000o`0000000P000?l00`000000003o000000020000o`05000000000?l000000000o`000000
0P000?l01@000000oooo000000000?l0000008`0oooo0P0000040?ooo`8000002P3oool2000000@0
oooo0P00000B0?ooo`@000005`3oool200000180oooo0P00000A0?ooo`800000103oool2000000`0
oooo0P0000040?ooo`8000008@3oool2000000@0oooo0P0000070?ooo`H000001@3oool600000003
0?ooo`000000000000<0oooo2P0000060?ooo`800000103oool2000000P0oooo1P0000060?ooo`P0
0000203oool4000001@0oooo1P0000060?ooo`8000007@3oool600000080oooo1P0000060?ooo`80
0000103oool2000004`0oooo000c0?ooo`040000003oool0oooo000000L0oooo00@000000000o`00
0?l000001P3oool01@000000003o0000003oool000000080003o00<000000000o`0000000P000?l0
0`000000oooo0?ooo`0R0?ooo`04000000000?l0003o000000P0oooo00P000000000o`000?l00000
0000o`000000003o00000080003o00D000000000o`000000003o000000020000o`030000003oool0
oooo05h0oooo00<000000000o`0000000P000?l01@000000003o000000000?l000000080003o00<0
00000000o`000000;03oool010000000003o0000o`0000060?ooo`03000000000?l0000001/0oooo
00H000000000o`000?l000000?ooo`0000020000o`050000003oool000000000o`0000000P3oool0
1@000000003o000000000?l000000080003o00<000000?ooo`0000000P000?l00`000000oooo0?oo
o`0N0?ooo`03000000000?l0000000@0oooo00<000000000o`0000000P000?l01@000000003o0000
00000?l000000080003o00D000000000o`000000003o000000020000o`030000003oool0oooo00T0
oooo00D000000000o`000000003o000000020000o`05000000000?l000000000o`0000000P000?l0
0`000000003o000000020000o`05000000000?l000000000o`0000000P000?l01@000000003o0000
00000?l000000080003o00D000000000o`000000003o000000020000o`03000000000?l000000080
003o00D000000000o`000000003o000000020000o`05000000000?l000000000o`0000000P000?l0
0`000000003o000000020000o`05000000000?l000000000o`0000000P000?l01@000000oooo0000
00000?l0000008`0oooo0P0000040?ooo`8000002P3oool2000000@0oooo0P00000B0?ooo`@00000
5`3oool200000180oooo0P00000A0?ooo`800000103oool2000000`0oooo0P0000040?ooo`800000
8@3oool2000000@0oooo0P0000070?ooo`H000001@3oool6000000030?ooo`000000000000<0oooo
2P0000060?ooo`800000103oool2000000P0oooo1P0000060?ooo`P00000203oool4000001@0oooo
1P0000060?ooo`8000007@3oool600000080oooo1P0000060?ooo`800000103oool2000004`0oooo
000d0?ooo`800000203oool010000000003o0000o`0000060?ooo`05000000000?l000000?ooo`00
00000P000?l00`000000003o000000020000o`030000003oool0oooo0280oooo00@000000000o`00
0?l00000203oool020000000003o0000o`000000003o000000000?l000000P000?l01@000000003o
000000000?l000000080003o00<000000?ooo`3oool0GP3oool00`000000003o000000020000o`05
000000000?l000000000o`0000000P000?l00`000000003o0000000/0?ooo`04000000000?l0003o
000000H0oooo00<000000000o`0000006`3oool01P000000003o0000o`000000oooo00000080003o
00D000000?ooo`000000003o000000020?ooo`05000000000?l000000000o`0000000P000?l00`00
0000oooo000000020000o`030000003oool0oooo01h0oooo00<000000000o`000000103oool00`00
0000003o000000020000o`05000000000?l000000000o`0000000P000?l01@000000003o00000000
0?l000000080003o00<000000?ooo`3oool02@3oool01@000000003o000000000?l000000080003o
00D000000000o`000000003o000000020000o`03000000000?l000000080003o00D000000000o`00
0000003o000000020000o`05000000000?l000000000o`0000000P000?l01@000000003o00000000
0?l000000080003o00<000000000o`0000000P000?l01@000000003o000000000?l000000080003o
00D000000000o`000000003o000000020000o`03000000000?l000000080003o00D000000000o`00
0000003o000000020000o`050000003oool000000000o`000000SP3oool4000000h0oooo1000000F
0?ooo`8000005`3oool8000000h0oooo1P00000;0?ooo`P000003P3oool4000002D0oooo1000000=
0?ooo`800000203oool4000000T0oooo0P0000020?ooo`800000203oool4000000h0oooo0P000008
0?ooo`H000002P3oool2000001P0oooo0P0000060?ooo`P000006`3oool2000000H0oooo4000001<
0?ooo`00?P3oool010000000003o0000o`0000060?ooo`05000000000?l000000?ooo`0000000P00
0?l00`000000003o000000020000o`030000003oool0oooo0280oooo00@000000000o`000?l00000
203oool020000000003o0000o`000000003o000000000?l000000P000?l01@000000003o00000000
0?l000000080003o00<000000?ooo`3oool0GP3oool00`000000003o000000020000o`0500000000
0?l000000000o`0000000P000?l00`000000003o0000000/0?ooo`04000000000?l0003o000000H0
oooo00<000000000o`0000006`3oool01P000000003o0000o`000000oooo00000080003o00D00000
0?ooo`000000003o000000020?ooo`05000000000?l000000000o`0000000P000?l00`000000oooo
000000020000o`030000003oool0oooo01h0oooo00<000000000o`000000103oool00`000000003o
000000020000o`05000000000?l000000000o`0000000P000?l01@000000003o000000000?l00000
0080003o00<000000?ooo`3oool02@3oool01@000000003o000000000?l000000080003o00D00000
0000o`000000003o000000020000o`03000000000?l000000080003o00D000000000o`000000003o
000000020000o`05000000000?l000000000o`0000000P000?l01@000000003o000000000?l00000
0080003o00<000000000o`0000000P000?l01@000000003o000000000?l000000080003o00D00000
0000o`000000003o000000020000o`03000000000?l000000080003o00D000000000o`000000003o
000000020000o`050000003oool000000000o`000000SP3oool4000000h0oooo1000000F0?ooo`80
00005`3oool8000000h0oooo1P00000;0?ooo`P000003P3oool4000002D0oooo1000000=0?ooo`80
0000203oool4000000T0oooo0P0000020?ooo`800000203oool4000000h0oooo0P0000080?ooo`H0
00002P3oool2000001P0oooo0P0000060?ooo`P000006`3oool2000000H0oooo4000001<0?ooo`00
?P3oool010000000003o0000o`0000060?ooo`05000000000?l000000?ooo`0000000P000?l00`00
0000003o000000020000o`030000003oool0oooo0280oooo00@000000000o`000?l00000203oool0
20000000003o0000o`000000003o000000000?l000000P000?l01@000000003o000000000?l00000
0080003o00<000000?ooo`3oool0GP3oool00`000000003o000000020000o`05000000000?l00000
0000o`0000000P000?l00`000000003o0000000/0?ooo`04000000000?l0003o000000H0oooo00<0
00000000o`0000006`3oool01P000000003o0000o`000000oooo00000080003o00D000000?ooo`00
0000003o000000020?ooo`05000000000?l000000000o`0000000P000?l00`000000oooo00000002
0000o`030000003oool0oooo01h0oooo00<000000000o`000000103oool00`000000003o00000002
0000o`05000000000?l000000000o`0000000P000?l01@000000003o000000000?l000000080003o
00<000000?ooo`3oool02@3oool01@000000003o000000000?l000000080003o00D000000000o`00
0000003o000000020000o`03000000000?l000000080003o00D000000000o`000000003o00000002
0000o`05000000000?l000000000o`0000000P000?l01@000000003o000000000?l000000080003o
00<000000000o`0000000P000?l01@000000003o000000000?l000000080003o00D000000000o`00
0000003o000000020000o`03000000000?l000000080003o00D000000000o`000000003o00000002
0000o`050000003oool000000000o`000000o`3ooooo0?ooodH0oooo000n0?ooo`@000001P3oool3
000000040?ooo`000000003o0000o`<000000P000?l00`000000oooo0?ooo`0R0?ooo`@00000203o
ool4000000040000o`000000003o00000080003o00<000000000o`0000001@00001P0?ooo`030000
00000?l000000080003o00D000000000o`000000003o000000020000o`03000000000?l0000002`0
oooo00@000000000o`000?l000001P3oool3000001/0oooo100000000`3oool00000000000020000
00040?ooo`000000000000000080oooo200000000`3oool000000000000200000200oooo0`000004
0?ooo`H0000000<0003o000000000000100000000`000?l000000000o`04000000/0oooo2P000000
1`000?l000000000o`000?l000000000o`0000000P000?l01@000000003o000000000?l000000080
003o00<000000000o`0000000P0000020000o`05000000000?l000000000o`0000000P000?l00`00
0000003o000000020000o`05000000000?l000000000o`0000000P000?l01@000000003o00000000
0?l000000080003o00<000000000o`0000000P000?l3000000030000o`00000000000080000000@0
oooo0000000000000000o`3ooooo0?ooodH0oooo000n0?ooo`030000003oool0oooo00/0oooo00H0
00000000o`000?l000000?ooo`0000020000o`030000003oool0oooo0340oooo00D000000000o`00
0000003o000000020000o`03000000000?l0000006D0oooo00<000000000o`0000000P000?l01@00
0000003o000000000?l000000080003o00<000000000o`000000;03oool010000000003o0000o`00
001/0?ooo`03000000000?l0000000@0oooo00D000000000o`000000003o0000000G0?ooo`030000
00000?l000000080003o00<000000000o`0000000P000?l01@000000003o000000000?l000000080
003o00D000000000o`000000oooo000000020000o`05000000000?l000000000o`0000000P000?l0
0`000000003o000000020000o`05000000000?l000000000o`0000000P000?l01@000000003o0000
00000?l000000080003o00<000000000o`0000000P000?l01@000000oooo000000000?l0000000H0
oooo00<000000?ooo`3oool0o`3ooooo0?oood@0oooo000n0?ooo`030000003oool0oooo00/0oooo
00H000000000o`000?l000000?ooo`0000020000o`030000003oool0oooo0340oooo00D000000000
o`000000003o000000020000o`03000000000?l0000006D0oooo00<000000000o`0000000P000?l0
1@000000003o000000000?l000000080003o00<000000000o`000000;03oool010000000003o0000
o`00001/0?ooo`03000000000?l0000000@0oooo00D000000000o`000000003o0000000G0?ooo`03
000000000?l000000080003o00<000000000o`0000000P000?l01@000000003o000000000?l00000
0080003o00D000000000o`000000oooo000000020000o`05000000000?l000000000o`0000000P00
0?l00`000000003o000000020000o`05000000000?l000000000o`0000000P000?l01@000000003o
000000000?l000000080003o00<000000000o`0000000P000?l01@000000oooo000000000?l00000
00H0oooo00<000000?ooo`3oool0o`3ooooo0?oood@0oooo000n0?ooo`030000003oool0oooo00/0
oooo00H000000000o`000?l000000?ooo`0000020000o`030000003oool0oooo0340oooo00D00000
0000o`000000003o000000020000o`03000000000?l0000006D0oooo00<000000000o`0000000P00
0?l01@000000003o000000000?l000000080003o00<000000000o`000000;03oool010000000003o
0000o`00001/0?ooo`03000000000?l0000000@0oooo00D000000000o`000000003o0000000G0?oo
o`03000000000?l000000080003o00<000000000o`0000000P000?l01@000000003o000000000?l0
00000080003o00D000000000o`000000oooo000000020000o`05000000000?l000000000o`000000
0P000?l00`000000003o000000020000o`05000000000?l000000000o`0000000P000?l01@000000
003o000000000?l000000080003o00<000000000o`0000000P000?l01@000000oooo000000000?l0
000000H0oooo00<000000?ooo`3oool0Q03ooooo00000:4000007P3oool003h0oooo00<000000?oo
o`3oool02`3oool01P000000003o0000o`000000oooo00000080003o00<000000?ooo`3oool0<@3o
ool01@000000003o000000000?l000000080003o00<000000000o`000000I@3oool00`000000003o
000000020000o`05000000000?l000000000o`0000000P000?l00`000000003o0000000/0?ooo`04
000000000?l0003o000006`0oooo00<000000000o`000000103oool01@000000003o000000000?l0
000001L0oooo00<000000000o`0000000P000?l00`000000003o000000020000o`05000000000?l0
00000000o`0000000P000?l01@000000003o0000003oool000000080003o00D000000000o`000000
003o000000020000o`03000000000?l000000080003o00D000000000o`000000003o000000020000
o`05000000000?l000000000o`0000000P000?l00`000000003o000000020000o`050000003oool0
00000000o`0000001P3oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0=03oool00`000000oooo0?ooo`0L0?ooo`00?P3oool00`000000oooo0?ooo`0;
0?ooo`06000000000?l0003o0000003oool000000P000?l00`000000oooo0?ooo`0a0?ooo`050000
00000?l000000000o`0000000P000?l00`000000003o0000001U0?ooo`03000000000?l000000080
003o00D000000000o`000000003o000000020000o`03000000000?l0000002`0oooo00@000000000
o`000?l00000K03oool00`000000003o000000040?ooo`05000000000?l000000000o`0000005`3o
ool00`000000003o000000020000o`03000000000?l000000080003o00D000000000o`000000003o
000000020000o`05000000000?l000000?ooo`0000000P000?l01@000000003o000000000?l00000
0080003o00<000000000o`0000000P000?l01@000000003o000000000?l000000080003o00D00000
0000o`000000003o000000020000o`03000000000?l000000080003o00D000000?ooo`000000003o
000000060?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0V0?ooo`030000003oool0oooo00h0oooo00D00?l00?ooo`3oool0oooo0000000:0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`00o`00oooo003o00020?ooo`03
003o003oool0oooo00@0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo02P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0d0?ooo`03
0000003oool0oooo01`0oooo000n0?ooo`030000003oool0oooo00/0oooo00H000000000o`000?l0
00000?ooo`0000020000o`030000003oool0oooo0340oooo00D000000000o`000000003o00000002
0000o`03000000000?l0000006D0oooo00<000000000o`0000000P000?l01@000000003o00000000
0?l000000080003o00<000000000o`000000;03oool010000000003o0000o`00001/0?ooo`030000
00000?l0000000@0oooo00D000000000o`000000003o0000000G0?ooo`03000000000?l000000080
003o00<000000000o`0000000P000?l01@000000003o000000000?l000000080003o00D000000000
o`000000oooo000000020000o`05000000000?l000000000o`0000000P000?l00`000000003o0000
00020000o`05000000000?l000000000o`0000000P000?l01@000000003o000000000?l000000080
003o00<000000000o`0000000P000?l01@000000oooo000000000?l0000000H0oooo00<000000?oo
o`3oool0Q03oool00`000000oooo0?ooo`070?oooaH00?l01`3ooolK003o00l0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`070?ooo`T00?l000<000000?ooo`00o`002000o`090?oo
o`030000003oool0oooo01<0oooo0`00o`0@0?ooo`@00?l03@3oool01@00o`00oooo0?ooo`3oool0
000000X0oooo00@000000?ooo`3oool00?l00`3oool2003o00L0oooo00<000000?ooo`3oool02`3o
ool2003o00030?ooo`00o`00oooo00<00?l01P3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo03@0oooo00<000000?ooo`3oool0703oool003h0oooo00<000000?ooo`3oool02`3oool0
1P000000003o0000o`000000oooo00000080003o00<000000?ooo`3oool0<@3oool01@000000003o
000000000?l000000080003o00<000000000o`000000I@3oool00`000000003o000000020000o`05
000000000?l000000000o`0000000P000?l00`000000003o0000000/0?ooo`04000000000?l0003o
000006`0oooo00<000000000o`000000103oool01@000000003o000000000?l0000001L0oooo00<0
00000000o`0000000P000?l00`000000003o000000020000o`05000000000?l000000000o`000000
0P000?l01@000000003o0000003oool000000080003o00D000000000o`000000003o000000020000
o`03000000000?l000000080003o00D000000000o`000000003o000000020000o`05000000000?l0
00000000o`0000000P000?l00`000000003o000000020000o`050000003oool000000000o`000000
1P3oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo01`0oooo00<00?l00?ooo`3oool0
1@3oool00`00o`00oooo0?ooo`0G0?ooo`03003o003oool0oooo02/0oooo00<00?l00?ooo`3oool0
1@3oool01000o`00oooo0?ooo`00o`070?ooo`03003o003oool0oooo01d0oooo00<00?l00?ooo`00
o`00403oool01000o`00oooo0?ooo`00o`0=0?ooo`03003o003oool0oooo00l0oooo00L00?l00?oo
o`3oool0oooo003o003oool00?l001@0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?oo
o`2R0?ooo`030000003oool0oooo01`0oooo000n0?ooo`<000002`3oool01@000000003o0000o`00
0000oooo00@00000<`3oool01@000000003o000000000?l000000080003o00<000000000o`000000
I@3oool300000080003o200000000`000?l000000?ooo`0[0?ooo`@00000K03oool3000000@0oooo
00<000000000o`0000000P00000G0?ooo`<000000P000?l6000000040000o`000000003o00000080
003o00D000000000o`000000oooo000000020000o`05000000000?l000000000o`0000000P000?l0
0`000000003o000000020000o`05000000000?l000000000o`0000000P000?l01@000000003o0000
00000?l000000080003o00<000000000o`0000000P000?l01@000000oooo000000000?l0000000D0
oooo0P0000260?ooo`030000003oool0oooo01`0oooo00<00?l00?ooo`3oool01@3oool00`00o`00
oooo0?ooo`0G0?ooo`03003o003oool0oooo02/0oooo00<00?l00?ooo`3oool01@3oool01000o`00
oooo0?ooo`00o`070?ooo`03003o003oool0oooo01d0oooo00<00?l00?ooo`3oool01000o`0<0?oo
o`04003o003oool0oooo003o00d0oooo00<00?l00?ooo`3oool03`3oool01@00o`00oooo0?ooo`3o
ool00?l00080oooo0P00o`0B0?ooo`03003o003oool0oooo00@0oooo00<00?l00?ooo`3oool0XP3o
ool00`000000oooo0?ooo`0L0?ooo`00?P3oool00`000000oooo0?ooo`0;0?ooo`04000000000?l0
003o000003P0oooo00D000000000o`000000003o000000020000o`03000000000?l0000006L0oooo
00@000000000o`000?l000001P3oool00`000000003o0000002S0?ooo`03000000000?l0000001/0
oooo00@000000000o`000?l00000103oool01@000000003o000000000?l000000080003o00D00000
0000o`000000oooo000000020000o`05000000000?l000000000o`0000000P000?l00`000000003o
000000020000o`05000000000?l000000000o`0000000P000?l01@000000003o000000000?l00000
0080003o00<000000000o`0000000P000?l01@000000oooo000000000?l0000000H0oooo00<00000
0?ooo`3oool0Q03oool00`000000oooo0?ooo`0L0?ooo`03003o003oool0oooo00D0oooo00<00?l0
0?ooo`3oool05`3oool00`00o`00oooo0?ooo`020?ooo`H00?l08`3oool00`00o`00oooo0?ooo`05
0?ooo`04003o003oool0oooo003o00L0oooo00<00?l00?ooo`3oool07@3oool00`00o`00oooo0?oo
o`030?ooo`03003o003oool0oooo00X0oooo00@00?l00?ooo`3oool00?l03@3oool00`00o`00oooo
0?ooo`0?0?ooo`09003o003oool0oooo0?ooo`00o`00oooo0000o`3oool00?l00180oooo00<00?l0
0?ooo`3oool0103oool00`00o`00oooo0?ooo`2R0?ooo`030000003oool0oooo01`0oooo000n0?oo
o`030000003oool0oooo00/0oooo00@000000000o`000?l00000>03oool01@000000003o00000000
0?l000000080003o00<000000000o`000000I`3oool010000000003o0000o`0000060?ooo`030000
00000?l000000:<0oooo00<000000000o`0000006`3oool010000000003o0000o`0000040?ooo`05
000000000?l000000000o`0000000P000?l01@000000003o0000003oool000000080003o00D00000
0000o`000000003o000000020000o`03000000000?l000000080003o00D000000000o`000000003o
000000020000o`05000000000?l000000000o`0000000P000?l00`000000003o000000020000o`05
0000003oool000000000o`0000001P3oool00`000000oooo0?ooo`240?ooo`8000007@3oool00`00
o`00oooo0?ooo`050?ooo`03003o003oool0oooo01L0oooo00<00?l00?ooo`3oool00P3oool00`00
o`00oooo0?ooo`020?ooo`03003o003oool0oooo0240oooo00<00?l00?ooo`3oool01@3oool01000
o`00oooo0?ooo`00o`070?ooo`03003o003oool0oooo01d0oooo00<00?l00?ooo`3oool00`3oool0
0`00o`00oooo0?ooo`0:0?ooo`04003o003oool0oooo003o00d0oooo00<00?l00?ooo`3oool03`3o
ool01P00o`00oooo0?ooo`3oool00?l00?ooo`<0003o00<00?l00?ooo`3oool03`3oool00`00o`00
oooo0?ooo`040?ooo`03003o003oool0oooo0340oooo0P00o`1_0?ooo`030000003oool0oooo01`0
oooo000n0?ooo`030000003oool0oooo00/0oooo00@000000000o`000?l00000>03oool01@000000
003o000000000?l000000080003o00<000000000o`000000I`3oool010000000003o0000o`000006
0?ooo`03000000000?l000000:<0oooo00<000000000o`0000006`3oool010000000003o0000o`00
00040?ooo`05000000000?l000000000o`0000000P000?l01@000000003o0000003oool000000080
003o00D000000000o`000000003o000000020000o`03000000000?l000000080003o00D000000000
o`000000003o000000020000o`05000000000?l000000000o`0000000P000?l00`000000003o0000
00020000o`050000003oool000000000o`0000001P3oool00`000000oooo0?ooo`240?ooo`030000
003oool0oooo01`0oooo00<00?l00?ooo`3oool01@3oool00`00o`00oooo0?ooo`0G0?ooo`03003o
003oool0oooo0080oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`0Q0?ooo`03003o
003oool0oooo00D0oooo00@00?l00?ooo`3oool00?l01`3oool00`00o`00oooo0?ooo`0M0?ooo`03
003o003oool0oooo00<0oooo00<00?l00?ooo`3oool02P3oool01000o`00oooo0?ooo`00o`0=0?oo
o`03003o003oool0oooo00l0oooo00X00?l00?ooo`3oool0oooo003o00000?l0oooo0000o`3oool0
0?l04@3oool00`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo0340oooo0P00o`040?ooo`03
003o003oool0oooo06P0oooo00<000000?ooo`3oool0703oool003h0oooo00<000000?ooo`3oool0
2`3oool010000000003o0000o`00000h0?ooo`05000000000?l000000000o`0000000P000?l00`00
0000003o0000001W0?ooo`04000000000?l0003o000000H0oooo00<000000000o`000000X`3oool0
0`000000003o0000000K0?ooo`04000000000?l0003o000000@0oooo00D000000000o`000000003o
000000020000o`05000000000?l000000?ooo`0000000P000?l01@000000003o000000000?l00000
0080003o00<000000000o`0000000P000?l01@000000003o000000000?l000000080003o00D00000
0000o`000000003o000000020000o`03000000000?l000000080003o00D000000?ooo`000000003o
000000060?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool07@3oool00`00o`00oooo
0?ooo`030?ooo`03003o003oool0oooo01P0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo
0?ooo`020?ooo`03003o003oool0oooo0240oooo00<00?l00?ooo`3oool00P3oool010000?l0oooo
0?ooo`00o`020?ooo`03003o00000?l0003o00D0003o00@00?l00?ooo`3oool0oooo0P000?lJ0?oo
o`03003o00000?l0003o00<0003o00<00?l00?ooo`3oool02P3oool01000o`00oooo0?ooo`00o`0=
0?ooo`03003o003oool0oooo00l0oooo00H00?l00?ooo`3oool0oooo003o00000?l30?ooo`03003o
003oool0oooo00l0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`0D0?ooo`80003o
6`3oool2003o00@0oooo00<00?l00?ooo`3oool0J03oool00`000000oooo0?ooo`0L0?ooo`00?P3o
ool00`000000oooo0?ooo`0;0?ooo`04000000000?l0003o000003P0oooo00D000000000o`000000
003o000000020000o`03000000000?l0000006L0oooo00@000000000o`000?l000001P3oool00`00
0000003o0000002S0?ooo`03000000000?l0000001/0oooo00@000000000o`000?l00000103oool0
1@000000003o000000000?l000000080003o00D000000000o`000000oooo000000020000o`050000
00000?l000000000o`0000000P000?l00`000000003o000000020000o`05000000000?l000000000
o`0000000P000?l01@000000003o000000000?l000000080003o00<000000000o`0000000P000?l0
1@000000oooo000000000?l0000000H0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?oo
o`0<0?ooo`030000o`3oool0003o00D0oooo00<0003o0?ooo`3oool01P3oool00`00o`00oooo0?oo
o`030?ooo`03003o003oool0oooo0080oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?oo
o`0:0?ooo`03003o003oool0oooo0080oooo00H00?l00?ooo`3oool0003o0?ooo`00o`0@0?ooo`03
0000o`3oool0oooo0100oooo00<00?l00000o`000?l00P000?l0103oool0003o0000o`00o`020?oo
o`03003o003oool0oooo00D0oooo00H00?l00?ooo`3oool0oooo0000o`00o`0J0?ooo`03003o003o
ool0oooo00<0oooo00<00?l00?ooo`3oool02P3oool01000o`00003o0000o`00o`0=0?ooo`03003o
003oool0oooo00l0oooo00D00?l00?ooo`3oool0oooo003o00040?ooo`03003o003oool0oooo00l0
oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`0D0?ooo`030000o`00o`00oooo01X0
oooo0P00o`040?ooo`03003o003oool0oooo06P0oooo00<000000?ooo`3oool0703oool003h0oooo
00<000000?ooo`3oool02`3oool010000000003o0000o`00000h0?ooo`05000000000?l000000000
o`0000000P000?l00`000000003o0000001W0?ooo`04000000000?l0003o000000H0oooo00<00000
0000o`000000X`3oool00`000000003o0000000K0?ooo`04000000000?l0003o000000@0oooo00D0
00000000o`000000003o000000020000o`05000000000?l000000?ooo`0000000P000?l01@000000
003o000000000?l000000080003o00<000000000o`0000000P000?l01@000000003o000000000?l0
00000080003o00D000000000o`000000003o000000020000o`03000000000?l000000080003o00D0
00000?ooo`000000003o000000060?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0
1`3oool50000o`030?ooo`000?l0oooo00D0003o00<0oooo0000o`000?l01P000?l00`00o`00oooo
0?ooo`030?ooo`03003o00000?l0003o0080003o00<0oooo0000o`000?l01P000?l00`3oool0003o
0000o`0:0000o`03003o003oool0oooo0080oooo00H00?l00000o`000?l0oooo0000o`00o`050?oo
o`80003o00<0oooo0000o`000?l01P3oool00`00o`00oooo0?ooo`0@0?ooo`03003o003oool0oooo
00D0oooo00@00?l00?ooo`3oool00?l01`3oool01000o`00oooo0?ooo`3oool2003o01X0oooo00<0
0?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`0:0?ooo`04003o003oool0oooo003o00d0oooo
00<00?l00?ooo`3oool03`3oool01@00o`00oooo0?ooo`3oool00?l000@0oooo00<0003o003o003o
ool03`3oool00`00o`00oooo0?ooo`020?ooo`80000000<00?l0000000000000503oool2003o01/0
oooo0P00o`040?ooo`03003o003oool0oooo06P0oooo00<000000?ooo`3oool0703oool003h0oooo
0`00000;0?ooo`@00000>03oool01@000000003o000000000?l000000080003o00<000000000o`00
0000I`3oool4000000H0oooo00<000000000o`000000X`3oool3000001/0oooo100000040?ooo`03
000000000?l00000008000000P000?l010000000003o0000003oool4000000040000o`000000003o
00000080003o00<000000000o`0000000P000?l01@000000003o000000000?l000000080003o00D0
00000000o`000000003o000000020000o`03000000000?l0000000<0000000@0oooo000000000000
00001@3oool2000008H0oooo00<000000?ooo`3oool0703oool01@000?l00?l00?ooo`3oool00?l0
0080oooo00<00?l00000o`3oool0603oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo
0080oooo00<00?l00?ooo`3oool00`3oool20000o`030?ooo`000?l00?l000H0oooo00<00?l00?oo
o`3oool0403oool00`00o`00oooo0?ooo`050?ooo`04003o003oool0oooo003o00L0oooo00@00?l0
0?ooo`3oool0oooo0P00o`0J0?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool02P3o
ool01000o`00oooo0?ooo`00o`0=0?ooo`03003o003oool0oooo00`0oooo00@0003o0?ooo`3oool0
0?l00`3oool00`00o`00oooo0?ooo`020?ooo`030000o`00o`00oooo00l0oooo00<00?l00?ooo`3o
ool00P3oool200000003003o00000000000001@0oooo0P00o`0K0?ooo`800?l0103oool00`00o`00
oooo0?ooo`1X0?ooo`030000003oool0oooo01`0oooo000n0?ooo`030000003oool0oooo04L0oooo
00D000000000o`000000003o000000020000o`03000000000?l000000740oooo00<000000000o`00
0000b@3oool01@000000003o0000003oool000000080003o00<000000000o`000000103oool01@00
0000003o000000000?l000000080003o00<000000000o`0000000P000?l01@000000003o00000000
0?l000000080003o00D000000000o`000000003o000000020000o`03000000000?l0000000d0oooo
00<000000?ooo`3oool0Q03oool2000001d0oooo00T0003o003o003oool00?l00?ooo`00o`00oooo
003o00000?l06@3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo0080oooo00<00?l0
0?ooo`3oool00`3oool2003o00030?ooo`00o`000?l000H0oooo00<00?l00?ooo`3oool0403oool0
0`00o`00oooo0?ooo`050?ooo`04003o003oool0oooo003o00L0oooo00@00?l00?ooo`3oool0oooo
0P00o`0J0?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool02P3oool01000o`00oooo
0?ooo`00o`0=0?ooo`03003o003oool0oooo00`0oooo00@00?l00?ooo`3oool00?l00`3oool00`00
o`00oooo0?ooo`020?ooo`030000o`00o`00oooo00l0oooo00<00?l00?ooo`000000100000000`00
o`0000000000000D0?ooo`800?l06`3oool2003o00@0oooo00<00?l00?ooo`3oool0J03oool00`00
0000oooo0?ooo`0L0?ooo`00?P3oool00`000000oooo0?ooo`170?ooo`05000000000?l000000000
o`0000000P000?l00`000000003o0000001a0?ooo`03000000000?l000000<T0oooo00D000000000
o`000000oooo000000020000o`03000000000?l0000000@0oooo00D000000000o`000000003o0000
00020000o`03000000000?l000000080003o00D000000000o`000000003o000000020000o`050000
00000?l000000000o`0000000P000?l00`000000003o0000000=0?ooo`030000003oool0oooo08@0
oooo00<000000?ooo`3oool0703oool010000?l0oooo003o0000o`020?ooo`800?l000<0003o0?oo
o`3oool05`3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo0080oooo00<00?l00?oo
o`3oool00`3oool2003o00030?ooo`00o`000?l000H0oooo00<00?l00?ooo`3oool0403oool00`00
o`00oooo0?ooo`050?ooo`04003o003oool0oooo003o00L0oooo00@00?l00?ooo`3oool0oooo0P00
o`0J0?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool02P3oool01000o`00oooo0?oo
o`00o`0=0?ooo`03003o003oool0oooo00`0oooo00@00?l00?ooo`3oool00?l00`3oool00`00o`00
oooo0?ooo`020?ooo`030000o`00o`00oooo00l0oooo00<00?l00000000000001@0000000`00o`00
00000?ooo`0C0?ooo`800?l06`3oool2003o00@0oooo00<00?l00?ooo`3oool0J03oool00`000000
oooo0?ooo`0L0?ooo`00?P3oool00`000000oooo0?ooo`170?ooo`05000000000?l000000000o`00
00000P000?l00`000000003o0000001a0?ooo`03000000000?l000000<T0oooo00D000000000o`00
0000oooo000000020000o`03000000000?l0000000@0oooo00D000000000o`000000003o00000002
0000o`03000000000?l000000080003o00D000000000o`000000003o000000020000o`0500000000
0?l000000000o`0000000P000?l00`000000003o0000000=0?ooo`030000003oool0oooo08@0oooo
00<000000?ooo`3oool0703oool00`000?l0oooo0?ooo`040?ooo`03003o00000?l0oooo01P0oooo
00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo00<0oooo
0P00o`000`3oool00?l0003o00060?ooo`03003o003oool0oooo0100oooo00<00?l00?ooo`3oool0
1@3oool01000o`00oooo0?ooo`00o`070?ooo`040000o`00o`00oooo0?ooo`800?l06P3oool00`00
o`00oooo0?ooo`030?ooo`03003o003oool0oooo00X0oooo00@00?l00?ooo`3oool00?l03@3oool0
0`00o`00oooo0?ooo`0<0?ooo`04003o003oool0oooo003o00<0oooo00<00?l00?ooo`3oool00`3o
ool00`00o`00oooo0?ooo`0=0?ooo`0300000000o`00000000H0000000<00?l00000003oool04`3o
ool2003o01/0oooo0P00o`040?ooo`03003o003oool0oooo06P0oooo00<000000?ooo`3oool0703o
ool003h0oooo00<000000?ooo`3oool0A`3oool01@000000003o000000000?l000000080003o00<0
00000000o`000000L@3oool00`000000003o000000390?ooo`05000000000?l000000?ooo`000000
0P000?l00`000000003o000000040?ooo`05000000000?l000000000o`0000000P000?l00`000000
003o000000020000o`05000000000?l000000000o`0000000P000?l01@000000003o000000000?l0
00000080003o00<000000000o`0000003@3oool00`000000oooo0?ooo`240?ooo`030000003oool0
oooo00X0oooo1@00000=0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool05`3oool0
0`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool00`3oool2
003o00030?ooo`00o`000?l000H0oooo00<00?l00?ooo`3oool0403oool00`00o`00oooo0?ooo`05
0?ooo`04003o003oool0oooo003o00L0oooo00@0003o003o003oool0oooo0P00o`0J0?ooo`03003o
003oool0oooo00<0oooo00<00?l00?ooo`3oool02P3oool01000o`00oooo0?ooo`00o`0=0?ooo`03
003o003oool0oooo00`0oooo00@00?l00?ooo`3oool00?l00`3oool00`00o`00oooo0?ooo`030?oo
o`030000o`00o`00oooo00d0oooo00<00000003o000000001P0000000`00o`00oooo0?ooo`0C0?oo
o`800?l06`3oool2003o00@0oooo00<00?l00?ooo`3oool0J03oool00`000000oooo0?ooo`0L0?oo
o`00?P3oool00`000000oooo0?ooo`170?ooo`05000000000?l000000000o`0000000P000?l00`00
0000003o0000001a0?ooo`03000000000?l000000<T0oooo00D000000000o`000000oooo00000002
0000o`03000000000?l0000000@0oooo00D000000000o`000000003o000000020000o`0300000000
0?l000000080003o00D000000000o`000000003o000000020000o`05000000000?l000000000o`00
00000P000?l00`000000003o0000000=0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3o
ool02P3oool5000000d0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0G0?ooo`03
003o003oool0oooo0080oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`030?ooo`80
0?l000<0oooo003o0000o`001P3oool00`00o`00oooo0?ooo`0@0?ooo`03003o003oool0oooo00D0
oooo00@00?l00?ooo`3oool00?l01`3oool010000?l00?l00?ooo`3oool2003o01X0oooo00<00?l0
0?ooo`3oool00`3oool00`00o`00oooo0?ooo`0:0?ooo`04003o003oool0oooo003o00`0oooo00<0
003o003o003oool03@3oool01000o`00oooo0?ooo`00o`030?ooo`03003o003oool0oooo00<0oooo
00<0003o003o003oool03@3oool00`0000000?l00000o`0600000005003o003oool0oooo0?ooo`00
0?l04@3oool2003o01/0oooo0P00o`040?ooo`03003o003oool0oooo06P0oooo00<000000?ooo`3o
ool0703oool003h0oooo00<000000?ooo`3oool0A`3oool01@000000003o000000000?l000000080
003o00<000000000o`000000L@3oool00`000000003o000000390?ooo`05000000000?l000000?oo
o`0000000P000?l00`000000003o000000040?ooo`05000000000?l000000000o`0000000P000?l0
0`000000003o000000020000o`05000000000?l000000000o`0000000P000?l01@000000003o0000
00000?l000000080003o00<000000000o`0000003@3oool00`000000oooo0?ooo`240?ooo`030000
003oool0oooo00X0oooo1@00000=0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0
5`3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool0
0`3oool2003o00030?ooo`00o`000?l000H0oooo00<00?l00?ooo`3oool0403oool00`00o`00oooo
0?ooo`050?ooo`04003o003oool0oooo003o00P0oooo00<00?l00?ooo`3oool00P00o`0J0?ooo`03
003o003oool0oooo00<0oooo00<00?l00?ooo`3oool02P3oool01000o`00oooo0?ooo`00o`0<0?oo
o`030000o`00o`00oooo00d0oooo00@00?l00?ooo`3oool00?l00`3oool00`00o`00oooo0?ooo`03
0?ooo`030000o`00o`00003o00d0oooo00<00000003o00000?l01@0000000`000?l00?l00?ooo`02
0?ooo`030000o`3oool0oooo00l0oooo0P00o`0K0?ooo`800?l0103oool00`00o`00oooo0?ooo`1X
0?ooo`030000003oool0oooo01`0oooo000n0?ooo`<00000A`3oool01@000000003o000000000?l0
00000080003o00<000000000o`000000L@3oool300000<T0oooo00D000000000o`000000oooo0000
00020000o`<00000103oool01@000000003o000000000?l000000080003o00<000000000o`000000
0P000?l01@000000003o000000000?l000000080003o00D000000000o`000000003o000000020000
o`<00000303oool2000008H0oooo0P00000;0?ooo`D000003@3oool00`000?l0oooo0?ooo`050?oo
o`030000o`3oool0oooo01L0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`020?oo
o`03003o003oool0oooo00<0oooo0P00o`000`3oool00?l0003o00060?ooo`03003o003oool0oooo
0100oooo00<00?l00?ooo`3oool01@3oool01000o`00oooo0?ooo`00o`080?ooo`03003o003oool0
oooo00800?l06P3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo00X0oooo00@00?l0
0?ooo`3oool00?l0303oool00`000?l00?l00000o`0=0?ooo`04003o003oool0oooo003o00<0oooo
00<00?l00?ooo`3oool00`3oool00`000?l00?l00000o`0=0?ooo`0300000000o`00003o00@00000
0P000?l01@00o`00oooo0?ooo`000?l00?l00140oooo0P00o`0K0?ooo`800?l0103oool00`00o`00
oooo0?ooo`1X0?ooo`030000003oool0oooo01`0oooo000n0?ooo`030000003oool0oooo04L0oooo
00D000000000o`000000003o000000020000o`03000000000?l000000?l0oooo?P3oool01@000000
003o0000003oool000000080003o00<000000?ooo`3oool0103oool01@000000003o000000000?l0
00000080003o00<000000000o`0000000P000?l01@000000003o000000000?l000000080003o00D0
00000000o`000000003o000000020000o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
Q03oool00`000000oooo0?ooo`0:0?ooo`D000003@3oool00`000?l0oooo0?ooo`050?ooo`030000
o`3oool0oooo01L0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`020?ooo`03003o
003oool0oooo00<0oooo0P00o`000`3oool00?l0003o00060?ooo`03003o003oool0oooo0100oooo
00<00?l00?ooo`3oool01@3oool01000o`00oooo0?ooo`00o`080?ooo`03003o003oool0oooo0080
0?l06P3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo00X0oooo00@00?l00?ooo`3o
ool00?l0303oool00`000?l00?l00000o`0=0?ooo`04003o003oool0oooo003o00<0oooo00<00?l0
0?ooo`3oool0103oool00`000?l00?l00?ooo`0=0?ooo`06003o00000?l0oooo0?ooo`000000003o
0P0000001@00o`00oooo0?ooo`000?l00?l00140oooo0P00o`0K0?ooo`800?l0103oool00`00o`00
oooo0?ooo`1X0?ooo`030000003oool0oooo01`0oooo000n0?ooo`030000003oool0oooo04L0oooo
00D000000000o`000000003o000000020000o`03000000000?l000000?l0oooo?P3oool01@000000
003o0000003oool000000080003o00<000000?ooo`3oool0103oool01@000000003o000000000?l0
00000080003o00<000000000o`0000000P000?l01@000000003o000000000?l000000080003o00D0
00000000o`000000003o000000020000o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
Q03oool00`000000oooo0?ooo`0L0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0
5`3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool0
0`3oool2003o00030?ooo`00o`000?l000H0oooo00<00?l00?ooo`3oool0403oool00`00o`00oooo
0?ooo`050?ooo`04003o003oool0oooo003o00P0oooo00<00?l00?ooo`3oool00P00o`0J0?ooo`03
003o003oool0oooo00<0oooo00<00?l00?ooo`3oool02P3oool01000o`00oooo0?ooo`00o`050?oo
o`030000o`3oool0oooo00@0oooo0P00o`000`000?l0oooo0?ooo`0;0?ooo`04003o003oool0oooo
003o00<0oooo00<00?l00?ooo`3oool01@3oool00`00o`00oooo0?ooo`0<0?ooo`06003o00000?l0
oooo0000o`3oool0003o0P3oool01`00o`00oooo0?ooo`000?l00?l00?ooo`000?l03`3oool2003o
01/0oooo0P00o`040?ooo`03003o003oool0oooo06P0oooo00<000000?ooo`3oool0703oool003h0
oooo00<000000?ooo`3oool0A`3oool01@000000003o000000000?l000000080003o00<000000000
o`000000o`3oooln0?ooo`05000000000?l000000?ooo`0000000P000?l00`000000oooo0?ooo`04
0?ooo`05000000000?l000000000o`0000000P000?l00`000000003o000000020000o`0500000000
0?l000000000o`0000000P000?l01@000000003o000000000?l000000080003o00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo01`0oooo00<0003o0?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`0G0?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3o
ool00P3oool00`00o`00oooo0?ooo`030?ooo`800?l000<0oooo003o0000o`001P3oool00`00o`00
oooo0?ooo`0@0?ooo`03003o003oool0oooo00D0oooo00@00?l00?ooo`3oool00?l0203oool00`00
o`00oooo0?ooo`02003o01X0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`0:0?oo
o`04003o003oool0oooo003o00D0oooo00<0003o0?ooo`3oool0103oool2003o00030000o`3oool0
oooo00/0oooo00L00?l00?ooo`3oool00?l00000o`3oool00?l000P0oooo00<00?l00?ooo`3oool0
303oool00`00o`00oooo0000o`020000o`<0oooo00L00?l00000o`000?l0oooo003o003oool0003o
00l0oooo0P00o`0K0?ooo`800?l0103oool00`00o`00oooo0?ooo`1X0?ooo`030000003oool0oooo
01`0oooo000n0?ooo`030000003oool0oooo04L0oooo00D000000000o`000000003o000000020000
o`03000000000?l000000?l0oooo?P3oool01@000000003o0000003oool000000080003o00<00000
0?ooo`3oool0103oool01@000000003o000000000?l000000080003o00<000000000o`0000000P00
0?l01@000000003o000000000?l000000080003o00D000000000o`000000003o000000020000o`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`0L0?ooo`03
0000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool05`3oool00`00o`00oooo0?ooo`020?ooo`03
003o003oool0oooo0080oooo00<00?l00?ooo`3oool00`3oool2003o00030?ooo`00o`000?l000H0
oooo00<00?l00?ooo`3oool0403oool00`00o`00oooo0?ooo`050?ooo`04003o003oool0oooo003o
00P0oooo00<00?l00?ooo`000?l00P00o`0J0?ooo`03003o003oool0oooo00<0oooo00<00?l00?oo
o`3oool02P3oool01000o`00oooo0?ooo`00o`050?ooo`030000o`3oool0oooo00@0oooo00<00?l0
0?ooo`00o`003@3oool00`00o`00oooo0?ooo`02003o00030?ooo`00o`00oooo00L0oooo00<00?l0
0?ooo`3oool0303oool01@00o`00oooo0?ooo`3oool0003o00<0oooo00<00?l00?ooo`3oool00P00
o`000`3oool0003o0?ooo`0>0?ooo`800?l06P3oool00`000?l00?l0003o00040?ooo`03003o003o
ool0oooo06P0oooo00<000000?ooo`3oool0703oool003<0oooo0`0000080?ooo`030000003oool0
oooo04L0oooo00D000000000o`000000003o000000020000o`03000000000?l000000?l0oooo?P3o
ool01@000000003o0000003oool000000080003o00<000000?ooo`3oool0103oool01@000000003o
000000000?l000000080003o00<000000000o`0000000P000?l01@000000003o000000000?l00000
0080003o00D000000000o`000000003o000000020000o`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0Q03oool00`000000oooo0?ooo`0L0?ooo`030000o`3oool0oooo00D0oooo00<0003o
0?ooo`3oool05`3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo0080oooo00<00?l0
0?ooo`3oool00`3oool2003o00030?ooo`00o`000?l000H0oooo00<00?l00?ooo`3oool0403oool0
0`00o`00oooo0?ooo`050?ooo`04003o003oool0oooo003o00P0oooo00<00?l00?ooo`000?l00P00
o`000`000?l0oooo0?ooo`0G0?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool02P3o
ool01000o`00oooo0?ooo`00o`050?ooo`030000o`3oool0oooo00@0oooo00<00?l00?ooo`00o`00
3@3oool00`00o`00oooo0?ooo`02003o00030?ooo`00o`00oooo00L0oooo00<00?l00?ooo`3oool0
2`3oool00`00o`00003o0?ooo`060?ooo`03003o003oool0oooo00800?l000<0oooo0000o`3oool0
3P3oool2003o01X0oooo00<0003o003o0000o`00103oool00`00o`00oooo0?ooo`1X0?ooo`030000
003oool0oooo01`0oooo000f0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0A`3o
ool01@000000003o000000000?l000000080003o00<000000000o`000000o`3oooln0?ooo`050000
00000?l000000?ooo`0000000P000?l00`000000oooo0?ooo`040?ooo`05000000000?l000000000
o`0000000P000?l00`000000003o000000020000o`05000000000?l000000000o`0000000P000?l0
1@000000003o000000000?l000000080003o00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`240?ooo`030000003oool0oooo01`0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?oo
o`0G0?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?oo
o`030?ooo`800?l000<0oooo003o0000o`001P3oool00`00o`00oooo0?ooo`0@0?ooo`03003o003o
ool0oooo00H0oooo0P00o`090?ooo`03003o003oool0003o00800?l000<0003o0?ooo`3oool05P3o
ool00`000?l00?l00?ooo`040?ooo`03003o00000?l0oooo00X0oooo00D00?l00?ooo`3oool00?l0
0000o`040?ooo`030000o`3oool0oooo00@0oooo00<00?l00?ooo`00o`003@3oool00`00o`00oooo
0?ooo`02003o00030?ooo`00o`00oooo00L0oooo00<00?l00?ooo`3oool02`3oool00`00o`00oooo
0?ooo`060?ooo`03003o003oool0oooo00800?l000<0oooo0000o`3oool03P3oool2003o01X0oooo
00<0003o003o0000o`00103oool00`00o`00oooo0?ooo`1X0?ooo`030000003oool0oooo01`0oooo
000f0?ooo`030000003oool0oooo00D0oooo100000160?ooo`05000000000?l000000000o`000000
0P000?l00`000000003o0000003o0?oooch0oooo0`0000001@3oool000000000o`000?l0000000H0
oooo00D000000000o`000000003o000000020000o`03000000000?l000000080003o00D000000000
o`000000003o000000020000o`05000000000?l000000000o`0000000P000?l00`000000oooo0?oo
o`0;0?ooo`<00000QP3oool2000001h0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?oo
o`0H0?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?oo
o`030?ooo`800?l000<0oooo003o0000o`001P3oool00`00o`00oooo0?ooo`0@0?ooo`03003o003o
ool0oooo00H0oooo0P00o`090?ooo`03003o003oool0003o00800?l000<0003o0?ooo`3oool05P3o
ool00`00o`00oooo0?ooo`040?ooo`03003o00000?l0oooo00X0oooo00D00?l00?ooo`3oool0oooo
003o00030?ooo`030000o`00o`00oooo00D0oooo00<00?l00?ooo`00o`003@3oool00`00o`00oooo
0?ooo`02003o00030?ooo`00o`00oooo00L0oooo00<00?l00?ooo`3oool02`3oool00`00o`00oooo
0?ooo`060?ooo`03003o003oool0oooo00800?l000<0oooo0000o`3oool03P3oool2003o01X0oooo
00<0003o003o0000o`00103oool00`00o`00oooo0?ooo`1X0?ooo`030000003oool0oooo01`0oooo
000c0?ooo`<00000203oool00`000000oooo0?ooo`170?ooo`05000000000?l000000000o`000000
0P000?l00`000000003o0000003o0?oood80oooo00@000000000o`000?l000001P3oool01@000000
003o000000000?l000000080003o00<000000000o`0000000P000?l01@000000003o000000000?l0
00000080003o00D000000000o`000000003o000000020000o`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0Q03oool00`000000oooo0?ooo`0M0?ooo`030000o`3oool0oooo00<0oooo00<0
003o0?ooo`3oool0503oool400000003003o003oool0oooo0080oooo00<00?l00?ooo`3oool00P3o
ool00`00o`00oooo0?ooo`030?ooo`800?l000<0oooo003o0000o`001P3oool00`00o`00oooo0?oo
o`0@0?ooo`03003o003oool0oooo00H0oooo0P00o`090?ooo`06003o003oool00?l00?ooo`00o`00
003o603oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0oooo00T0oooo00D00?l00?ooo`3o
ool0oooo003o00030?ooo`030000o`00o`00003o00D0oooo00<00?l00?ooo`00o`003@3oool00`00
o`00oooo0?ooo`02003o00030?ooo`00o`00oooo00L0oooo00<00?l00?ooo`3oool02`3oool00`00
o`00oooo0?ooo`070?ooo`@00?l000<0oooo0000o`3oool03P3oool2003o01X0oooo00<0003o003o
0000o`00103oool00`00o`00oooo0?ooo`1X0?ooo`030000003oool0oooo01`0oooo000c0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0A`3oool01@000000003o000000000?l00000
0080003o00<000000000o`000000o`3ooom20?ooo`04000000000?l0003o000000H0oooo00D00000
0000o`000000003o000000020000o`03000000000?l000000080003o00D000000000o`000000003o
000000020000o`05000000000?l000000000o`0000000P000?l00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo08@0oooo00<000000?ooo`3oool07@3oool00`000?l0oooo0?ooo`030?ooo`03
0000o`3oool0oooo01@0oooo100000000`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo0080
oooo00<00?l00?ooo`3oool00`3oool2003o00030?ooo`00o`000?l000H0oooo00<00?l00?ooo`3o
ool0403oool00`00o`00oooo0?ooo`060?ooo`800?l02@3oool00`00o`00oooo003o00020?ooo`03
003o003oool0oooo01H0oooo00<00?l00?ooo`3oool01@3oool00`00o`00oooo0?ooo`090?ooo`05
003o003oool0oooo0?ooo`00o`000`3oool00`000?l00?l00000o`050?ooo`03003o003oool00?l0
00d0oooo00<00?l00?ooo`3oool00P00o`000`3oool00?l00?ooo`070?ooo`03003o003oool0oooo
00/0oooo00<00?l00?ooo`3oool02P3oool00`00o`00oooo003o000?0?ooo`800?l06P3oool00`00
o`00oooo003o00040?ooo`03003o003oool0oooo06P0oooo00<000000?ooo`3oool0703oool003<0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`170?ooo`05000000000?l000000000
o`0000000P000?l00`000000003o0000003o0?oood80oooo00@000000000o`000?l000001P3oool0
1@000000003o000000000?l000000080003o00<000000000o`0000000P000?l01@000000003o0000
00000?l000000080003o00D000000000o`000000003o000000020000o`030000003oool0oooo00d0
oooo00<000000?ooo`3oool0D03oool4000000P0oooo0P0000080?ooo`P00000103oool6000000`0
oooo00<000000?ooo`3oool07@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo01@0
oooo100000000`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3o
ool00`3oool2003o00030?ooo`00o`000?l000H0oooo00<00?l00?ooo`3oool0403oool00`00o`00
oooo0?ooo`060?ooo`800?l02@3oool00`00o`00oooo003o00020?ooo`03003o003oool0oooo01H0
oooo00<00?l00?ooo`3oool01@3oool00`00o`00oooo0?ooo`090?ooo`05003o003oool0oooo0?oo
o`00o`000`3oool00`000?l00?l0003o00050?ooo`03003o003oool00?l000d0oooo00<00?l00?oo
o`3oool00P00o`000`3oool00?l00?ooo`070?ooo`03003o003oool0oooo00/0oooo00<00?l00?oo
o`3oool02P3oool00`00o`00oooo003o000?0?ooo`800?l06P3oool00`00o`00oooo003o00040?oo
o`03003o003oool0oooo06P0oooo00<000000?ooo`3oool0703oool003<0oooo100000070?ooo`03
0000003oool0oooo04L0oooo00D000000000o`000000003o000000020000o`03000000000?l00000
0?l0oooo@P3oool010000000003o0000o`0000060?ooo`05000000000?l000000000o`0000000P00
0?l00`000000003o000000020000o`05000000000?l000000000o`0000000P000?l01@000000003o
000000000?l000000080003o00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1@0?ooo`@0
0000203oool2000000P0oooo200000040?ooo`H00000303oool00`000000oooo0?ooo`0M0?ooo`03
0000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool02`3oool=00000003003o00000000oooo0080
oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`030?ooo`800?l000<0oooo003o0000
o`001P3oool00`00o`00oooo0?ooo`0@0?ooo`04003o003oool0oooo0?ooo`D000000P00o`090?oo
o`03003o003oool00?l00080oooo00<00?l00?ooo`3oool05P3oool00`00o`00oooo0?ooo`050?oo
o`03003o003oool0oooo00T0oooo00D00?l00?ooo`3oool0oooo003o00030?ooo`050000o`00o`00
0?l00?ooo`000?l00`3oool00`00o`00oooo003o000=0?ooo`03003o003oool0oooo00800?l000<0
oooo003o003oool01`3oool00`00o`00oooo0?ooo`090?ooo`80000000<00?l00000000000002P3o
ool00`00o`00oooo003o000?0?ooo`800?l06P3oool00`00o`00oooo003o00040?ooo`03003o003o
ool0oooo06P0oooo00<000000?ooo`3oool0703oool003h0oooo00<000000?ooo`3oool0A`3oool0
1@000000003o000000000?l000000080003o00<000000000o`000000o`3ooom20?ooo`0400000000
0?l0003o000000H0oooo00D000000000o`000000003o000000020000o`03000000000?l000000080
003o00D000000000o`000000003o000000020000o`05000000000?l000000000o`0000000P000?l0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo04h0oooo0P0000040?ooo`800000403oool2
00000100oooo0P00000:0?ooo`030000003oool0oooo00P0oooo4P0000030?ooo`030000o`3oool0
oooo0080oooo00<000000000o`0000006@0000000`00o`0000000?ooo`020?ooo`03003o003oool0
oooo0080oooo00<00?l00?ooo`3oool00`3oool2003o00030?ooo`00o`000?l000H0oooo00<00?l0
0?ooo`3oool03P3oool200000003003o00000000000000H000000P00o`0900000003003o003oool0
0?l00080oooo00<00?l00?ooo`3oool05P3oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0
oooo00P0oooo00<00000003o000000000P0000002@00o`00oooo0?ooo`3oool0003o003o00000?l0
0?l00000o`030?ooo`03003o003oool00?l000d0oooo00<00?l00?ooo`3oool00P00o`000`3oool0
0?l00?ooo`070?ooo`03003o003oool0oooo00T0oooo0P0000000`00o`0000000000000:0?ooo`03
003o003oool00?l000l0oooo0P00o`0J0?ooo`03003o003oool00?l000@0oooo00<00?l00?ooo`3o
ool0J03oool00`000000oooo0?ooo`0L0?ooo`00?P3oool00`000000oooo0?ooo`170?ooo`050000
00000?l000000000o`0000000P000?l00`000000003o0000003o0?oood80oooo00@000000000o`00
0?l000001P3oool01@000000003o000000000?l000000080003o00<000000000o`0000000P000?l0
1@000000003o000000000?l000000080003o00D000000000o`000000003o000000020000o`030000
003oool0oooo00d0oooo00<000000?ooo`3oool0CP3oool2000000@0oooo0P00000@0?ooo`800000
403oool2000000X0oooo0`0000040?oooaH000000`3oool00`000?l0oooo0?ooo`020?ooo`030000
00000?l0000001T0000000<00?l00000003oool00P3oool00`00o`00oooo0?ooo`020?ooo`03003o
003oool0oooo00<0oooo0P00o`000`3oool00?l0003o00060?ooo`03003o003oool0oooo00h0oooo
0P0000000`00o`00000000000006000000800?l02@0000000`00o`000000003o00020?ooo`03003o
003oool0oooo01D0oooo00<00000003o00000000100000020?ooo`03003o003oool0oooo00L0oooo
0P0000001@00o`0000000000000000000?l000<0oooo00H00?l00?ooo`3oool00?l00?ooo`000?l2
0?ooo`03003o003oool00?l000d0oooo00<00?l00?ooo`3oool00P00o`000`3oool00?l00?ooo`07
0?ooo`03003o00000?l0oooo00T0oooo0P0000000`00o`0000000000000:0?ooo`03003o003oool0
0?l000l0oooo0P00o`0J0?ooo`03003o003oool00?l000@0oooo00<00?l00?ooo`3oool0J03oool0
0`000000oooo0?ooo`0L0?ooo`00?P3oool00`000000oooo0?ooo`170?ooo`05000000000?l00000
0000o`0000000P000?l00`000000003o0000003o0?oood80oooo00@000000000o`000?l000001P3o
ool01@000000003o000000000?l000000080003o00<000000000o`0000000P000?l01@000000003o
000000000?l000000080003o00D000000000o`000000003o000000020000o`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0CP3oool2000000@0oooo0P00000B0?ooo`8000003P3oool20000
00X0oooo00<000000?ooo`3oool0103ooolF000000<0oooo00<0003o0?ooo`3oool00P3oool00`00
0000003o0000000I00000003003o00000000oooo0080oooo00<00?l00?ooo`3oool00P3oool00`00
o`00oooo0?ooo`030?ooo`800?l000<0oooo003o0000o`001P3oool00`00o`00oooo0?ooo`0>0?oo
o`80000000<00?l00000000000001P000002003o00T0000000<00?l00000o`00o`000P3oool00`00
o`00oooo0?ooo`0E0?ooo`0300000000o`00000000@000000P3oool00`00o`00oooo0?ooo`070?oo
o`80000000D00?l00000000000000000003o00030?ooo`06003o003oool0oooo003o003oool0003o
0P3oool00`00o`00oooo003o000=0?ooo`03003o00000000000000800?l000<00000003o00000000
0P0000050?ooo`03003o00000?l0oooo00T0oooo0P0000000`00o`0000000000000:0?ooo`03003o
003oool00?l000h0oooo00@0003o003o0000o`00003o6@3oool00`00o`00oooo003o00040?ooo`03
003o003oool0oooo06P0oooo00<000000?ooo`3oool0703oool003h0oooo0`0000170?ooo`050000
00000?l000000000o`0000000P000?l00`000000003o0000003o0?oood80oooo100000060?ooo`05
000000000?l000000000o`0000000P000?l00`000000003o000000020000o`05000000000?l00000
0000o`0000000P000?l01@000000003o000000000?l000000080003o00<000000?ooo`3oool0303o
ool200000500oooo0P0000040?ooo`8000004P3oool2000000h0oooo0P00000:0?ooo`030000003o
ool0oooo00@0oooo5P0000030?ooo`030000o`3oool0oooo0080oooo00<000000000o`0000006@00
00000`00o`0000000?ooo`020?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool00`3o
ool2003o00030?ooo`00o`000?l000H0oooo00<00?l00?ooo`3oool03P3oool200000003003o0000
0000000000H000000P00o`0900000003003o00000?l00?l00080oooo00<00?l00?ooo`3oool05@3o
ool00`0000000?l00000000400000080oooo00<00?l00?ooo`3oool01`3oool200000005003o0000
0000000000000000o`000`3oool01P00o`00oooo0?ooo`00o`00oooo0000o`80oooo00<00?l00?oo
o`00o`00303oool010000?l00?l0000000000?l2003o00030000o`00o`000000008000001@3oool0
0`00o`00003o0?ooo`090?ooo`80000000<00?l00000000000002P3oool00`00o`00oooo003o000>
0?ooo`040000o`00o`000?l00000oaT0oooo00<00?l00?ooo`00o`00103oool00`00o`00oooo0?oo
o`1X0?ooo`030000003oool0oooo01`0oooo000n0?ooo`030000003oool0oooo04L0oooo00D00000
0000o`000000003o000000020000o`03000000000?l000000?l0ooooC03oool01@000000003o0000
00000?l000000080003o00<000000000o`0000000P000?l01@000000003o000000000?l000000080
003o00D000000000o`000000003o000000020000o`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0CP3oool2000000@0oooo0P00000D0?ooo`8000001P3oool6000000`0oooo00<000000?oo
o`3oool0103ooolF000000<0oooo00<0003o0?ooo`3oool00P3oool00`000000003o0000000I0000
0003003o003oool0oooo0080oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`030?oo
o`800?l000<0oooo003o0000o`001P3oool00`00o`00oooo0?ooo`0>0?ooo`80000000<00?l00000
000000001P000002003o00T0000000<00?l00000o`00o`000P3oool00`00o`00oooo0?ooo`0E0?oo
o`0300000000o`00000000@000000P3oool00`00o`00oooo0?ooo`070?ooo`80000000D00?l00000
000000000000003o00030?ooo`06003o003oool0oooo0?ooo`00o`00003o0P3oool00`00o`00oooo
003o000<0?ooo`080000o`00o`00003o003o000000000?l000000000o`03000000D0oooo00<00?l0
0000o`3oool02`3oool00`00o`00oooo0?ooo`0:0?ooo`03003o003oool00?l000h0oooo00@0003o
003o0000o`00003o6@3oool00`00o`00oooo003o00040?ooo`03003o003oool0oooo06P0oooo00<0
00000?ooo`3oool0703oool003h0oooo00<000000?ooo`3oool0A`3oool01@000000003o00000000
0?l000000080003o00<000000000o`000000o`3ooom<0?ooo`05000000000?l000000000o`000000
0P000?l00`000000003o000000020000o`05000000000?l000000000o`0000000P000?l01@000000
003o000000000?l000000080003o00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1>0?oo
o`800000103oool2000001@0oooo0P0000060?ooo`H00000303oool00`000000oooo0?ooo`040?oo
o`l000002P3oool00`000?l0oooo0?ooo`030?ooo`040000o`3oool0oooo0?ooo`L00000403oool0
0`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool00`3oool2
003o00030?ooo`00o`000?l000H0oooo00<00?l00?ooo`3oool0403oool00`00o`00000000000006
000000800?l02@0000000`00o`00003o003o00020?ooo`03003o003oool0003o01D0oooo00<00000
003o00000000100000020?ooo`03003o003oool0oooo00L0oooo0P0000001@00o`00000000000000
00000?l000<0oooo00H00?l00?ooo`3oool0oooo003o00000?l20?ooo`03003o003oool00?l000`0
oooo00P0003o003o00000?l00?l000000000o`000000003o00<000001@3oool00`00o`00003o0?oo
o`0;0?ooo`03003o003oool0oooo00X0oooo00@00?l00?ooo`00o`00003o3@3oool010000?l00?l0
003o00000?lI0?ooo`03003o003oool00?l000@0oooo00<00?l00?ooo`3oool0J03oool00`000000
oooo0?ooo`0L0?ooo`00?P3oool00`000000oooo0?ooo`170?ooo`05000000000?l000000000o`00
00000P000?l00`000000003o0000003o0?oood`0oooo00D000000000o`000000003o000000020000
o`03000000000?l000000080003o00D000000000o`000000003o000000020000o`05000000000?l0
00000000o`0000000P000?l00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo04h0oooo0P00
00040?ooo`8000005P3oool2000000@0oooo0P00000@0?ooo`030000003oool0oooo01d0oooo00<0
003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0H0?ooo`03003o003oool0oooo0080oooo00<0
0?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`030?ooo`800?l000<0oooo003o0000o`001P3o
ool00`00o`00oooo0?ooo`0@0?ooo`03003o003oool0oooo00H0oooo0P00o`0:0?ooo`800?l00P3o
ool01000o`00003o0?ooo`000?lE0?ooo`03003o003oool0oooo00D0oooo00<00?l00?ooo`3oool0
2@3oool01@00o`00oooo0?ooo`3oool00?l00080oooo00<0003o003o003oool00P3oool01`00o`00
003o0?ooo`000?l00?l00?ooo`00o`00303oool020000?l00?l00000o`00o`000000003o00000000
0?l00`0000050?ooo`04003o00000?l0oooo0?ooo`H0003o103oool00`00o`00oooo0?ooo`0:0?oo
o`04003o003oool00?l00000o`d0oooo00@0003o003o0000o`00003o603oool2003o00030?ooo`00
o`00oooo00<0oooo00<00?l00?ooo`3oool0J03oool00`000000oooo0?ooo`0L0?ooo`00?P3oool0
0`000000oooo0?ooo`170?ooo`05000000000?l000000000o`0000000P000?l00`000000003o0000
003o0?oood`0oooo00D000000000o`000000003o000000020000o`03000000000?l000000080003o
00D000000000o`000000003o000000020000o`05000000000?l000000000o`0000000P000?l00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo04h0oooo0P0000040?ooo`8000005P3oool20000
00@0oooo0P00000@0?ooo`030000003oool0oooo01d0oooo0P000?l40?ooo`030000o`3oool0oooo
01P0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo
00<0oooo0P00o`000`3oool00?l0003o00060?ooo`03003o003oool0oooo00H0oooo00<0003o0?oo
o`3oool01`3oool00`00o`00oooo0?ooo`060?ooo`800?l02P3oool2003o0080oooo00@00?l00?oo
o`3oool0003o5@3oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0oooo00T0oooo00D00?l0
0?ooo`3oool0oooo003o00020?ooo`030000o`00o`00oooo00<0oooo00H00?l00?ooo`000?l00?l0
0?ooo`00o`0<0?ooo`800?l000H0003o003o003oool00?l00?ooo`00o`090?ooo`04003o003oool0
oooo0000o`D0oooo0`000?l00`3oool00?l00?ooo`0;0?ooo`04003o003oool00?l00000o`d0oooo
00@0003o003o0000o`00003o603oool2003o00030?ooo`00o`00oooo00<0oooo00<00?l00?ooo`3o
ool0D`3oool20000oa<0oooo00<000000?ooo`3oool0703oool003h0oooo00<000000?ooo`3oool0
A`3oool01@000000003o000000000?l000000080003o00<000000000o`000000o`3ooom<0?ooo`05
000000000?l000000000o`0000000P000?l00`000000003o000000020000o`05000000000?l00000
0000o`0000000P000?l01@000000003o000000000?l000000080003o00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`1>0?ooo`800000103oool200000100oooo0P0000040?ooo`800000103o
ool200000100oooo0P00000N0?ooo`80003o00D0oooo0000o`000?l0oooo0000o`0J0?ooo`03003o
003oool0oooo0080oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`030?ooo`800?l0
00<0oooo003o0000o`001P3oool00`00o`00oooo0?ooo`060?ooo`030000o`3oool0oooo00L0oooo
00<00?l00?ooo`3oool01P3oool2003o00X0oooo0P00o`020?ooo`05003o003oool0oooo0?ooo`00
0?l01@3oool20000o`80oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`03
003o003oool0oooo00D0oooo00<00?l00?ooo`000?l00P000?l70?ooo`05003o003oool0oooo0?oo
o`00o`000P3oool00`000?l00?l00?ooo`030?ooo`06003o003oool0003o003o003oool00?l0303o
ool2003o00060000o`00o`00oooo003o003oool00?l02@3oool01000o`00oooo0?ooo`000?l80?oo
o`030000o`00o`00oooo00/0oooo00@00?l00?ooo`00o`00003o3@3oool01000o`00oooo003o0000
0?lH0?ooo`800?l000<0oooo003o003oool00`3oool00`00o`00oooo0?ooo`1C0?ooo`80003o4`3o
ool00`000000oooo0?ooo`0L0?ooo`00?P3oool00`000000oooo0?ooo`170?ooo`05000000000?l0
00000000o`0000000P000?l00`000000003o0000003o0?oood`0oooo00D000000000o`000000003o
000000020000o`03000000000?l000000080003o00D000000000o`000000003o000000020000o`05
000000000?l000000000o`0000000P000?l00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
04h0oooo0P0000040?ooo`800000403oool2000000@0oooo0P0000040?ooo`800000403oool00`00
0000oooo0?ooo`0O0?ooo`030000o`3oool0oooo0080003o6P3oool00`00o`00oooo0?ooo`020?oo
o`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool00`3oool2003o00030?ooo`00o`000?l0
00H0oooo00<00?l00?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`03003o003oool0oooo
00H0oooo0P00o`0:0?ooo`800?l00P3oool01000o`00oooo0?ooo`3oool30000o`030?ooo`000?l0
003o0080oooo0P000?l01P3oool0003o0?ooo`3oool0003o0?ooo`D0003o00<00?l00?ooo`3oool0
1@3oool01@00o`00003o0?ooo`3oool0003o00L0oooo00D00?l00?ooo`3oool0oooo003o00020?oo
o`030000o`00o`00oooo00<0oooo00H00?l00?ooo`000?l00?l00?ooo`00o`0<0?ooo`800?l000H0
003o003o003oool00?l00?ooo`00o`090?ooo`04003o003oool0oooo0000o`T0oooo00<00?l00?oo
o`3oool02P3oool01000o`00oooo003o00000?l=0?ooo`04003o003oool0oooo003o01P0oooo0P00
o`000`3oool00?l00?ooo`030?ooo`03003o003oool0oooo03d0oooo0P000?lD0?ooo`80003o4`3o
ool00`000000oooo0?ooo`0L0?ooo`00?P3oool3000004L0oooo00D000000000o`000000003o0000
00020000o`<00000o`3ooom<0?ooo`05000000000?l000000000o`0000000P000?l00`000000003o
000000020000o`05000000000?l000000000o`0000000P000?l01@000000003o000000000?l00000
0080003o00<000000?ooo`3oool0303oool200000580oooo1000000D0?ooo`@000001P3oool80000
00X0oooo00<000000?ooo`3oool0?P3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo
0080oooo00<00?l00?ooo`3oool00`3oool2003o00030?ooo`00o`000?l000H0oooo00<00?l00?oo
o`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`03003o003oool0oooo00H0oooo0P00o`0:0?oo
o`800?l00P3oool00`00o`00oooo0?ooo`040?ooo`030000o`3oool0003o00<0oooo00<0003o0?oo
o`3oool00P000?l70?ooo`03003o003oool0oooo00D0oooo00D00?l00?ooo`3oool0oooo0000o`07
0?ooo`09003o003oool0oooo0?ooo`00o`00003o0?ooo`000?l00?l000@0oooo00H00?l00?ooo`00
0?l00?l00?ooo`00o`0<0?ooo`05003o003oool00?l0003o003oool00`00o`090?ooo`03003o003o
ool0003o00X0oooo00<00?l00?ooo`3oool02P3oool01000o`00oooo003o00000?l=0?ooo`04003o
003oool0oooo003o01P0oooo0P00o`000`3oool00?l00?ooo`030?ooo`03003o003oool0oooo03d0
oooo0P000?l90?ooo`800?l02@3oool20000oa<0oooo00<000000?ooo`3oool0703oool003h0oooo
00<000000?ooo`3oool0A`3oool01@000000003o000000000?l000000080003o00<000000?ooo`3o
ool0o`3ooom<0?ooo`05000000000?l000000000o`0000000P000?l00`000000003o000000020000
o`05000000000?l000000000o`0000000P000?l01@000000003o000000000?l000000080003o00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`1@0?ooo`@00000503oool4000000H0oooo2000
000:0?ooo`030000003oool0oooo03h0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?oo
o`020?ooo`03003o003oool0oooo00<0oooo0P00o`000`3oool00?l0003o00060?ooo`03003o003o
ool0oooo00H0oooo00<0003o0?ooo`3oool01`3oool00`00o`00oooo0?ooo`060?ooo`800?l02P3o
ool2003o0080oooo00<00?l00?ooo`3oool05P3oool00`00o`00oooo0?ooo`050?ooo`05003o003o
ool0oooo0?ooo`000?l01`3oool01@00o`00oooo0?ooo`3oool00?l000<0003o00<00?l00?ooo`3o
ool00P3oool01`00o`00oooo0000o`00o`00oooo003o00000?l00`3oool20000o`H0oooo00@00?l0
0?ooo`00o`000?l03@3oool00`00o`00oooo0000o`0:0?ooo`03003o003oool0oooo00X0oooo00@0
0?l00?ooo`00o`00003o3@3oool01000o`00oooo0?ooo`00o`0H0?ooo`800?l000<0oooo003o003o
ool00`3oool00`00o`00oooo0?ooo`0m0?ooo`80003o2@3oool2003o00T0oooo0P000?lC0?ooo`03
0000003oool0oooo01`0oooo000n0?ooo`030000003oool0oooo04L0oooo00D000000000o`000000
003o000000020000o`030000003oool0oooo0?l0ooooC03oool01@000000003o000000000?l00000
0080003o00<000000000o`0000000P000?l01@000000003o000000000?l000000080003o00D00000
0000o`000000003o000000020000o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0Q03o
ool00`000000oooo0?ooo`0n0?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool00P3o
ool00`00o`00oooo0?ooo`030?ooo`800?l000<0oooo003o0000o`001P3oool00`00o`00oooo0?oo
o`060?ooo`030000o`3oool0oooo00L0oooo00<00?l00?ooo`3oool01P3oool2003o00X0oooo0P00
o`020?ooo`03003o003oool00?l001H0oooo00<00?l00?ooo`3oool01@3oool01@00o`00oooo0?oo
o`3oool0003o00L0oooo00D00?l00?ooo`3oool0oooo003o00020?ooo`03003o003oool0oooo00<0
oooo00P00?l00?ooo`000?l00?l00?ooo`00o`00003o0?ooo`80003o0P3oool20000o`@0oooo00@0
0?l00?ooo`00o`000?l03@3oool01@00o`00oooo0000o`3oool00?l000<0oooo00<00?l00?ooo`3o
ool00P3oool00`00o`00oooo0?ooo`0:0?ooo`04003o003oool00?l00000o`d0oooo00@00?l00?oo
o`3oool00?l0603oool2003o00030?ooo`00o`00oooo00<0oooo00<00?l00?ooo`3oool0?@3oool2
0000o`P0oooo00<00?l00?ooo`00o`002@3oool20000oa<0oooo00<000000?ooo`3oool0703oool0
03h0oooo00<000000?ooo`3oool0A`3oool01@000000003o000000000?l000000080003o00<00000
0?ooo`3oool0o`3ooom<0?ooo`05000000000?l000000000o`0000000P000?l00`000000003o0000
00020000o`05000000000?l000000000o`0000000P000?l01@000000003o000000000?l000000080
003o00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo03h0
oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo00<0
oooo0P00o`000`3oool00?l0003o00060?ooo`03003o003oool0oooo00H0oooo00<0003o0?ooo`3o
ool01`3oool00`00o`00oooo0?ooo`060?ooo`800?l02P3oool2003o0080oooo0P00o`000`3oool0
0?l00?ooo`0D0?ooo`03003o003oool0oooo00D0oooo00D00?l00?ooo`3oool0oooo0000o`070?oo
o`05003o003oool0oooo0?ooo`00o`000P3oool00`00o`00oooo0?ooo`030?ooo`03003o00000?l0
0?l00080oooo00<00?l00000o`3oool00P000?l30?ooo`030000o`3oool0oooo0080oooo00@00?l0
0?ooo`00o`000?l03@3oool01@00o`00oooo0000o`00o`00oooo00<00?l000H0oooo003o0000o`00
0?l00?ooo`00o`0<0?ooo`04003o003oool00?l0003o00d0oooo00@00?l00?ooo`3oool00?l0603o
ool2003o00030?ooo`00o`00oooo00<0oooo00<00?l00?ooo`3oool0?@3oool20000o`L0oooo0P00
o`020?ooo`04003o003oool00?l0003o00D0oooo0P000?lC0?ooo`030000003oool0oooo01`0oooo
000n0?ooo`030000003oool0oooo04L0oooo00D000000000o`000000003o000000020000o`030000
003oool0oooo0?l0ooooC03oool01@000000003o000000000?l000000080003o00<000000000o`00
00000P000?l01@000000003o000000000?l000000080003o00D000000000o`000000003o00000002
0000o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0Q03oool2000003l0oooo00<00?l0
0?ooo`3oool00P3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo00<0oooo0P00o`00
0`3oool00?l0003o00060?ooo`03003o003oool0oooo00H0oooo00<0003o0?ooo`3oool01`3oool0
0`00o`00oooo0?ooo`060?ooo`800?l02P3oool2003o0080oooo00@00?l00?ooo`3oool00?l05@3o
ool00`00o`00oooo0?ooo`050?ooo`05003o003oool0oooo0?ooo`000?l01`3oool01@00o`00oooo
0?ooo`3oool00?l00080oooo00<00?l00?ooo`3oool00`3oool00`00o`00003o003o00020?ooo`03
003o00000?l0003o00D0oooo00<0003o0?ooo`3oool00P3oool01000o`00oooo003o0000o`0=0?oo
o`04003o00000?l0003o003o00L0oooo00<00?l00?ooo`00o`00303oool01000o`00oooo003o0000
o`0=0?ooo`04003o003oool0oooo003o01P0oooo0P00o`000`3oool00?l00?ooo`030?ooo`03003o
003oool0oooo03d0oooo0P000?l30?ooo`800?l000<0oooo003o003oool00`3oool2003o00030?oo
o`00o`00oooo00@0oooo0P000?lC0?ooo`030000003oool0oooo01`0oooo000n0?ooo`030000003o
ool0oooo04L0oooo00D000000000o`000000003o000000020000o`030000003oool0oooo0?l0oooo
C03oool01@000000003o000000000?l000000080003o00<000000000o`0000000P000?l01@000000
003o000000000?l000000080003o00D000000000o`000000003o000000020000o`030000003oool0
oooo00d0oooo00<000000?ooo`3oool0AP3oool8000003H0oooo00<000000?ooo`3oool0?P3oool0
0`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool00`3oool2
003o00030?ooo`00o`000?l000H0oooo00<00?l00?ooo`3oool01P3oool00`000?l0oooo0?ooo`07
0?ooo`03003o003oool0oooo00H0oooo0P00o`0:0?ooo`03003o003oool0oooo00@0oooo00<00?l0
0?ooo`3oool04`3oool00`00o`00oooo0?ooo`050?ooo`05003o003oool00?l00?ooo`000?l01`3o
ool01@00o`00oooo0?ooo`3oool00?l00080oooo00<00?l00?ooo`3oool00`3oool00`00o`00003o
003o00020?ooo`03003o00000?l0003o00D0oooo00<0003o0?ooo`3oool00P3oool01000o`00oooo
003o0000o`0=0?ooo`04003o003oool0oooo003o00P0oooo00<00?l00?ooo`3oool02`3oool01000
o`00oooo003o0000o`0=0?ooo`04003o003oool0oooo003o01P0oooo0P00o`000`3oool00?l00?oo
o`030?ooo`03003o003oool0oooo03d0oooo0P000?l30?ooo`04003o003oool00?l0003o00L0oooo
00<00?l00?ooo`3oool00`3oool20000oa<0oooo00<000000?ooo`3oool0703oool003h0oooo00<0
00000?ooo`3oool0A`3oool01@000000003o000000000?l000000080003o00<000000?ooo`3oool0
o`3ooom<0?ooo`05000000000?l000000000o`0000000P000?l00`000000003o000000020000o`05
000000000?l000000000o`0000000P000?l01@000000003o000000000?l000000080003o00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`160?ooo`P00000=P3oool00`000000oooo0?ooo`0n
0?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`03
0?ooo`800?l000<0oooo003o0000o`001P3oool00`00o`00oooo0?ooo`060?ooo`03003o003oool0
oooo00L0oooo00<00?l00?ooo`3oool01`3oool00`00o`00oooo0?ooo`080?ooo`03003o003oool0
oooo00D0oooo00<00?l00?ooo`00o`000`3oool2003o0080oooo00<00?l00?ooo`3oool00P3oool0
1000o`00oooo0?ooo`00o`020?ooo`03003o003oool0oooo00D0oooo0P00o`000`3oool00?l00000
o`070?ooo`05003o003oool0oooo0?ooo`00o`000P3oool00`00o`00oooo0?ooo`030?ooo`03003o
00000?l00?l00080oooo00<00?l00000o`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`04003o
003oool00?l0003o00d0oooo00@00?l00?ooo`3oool00?l05P3oool01000o`00oooo003o0000o`0=
0?ooo`04003o003oool0oooo003o01P0oooo0P00o`000`3oool00?l00000o`020?ooo`030000o`00
o`00oooo03h0oooo0P000?l30?ooo`03003o003oool0oooo00P0oooo00<00?l00?ooo`3oool00`3o
ool2003o01<0oooo00<000000?ooo`3oool0703oool003h0oooo0`0000170?ooo`05000000000?l0
00000000o`0000000P000?l00`000000oooo0?ooo`3o0?oood`0oooo00D000000000o`000000003o
000000020000o`03000000000?l000000080003o00D000000000o`000000003o000000020000o`05
000000000?l000000000o`0000000P000?l00`000000oooo0?ooo`0<0?ooo`800000BP3oool20000
03X0oooo00<000000?ooo`3oool0?P3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo
0080oooo00<00?l00?ooo`3oool00`3oool2003o00030?ooo`00o`000?l000<0oooo00@0003o0?oo
o`3oool00?l0203oool00`00o`00oooo0?ooo`070?ooo`03003o003oool0oooo0180oooo00<00?l0
0?ooo`3oool01@3oool2003o00060?ooo`00o`000?l00?ooo`00o`00oooo0`00o`020?ooo`800?l0
00@0oooo003o0000o`00oooo0`00o`070?ooo`800?l00P3oool00`00o`00oooo0?ooo`050?ooo`04
003o003oool0oooo0?ooo`800?l000<0oooo003o003oool0103oool00`00o`00003o003o00020?oo
o`03003o00000?l0oooo00D0oooo00<0003o0?ooo`3oool00P3oool01000o`00oooo003o0000o`0=
0?ooo`03003o003oool00?l001L0oooo00D00?l00?ooo`00o`000?l00000o`0<0?ooo`04003o003o
ool0oooo003o01P0oooo0P00o`000`3oool00?l00000o`020?ooo`030000o`00o`00oooo03h0oooo
0P000?l30?ooo`03003o003oool0oooo00P0oooo00<00?l00?ooo`3oool00`3oool2003o01<0oooo
00<000000?ooo`3oool0703oool003h0oooo00<000000?ooo`3oool0A`3oool01@000000003o0000
00000?l000000080003o00<000000?ooo`3oool0o`3ooom<0?ooo`05000000000?l000000000o`00
00000P000?l00`000000003o000000020000o`05000000000?l000000000o`0000000P000?l01@00
0000003o000000000?l000000080003o00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`18
0?ooo`800000>P3oool00`000000oooo0?ooo`0n0?ooo`03003o003oool0oooo0080oooo00<00?l0
0?ooo`3oool00P3oool00`00o`00oooo0?ooo`030?ooo`800?l000<0oooo003o0000o`000`3oool2
0000o`030?ooo`00o`00oooo00L0oooo00<00?l00?ooo`3oool01`3oool00`00o`00oooo0?ooo`0J
0?ooo`07003o003oool0oooo0?ooo`00o`00oooo003o00020?ooo`05003o003oool00?l00?ooo`00
o`000`3oool00`00o`00oooo0?ooo`0=0?ooo`03003o003oool0oooo00D0oooo00<00?l00?ooo`3o
ool00`3oool2003o00D0oooo00<00?l00000o`00o`000`3oool00`00o`00oooo0?ooo`020?ooo`03
003o003oool00?l000@0oooo00@00?l00?ooo`00o`000?l03@3oool00`00o`00oooo003o000G0?oo
o`05003o003oool00?l0003o00000?l0303oool01000o`00oooo0?ooo`00o`0H0?ooo`800?l000<0
oooo003o00000?l00P3oool00`000?l00?l00?ooo`0m0?ooo`030000o`00o`000?l000<0oooo00<0
0?l00?ooo`3oool0203oool00`00o`00oooo0?ooo`030?ooo`800?l000<0003o0?ooo`3oool0403o
ool00`000000oooo0?ooo`0L0?ooo`00?P3oool00`000000oooo0?ooo`170?ooo`05000000000?l0
00000000o`0000000P000?l00`000000oooo0?ooo`3o0?oood`0oooo00D000000000o`000000003o
000000020000o`03000000000?l000000080003o00D000000000o`000000003o000000020000o`05
000000000?l000000000o`0000000P000?l00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
04P0oooo0P00000j0?ooo`030000003oool0oooo03h0oooo00<00?l00?ooo`3oool00P3oool00`00
o`00oooo0?ooo`020?ooo`03003o003oool0oooo00<0oooo0P00o`000`000?l00?l0003o00030?oo
o`80003o00<0oooo003o003oool01`3oool00`00o`00oooo0?ooo`070?ooo`03003o003oool0oooo
01h0oooo0P00o`050?ooo`800?l0503oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0oooo
00X0oooo00<00?l00000o`00o`000`3oool01000o`00oooo003o003oool4003o00@0oooo00@00?l0
0?ooo`00o`000?l03@3oool00`00o`00oooo003o000G0?ooo`05003o003oool00?l0003o00000?l0
303oool01000o`00oooo0?ooo`00o`0H0?ooo`05003o003oool0oooo003o00000?l00P3oool00`00
0?l00?l00?ooo`0m0?ooo`040000o`00o`000?l00000o`80oooo00<00?l00?ooo`3oool0203oool0
0`00o`00oooo0?ooo`030?ooo`800?l000<0003o0?ooo`3oool0403oool00`000000oooo0?ooo`0L
0?ooo`00?P3oool00`000000oooo0?ooo`170?ooo`05000000000?l000000000o`0000000P000?l0
0`000000oooo0?ooo`3o0?oood`0oooo00D000000000o`000000003o000000020000o`0300000000
0?l000000080003o00D000000000o`000000003o000000020000o`05000000000?l000000000o`00
00000P000?l00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo04P0oooo0P00000j0?ooo`03
0000003oool0oooo03h0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`020?ooo`03
003o003oool0oooo00<0oooo0P00o`000`000?l00?l0003o00030?ooo`80003o00<0oooo003o003o
ool01`3oool00`00o`00oooo0?ooo`070?ooo`03003o003oool0oooo01l0oooo00<00?l00?ooo`3o
ool00`3oool2003o01@0oooo00<00?l00?ooo`3oool01@3oool00`00o`00oooo0?ooo`0;0?ooo`80
0?l00`3oool01000o`00oooo003o0000o`020?ooo`800?l0103oool01000o`00oooo003o0000o`0=
0?ooo`03003o003oool00?l001L0oooo00D00?l00?ooo`00o`000?l00000o`0<0?ooo`04003o003o
ool0oooo003o01P0oooo00D00?l00?ooo`3oool00?l00000o`020?ooo`030000o`00o`00oooo03d0
oooo00@0003o003o0000o`00003o0P3oool00`00o`00oooo0?ooo`080?ooo`03003o003oool0oooo
00<0oooo0P00o`000`000?l0oooo0?ooo`0@0?ooo`030000003oool0oooo01`0oooo000n0?ooo`03
0000003oool0oooo04L0oooo00D000000000o`000000003o000000020000o`030000003oool0oooo
0?l0ooooC03oool01@000000003o000000000?l000000080003o00<000000000o`0000000P000?l0
1@000000003o000000000?l000000080003o00D000000000o`000000003o000000020000o`030000
003oool0oooo00d0oooo00<000000?ooo`3oool0B03oool2000003X0oooo0P00000o0?ooo`03003o
003oool0oooo0080oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`020?ooo`040000
o`00o`000?l00000o`800?l00`3oool30000o`03003o003oool0oooo00H0oooo00<00?l00?ooo`3o
ool01P3oool00`000?l00?l00?ooo`0P0?ooo`03003o003oool0oooo00@0oooo00<00?l00?ooo`3o
ool04P3oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0oooo00/0oooo0P00o`030?ooo`80
0?l000<0oooo003o003oool00P3oool00`00o`00oooo0?ooo`020?ooo`04003o003oool00?l0003o
00d0oooo00<00?l00?ooo`00o`005`3oool01@00o`00oooo003o0000o`00003o00`0oooo00@00?l0
0?ooo`3oool00?l0603oool01@00o`00oooo0?ooo`00o`00003o0080oooo00<0003o003o003oool0
:@3oool00`000?l0oooo0?ooo`0A0?ooo`040000o`00o`000?l00000o`80oooo00<00?l00?ooo`3o
ool0203oool00`00o`00oooo0?ooo`030?ooo`800?l000<0003o0?ooo`3oool0403oool00`000000
oooo0?ooo`0L0?ooo`00?P3oool00`000000oooo0?ooo`170?ooo`05000000000?l000000000o`00
00000P000?l00`000000oooo0?ooo`3o0?oood`0oooo00D000000000o`000000003o000000020000
o`03000000000?l000000080003o00D000000000o`000000003o000000020000o`05000000000?l0
00000000o`0000000P000?l00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo04P0oooo0P00
000j0?ooo`030000003oool0oooo03h0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?oo
o`020?ooo`03003o00000?l0oooo0080oooo00@0003o003o0000o`00003o0P00o`030?ooo`<0003o
00<00?l00?ooo`3oool01P3oool00`00o`00oooo0?ooo`060?ooo`030000o`00o`00oooo03`0oooo
00<00?l00?ooo`3oool01@3oool00`00o`00oooo0?ooo`0;0?ooo`800?l00`3oool2003o00D0oooo
00<00?l00?ooo`3oool00P3oool01000o`00oooo003o0000o`0=0?ooo`800?l0603oool01@00o`00
oooo003o0000o`00003o00`0oooo00@00?l00?ooo`3oool00?l0603oool01@00o`00oooo0?ooo`00
o`00003o0080oooo00<0003o003o003oool0:@3oool00`000?l0oooo0?ooo`0A0?ooo`040000o`00
o`000?l00000o`80oooo00<00?l00?ooo`3oool0203oool00`00o`00oooo0?ooo`030?ooo`800?l0
00<0003o0?ooo`3oool0403oool00`000000oooo0?ooo`0L0?ooo`00?P3oool00`000000oooo0?oo
o`170?ooo`05000000000?l000000000o`0000000P000?l00`000000oooo0?ooo`3o0?oood`0oooo
00D000000000o`000000003o000000020000o`03000000000?l000000080003o00D000000000o`00
0000003o000000020000o`05000000000?l000000000o`0000000P000?l00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo04H0oooo0P0000020?ooo`H00000=03oool00`000000oooo0?ooo`0n
0?ooo`06003o00000?l0oooo0?ooo`000?l00?l0103oool00`00o`00003o0?ooo`020?ooo`040000
o`00o`000?l00000o`800?l00`3oool30000o`03003o003oool0oooo00H0oooo00<00?l00?ooo`3o
ool01P3oool00`000?l00?l00?ooo`0l0?ooo`03003o003oool0oooo00D0oooo00<00?l00?ooo`3o
ool02`3oool2003o00<0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`020?ooo`04
003o003oool00?l0003o00d0oooo0P00o`0H0?ooo`05003o003oool00?l0003o00000?l0303oool0
1000o`00oooo0?ooo`00o`0H0?ooo`05003o003oool0oooo003o00000?l00P3oool2003o02X0oooo
00<0003o0?ooo`3oool04@3oool010000?l00?l0003o00000?l20?ooo`03003o003oool0oooo00P0
oooo00<00?l00?ooo`3oool00`3oool2003o00030000o`3oool0oooo0100oooo00<000000?ooo`3o
ool0703oool003h0oooo00<000000?ooo`3oool0A`3oool01@000000003o000000000?l000000080
003o00<000000?ooo`3oool0o`3ooom<0?ooo`05000000000?l000000000o`0000000P000?l00`00
0000003o000000020000o`05000000000?l000000000o`0000000P000?l01@000000003o00000000
0?l000000080003o00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`160?ooo`8000000P3o
ool6000003@0oooo00<000000?ooo`3oool0?P3oool01P00o`00003o0?ooo`3oool0003o003o00@0
oooo00<00?l00000o`3oool00P3oool010000?l00?l0003o00000?l2003o00030000o`3oool0oooo
00<0003o00<00?l00?ooo`3oool01P3oool00`00o`00oooo0?ooo`060?ooo`030000o`00o`00oooo
03`0oooo00<00?l00?ooo`3oool01@3oool00`00o`00oooo0?ooo`0;0?ooo`800?l00`3oool00`00
o`00oooo0?ooo`040?ooo`03003o003oool0003o0080oooo00@00?l00?ooo`00o`000?l09`3oool0
1@00o`00oooo003o0000o`00003o00`0oooo00@00?l00?ooo`3oool00?l0603oool01@00o`00oooo
0?ooo`3oool00?l00080oooo0P00o`0Y0?ooo`80003o4`3oool010000?l00?l0003o00000?l20?oo
o`03003o003oool0oooo00P0oooo00<00?l00?ooo`3oool00`3oool2003o00030000o`3oool0oooo
0100oooo00<000000?ooo`3oool0703oool003h0oooo0`0000170?ooo`05000000000?l000000000
o`0000000P000?l00`000000oooo0?ooo`3o0?oood`0oooo0`0000001`000?l000000000o`000?l0
00000000o`0000000P000?l01@000000003o000000000?l000000080003o00@000000000o`000000
003o1000000>0?ooo`800000QP3oool00`000000oooo0?ooo`0n0?ooo`06003o00000?l0oooo0?oo
o`000?l00?l0103oool00`00o`00003o0?ooo`020?ooo`040000o`00o`000?l00000o`800?l000@0
003o0?ooo`000?l0oooo0P000?l00`00o`00oooo0?ooo`060?ooo`03003o003oool0oooo00H0oooo
00<00?l00?ooo`3oool0?03oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0oooo00/0oooo
00<00?l00?ooo`3oool02@3oool01`00o`00oooo0000o`3oool0003o003o003oool00P00o`0W0?oo
o`05003o003oool00?l0003o00000?l0303oool01000o`00oooo0?ooo`00o`0H0?ooo`05003o003o
ool0oooo0?ooo`00o`000P3oool2003o02T0oooo0P000?l@0?ooo`80003o00D0oooo0000o`00o`00
0?l00000o`020?ooo`03003o003oool0oooo00P0oooo00<00?l00?ooo`3oool00`3oool2003o0003
0000o`3oool0oooo0100oooo00<000000?ooo`3oool0703oool003h0oooo00<000000?ooo`3oool0
A`3oool01@000000003o000000000?l000000080003o00<000000?ooo`3oool0o`3ooom>0?ooo`03
000000000?l000000080003o00<000000000o`0000000P000?l01@000000003o000000000?l00000
0080003o00D000000000o`000000003o0000000B0?ooo`030000003oool0oooo08@0oooo00<00000
0?ooo`3oool0?P3oool01P00o`00003o0?ooo`3oool0003o003o00@0oooo00<00?l00000o`3oool0
0P3oool010000?l00?l0003o00000?l2003o00070000o`3oool0003o0?ooo`00o`00003o003o0008
0?ooo`03003o003oool0oooo00H0oooo00<00?l00?ooo`3oool0?03oool00`00o`00oooo0?ooo`05
0?ooo`03003o003oool0oooo00/0oooo00<00?l00?ooo`3oool02@3oool01`00o`00oooo0000o`00
0?l0oooo003o003oool00P00o`0W0?ooo`03003o003oool00?l000800?l02`3oool01@000?l00?l0
0?ooo`3oool00?l001P0oooo00D00?l00?ooo`3oool0oooo003o00020?ooo`800?l06`3oool00`00
0?l0oooo0?ooo`020?ooo`80003o1P3oool30000o``0oooo0P000?l0103oool0003o0?ooo`3oool2
0000o`800?l000@0003o0?ooo`3oool00?l02P3oool00`00o`00oooo0?ooo`030?ooo`800?l000<0
003o0?ooo`3oool0403oool00`000000oooo0?ooo`0L0?ooo`00?P3oool00`000000oooo0?ooo`17
0?ooo`05000000000?l000000000o`0000000P000?l00`000000oooo0?ooo`3o0?ooodh0oooo00<0
00000000o`0000000P000?l00`000000003o000000020000o`05000000000?l000000000o`000000
0P000?l01@000000003o000000000?l000000180oooo00<000000?ooo`3oool0B03oool400000080
oooo0P00000d0?ooo`800000?`3oool01P00o`00003o0?ooo`3oool0003o003o00D0oooo01400?l0
0?ooo`3oool0oooo0000o`00o`00oooo003o003oool00?l00000o`3oool0003o0?ooo`00o`00003o
003o00080?ooo`03003o003oool0oooo00H0oooo00<00?l00?ooo`3oool0?03oool00`00o`00oooo
0?ooo`050?ooo`03003o003oool0oooo00/0oooo00<00?l00?ooo`3oool02@3oool00`00o`00oooo
0000o`020?ooo`04003o003oool00?l0003o02L0oooo00<00?l00000o`00o`000P00o`0;0?ooo`06
0000o`00o`00oooo0?ooo`00o`00003o5`3oool01@00o`00oooo0?ooo`3oool00?l00080oooo0P00
o`0K0?ooo`D0003o0P3oool30000o`<0oooo00<0003o0?ooo`000?l0203oool20000o`80oooo00@0
003o0?ooo`000?l0003o0`3oool01000o`00oooo003o00000?l20?ooo`03003o003oool0oooo00P0
oooo00<00?l00?ooo`3oool00P3oool010000?l00?l0003o00000?lB0?ooo`030000003oool0oooo
01`0oooo000n0?ooo`030000003oool0oooo04L0oooo00D000000000o`000000003o000000020000
o`030000003oool0oooo0?l0ooooCP3oool00`000000003o000000020000o`03000000000?l00000
0080003o00D000000000o`000000003o000000020000o`05000000000?l000000000o`0000004P3o
ool00`000000oooo0?ooo`180?ooo`@000000P3oool2000003@0oooo00<000000?ooo`3oool0?`3o
ool01000o`00oooo0?ooo`00o`060?ooo`0=003o003oool0oooo0?ooo`000?l00?l00?ooo`00o`00
oooo003o00000?l0oooo0000o`02003o00030000o`00o`00oooo00L0oooo00<00?l00?ooo`3oool0
1P3oool00`00o`00oooo0?ooo`0l0?ooo`03003o003oool0oooo00D0oooo00<00?l00?ooo`3oool0
2`3oool00`00o`00oooo0?ooo`090?ooo`03003o003oool0003o0080oooo00@00?l00?ooo`00o`00
0?l09`3oool01@00o`00003o003o003oool00?l000/0oooo00H0003o003o003oool0oooo003o0000
0?lG0?ooo`05003o003oool0oooo0?ooo`00o`000P3oool2003o01/0oooo00<0003o0?ooo`3oool0
1P3oool01`000?l0oooo0?ooo`3oool0003o0?ooo`000?l0203oool20000o`80oooo00<0003o0?oo
o`3oool0103oool01000o`00oooo003o00000?l20?ooo`03003o003oool0oooo00P0oooo00<00?l0
0?ooo`3oool00P3oool01@000?l00?l00?ooo`00o`00003o0140oooo00<000000?ooo`3oool0703o
ool003h0oooo00<000000?ooo`3oool0A`3oool01@000000003o000000000?l000000080003o00<0
00000?ooo`3oool0o`3ooom>0?ooo`03000000000?l000000080003o00<000000000o`0000000P00
0?l01@000000003o000000000?l000000080003o00D000000000o`000000003o0000000B0?ooo`03
0000003oool0oooo04H0oooo0P0000040?ooo`800000=P3oool00`000000oooo0?ooo`0G0?ooo`D0
00008`3oool01000o`00oooo0?ooo`00o`060?ooo`05003o003oool0oooo0?ooo`00o`000P3oool0
1P00o`00oooo003o00000?l0oooo0000o`@00?l0203oool00`00o`00oooo0?ooo`060?ooo`03003o
003oool0oooo03`0oooo00<00?l00?ooo`3oool01@3oool00`00o`00oooo0?ooo`0;0?ooo`03003o
003oool0oooo00T0oooo00<00?l00?ooo`000?l00P3oool01000o`00oooo003o0000o`0W0?ooo`05
003o00000?l00?l00?ooo`00o`002`3oool01P000?l00?l00?ooo`3oool00?l00000oaL0oooo00D0
0?l00?ooo`3oool0oooo003o00020?ooo`800?l06`3oool00`000?l0oooo0?ooo`060?ooo`070000
o`3oool0oooo0?ooo`000?l0oooo0000o`080?ooo`80003o0P3oool00`000?l0oooo0?ooo`040?oo
o`04003o003oool00?l00000o`80oooo00<00?l00?ooo`3oool0203oool00`00o`00oooo0?ooo`02
0?ooo`050000o`00o`00oooo003o00000?l04@3oool00`000000oooo0?ooo`0L0?ooo`00;@3oool4
000000<0oooo0P0000080?ooo`030000003oool0oooo04L0oooo00D000000000o`000000003o0000
00020000o`030000003oool0oooo0?l0ooooCP3oool00`000000003o000000020000o`0300000000
0?l000000080003o00D000000000o`000000003o000000020000o`05000000000?l000000000o`00
00004P3oool00`000000oooo0?ooo`160?ooo`800000103oool2000000h0oooo100000080?ooo`80
0000203oool6000000`0oooo00<000000?ooo`3oool05P3oool700000280oooo00@00?l00?ooo`3o
ool00?l01P3oool01@00o`00oooo0?ooo`3oool00?l00080oooo00H00?l00?ooo`00o`00003o0?oo
o`000?l4003o00P0oooo00<00?l00?ooo`3oool01P3oool00`00o`00oooo0?ooo`0l0?ooo`03003o
003oool0oooo00D0oooo00<00?l00?ooo`3oool02`3oool00`00o`00oooo0?ooo`090?ooo`03003o
003oool0003o0080oooo00@00?l00?ooo`00o`000?l09`3oool01@00o`00003o003o003oool00?l0
00/0oooo00H0003o003o003oool0oooo003o00000?lG0?ooo`05003o003oool0oooo0?ooo`00o`00
0P3oool2003o01/0oooo00<0003o0?ooo`3oool01P3oool01`000?l0oooo0?ooo`3oool0003o0?oo
o`000?l0203oool20000o`80oooo00<0003o0?ooo`3oool0103oool01000o`00oooo0?ooo`00o`02
0?ooo`03003o003oool0oooo00P0oooo00<00?l00?ooo`3oool00P3oool01@000?l00?l00?ooo`00
o`00003o0140oooo00<000000?ooo`3oool0703oool002l0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0A`3oool01@000000003o0000
00000?l000000080003o00<000000?ooo`3oool0o`3ooom>0?ooo`03000000000?l000000080003o
00<000000000o`0000000P000?l01@000000003o000000000?l000000080003o00D000000000o`00
0000003o0000000B0?ooo`030000003oool0oooo04P0oooo1P00000>0?ooo`@00000203oool20000
00P0oooo1P00000<0?ooo`030000003oool0oooo01H0oooo2000000Q0?ooo`04003o003oool0oooo
003o00H0oooo00D00?l00?ooo`3oool0oooo003o00020?ooo`06003o003oool0oooo003o003oool0
003o1000o`080?ooo`03003o003oool0oooo00H0oooo00<00?l00?ooo`3oool0<P3oool7000000<0
oooo00<00?l00?ooo`3oool01@3oool00`00o`00oooo0?ooo`0;0?ooo`03003o003oool0oooo00T0
oooo00<00?l00?ooo`000?l00P3oool01000o`00oooo003o0000o`040?ooo`D000007P3oool01@00
o`00003o003o003oool00?l000/0oooo00H0003o003o003oool0oooo003o00000?lG0?ooo`05003o
003oool0oooo0?ooo`00o`000P3oool2003o01/0oooo00<0003o0?ooo`3oool01P3oool01`000?l0
oooo0?ooo`3oool0003o0?ooo`00o`00203oool20000o`80oooo00<0003o0?ooo`3oool0103oool0
1000o`00oooo0?ooo`00o`020?ooo`03003o003oool0oooo00P0oooo00<00?l00?ooo`3oool00P3o
ool01@000?l00?l00?ooo`00o`00003o0140oooo00<000000?ooo`3oool0703oool002l0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00D0oooo100000160?ooo`<00000
00D0003o000000000?l0003o0000003o0?oooe00oooo00<000000000o`0000000P000?l00`000000
003o000000020000o`05000000000?l000000000o`0000000P000?l01@000000003o000000000?l0
00000100oooo0`00001:0?ooo`H00000303oool2000000@0oooo0P00000F0?ooo`8000002P3oool0
0`000000oooo0?ooo`0F0?ooo`P000008@3oool01000o`00000000000000o`0600000005003o003o
ool0oooo0?ooo`00o`000P3oool01P00o`00oooo0?ooo`00o`00oooo0000o`@00?l0203oool00`00
o`00oooo0?ooo`060?ooo`03003o003oool0oooo0380oooo1`0000030?ooo`03003o003oool0oooo
00D0oooo00<00?l00?ooo`3oool02`3oool00`00o`00oooo0?ooo`090?ooo`03003o003oool0003o
0080oooo00@00?l00?ooo`00o`000?l00`3oool6000001h0oooo00H00?l00000o`00o`00oooo003o
00000?l:0?ooo`060000o`00o`00oooo0?ooo`00o`00003o5`3oool01@00o`00oooo0?ooo`3oool0
0?l00080oooo0P00o`0K0?ooo`030000o`3oool0oooo00H0oooo00L0003o0?ooo`3oool0oooo0000
o`3oool00?l000P0oooo0P000?l20?ooo`030000o`3oool0oooo00@0oooo00@00?l00?ooo`3oool0
0?l00P3oool00`00o`00oooo0?ooo`080?ooo`03003o003oool0oooo0080oooo00D0003o003o003o
ool00?l00000o`0A0?ooo`030000003oool0oooo01`0oooo000_0?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo04T0oooo00<000000000
o`0000000P000?l00`000000oooo0?ooo`3o0?ooodh0oooo00<000000000o`0000000P000?l00`00
0000003o000000020000o`05000000000?l000000000o`0000000P000?l01@000000003o00000000
0?l000000180oooo00<000000?ooo`3oool0C03oool2000000`0oooo0P0000040?ooo`8000005P3o
ool2000000X0oooo0`00000F0?ooo`P000008@3oool01000o`00000000000000o`0600000005003o
00000000oooo0?ooo`00o`000P3oool01P00o`00oooo0?ooo`00o`00oooo0000o`@00?l0203oool0
0`00o`00oooo0?ooo`060?ooo`03003o003oool0oooo0380oooo1`0000030?ooo`03003o003oool0
oooo00D0oooo00<00?l00?ooo`3oool05`3oool00`00o`00oooo003o00020?ooo`04003o003oool0
0?l0003o00<0oooo1P00000N0?ooo`06003o00000?l00?l00?ooo`00o`00003o2P3oool01P000?l0
0?l00?ooo`3oool00?l00000oaL0oooo00D00?l00?ooo`3oool0oooo003o00020?ooo`800?l06`3o
ool00`000?l0oooo0?ooo`060?ooo`070000o`3oool0oooo0?ooo`000?l0oooo003o00080?ooo`80
003o0P3oool00`000?l0oooo0?ooo`040?ooo`04003o003oool0oooo003o0080oooo00<00?l00?oo
o`3oool0203oool00`00o`00oooo0?ooo`020?ooo`050000o`00o`00oooo003o00000?l04@3oool0
0`000000oooo0?ooo`0L0?ooo`00;`3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`190?ooo`03000000000?l000000080003o00<00000
0?ooo`3oool0o`3ooom>0?ooo`03000000000?l000000080003o00<000000000o`0000000P000?l0
1@000000003o000000000?l000000080003o00D000000000o`000000003o0000000B0?ooo`030000
003oool0oooo04`0oooo0P00000<0?ooo`800000103oool2000001H0oooo0P00000:0?ooo`030000
003oool0oooo01H0oooo2000000Q0?ooo`04003o000000000000003o00H0000000D00?l00000003o
ool0oooo003o00020?ooo`06003o003oool0oooo003o003oool0003o1000o`080?ooo`03003o003o
ool0oooo00H0oooo00<00?l00?ooo`3oool0<P3oool7000000<0oooo00<00?l00?ooo`3oool01@3o
ool00`00o`00oooo0?ooo`0G0?ooo`03003o003oool00?l000800?l00P3oool2003o00<0oooo1P00
000N0?ooo`06003o00000?l00?l00?ooo`00o`00003o2P3oool01P000?l00?l00?ooo`3oool00?l0
0000oaL0oooo00D00?l00?ooo`3oool0oooo003o00020?ooo`800?l06`3oool00`000?l0oooo0?oo
o`060?ooo`050000o`3oool0oooo0?ooo`000?l00P00o`080?ooo`80003o00<0oooo0000o`3oool0
1P3oool01000o`00oooo0?ooo`00o`020?ooo`03003o003oool0oooo00P0oooo00<00?l00?ooo`3o
ool00P3oool01@000?l00?l00?ooo`00o`00003o0140oooo00<000000?ooo`3oool0703oool002d0
oooo0`0000030?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3oool0B@3oool00`00
0000003o000000020000o`030000003oool0oooo0?l0ooooCP3oool00`000000003o000000020000
o`03000000000?l000000080003o00D000000000o`000000003o000000020000o`05000000000?l0
00000000o`0000004P3oool00`000000oooo0?ooo`180?ooo`@000003P3oool2000000@0oooo0P00
000F0?ooo`8000002P3oool00`000000oooo0?ooo`0I0?ooo`D000008@3oool01000o`0000000000
0000o`0600000005003o00000000oooo0?ooo`00o`000P3oool01P00o`00oooo0?ooo`00o`00oooo
0000o`@00?l0203oool00`00o`00003o0?ooo`060?ooo`03003o003oool0oooo0380oooo1`000003
0?ooo`03003o003oool0oooo00D0oooo00<00?l00?ooo`3oool05`3oool01@00o`00003o003o003o
ool00?l00080oooo0P00o`030?ooo`H000007`3oool2003o00030?ooo`00o`00003o00X0oooo00H0
003o003o003oool0oooo003o00000?lG0?ooo`05003o003oool0oooo0?ooo`00o`000P3oool2003o
01/0oooo00<0003o0?ooo`3oool01P3oool01@000?l0oooo0?ooo`000?l0oooo00800?l0203oool0
10000?l0oooo0000o`000?l70?ooo`04003o003oool0oooo003o0080oooo00<00?l00?ooo`3oool0
203oool00`00o`00oooo0?ooo`020?ooo`050000o`00o`00oooo003o00000?l04@3oool00`000000
oooo0?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`020?ooo`800000203oool00`000000oooo
0?ooo`190?ooo`03000000000?l000000080003o00<000000?ooo`3oool0o`3ooom>0?ooo`030000
00000?l000000080003o00<000000000o`0000000P000?l01@000000003o000000000?l000000080
003o00D000000000o`000000003o0000000B0?ooo`030000003oool0oooo04P0oooo1000000>0?oo
o`800000103oool200000100oooo1P00000<0?ooo`030000003oool0oooo03l0oooo00@00?l00000
000000000?l01P0000001@00o`0000000?ooo`3oool00?l00080oooo00L00?l00?ooo`3oool00?l0
0?ooo`00o`00oooo00<00?l0203oool00`00o`00003o0?ooo`060?ooo`03003o003oool0oooo03`0
oooo00<00?l00?ooo`3oool01@3oool00`00o`00oooo0?ooo`0G0?ooo`03003o00000?l00?l000@0
oooo0P00o`030?ooo`D00000803oool2003o00030?ooo`00o`00003o00X0oooo0P00o`020?ooo`03
003o00000?l0oooo01H0oooo00D00?l00?ooo`3oool0oooo003o00020?ooo`800?l06`3oool00`00
0?l0oooo003o00060?ooo`050000o`3oool0oooo0000o`3oool00P00o`080?ooo`040000o`3oool0
003o0000o`800?l0103oool2003o0080oooo00@00?l00?ooo`3oool00?l02P3oool00`00o`00oooo
0?ooo`020?ooo`050000o`00o`00oooo003o00000?l04@3oool00`000000oooo0?ooo`0L0?ooo`00
?P3oool00`000000oooo0?ooo`190?ooo`03000000000?l000000080003o00<000000?ooo`3oool0
o`3ooom>0?ooo`03000000000?l000000080003o00<000000000o`0000000P000?l01@000000003o
000000000?l000000080003o00D000000000o`000000003o0000000B0?ooo`030000003oool0oooo
05X0oooo0P0000040?ooo`800000403oool6000000`0oooo00<000000?ooo`3oool0?`3oool01000
o`00oooo0?ooo`00o`0600000005003o00000000oooo0?ooo`00o`000P3oool01`00o`00oooo0?oo
o`00o`00oooo003o003oool00`00o`080?ooo`03003o00000?l0oooo00H0oooo00<00?l00?ooo`3o
ool0?03oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0oooo01L0oooo00<00?l00000o`00
o`00;P3oool2003o00030?ooo`00o`00003o00X0oooo00H00?l00?ooo`3oool0oooo003o00000?lG
0?ooo`05003o003oool0oooo0?ooo`00o`000P3oool2003o01/0oooo00<00?l00?ooo`00o`000`00
o`00103oool00?l00?ooo`000?l20?ooo`040000o`00o`00oooo003o00<0oooo00<00?l00?ooo`3o
ool00P00o`0010000?l0oooo0000o`000?l2003o0080oooo0P00o`040?ooo`04003o003oool0oooo
003o00X0oooo00<00?l00?ooo`3oool00P3oool01@000?l00?l00?ooo`00o`00003o0140oooo00<0
00000?ooo`3oool0703oool003h0oooo00<000000?ooo`3oool0B@3oool00`000000003o00000002
0000o`030000003oool0oooo0?l0ooooCP3oool00`000000003o000000020000o`03000000000?l0
00000080003o00D000000000o`000000003o000000020000o`05000000000?l000000000o`000000
4P3oool00`000000oooo0?ooo`1J0?ooo`800000103oool200000100oooo0P00000@0?ooo`030000
003oool0oooo03l0oooo00@00?l00?ooo`3oool00?l01P3oool01@00o`00oooo0?ooo`3oool00?l0
0080oooo00L00?l00?ooo`3oool00?l00?ooo`00o`00oooo00<00?l0203oool00`00o`00003o0?oo
o`060?ooo`03003o003oool0oooo03`0oooo00<00?l00?ooo`3oool01@3oool00`00o`00oooo0?oo
o`0G0?ooo`03003o00000?l00?l002h0oooo0P00o`000`3oool00?l00000o`0:0?ooo`06003o003o
ool0oooo0?ooo`00o`00003o5`3oool01@00o`00oooo0?ooo`3oool00?l00080oooo0P00o`0K0?oo
o`800?l0103oool01000o`00oooo003o00000?l20?ooo`040000o`00o`00oooo003o00<0oooo0`00
o`020?ooo`800?l00P000?l01000o`00oooo003o0000o`060?ooo`03003o00000?l00?l000`0oooo
00D00?l00?ooo`3oool0oooo003o00020?ooo`800?l04@3oool00`000000oooo0?ooo`0L0?ooo`00
?P3oool3000004T0oooo00<000000000o`0000000P000?l00`000000oooo0?ooo`3o0?ooodh0oooo
00<000000000o`0000000`0000002@000?l000000000o`000?l000000000o`000000003o00000002
0000o`05000000000?l000000000o`0000004@3oool2000004`0oooo1000000<0?ooo`800000103o
ool200000100oooo0P00000@0?ooo`030000003oool0oooo03l0oooo00@00?l00?ooo`3oool00?l0
1P3oool01@00o`00oooo0?ooo`3oool00?l00080oooo00L00?l00?ooo`3oool00?l00?ooo`00o`00
oooo00<00?l0203oool00`00o`00003o0?ooo`060?ooo`03003o003oool0oooo03`0oooo00<00?l0
0?ooo`3oool01@3oool00`00o`00oooo0?ooo`0G0?ooo`03003o00000?l00?l002h0oooo00D00?l0
0?ooo`3oool00?l00000o`0:0?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool05@3o
ool01@00o`00oooo0?ooo`3oool00?l00080oooo00<00?l00000o`00o`006P3oool2003o00H0oooo
00P00?l00000o`3oool0oooo0000o`00o`00oooo003o00<0oooo00<00?l00?ooo`3oool00P3oool0
1@000?l00?l00000o`000?l00?l000T0oooo00<00?l00000o`00o`002P3oool20000o`05003o003o
ool0oooo0?ooo`00o`000`3oool00`00o`00oooo0?ooo`0?0?ooo`030000003oool0oooo01`0oooo
000n0?ooo`030000003oool0oooo04T0oooo00<000000000o`0000000P000?l00`000000oooo0?oo
o`3o0?ooodh0oooo00<000000000o`0000000P3oool00`000000003o000000020000o`0500000000
0?l000000000o`0000000P000?l01@000000003o000000000?l000000180oooo00<000000?ooo`3o
ool0BP3oool4000000`0oooo0P0000040?ooo`800000403oool200000100oooo0P0000100?ooo`04
003o003oool0oooo003o00H0oooo00D00?l00?ooo`3oool0oooo003o00020?ooo`07003o003oool0
oooo003o003oool00?l00?ooo`03003o00P0oooo00<00?l00000o`3oool01P3oool00`00o`00oooo
0?ooo`0l0?ooo`03003o003oool0oooo00D0oooo00<00?l00?ooo`3oool05`3oool00`00o`00003o
003o000^0?ooo`05003o003oool0oooo003o00000?l02P3oool00`00o`00oooo0?ooo`020?ooo`03
003o003oool0oooo01D0oooo00D00?l00?ooo`3oool0oooo003o00020?ooo`03003o00000?l00?l0
01X0oooo00<00?l00?ooo`3oool01P3oool01`00o`00oooo0?ooo`000?l00?l00?ooo`00o`000`3o
ool00`00o`00oooo0?ooo`020?ooo`050000o`00o`00003o0000o`00o`002@3oool00`00o`00003o
003o00060?ooo`80003o0P3oool20000o`05003o003oool0oooo0?ooo`00o`000`3oool00`00o`00
oooo0?ooo`0?0?ooo`030000003oool0oooo01`0oooo000n0?ooo`030000003oool0oooo04T0oooo
00<000000000o`0000000P000?l00`000000oooo0?ooo`3o0?ooodh0oooo00<000000000o`000000
0P3oool00`000000003o000000020000o`05000000000?l000000000o`0000000P000?l01@000000
003o000000000?l000000180oooo00<000000?ooo`3oool0B03oool2000000@0oooo0P00000:0?oo
o`800000103oool200000100oooo0P00000@0?ooo`030000003oool0oooo03l0oooo00@00?l00?oo
o`3oool00?l01P3oool01@00o`00oooo0?ooo`3oool00?l00080oooo00L00?l00?ooo`3oool00?l0
0?ooo`00o`00oooo00<00?l0203oool00`00o`00003o0?ooo`060?ooo`03003o003oool0oooo03`0
oooo00<00?l00?ooo`3oool01@3oool00`00o`00oooo0?ooo`0G0?ooo`03003o00000?l00?l002h0
oooo00D00?l00?ooo`3oool00?l00000o`0:0?ooo`03003o003oool0oooo0080oooo00<00?l00?oo
o`3oool05@3oool01@00o`00oooo0?ooo`3oool00?l00080oooo00<00?l00000o`00o`006P3oool0
0`00o`00oooo0?ooo`060?ooo`07003o003oool0oooo0000o`00o`00oooo003o00030?ooo`03003o
003oool0oooo0080oooo00D0003o003o00000?l0003o003o00090?ooo`03003o00000?l00?l000H0
oooo0P000?l20?ooo`80003o00D00?l00?ooo`3oool0oooo003o00030?ooo`03003o003oool0oooo
00l0oooo00<000000?ooo`3oool0703oool003h0oooo00<000000?ooo`3oool0B@3oool00`000000
003o000000020000o`030000003oool0oooo0?l0ooooCP3oool00`000000003o000000020?ooo`03
000000000?l000000080003o00D000000000o`000000003o000000020000o`05000000000?l00000
0000o`0000004P3oool00`000000oooo0?ooo`180?ooo`800000103oool2000000`0oooo1000000B
0?ooo`P000002P3oool00`000000oooo0?ooo`0o0?ooo`04003o003oool0oooo003o00H0oooo00D0
0?l00?ooo`3oool0oooo003o00020?ooo`07003o003oool0oooo003o003oool00?l00?ooo`03003o
00P0oooo00<00?l00000o`3oool01P3oool00`00o`00oooo0?ooo`0l0?ooo`03003o003oool0oooo
00D0oooo00<00?l00?ooo`3oool05`3oool00`00o`00003o003o000^0?ooo`05003o003oool0oooo
003o00000?l02P3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo01D0oooo00D00?l0
0?ooo`3oool0oooo003o00020?ooo`03003o00000?l00?l001X0oooo00<00?l00?ooo`3oool01P3o
ool01`00o`00oooo0?ooo`000?l00?l00?ooo`00o`000`3oool00`00o`00oooo0?ooo`020?ooo`05
0000o`00o`00003o0000o`00o`002@3oool00`00o`00003o003o00060?ooo`80003o00D0oooo0000
o`3oool0003o003o00030?ooo`05003o003oool0oooo0?ooo`00o`004@3oool00`000000oooo0?oo
o`0L0?ooo`00?P3oool00`000000oooo0?ooo`190?ooo`03000000000?l000000080003o00<00000
0?ooo`3oool0o`3ooom>0?ooo`03000000000?l000000080oooo00<000000000o`0000000P000?l0
1@000000003o000000000?l000000080003o00D000000000o`000000003o0000000B0?ooo`030000
003oool0oooo04P0oooo0P00000B0?ooo`@000004P3oool8000000X0oooo00<000000?ooo`3oool0
?`3oool01000o`00oooo0?ooo`00o`060?ooo`05003o003oool0oooo0?ooo`00o`000P3oool01`00
o`00oooo0?ooo`00o`00oooo003o003oool00`00o`000`000?l0oooo0?ooo`050?ooo`03003o0000
0?l0oooo00H0oooo00<00?l00?ooo`3oool0?03oool00`00o`00oooo0?ooo`050?ooo`03003o003o
ool0oooo01L0oooo00<00?l00000o`00o`00;P3oool01@00o`00oooo0?ooo`3oool00?l000X0oooo
00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`0E0?ooo`05003o003oool0oooo0?ooo`00
o`000P3oool00`00o`00003o003o000J0?ooo`03003o003oool0oooo00H0oooo00L00?l00?ooo`3o
ool0003o003o003oool00?l000<0oooo00<00?l00?ooo`3oool00P3oool01@000?l00?l00?ooo`3o
ool00?l000T0oooo00<00?l00000o`00o`001@3oool00`000?l0oooo0?ooo`020000o`030?ooo`00
0?l00?l000<0oooo00D00?l00?ooo`3oool0oooo003o000A0?ooo`030000003oool0oooo01`0oooo
000n0?ooo`030000003oool0oooo04T0oooo00<000000000o`0000000P000?l00`000000oooo0?oo
o`3o0?ooodh0oooo00<000000000o`0000000P3oool00`000000003o000000020000o`0500000000
0?l000000000o`0000000P000?l01@000000003o000000000?l000000180oooo00<000000?ooo`3o
ool0B03oool2000003X0oooo00<000000?ooo`3oool0?`3oool01000o`00oooo0?ooo`00o`060?oo
o`05003o003oool0oooo0?ooo`00o`000P3oool01`00o`00oooo0?ooo`00o`00oooo003o003oool0
0`00o`000`000?l0oooo0?ooo`050?ooo`03003o00000?l0oooo00H0oooo00<00?l00?ooo`3oool0
?03oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0oooo01P0oooo0P00o`0^0?ooo`05003o
003oool0oooo0?ooo`00o`002P3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo01D0
oooo00D00?l00?ooo`3oool0oooo003o00020?ooo`03003o00000?l00?l001X0oooo00<00?l00?oo
o`3oool01P3oool01`00o`00oooo0000o`3oool00?l00?ooo`00o`000`3oool00`00o`00oooo0?oo
o`020?ooo`050000o`00o`00oooo0?ooo`00o`002@3oool00`00o`00003o003o00050?ooo`030000
o`3oool0oooo0080003o00<0oooo0000o`00o`000`3oool01@00o`00oooo0?ooo`3oool00?l00140
oooo00<000000?ooo`3oool0703oool003h0oooo00<000000?ooo`3oool0B@3oool00`000000003o
000000020000o`030000003oool0oooo0?l0ooooCP3oool00`000000003o000000020?ooo`030000
00000?l000000080003o00D000000000o`000000003o000000020000o`05000000000?l000000000
o`0000004P3oool00`000000oooo0?ooo`180?ooo`800000>P3oool00`000000oooo0?ooo`0o0?oo
o`04003o003oool0oooo003o00H0oooo00D00?l00?ooo`3oool0oooo003o00020?ooo`07003o003o
ool0oooo003o003oool00?l00?ooo`03003o00030000o`3oool0oooo00D0oooo00<00?l00000o`3o
ool01P3oool00`00o`00oooo0?ooo`0l0?ooo`03003o003oool0oooo00D0oooo00<00?l00?ooo`3o
ool0603oool2003o02h0oooo00D00?l00?ooo`3oool0oooo003o000:0?ooo`03003o003oool0oooo
0080oooo00<00?l00?ooo`3oool05@3oool01@00o`00oooo0?ooo`3oool00?l00080oooo00<00?l0
0000o`00o`006P3oool00`00o`00oooo0?ooo`060?ooo`07003o00000?l0003o0?ooo`00o`00oooo
003o00030?ooo`03003o003oool0oooo0080oooo00@0003o003o003oool00?l02P3oool00`00o`00
003o003o00020000o`80oooo0P000?l20?ooo`80003o0P3oool01@00o`00oooo0?ooo`3oool00?l0
00<0oooo00<00?l00?ooo`3oool03`3oool00`000000oooo0?ooo`0L0?ooo`00?P3oool3000004T0
oooo00<000000000o`0000000P000?l00`000000oooo0?ooo`3o0?ooodh0oooo00<000000000o`00
00000P3oool00`000000003o000000020000o`05000000000?l000000000o`0000000P000?l01@00
0000003o000000000?l000000140oooo0P00001:0?ooo`800000>P3oool200000400oooo00@00?l0
0?ooo`3oool00?l01P3oool01@00o`00oooo0?ooo`3oool00?l00080oooo00L00?l00?ooo`3oool0
0?l00?ooo`00o`00oooo00<00?l000<0003o0?ooo`3oool01@3oool00`00o`00003o0?ooo`060?oo
o`03003o003oool0oooo03`0oooo00<00?l00?ooo`3oool01@3oool00`00o`00oooo0?ooo`0H0?oo
o`800?l03@3oool5000001`0oooo00D00?l00?ooo`3oool0oooo003o000:0?ooo`03003o003oool0
oooo0080oooo00<00?l00?ooo`3oool05@3oool01@00o`00oooo0?ooo`3oool00?l00080oooo00<0
0?l00000o`00o`006P3oool00`00o`00oooo0?ooo`060?ooo`07003o00000?l0003o0?ooo`00o`00
oooo003o00030?ooo`03003o003oool0oooo0080oooo00@0003o003o003oool00?l02P3oool01`00
o`00003o003o00000000003o0?ooo`000?l0203oool01@00o`00oooo0000o`000?l00?l000<0oooo
00<00?l00?ooo`3oool03`3oool00`000000oooo0?ooo`0L0?ooo`00?P3oool00`000000oooo0?oo
o`190?ooo`03000000000?l000000080003o00<000000?ooo`3oool0o`3ooom>0?ooo`0300000000
0?l000000080oooo00<000000000o`0000000P000?l01@000000003o000000000?l000000080003o
00D000000000o`000000003o0000000B0?ooo`030000003oool0oooo04H0oooo2000000f0?ooo`03
0000003oool0oooo03l0oooo00@00?l00?ooo`3oool00?l01P3oool01@00o`00oooo0?ooo`3oool0
0?l00080oooo00L00?l00?ooo`3oool00?l00?ooo`00o`00oooo00<00?l000<0003o0?ooo`3oool0
1@3oool2003o00L0oooo00<00?l00?ooo`3oool0?03oool00`00o`00oooo0?ooo`050?ooo`03003o
003oool0oooo01P0oooo0P00o`0=0?ooo`D00000703oool01P00o`00oooo0?ooo`3oool00?l00000
o`T0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`0E0?ooo`05003o003oool0oooo
0?ooo`00o`000P3oool00`00o`00003o003o000J0?ooo`03003o003oool0oooo00H0oooo00@00?l0
0000o`000?l00?l00P3oool01@00o`00oooo0?ooo`3oool00?l000@0oooo00@0003o0?ooo`00o`00
0?l02P3oool00`00o`00003o003o000200000080003o203oool01@00o`00oooo0000o`3oool00?l0
00<0oooo00<00?l00?ooo`3oool03`3oool00`000000oooo0?ooo`0L0?ooo`00?P3oool00`000000
oooo0?ooo`190?ooo`03000000000?l000000080003o00<000000?ooo`3oool0o`3ooom>0?ooo`03
000000000?l000000080oooo00<000000000o`0000000P000?l01@000000003o000000000?l00000
0080003o00D000000000o`000000003o0000000B0?ooo`030000003oool0oooo04H0oooo2000000f
0?ooo`030000003oool0oooo03l0oooo00@00?l00?ooo`3oool00?l01P3oool01@00o`00oooo0?oo
o`3oool00?l00080oooo00L00?l00?ooo`3oool00?l00000o`00o`00oooo00<00?l000<0003o0?oo
o`3oool01@3oool2003o00L0oooo00<00?l00?ooo`3oool0?03oool00`00o`00oooo0?ooo`050?oo
o`03003o003oool0oooo01P0oooo0P00o`0=0?ooo`D00000703oool01P00o`00oooo0?ooo`3oool0
0?l00000o`T0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`0E0?ooo`05003o003o
ool0oooo0?ooo`00o`000P3oool00`00o`00003o003o000J0?ooo`03003o003oool0oooo00H0oooo
00@00?l00000o`000?l00?l00P3oool01@00o`00oooo0?ooo`3oool00?l000@0oooo00@0003o0?oo
o`00o`000?l02P3oool00`00o`000000003o0002000000X0oooo00D00?l00000o`3oool0oooo003o
00030?ooo`03003o003oool0oooo00l0oooo00<000000?ooo`3oool0703oool003h0oooo00<00000
0?ooo`3oool0B@3oool00`000000003o000000020000o`030000003oool0oooo0?l0ooooCP3oool0
0`000000003o000000020?ooo`03000000000?l000000080003o00D000000000o`000000003o0000
00020000o`05000000000?l000000000o`0000004P3oool00`000000oooo0?ooo`180?ooo`800000
>P3oool00`000000oooo0?ooo`0o0?ooo`04003o003oool0oooo003o00H0oooo00D00?l00?ooo`3o
ool0oooo003o00020?ooo`07003o003oool0oooo003o00000?l00?l00?ooo`03003o00030000o`3o
ool0oooo00D0oooo0P00o`070?ooo`03003o003oool0oooo03`0oooo00<00?l00?ooo`3oool0103o
ool00`00o`00003o0?ooo`0I0?ooo`800?l03@3oool5000001`0oooo00H00?l00?ooo`3oool0oooo
003o00000?l90?ooo`03003o003oool0oooo0080oooo00<00?l00000o`3oool05@3oool01@00o`00
oooo0?ooo`3oool00?l00080oooo00<00?l00?ooo`00o`006P3oool00`00o`00oooo0?ooo`060?oo
o`04003o00000?l0003o003o0080oooo00D00?l00?ooo`3oool0oooo003o00040?ooo`040000o`3o
ool00?l0003o00X0oooo00<00?l000000000o`00100000080?ooo`05003o00000?l0oooo0?ooo`00
o`000`3oool00`00o`00oooo0?ooo`0?0?ooo`030000003oool0oooo01`0oooo000n0?ooo`030000
003oool0oooo04T0oooo00<000000000o`0000000P000?l00`000000oooo0?ooo`3o0?ooodh0oooo
00<000000000o`0000000P3oool00`000000003o000000020000o`05000000000?l000000000o`00
00000P000?l01@000000003o000000000?l000000180oooo00<000000?ooo`3oool0B03oool20000
03X0oooo00<000000?ooo`3oool0?`3oool01000o`00oooo0?ooo`00o`060?ooo`05003o003oool0
oooo0?ooo`00o`000P3oool01`00o`00oooo0?ooo`00o`00003o003o003oool00`00o`000`000?l0
oooo0?ooo`050?ooo`800?l01`3oool00`00o`00oooo0?ooo`0l0?ooo`03003o003oool0oooo00@0
oooo00<00?l00000o`3oool06@3oool2003o00d0oooo1@00000L0?ooo`06003o003oool0oooo0?oo
o`00o`00003o203oool00`000?l00?l00?ooo`030?ooo`03003o00000?l0oooo01D0oooo00D00?l0
0?ooo`3oool0oooo003o00020?ooo`03003o003oool00?l001X0oooo00<00?l00?ooo`3oool01P3o
ool01000o`00003o0000o`00o`020?ooo`05003o003oool0oooo0?ooo`00o`00103oool010000?l0
oooo003o0000o`0:0?ooo`03003o000000000?l000@00000203oool01@00o`00oooo0?ooo`3oool0
0?l000<0oooo00<00?l00?ooo`3oool03`3oool00`000000oooo0?ooo`0L0?ooo`00?P3oool00`00
0000oooo0?ooo`190?ooo`03000000000?l000000080003o00<000000?ooo`3oool0o`3ooom>0?oo
o`03000000000?l000000080oooo00<000000000o`0000000P000?l01@000000003o000000000?l0
00000080003o00D000000000o`000000003o0000000B0?ooo`030000003oool0oooo04H0oooo2P00
000d0?ooo`030000003oool0oooo03l0oooo00@00?l00?ooo`3oool00?l01P3oool01@00o`00oooo
0?ooo`3oool00?l00080oooo00L00?l00?ooo`3oool00?l00000o`00o`00oooo00<00?l000<0003o
0?ooo`3oool01@3oool2003o00L0oooo00<00?l00?ooo`3oool0?03oool00`00o`00oooo0?ooo`04
0?ooo`03003o00000?l0oooo01T0oooo00<00?l00?ooo`3oool0;@3oool01P00o`00oooo0?ooo`3o
ool00?l00000o`P0oooo00<0003o003o003oool00`3oool00`00o`00003o0?ooo`0D0?ooo`03003o
00000?l0oooo0080oooo00H00?l00?ooo`3oool00?l00?ooo`00o`0J0?ooo`03003o003oool0oooo
00H0oooo00@00?l00000o`000?l00?l00P3oool01@00o`00oooo0?ooo`3oool00?l000@0oooo00@0
003o0?ooo`00o`000?l02P3oool00`00o`00oooo003o0004000000P0oooo00D00?l00?ooo`3oool0
oooo003o00030?ooo`03003o003oool0oooo00l0oooo00<000000?ooo`3oool0703oool003h0oooo
00<000000?ooo`3oool0B@3oool00`000000003o000000020000o`030000003oool0oooo0?l0oooo
CP3oool00`000000003o000000020?ooo`03000000000?l000000080003o00D000000000o`000000
003o000000020000o`05000000000?l000000000o`0000004P3oool00`000000oooo0?ooo`160?oo
o`X00000=03oool00`000000oooo0?ooo`0o0?ooo`04003o003oool0oooo003o00H0oooo00D00?l0
0?ooo`3oool0oooo003o00020?ooo`06003o003oool0oooo003o00000?l00?l00P3oool2003o0003
0000o`3oool0oooo00D0oooo0P00o`070?ooo`03003o003oool0oooo03`0oooo00<00?l00?ooo`3o
ool0103oool00`00o`00003o0?ooo`0I0?ooo`03003o003oool0oooo02d0oooo00H00?l00?ooo`3o
ool0oooo003o00000?l80?ooo`03003o003oool0oooo00<0oooo00<00?l00000o`3oool0503oool0
0`00o`00003o0?ooo`020?ooo`06003o003oool0oooo003o003oool00?l06P3oool00`00o`00oooo
0?ooo`060?ooo`04003o00000?l0003o003o0080oooo00D00?l00?ooo`3oool0oooo003o00040?oo
o`040000o`3oool00?l0003o00/0oooo0P00o`04000000P0oooo00D00?l00?ooo`3oool0oooo003o
00030?ooo`03003o003oool0oooo00l0oooo00<000000?ooo`3oool0703oool003h0oooo00<00000
0?ooo`3oool0B@3oool00`000000003o000000020000o`030000003oool0oooo0?l0ooooCP3oool0
0`000000003o000000020?ooo`03000000000?l000000080003o00D000000000o`000000003o0000
00020000o`05000000000?l000000000o`0000004P3oool00`000000oooo0?ooo`1:0?ooo`800000
>03oool200000400oooo00@00?l00?ooo`3oool00?l01P3oool01@00o`00oooo0?ooo`3oool00?l0
0080oooo00H00?l00?ooo`3oool00?l00000o`00o`020?ooo`800?l000<0003o0?ooo`3oool01@3o
ool2003o00L0oooo00<00?l00?ooo`3oool0?03oool00`00o`00oooo0?ooo`040?ooo`03003o0000
0?l0oooo01T0oooo00<00?l00?ooo`3oool0;@3oool01P00o`00oooo0?ooo`3oool00?l00000o`P0
oooo00<00?l00?ooo`3oool00`3oool00`00o`00003o0?ooo`0D0?ooo`03003o00000?l0oooo0080
oooo00H00?l00?ooo`3oool00?l00?ooo`00o`0J0?ooo`03003o003oool0oooo00H0oooo00@00?l0
0000o`3oool00?l00P3oool01@00o`00oooo0?ooo`3oool00?l000@0oooo00@0003o0?ooo`00o`00
0?l02`3oool2003o00@00000203oool01@00o`00oooo0?ooo`3oool00?l000<0oooo00<00?l00?oo
o`3oool03`3oool00`000000oooo0?ooo`0L0?ooo`00?P3oool3000004T0oooo00<000000000o`00
00000P000?l00`000000oooo0?ooo`3o0?ooodh0oooo00<000000000o`0000000P3oool00`000000
003o000000020000o`05000000000?l000000000o`0000000P000?l00`000000003o000000020000
0140oooo0P00001<0?ooo`800000>03oool00`000000oooo0?ooo`0o0?ooo`04003o003oool0oooo
003o00H0oooo00D00?l00?ooo`3oool0oooo003o00020?ooo`06003o003oool0oooo003o00000?l0
0?l00P3oool00`00o`00oooo003o00070?ooo`800?l01`3oool00`00o`00oooo0?ooo`0l0?ooo`03
003o003oool0oooo00@0oooo00<00?l00000o`3oool06@3oool00`00o`00oooo0?ooo`0]0?ooo`06
003o003oool0oooo0?ooo`00o`00003o203oool00`00o`00oooo0?ooo`030?ooo`03003o00000?l0
oooo01@0oooo00<00?l00000o`3oool00P3oool01P00o`00oooo0?ooo`00o`00oooo003o01X0oooo
00<00?l00?ooo`3oool01P3oool01000o`00003o0?ooo`00o`020?ooo`05003o003oool0oooo0?oo
o`00o`00103oool010000?l0oooo003o0000o`0;0?ooo`800?l0303oool01@00o`00oooo0?ooo`3o
ool00?l000<0oooo00<00?l00?ooo`3oool03`3oool00`000000oooo0?ooo`0L0?ooo`00?P3oool0
0`000000oooo0?ooo`190?ooo`03000000000?l000000080003o00<000000?ooo`3oool0o`3ooom>
0?ooo`03000000000?l000000080oooo00<000000000o`0000000P000?l01@000000003o00000000
0?l000000080003o00<000000000o`000000503oool00`000000oooo0?ooo`1:0?ooo`800000>03o
ool00`000000oooo0?ooo`0o0?ooo`04003o003oool0oooo003o00H0oooo00D00?l00?ooo`3oool0
oooo003o00020?ooo`06003o003oool0oooo003o00000?l00?l00P3oool00`00o`00oooo003o0007
0?ooo`800?l01`3oool00`00o`00oooo0?ooo`0l0?ooo`03003o003oool0oooo00@0oooo00<00?l0
0000o`3oool06@3oool00`00o`00oooo0?ooo`0]0?ooo`06003o003oool0oooo0?ooo`00o`00003o
203oool00`00o`00oooo0?ooo`030?ooo`03003o00000?l0oooo01@0oooo00<00?l00000o`3oool0
0P3oool01P00o`00003o0?ooo`00o`00oooo003o01X0oooo00<00?l00?ooo`3oool01P3oool01000
o`00003o0?ooo`00o`020?ooo`05003o003oool0oooo0?ooo`00o`00103oool00`000?l0oooo0?oo
o`0<0?ooo`800?l0303oool01@00o`00oooo0?ooo`3oool00?l000<0oooo00<00?l00?ooo`3oool0
3`3oool00`000000oooo0?ooo`0L0?ooo`00?P3oool00`000000oooo0?ooo`190?ooo`0300000000
0?l000000080003o00<000000?ooo`3oool0o`3ooom>0?ooo`03000000000?l000000080oooo00<0
00000000o`0000000P000?l01@000000003o000000000?l000000080003o00<000000000o`000000
503oool00`000000oooo0?ooo`1:0?ooo`800000>03oool00`000000oooo0?ooo`0o0?ooo`04003o
003oool0oooo003o00H0oooo00D00?l00?ooo`3oool0oooo003o00020?ooo`06003o003oool0oooo
003o00000?l00?l00P3oool00`00o`00oooo003o00070?ooo`800?l01`3oool00`00o`00oooo0?oo
o`0l0?ooo`03003o003oool0oooo00@0oooo00<00?l00000o`3oool06@3oool00`00o`00oooo0?oo
o`0]0?ooo`06003o003oool0oooo0?ooo`00o`00003o203oool00`00o`00oooo0?ooo`030?ooo`03
003o00000?l0oooo01@0oooo00<00?l00000o`3oool00P3oool01P00o`00003o0000o`00o`00oooo
003o01X0oooo00<00?l00?ooo`3oool01P3oool01000o`00003o003o0000o`020?ooo`05003o0000
0?l0oooo0?ooo`00o`000`3oool00`000?l0oooo0?ooo`0=0?ooo`800?l0303oool01@00o`00oooo
0?ooo`3oool00?l000<0oooo00<00?l00?ooo`3oool03`3oool00`000000oooo0?ooo`0L0?ooo`00
?P3oool00`000000oooo0?ooo`190?ooo`03000000000?l000000080003o00<000000?ooo`3oool0
o`3ooom>0?ooo`03000000000?l000000080oooo00<000000000o`0000000P000?l01@000000003o
000000000?l000000080003o00<000000000o`000000503oool00`000000oooo0?ooo`1:0?ooo`80
0000>03oool00`000000oooo0?ooo`0o0?ooo`04003o003oool0oooo003o00H0oooo00D00?l00?oo
o`3oool0oooo003o00020?ooo`06003o003oool0oooo003o00000?l00?l00P3oool00`00o`00oooo
003o00070?ooo`800?l01`3oool00`00o`00oooo0?ooo`0l0?ooo`03003o003oool0oooo00@0oooo
00<00?l00000o`3oool06@3oool00`00o`00oooo0?ooo`0]0?ooo`06003o003oool0oooo0?ooo`00
o`00003o203oool00`00o`00oooo0?ooo`030?ooo`03003o00000?l0oooo01@0oooo00<00?l00000
o`3oool00P3oool01P00o`00oooo0000o`00o`00oooo003o01X0oooo00<00?l00?ooo`3oool01P3o
ool00`00o`00003o003o00030?ooo`05003o00000?l0oooo0?ooo`00o`000`3oool00`000?l0oooo
0?ooo`0=0?ooo`800?l00`0000090?ooo`05003o003oool0oooo0?ooo`00o`000`3oool00`00o`00
oooo0?ooo`0?0?ooo`030000003oool0oooo01`0oooo000n0?ooo`030000003oool0oooo04T0oooo
00<000000000o`0000000P000?l00`000000oooo0?ooo`3o0?ooodh0oooo00<000000000o`000000
0P3oool00`000000003o000000020000o`05000000000?l000000000o`0000000P000?l00`000000
003o0000000D0?ooo`030000003oool0oooo04X0oooo0P00000h0?ooo`030000003oool0oooo03l0
oooo00@00?l00?ooo`3oool00?l01P3oool01@00o`00oooo0?ooo`3oool00?l00080oooo00H00?l0
0?ooo`3oool00?l00000o`00o`020?ooo`03003o003oool00?l000L0oooo0P00o`070?ooo`03003o
003oool0oooo03`0oooo00<00?l00?ooo`3oool0103oool00`00o`00003o0?ooo`0I0?ooo`03003o
003oool0oooo0180oooo1@00000F0?ooo`06003o003oool0oooo0?ooo`00o`00003o203oool00`00
o`00oooo0?ooo`030?ooo`03003o00000?l0oooo01@0oooo00<00?l00000o`3oool00P3oool01P00
o`00oooo0?ooo`00o`00oooo003o01X0oooo00<00?l00?ooo`3oool01P3oool00`00o`00003o003o
00030?ooo`05003o00000?l0oooo0?ooo`00o`000`3oool00`000?l0oooo0?ooo`0=0?ooo`800?l0
0`0000090?ooo`05003o003oool0oooo0?ooo`00o`000`3oool00`00o`00oooo0?ooo`0?0?ooo`03
0000003oool0oooo01`0oooo000n0?ooo`030000003oool0oooo04T0oooo00<000000000o`000000
0P000?l00`000000oooo0?ooo`3o0?ooodh0oooo00<000000000o`0000000P3oool00`000000003o
000000020000o`05000000000?l000000000o`0000000P000?l00`000000003o0000000D0?ooo`03
0000003oool0oooo04P0oooo1000000h0?ooo`800000@03oool01000o`00oooo0?ooo`00o`060?oo
o`05003o003oool0oooo0?ooo`00o`000P3oool01P00o`00oooo0?ooo`00o`00003o003o0080oooo
00<00?l00?ooo`00o`001`3oool2003o00030000o`3oool0oooo00@0oooo00<00?l00?ooo`3oool0
?03oool00`00o`00oooo0?ooo`040?ooo`03003o00000?l0oooo01T0oooo00<00?l00?ooo`3oool0
4P3oool5000001H0oooo00H00?l00?ooo`3oool0oooo003o00000?l80?ooo`03003o003oool0oooo
00<0oooo00<00?l00000o`3oool0503oool00`00o`00003o0?ooo`020?ooo`06003o003oool0oooo
003o003oool00?l06P3oool00`00o`00oooo0?ooo`070?ooo`800?l00`3oool01@00o`00003o0?oo
o`3oool00?l000<0oooo00<0003o0?ooo`3oool03@3oool2003o00D000001`3oool01@00o`00oooo
0?ooo`3oool00?l000<0oooo00<00?l00?ooo`3oool03`3oool00`000000oooo0?ooo`0L0?ooo`00
?P3oool00`000000oooo0?ooo`190?ooo`03000000000?l000000080003o00<000000?ooo`3oool0
o`3ooom>0?ooo`03000000000?l000000080oooo00<000000000o`0000000P000?l01@000000003o
000000000?l000000080003o00<000000000o`000000503oool00`000000oooo0?ooo`180?ooo`@0
0000>03oool00`000000oooo0?ooo`0o0?ooo`04003o003oool0oooo003o00H0oooo00D00?l00?oo
o`3oool0oooo003o00020?ooo`03003o003oool0oooo00800?l00`3oool00`00o`00oooo003o0007
0?ooo`800?l000<0003o0?ooo`3oool0103oool00`00o`00oooo0?ooo`0l0?ooo`03003o003oool0
oooo00@0oooo00<00?l00000o`3oool06@3oool00`00o`00oooo0?ooo`0B0?ooo`D000005P3oool0
0`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo00H0oooo00<00?l00?ooo`3oool00`3oool0
0`00o`00003o0?ooo`0D0?ooo`03003o00000?l0oooo0080oooo00H00?l00?ooo`3oool00?l00?oo
o`00o`0J0?ooo`03003o003oool0oooo00L0oooo0P00o`030?ooo`05003o00000?l0000000000000
o`000P0000000`3oool0003o0?ooo`0>0?ooo`800?l01@0000070?ooo`03003o003oool00?l00080
0?l00`3oool00`00o`00oooo0?ooo`0?0?ooo`030000003oool0oooo01`0oooo000n0?ooo`<00000
B@3oool00`000000003o000000020000o`030000003oool0oooo0?l0ooooCP3oool00`000000003o
000000020?ooo`03000000000?l000000080003o00D000000000o`000000003o000000020000o`03
000000000?l0000001<0oooo0P0000260?ooo`030000003oool0oooo03l0oooo00@00?l00?ooo`3o
ool00?l01P3oool01@00o`00oooo0000o`3oool00?l00080oooo00<00?l00?ooo`3oool00P00o`03
0?ooo`03003o003oool00?l000L0oooo0P00o`000`000?l0oooo0?ooo`040?ooo`03003o003oool0
oooo03`0oooo00<00?l00?ooo`3oool0103oool00`00o`00003o0?ooo`0I0?ooo`03003o003oool0
oooo0180oooo1@00000F0?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool01P3oool0
0`00o`00oooo0?ooo`030?ooo`05003o00000?l0oooo0?ooo`000?l04P3oool00`00o`00003o0?oo
o`020?ooo`06003o003oool0oooo003o003oool00?l06P3oool00`00o`00oooo0?ooo`070?ooo`80
0?l00`3oool01@00o`00003o0000000000000?l000<0000000<0003o0?ooo`3oool03@3oool2003o
00D000001`3oool2003o00H0oooo00<00?l00?ooo`3oool03`3oool00`000000oooo0?ooo`0L0?oo
o`00?P3oool00`000000oooo0?ooo`190?ooo`03000000000?l000000080003o00<000000?ooo`3o
ool0o`3ooom>0?ooo`03000000000?l000000080oooo00<000000000o`0000000P000?l01@000000
003o000000000?l000000080003o00<000000000o`000000503oool00`000000oooo0?ooo`1@0?oo
o`@00000203oool2000000X0oooo0P0000080?ooo`H00000303oool00`000000oooo0?ooo`0o0?oo
o`04003o003oool0oooo003o00H0oooo00D00?l00000o`3oool0003o003o00020?ooo`03003o003o
ool0oooo00800?l00`3oool00`00o`00oooo003o00070?ooo`800?l000<0003o0?ooo`3oool0103o
ool00`00o`00oooo0?ooo`0l0?ooo`03003o003oool0oooo00@0oooo00<00?l00000o`3oool06@3o
ool00`00o`00oooo0?ooo`0:0?ooo`D000000`3oool5000001H0oooo00<00?l00?ooo`3oool00P3o
ool00`00o`00oooo0?ooo`060?ooo`03003o003oool0oooo00@0oooo00@00?l00?ooo`000?l0003o
4P3oool00`00o`00oooo0?ooo`020?ooo`06003o003oool0oooo003o003oool00?l06P3oool00`00
o`00oooo0?ooo`070?ooo`800?l00`3oool01@00o`00003o0000000000000?l000<0000000<0003o
0?ooo`3oool03@3oool2003o00D000003`3oool00`00o`00oooo0?ooo`0?0?ooo`030000003oool0
oooo01`0oooo000n0?ooo`030000003oool0oooo04T0oooo00<000000000o`0000000P000?l00`00
0000oooo0?ooo`3o0?ooodh0oooo00<000000000o`0000000P3oool00`000000003o000000020000
o`05000000000?l000000000o`0000000P000?l00`000000003o0000000D0?ooo`030000003oool0
oooo04P0oooo100000040?ooo`@00000203oool2000000X0oooo0P0000080?ooo`H00000303oool0
0`000000oooo0?ooo`0o0?ooo`04003o003oool0003o003o00H0oooo00D00?l00?ooo`3oool0oooo
003o00020?ooo`03003o003oool0oooo00800?l00`3oool00`00o`00oooo003o00070?ooo`800?l0
00<0oooo0000o`3oool0103oool00`00o`00oooo0?ooo`0l0?ooo`03003o003oool0oooo00@0oooo
00<00?l00000o`3oool06@3oool00`00o`00oooo0?ooo`0:0?ooo`H000007@3oool00`00o`00oooo
0?ooo`020?ooo`03003o003oool0oooo00H0oooo00<00?l00?ooo`3oool0103oool01000o`00003o
0000o`000?lB0?ooo`03003o003oool0oooo0080oooo00H00?l00?ooo`3oool00?l00?ooo`00o`0J
0?ooo`03003o003oool0oooo00L0oooo0P00o`030?ooo`05003o00000?l0000000000000o`000`00
00000`000?l0oooo0?ooo`0?0?ooo`D000003`3oool00`00o`00oooo0?ooo`0?0?ooo`030000003o
ool0oooo01`0oooo000n0?ooo`030000003oool0oooo04T0oooo00<000000000o`0000000P000?l0
0`000000oooo0?ooo`3o0?ooodh0oooo00<000000000o`0000000P3oool00`000000003o00000002
0000o`05000000000?l000000000o`0000000P000?l00`000000003o0000000D0?ooo`030000003o
ool0oooo04P0oooo100000020?ooo`800000103oool200000180oooo0P00000>0?ooo`8000002P3o
ool00`000000oooo0?ooo`0o0?ooo`04003o00000?l0003o003o00H0oooo00D00?l00?ooo`3oool0
oooo003o00020?ooo`03003o003oool0oooo00800?l00`3oool00`00o`00oooo003o00070?ooo`80
0?l000<0oooo0000o`3oool0103oool00`00o`00oooo0?ooo`0l0?ooo`03003o003oool0oooo00@0
oooo00<00?l00000o`3oool06@3oool00`00o`00oooo0?ooo`0:0?ooo`H000007@3oool00`00o`00
oooo0?ooo`020?ooo`03003o003oool0oooo00H0oooo00<00?l00?ooo`3oool0103oool01000o`00
003o0?ooo`000?lB0?ooo`03003o003oool0oooo0080oooo00H00?l00?ooo`3oool00?l00?ooo`00
o`0J0?ooo`03003o003oool0oooo00L0oooo0P00o`030?ooo`05003o00000?l0000000000000o`00
0`0000000`000?l0oooo0?ooo`0S0?ooo`03003o003oool0oooo00l0oooo00<000000?ooo`3oool0
703oool003h0oooo00<000000?ooo`3oool0B@3oool00`000000003o000000020000o`030000003o
ool0oooo0?l0ooooCP3oool00`000000003o000000020?ooo`03000000000?l000000080003o00D0
00000000o`000000003o000000020000o`03000000000?l0000001@0oooo00<000000?ooo`3oool0
AP3oool2000000@0oooo100000040?ooo`8000004P3oool2000000h0oooo0P00000:0?ooo`030000
003oool0oooo03l0oooo00@00?l00?ooo`3oool00?l01P3oool01@00o`00oooo0?ooo`3oool00?l0
0080oooo00<00?l00?ooo`3oool00P00o`030?ooo`03003o003oool00?l000L0oooo0P00o`000`3o
ool0003o0?ooo`020?ooo`80003o00<00?l00?ooo`3oool0?03oool00`00o`00oooo0?ooo`040?oo
o`03003o00000?l0oooo01T0oooo00<00?l00?ooo`3oool02P3oool6000001d0oooo00<00?l00?oo
o`3oool00P3oool00`00o`00oooo0?ooo`060?ooo`03003o003oool0oooo00@0oooo00@00?l00000
o`3oool0003o4P3oool00`00o`00oooo0?ooo`020?ooo`06003o003oool0oooo003o003oool00?l0
6P3oool00`00o`00oooo0?ooo`070?ooo`800?l00`3oool01@00o`00003o0?ooo`0000000?l000<0
000000<0003o0?ooo`3oool08`3oool00`00o`00oooo0?ooo`0?0?ooo`030000003oool0oooo01`0
oooo000]0?ooo`@000000P3oool3000000P0oooo00<000000?ooo`3oool0B@3oool00`000000003o
000000020000o`030000003oool0oooo0?l0ooooCP3oool00`000000003o000000020?ooo`030000
00000?l000000080003o00D000000000o`000000003o000000020000o`03000000000?l0000001@0
oooo00<000000?ooo`3oool0AP3oool2000000@0oooo100000040?ooo`800000503oool2000000`0
oooo0P00000:0?ooo`<00000?`3oool01000o`00oooo0?ooo`00o`060?ooo`05003o003oool0oooo
0?ooo`00o`000P3oool00`00o`00oooo0?ooo`02003o00<0oooo00<00?l00?ooo`00o`001`3oool2
003o00030?ooo`000?l0003o0080003o00<0oooo0000o`00o`00?P3oool00`00o`00oooo0?ooo`04
0?ooo`03003o00000?l0oooo01T0oooo00<00?l00?ooo`3oool02P3oool6000001d0oooo00<00?l0
0?ooo`3oool00P3oool00`00o`00oooo0?ooo`060?ooo`03003o003oool0oooo00@0oooo00@00?l0
0?ooo`3oool0oooo0P000?l@0?ooo`03003o003oool0oooo0080oooo00H00?l00?ooo`3oool00?l0
0?ooo`00o`0J0?ooo`03003o003oool0oooo00L0oooo00<00?l00?ooo`3oool00P3oool01@00o`00
003o0?ooo`3oool00?l000<0oooo00<0003o0?ooo`3oool08`3oool00`00o`00oooo0?ooo`0?0?oo
o`030000003oool0oooo01`0oooo000_0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`190?ooo`03000000000?l000000080003o00<000000?ooo`3o
ool0o`3ooom>0?ooo`03000000000?l000000080oooo00<000000000o`0000000P000?l01@000000
003o000000000?l000000080003o00<000000000o`000000503oool00`000000oooo0?ooo`160?oo
o`800000103oool4000000@0oooo0P00000D0?ooo`800000303oool2000000X0oooo00<000000?oo
o`3oool0?`3oool01000o`00oooo0?ooo`00o`060?ooo`05003o003oool0oooo0?ooo`00o`000P3o
ool00`00o`00oooo0?ooo`02003o00<0oooo00<00?l00?ooo`00o`001`3oool2003o00L0oooo00<0
0?l00?ooo`3oool0?03oool00`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo01T0oooo00<0
0?l00?ooo`3oool02`3oool5000001d0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?oo
o`060?ooo`03003o003oool0oooo00@0oooo00@00?l00?ooo`3oool0oooo0P000?l@0?ooo`03003o
003oool0oooo0080oooo00H00?l00?ooo`3oool00?l00?ooo`00o`0J0?ooo`03003o003oool0oooo
00L0oooo00<00?l00?ooo`3oool00P3oool01@00o`00003o0?ooo`3oool00?l000<0oooo00<0003o
0?ooo`3oool08`3oool00`00o`00oooo0?ooo`0?0?ooo`030000003oool0oooo01`0oooo000_0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool4000004P0oooo00<000000000
o`0000000P000?l00`000000oooo0?ooo`3o0?ooodh0oooo0`0000020?ooo`03000000000?l00000
0080003o00D000000000o`000000003o000000020000o`03000000000?l000000180oooo0`000018
0?ooo`800000103oool4000000@0oooo0P00000D0?ooo`8000001P3oool6000000`0oooo00<00000
0?ooo`3oool0?`3oool01000o`00oooo0?ooo`00o`060?ooo`05003o003oool0oooo0?ooo`00o`00
0P3oool00`00o`00oooo0?ooo`02003o00<0oooo00<00?l00?ooo`00o`001`3oool2003o00L0oooo
00<00?l00?ooo`3oool0?03oool00`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo01T0oooo
00<00?l00?ooo`3oool0;@3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo00H0oooo
00<00?l00?ooo`3oool0103oool01000o`00oooo0?ooo`3oool20000oa00oooo00<00?l00?ooo`3o
ool00P3oool01P00o`00oooo0?ooo`00o`00oooo003o01X0oooo00<00?l00?ooo`3oool01`3oool0
0`00o`00oooo0?ooo`020?ooo`05003o00000?l0oooo0?ooo`00o`000`3oool00`000?l0oooo0?oo
o`0S0?ooo`03003o003oool0oooo00l0oooo00<000000?ooo`3oool0703oool002l0oooo00@00000
0?ooo`3oool0oooo0`0000080?ooo`030000003oool0oooo04T0oooo00<000000000o`0000000P00
0?l00`000000oooo0?ooo`3o0?oooe<0oooo00<000000000o`0000000P000?l01@000000003o0000
00000?l000000080003o00<000000000o`000000503oool00`000000oooo0?ooo`160?ooo`800000
103oool4000000@0oooo0P00000D0?ooo`8000001P3oool6000000`0oooo00<000000?ooo`3oool0
?`3oool01000o`00oooo0?ooo`00o`060?ooo`05003o003oool0oooo0?ooo`00o`000P3oool00`00
o`00oooo0?ooo`02003o00<0oooo00<00?l00?ooo`00o`001`3oool2003o00L0oooo00<00?l00?oo
o`3oool0?03oool00`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo01T0oooo00<00?l00?oo
o`3oool0;@3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo00H0oooo00<00?l00?oo
o`3oool0103oool01000o`00oooo0?ooo`3oool20000oa00oooo00<00?l00?ooo`3oool00P3oool0
1P00o`00oooo0?ooo`00o`00oooo003o01X0oooo00<00?l00?ooo`3oool01`3oool00`00o`00oooo
0?ooo`030?ooo`04003o003oool0oooo003o00<0oooo00<0003o0?ooo`3oool08`3oool00`00o`00
003o0?ooo`0?0?ooo`030000003oool0oooo01`0oooo000_0?ooo`050000003oool0oooo0?ooo`00
00002P3oool00`000000oooo0?ooo`190?ooo`03000000000?l000000080003o00<000000?ooo`3o
ool0o`3ooomC0?ooo`03000000000?l000000080003o00D000000000o`000000003o000000020000
o`03000000000?l0000001@0oooo00<000000?ooo`3oool0AP3oool2000000@0oooo100000040?oo
o`8000005P3oool2000000@0oooo0P00000@0?ooo`030000003oool0oooo03l0oooo00@00?l00?oo
o`3oool00?l01P3oool01@00o`00oooo0?ooo`3oool00?l00080oooo00<00?l00?ooo`3oool00P00
o`030?ooo`03003o003oool00?l000L0oooo0P00o`070?ooo`03003o003oool0oooo03`0oooo00<0
0?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`190?ooo`03003o003oool0oooo0080oooo00<0
0?l00?ooo`3oool01P3oool00`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo0080oooo00<0
003o0?ooo`3oool03P3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool00?l00080oooo00<0
0?l00?ooo`3oool0603oool00`00o`00oooo0?ooo`070?ooo`03003o003oool0oooo00<0oooo00<0
0?l00?ooo`00o`00103oool00`000?l0oooo0?ooo`0S0?ooo`03003o00000?l0oooo00l0oooo00<0
00000?ooo`3oool0703oool002d0oooo0`0000030?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0B@3oool00`000000003o000000020000o`030000003oool0oooo0?l0ooooD`3oool0
0`000000003o000000020000o`05000000000?l000000000o`0000000P000?l00`000000003o0000
000D0?ooo`030000003oool0oooo04P0oooo100000020?ooo`800000103oool2000001H0oooo0P00
00040?ooo`800000403oool00`000000oooo0?ooo`0o0?ooo`04003o003oool0oooo003o00H0oooo
00D00?l00?ooo`3oool0oooo003o00020?ooo`03003o003oool0oooo00800?l00`3oool00`00o`00
oooo003o00070?ooo`<00?l01P3oool00`00o`00oooo0?ooo`0l0?ooo`03003o003oool0oooo00@0
oooo00<00?l00?ooo`3oool0B@3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo00H0
oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`020?ooo`030000o`3oool0oooo00h0
oooo00<00?l00?ooo`3oool00`3oool2003o0080oooo00<00?l00?ooo`3oool0603oool00`00o`00
oooo0?ooo`070?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`00o`00103oool00`000?l0
oooo0?ooo`0S0?ooo`03003o00000?l0oooo00l0oooo00<000000?ooo`3oool0703oool002l0oooo
00@000000?ooo`3oool0oooo100000070?ooo`030000003oool0oooo04T0oooo00<000000000o`00
00000P000?l00`000000oooo0?ooo`3o0?oooe<0oooo00<000000000o`0000000P000?l01@000000
003o000000000?l000000080003o00<000000000o`000000503oool00`000000oooo0?ooo`180?oo
o`@000000P3oool2000000@0oooo0P00000@0?ooo`800000103oool2000000@0oooo0P00000@0?oo
o`800000@03oool01000o`00oooo0?ooo`00o`060?ooo`05003o003oool0oooo0?ooo`00o`001@3o
ool2003o00<0oooo00<00?l00?ooo`00o`001`3oool3003o00H0oooo00<00?l00?ooo`3oool0?03o
ool00`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo04T0oooo00<00?l00?ooo`3oool00P3o
ool00`00o`00oooo0?ooo`060?ooo`03003o003oool0oooo00@0oooo00<00?l00?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`0>0?ooo`03003o003oool0oooo00L0oooo00<00?l00?ooo`3oool05`3o
ool00`000?l00?l00?ooo`080?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`00o`00103o
ool00`000?l0oooo0?ooo`0S0?ooo`03003o00000?l0oooo00l0oooo00<000000?ooo`3oool0703o
ool003h0oooo00<000000?ooo`3oool0B@3oool00`000000003o000000020000o`030000003oool0
oooo0?l0ooooD`3oool00`000000003o000000020000o`05000000000?l000000000o`0000000P00
0?l00`000000003o0000000D0?ooo`030000003oool0oooo04h0oooo0P0000040?ooo`800000403o
ool2000000@0oooo0P0000040?ooo`800000403oool00`000000oooo0?ooo`0o0?ooo`04003o003o
ool0oooo003o00H0oooo00D00?l00?ooo`3oool0oooo003o00050?ooo`800?l00`3oool00`00o`00
oooo003o00070?ooo`<00?l01P3oool00`00o`00oooo0?ooo`0l0?ooo`03003o003oool0oooo00@0
oooo00<00?l00?ooo`3oool01@3oool5000003l0oooo00<00?l00?ooo`3oool00P3oool00`00o`00
oooo0?ooo`060?ooo`03003o003oool0oooo00@0oooo00<00?l00?ooo`3oool00P3oool00`000?l0
oooo0?ooo`0>0?ooo`03003o003oool0oooo00L0oooo00<00?l00?ooo`3oool05`3oool00`000?l0
0?l00?ooo`080?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`00o`00103oool00`000?l0
oooo0?ooo`0S0?ooo`03003o00000?l0oooo00l0oooo00<000000?ooo`3oool0703oool002T0oooo
0`00000B0?ooo`030000003oool0oooo04T0oooo00<000000000o`0000000P000?l00`000000oooo
0?ooo`3o0?oooe<0oooo00<000000000o`0000000P000?l01@000000003o000000000?l000000080
003o00<000000000o`000000503oool00`000000oooo0?ooo`1@0?ooo`@000004P3oool8000000@0
oooo2000000:0?ooo`030000003oool0oooo03l0oooo00@00?l00?ooo`3oool00?l01P3oool01@00
o`00oooo0?ooo`3oool00?l000D0oooo0P00o`030?ooo`03003o003oool00?l000L0oooo0`00o`06
0?ooo`03003o003oool0oooo03`0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`05
0?ooo`D00000?`3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo00H0oooo00<00?l0
0?ooo`3oool0103oool00`00o`00oooo0?ooo`020?ooo`030000o`3oool0oooo00h0oooo00<00?l0
0?ooo`3oool01`3oool00`00o`00oooo0?ooo`0G0?ooo`030000o`00o`00oooo00P0oooo00<00?l0
0?ooo`3oool00`3oool00`00o`00oooo003o00040?ooo`030000o`3oool0oooo02<0oooo00<00?l0
0000o`3oool03`3oool00`000000oooo0?ooo`0L0?ooo`00:03oool00`000000oooo0?ooo`0C0?oo
o`<00000B@3oool00`000000003o000000020000o`030000003oool0oooo0?l0ooooD`3oool00`00
0000003o000000020000o`05000000000?l000000000o`0000000P000?l00`000000003o0000000C
0?ooo`800000DP3oool400000180oooo200000040?ooo`P000002P3oool00`000000oooo0?ooo`0o
0?ooo`04003o003oool0oooo003o00H0oooo0P00o`020?ooo`03003o003oool0oooo00<0oooo0P00
o`030?ooo`03003o003oool00?l000L0oooo0`00o`060?ooo`03003o003oool0oooo03`0oooo00<0
0?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`050?ooo`L00000?@3oool00`00o`00oooo0?oo
o`020?ooo`03003o003oool0oooo00H0oooo00<00?l00?ooo`3oool0103oool01P00o`00oooo0?oo
o`00o`00oooo0000oa00oooo00<00?l00?ooo`3oool01`3oool00`00o`00oooo0?ooo`0G0?ooo`03
0000o`00o`00oooo00P0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo003o00040?ooo`03
0000o`3oool0oooo02<0oooo00<00?l00000o`3oool03`3oool00`000000oooo0?ooo`0L0?ooo`00
:03oool3000001<0oooo00<000000?ooo`3oool0B@3oool00`000000003o000000020000o`030000
003oool0oooo0?l0ooooD`3oool00`000000003o000000020000o`05000000000?l000000000o`00
00000P000?l00`000000003o0000000D0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3o
ool0?`3oool01000o`00oooo0?ooo`00o`060?ooo`800?l00P3oool00`00o`00oooo0?ooo`030?oo
o`800?l00`3oool00`00o`00oooo003o00070?ooo`<00?l01P3oool00`00o`00oooo0?ooo`0l0?oo
o`03003o003oool0oooo00@0oooo00<00?l00?ooo`3oool01@3oool7000002<0oooo3@00000=0?oo
o`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool01P3oool00`00o`00oooo0?ooo`040?oo
o`06003o003oool00?l0003o003oool0003o403oool00`00o`00oooo0?ooo`070?ooo`03003o003o
ool0oooo01L0oooo00<0003o003o003oool0203oool00`00o`00oooo0?ooo`030?ooo`03003o003o
ool00?l000@0oooo00<0003o0?ooo`3oool08`3oool00`00o`00003o0?ooo`0?0?ooo`030000003o
ool0oooo01`0oooo000X0?ooo`040000003oool0oooo00000180oooo00<000000?ooo`3oool0B@3o
ool00`000000003o000000020000o`030000003oool0oooo0?l0ooooD`3oool00`000000003o0000
00020000o`05000000000?l000000000o`0000000P000?l00`000000003o0000000D0?ooo`030000
003oool0oooo08@0oooo00<000000?ooo`3oool0?`3oool01000o`00oooo0?ooo`00o`060?ooo`04
003o003oool00?l0003o00H0oooo0P00o`030?ooo`03003o003oool00?l000L0oooo00@00?l00?oo
o`3oool00?l01@3oool00`00o`00oooo0?ooo`0l0?ooo`03003o003oool0oooo00@0oooo00<00?l0
0?ooo`3oool01@3oool7000002<0oooo3P00000<0?ooo`03003o003oool0oooo0080oooo00<00?l0
0?ooo`3oool01P3oool00`00o`00oooo0?ooo`040?ooo`@00?l000<0oooo0000o`3oool03`3oool0
0`00o`00oooo0?ooo`070?ooo`03003o003oool0oooo01L0oooo00<0003o003o003oool03P3oool0
0`00o`00oooo003o00040?ooo`030000o`3oool0oooo02<0oooo00<00?l00000o`3oool03`3oool0
0`000000oooo0?ooo`0L0?ooo`00:@3oool2000001<0oooo00<000000?ooo`3oool0B@3oool00`00
0000003o000000020000o`030000003oool0oooo0?l0ooooD`3oool00`000000003o000000020000
o`05000000000?l000000000o`0000000P000?l00`000000003o0000000D0?ooo`030000003oool0
oooo08@0oooo0P0000100?ooo`04003o003oool00?l0003o00P0oooo00<00?l00?ooo`3oool01@3o
ool2003o00D0oooo00<00?l00?ooo`3oool01@3oool01000o`00oooo0?ooo`00o`050?ooo`03003o
003oool0oooo03`0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`070?ooo`D00000
8`3oool>000000`0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`060?ooo`03003o
003oool0oooo00@0oooo0P00o`00103oool00?l00?ooo`000?l@0?ooo`03003o003oool0oooo00L0
oooo00<00?l00?ooo`3oool05`3oool00`000?l00?l00?ooo`0>0?ooo`03003o003oool00?l000@0
oooo00<0003o0?ooo`3oool08`3oool00`00o`00003o0?ooo`0?0?ooo`030000003oool0oooo01`0
oooo000n0?ooo`030000003oool0oooo04T0oooo00<000000000o`0000000P000?l00`000000oooo
0?ooo`3o0?oooe<0oooo00<000000000o`0000000P000?l01@000000003o000000000?l000000080
003o00<000000000o`000000503oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo03l0
oooo1000o`0@0?ooo`03003o003oool0oooo00@0oooo00<00?l00?ooo`3oool01@3oool01P00o`00
oooo0?ooo`00o`00oooo003o00<0oooo00<00?l00?ooo`3oool0?03oool00`00o`00oooo0?ooo`04
0?ooo`03003o003oool0oooo00L0oooo1@00000N0?oooa<00000303oool00`00o`00oooo0?ooo`02
0?ooo`03003o003oool0oooo00H0oooo00<00?l00?ooo`3oool0103oool2003o0080oooo00<00?l0
0000o`3oool03`3oool00`00o`00oooo0?ooo`070?ooo`03003o003oool0oooo01L0oooo00<0003o
003o003oool03P3oool00`00o`00oooo003o00040?ooo`030000o`3oool0oooo02<0oooo00<00?l0
0000o`3oool03`3oool00`000000oooo0?ooo`0L0?ooo`009`3oool3000000030?ooo`0000000000
0140oooo00<000000?ooo`3oool0B@3oool00`000000003o000000020000o`030000003oool0oooo
0?l0ooooD`3oool00`000000003o000000020000o`05000000000?l000000000o`0000000P000?l0
0`000000003o0000000D0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0?`3oool2
003o00030?ooo`00o`00oooo00l0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`05
0?ooo`03003o003oool0oooo00800?l000@0oooo003o003oool00?l0?`3oool00`00o`00oooo0?oo
o`040?ooo`03003o003oool0oooo02X0oooo4`00000<0?ooo`03003o003oool0oooo0080oooo00<0
0?l00?ooo`3oool01P3oool00`00o`00oooo0?ooo`040?ooo`06003o003oool0oooo0?ooo`00o`00
003o403oool00`00o`00oooo0?ooo`070?ooo`03003o003oool0oooo01L0oooo00<0003o003o003o
ool03P3oool00`00o`00oooo003o00040?ooo`030000o`3oool0oooo02<0oooo00<00?l00000o`3o
ool03`3oool00`000000oooo0?ooo`0L0?ooo`00:03oool010000000oooo0?ooo`00000B0?ooo`03
0000003oool0oooo04T0oooo00<000000000o`0000000P000?l00`000000oooo0?ooo`3o0?oooe<0
oooo00<000000000o`0000000P000?l01@000000003o000000000?l000000080003o00<000000000
o`000000503oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo03l0oooo0P00o`000`3o
ool00?l00?ooo`0F0?ooo`03003o003oool0oooo00D0oooo00<00?l00?ooo`3oool00P00o`020?oo
o`800?l0?`3oool00`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo02X0oooo1@0000000`3o
ool000000000000;00000140oooo00<0003o003o003oool01P3oool00`00o`00oooo0?ooo`040?oo
o`04003o003oool0oooo0?ooo`800?l0403oool00`00o`00oooo0?ooo`070?ooo`03003o003oool0
oooo01L0oooo00<0003o003o003oool03P3oool00`00o`00oooo003o00040?ooo`030000o`3oool0
oooo02<0oooo00<00?l00000o`3oool03`3oool00`000000oooo0?ooo`0L0?ooo`00:03oool01000
0000oooo0?ooo`00000B0?ooo`030000003oool0oooo04T0oooo00<000000000o`0000000P000?l0
0`000000oooo0?ooo`3o0?oooe<0oooo00<000000000o`0000000P000?l01@000000003o00000000
0?l000000080003o00<000000000o`000000503oool00`000000oooo0?ooo`240?ooo`030000003o
ool0oooo03l0oooo00<00?l00?ooo`3oool0603oool00`00o`00oooo0?ooo`050?ooo`04003o003o
ool0oooo003o00@0oooo00<00?l00?ooo`3oool0?@3oool00`00o`00oooo0?ooo`040?ooo`03003o
003oool0oooo02X0oooo1@0000000`3oool0000000000008000001@0oooo00<0003o003o003oool0
1P3oool00`00o`00oooo0?ooo`040?ooo`04003o003oool0oooo0?ooo`800?l0403oool00`00o`00
oooo0?ooo`070?ooo`03003o003oool0oooo01L0oooo00<0003o003o003oool03P3oool00`00o`00
oooo003o00040?ooo`030000o`3oool0oooo02<0oooo00<00?l00000o`3oool03`3oool00`000000
oooo0?ooo`0L0?ooo`00:03oool010000000oooo0?ooo`00000B0?ooo`<00000B@3oool00`000000
003o000000020000o`030000003oool0oooo0?l0ooooD`3oool00`000000003o000000020000o`05
000000000?l000000000o`0000000P000?l00`000000003o0000000C0?ooo`800000QP3oool00`00
0000oooo0?ooo`0o0?ooo`03003o003oool0oooo01P0oooo00<00?l00?ooo`3oool0103oool00`00
0?l00?l00?ooo`160?ooo`03003o003oool0oooo00@0oooo00<00?l00?ooo`3oool0:P3oool50000
00030?ooo`000000000000@00000603oool00`000?l00?l00?ooo`060?ooo`03003o003oool0oooo
00T0oooo00<00?l00?ooo`3oool0103oool5000000D0oooo00<00?l00?ooo`3oool01`3oool00`00
o`00oooo0?ooo`0G0?ooo`030000o`00o`00oooo00h0oooo00<00?l00?ooo`00o`00103oool00`00
0?l0oooo0?ooo`0S0?ooo`03003o00000?l0oooo00l0oooo00<000000?ooo`3oool0703oool002L0
oooo00@000000?ooo`00000000004`3oool00`000000oooo0?ooo`190?ooo`03000000000?l00000
0080003o00<000000?ooo`3oool0o`3ooomC0?ooo`03000000000?l000000080003o00D000000000
o`000000003o000000020000o`03000000000?l0000001@0oooo00<000000?ooo`3oool0Q03oool0
0`000000oooo0?ooo`1J0?ooo`03003o003oool0oooo00@0oooo00<0003o003o003oool0AP3oool0
0`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo04h0oooo00<0003o003o003oool01@3oool0
0`00o`00003o0?ooo`0:0?ooo`03003o003oool0oooo00@0oooo1@0000050?ooo`03003o003oool0
oooo00L0oooo00<00?l00?ooo`3oool05`3oool00`000?l00?l00?ooo`0>0?ooo`03003o003oool0
0?l000@0oooo00<0003o0?ooo`3oool0403oool5000000h0oooo00<00?l00000o`3oool00P3oool5
000000P0oooo00<000000?ooo`3oool0703oool003h0oooo00<000000?ooo`3oool0B@3oool00`00
0000003o000000020000o`030000003oool0oooo0?l0ooooD`3oool00`000000003o000000020000
o`05000000000?l000000000o`0000000P000?l00`000000003o0000000D0?ooo`030000003oool0
oooo08@0oooo0P00001K0?ooo`03003o003oool0oooo00@0oooo00<0003o003o003oool0AP3oool0
0`00o`00003o0?ooo`040?ooo`03003o003oool0oooo04l0oooo00<00?l00?ooo`3oool0103oool0
0`00o`00003o0?ooo`0:0?ooo`03003o003oool0oooo00@0oooo1@0000050?ooo`03003o003oool0
oooo00L0oooo00<00?l00?ooo`3oool05`3oool00`000?l00?l00?ooo`0>0?ooo`03003o003oool0
0?l000<0oooo0P000?lB0?ooo`X000002P3oool01000o`00oooo0?ooo`3oool5000000P0oooo00<0
00000?ooo`3oool0703oool002X0oooo0P00000B0?ooo`030000003oool0oooo04T0oooo00<00000
0000o`0000000P000?l00`000000oooo0?ooo`3o0?oooe<0oooo00<000000000o`0000000P000?l0
1@000000003o000000000?l000000080003o00<000000000o`000000503oool00`000000oooo0?oo
o`240?ooo`030000003oool0oooo05X0oooo00<00?l00?ooo`3oool0103oool00`000?l00?l00?oo
o`160?ooo`03003o00000?l0oooo00@0oooo00<00?l00?ooo`3oool0C`3oool00`00o`00oooo0?oo
o`040?ooo`03003o00000?l0oooo00X0oooo00<00?l00?ooo`3oool0103oool5000000D0oooo00<0
0?l00?ooo`3oool01`3oool00`00o`00oooo0?ooo`0G0?ooo`030000o`00o`00oooo00h0oooo00<0
0?l00?ooo`00o`000`000?lD0?oooa@0000000<00?l00?ooo`0000001P0000080?ooo`030000003o
ool0oooo01`0oooo000Y0?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3oool0B@3o
ool00`000000003o000000020000o`030000003oool0oooo0?l0ooooD`3oool00`000000003o0000
00020000o`05000000000?l000000000o`0000000P000?l00`000000003o0000000D0?ooo`030000
003oool0oooo04@0oooo100000020?ooo`@00000=P3oool00`000000oooo0?ooo`1J0?ooo`03003o
003oool0oooo00@0oooo00<0003o003o003oool0AP3oool00`00o`00003o0?ooo`040?ooo`03003o
003oool0oooo02d0oooo1@00000M0?ooo`03003o003oool0oooo00@0oooo00<00?l00000o`3oool0
2P3oool00`00o`00oooo0?ooo`040?ooo`D000001@3oool00`00o`00oooo0?ooo`070?ooo`03003o
003oool0oooo00X0oooo1@0000080?ooo`030000o`00o`00oooo00h0oooo00<00?l00000o`00o`00
5`3ooolD00000003003o003oool0000000H00000203oool00`000000oooo0?ooo`0L0?ooo`00:@3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo04T0oooo00<000000000o`0000000P00
0?l00`000000oooo0?ooo`3o0?oooe<0oooo00<000000000o`0000000P000?l01@000000003o0000
00000?l000000080003o00<000000000o`000000503oool00`000000oooo0?ooo`140?ooo`@00000
0P3oool4000003H0oooo00<000000?ooo`3oool0FP3oool00`00o`00oooo0?ooo`040?ooo`030000
o`00o`00oooo04H0oooo00<00?l00000o`3oool0103oool00`00o`00oooo0?ooo`080?ooo`D00000
803oool5000001d0oooo00<00?l00?ooo`3oool0103oool00`00o`00003o0?ooo`0:0?ooo`03003o
003oool0oooo00h0oooo00<00?l00?ooo`3oool01`3oool00`00o`00oooo0?ooo`0:0?ooo`D00000
203oool00`000?l00?l00?ooo`0>0?ooo`03003o003oool00?l000H0oooo3P0000030?oooa@00000
00<00?l00?ooo`0000001P0000080?ooo`030000003oool0oooo01`0oooo000Y0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool0B@3oool00`000000003o000000020000o`030000003o
ool0oooo0?l0ooooD`3oool00`000000003o000000020000o`05000000000?l000000000o`000000
0P000?l00`000000003o0000000D0?ooo`030000003oool0oooo04@0oooo0P0000060?ooo`800000
=P3oool00`000000oooo0?ooo`1J0?ooo`03003o003oool0oooo00@0oooo00<0003o003o003oool0
AP3oool00`00o`00003o0000000400000003003o00000000oooo00P0oooo1@00000P0?ooo`D00000
7@3oool00`00o`00oooo0?ooo`040?ooo`03003o00000?l0oooo00X0oooo00<0003o003o003oool0
3P3oool00`00o`00oooo0?ooo`070?ooo`03003o003oool0oooo00X0oooo1@0000080?ooo`03003o
003oool0oooo00h0oooo00<00?l00?ooo`00o`005P0000040?oooa40000000<00?l0000000000000
1000000:0?ooo`030000003oool0oooo01`0oooo000X0?ooo`@000004P3oool3000004T0oooo00<0
00000000o`0000000P000?l00`000000oooo0?ooo`3o0?oooe<0oooo00<000000000o`0000000P00
0?l01@000000003o000000000?l000000080003o00<000000000o`0000004`3oool2000004H0oooo
0P0000060?ooo`800000=P3oool00`000000oooo0?ooo`1J0?ooo`03003o003oool0oooo00@0oooo
00<0003o003o003oool0AP3oool00`00o`00003o0000000400000003003o00000000oooo00P0oooo
1@00000P0?ooo`D00000403oool6000000L0oooo00<00?l00?ooo`3oool0103oool00`00o`00003o
0?ooo`0:0?ooo`030000o`00o`00oooo00D000002@3oool00`00o`00oooo0?ooo`070?ooo`03003o
003oool0oooo00X0oooo1@0000080?ooo`03003o003oool0oooo00/0oooo0`0000000`00o`000000
003o000F000000P0oooo3@0000000`00o`00000000000004000000X0oooo00<000000?ooo`3oool0
703oool002T0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`190?ooo`0300000000
0?l000000080003o00<000000?ooo`3oool0o`3ooomC0?ooo`03000000000?l000000080003o00D0
00000000o`000000003o000000020000o`03000000000?l0000001@0oooo00<000000?ooo`3oool0
A03oool200000080oooo0P0000020?ooo`800000=P3oool2000005/0oooo00<00?l00?ooo`3oool0
103oool00`000?l00?l00?ooo`140?ooo`80000000<00?l00000o`000000100000000`00o`000000
0?ooo`080?ooo`D00000803oool500000100oooo200000050?ooo`03003o003oool0oooo00@0oooo
00<00?l00000o`3oool02P3oool00`000?l00?l00?ooo`05000000T0oooo00<00?l00?ooo`3oool0
1`3oool00`00o`00oooo0?ooo`0:0?ooo`@0000000<00?l00?ooo`3oool0103oool200000003003o
00000000000000/0oooo0`0000000`00o`000000003o000F000000h0oooo1`0000001000o`000000
00000000000=0?ooo`030000003oool0oooo01`0oooo000X0?ooo`@000004P3oool00`000000oooo
0?ooo`190?ooo`03000000000?l000000080003o00<000000?ooo`3oool0o`3ooomC0?ooo`030000
00000?l000000080003o00D000000000o`000000003o000000020000o`03000000000?l0000001@0
oooo00<000000?ooo`3oool0A03oool200000080oooo0P0000020?ooo`800000=P3oool00`000000
oooo0?ooo`1J0?ooo`03003o00000000000000<0000000<0oooo0000o`00o`00A@3oool200000003
003o00000?l0000000@0000000<00?l0000000000000203oool5000003D0oooo3@0000000`00o`00
00000000000400000003003o00000?l0000000X0oooo00<0003o003o000000001P0000080?ooo`03
003o003oool0oooo00L0oooo00<00?l00?ooo`3oool03P3oool00`00o`00oooo0?ooo`0600000003
003o00000000000000/0oooo0`0000000`00o`000000003o000F000000X0oooo1@0000030?ooo`<0
000000@00?l000000000000000003@3oool00`000000oooo0?ooo`0L0?ooo`00:@3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo04T0oooo00<000000000o`0000000P000?l00`000000
oooo0?ooo`3o0?oooe<0oooo00<000000000o`0000000P000?l01@000000003o000000000?l00000
0080003o00<000000000o`000000503oool00`000000oooo0?ooo`140?ooo`8000000P3oool20000
0080oooo0P00000f0?ooo`030000003oool0oooo03`0oooo200000070?ooo`T000001P3oool00`00
o`00000000000004000000030000o`00o`00oooo04@0oooo0P0000000`00o`00003o000000040000
0003003o0000000000000480oooo3@0000000`00o`0000000000000400000003003o00000?l00000
00/0oooo00<00?l00000000000001@0000080?ooo`03003o003oool0000000@000000P3oool00`00
00000?l000000007000000030?ooo`000000000000<0000000<0oooo00000000o`00200000000`00
o`0000000000000;0?ooo`<0000000<00?l000000000o`002@0000080?ooo`D000002P3oool50000
00<0oooo0`0000001000o`00000000000000000=0?ooo`030000003oool0oooo01`0oooo000Y0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool0B@3oool00`000000003o000000020000
o`030000003oool0oooo0?l0ooooD`3oool00`000000003o000000020000o`05000000000?l00000
0000o`0000000P000?l00`000000003o0000000D0?ooo`030000003oool0oooo04@0oooo0P000002
0?ooo`8000000P3oool2000002@0oooo2000000:0?ooo`030000003oool0oooo03`0oooo20000006
0?oooa00000000<00?l0000000000000100000000`000?l00?l00?ooo`020?ooo`L000004`3oool6
00000280oooo0P0000000`00o`00003o0000000400000003003o00000000000000@0oooo1@00000C
0?ooo`D000008@3oool=00000003003o00000000000000@0000000<00?l00000o`0000001@3oool6
00000003003o00000000000000D00000203oool00`00o`00oooo0000000700000005003o00000000
000000000000o`002P0000000`00o`000000003o000800000003003o00000000000000/0oooo0`00
00001000o`000000003o0000000O0?ooo`D000001P3oool00`00o`00oooo0?ooo`020?ooo`D00000
1`3oool00`000000oooo0?ooo`0L0?ooo`00:@3oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo04T0oooo00<000000000o`0000000P000?l00`000000oooo0?ooo`3o0?oooe<0oooo00<0
00000000o`0000000P000?l01@000000003o000000000?l000000080003o00<000000000o`000000
503oool00`000000oooo0?ooo`140?ooo`@000000P3oool4000002@0oooo2000000:0?ooo`030000
003oool0oooo03`0oooo200000050?oooa40000000<00?l0000000000000100000000`000?l00?l0
0000000:000000@0oooo1@0000090?ooo`d000000P3oool5000001@0oooo0P0000000`00o`00003o
0000000400000003003o00000000000000@0oooo1@0000040?ooo`L00000203oool5000000X0oooo
1P00000D0?ooo`X0000000<00?l0000000000000100000000`00o`00003o0000000;00000003003o
00000000000000H0000000@0003o0000000000000?l00P0000000`3oool00?l00000000800000006
003o000000000000003o000000000?l02@0000000`00o`000000003o000800000003003o00000000
000000T000000`3oool200000003003o000000000?l000H000006P3oool5000000H0oooo00<00?l0
0?ooo`3oool00P3oool5000000L0oooo00<000000?ooo`3oool0703oool002P0oooo00<000000?oo
o`0000000P00000A0?ooo`030000003oool0oooo04T0oooo00<000000000o`0000000P000?l00`00
0000oooo0?ooo`3o0?oooe<0oooo00<000000000o`0000000P000?l01@000000003o000000000?l0
00000080003o00<000000000o`000000503oool00`000000oooo0?ooo`140?ooo`@000000P3oool4
000002P0oooo0P00000<0?ooo`030000003oool0oooo01`0oooo2P00000F0?ooo`P000000`3ooolC
00000003003o00000000000000@0000000<0003o003o000000002P0000040?ooo`D000001`3ooolR
000000<0oooo1`0000000`00o`00003o0000000400000004003o0000000000000?ooo`P00000103o
ool700000080oooo400000050?ooo`H000004`3oool;00000003003o00000000000000@0000000<0
0?l00000o`0000002`0000000`00o`0000000000000300000005003o000000000?l00000o`000000
0P00o`02000000800?l02@0000001P00o`00000000000000o`000000003o00P000001000o`080000
0003003o00000000000000h0000000<00?l000000000o`001P00000J0?ooo`D000001P3oool00`00
o`00oooo0?ooo`020?ooo`D000001`3oool00`000000oooo0?ooo`0L0?ooo`00?P3oool3000004T0
oooo00<000000000o`0000000P000?l00`000000oooo0?ooo`3o0?oooe<0oooo0`0000020000o`05
000000000?l000000000o`0000000P000?l00`000000003o0000000C0?ooo`800000AP3oool20000
00H0oooo0P00000X0?ooo`800000303oool00`000000oooo0?ooo`0J0?ooo``000005P3oool80000
00<0oooo4`0000000`00o`00000000000004000000030000o`00o`00000000X00000103oool60000
00H0oooo8`0000020?ooo`L0000000<00?l00000o`000000100000000`00o`00oooo0?ooo`090000
00030?ooo`000000000001X000001@3oool6000001<0oooo2`000002003o00D0000000<00?l00000
o`0000002`0000000`00o`00000000000003000000<00?l000P0003o003o000000000000003o0000
00000?l00000o`T0000000<00?l000000000o`000P0000000`00o`00000000000006000000@00?l0
200000000`00o`0000000000000>00000003003o000000000?l000H000009@3oool00`00o`00oooo
0?ooo`07000000L0oooo00<000000?ooo`3oool0703oool002P0oooo1@00000A0?ooo`030000003o
ool0oooo04T0oooo00<000000000o`0000000P000?l00`000000oooo0?ooo`3o0?oooeD0oooo00P0
00000000o`000?l000000000o`000000003o00000080003o00<000000000o`000000503oool00`00
0000oooo0?ooo`140?ooo`8000001P3oool2000002P0oooo0P00000<0?ooo`<000006P3oool<0000
0240oooo4`0000000`00o`00000000000004000000030000o`00o`00000000X00000103oool60000
00H0oooo8`0000020?ooo`L0000000<00?l00000o`3oool0103oool00`00o`00oooo0000000V0000
00D0oooo1P00000C0?ooo`T000000P3oool2003o0080oooo0`0000000`00o`0000000000000;0000
00030000o`00o`000?l00080000000H00?l00000000000000?l00000o`00o`02000000800?l000<0
00000000o`00000020000002003o00@0000000<00?l000000000o`001@0000001000o`000000003o
0000o`04000000050?ooo`000000000000000000o`00400000000`00o`000000003o000<00000080
oooo2@00000D0?ooo`03003o003oool0oooo00L000001`3oool00`000000oooo0?ooo`0L0?ooo`00
:P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo04T0oooo00<000000000o`000000
0P000?l00`000000oooo0?ooo`3o0?oooeD0oooo00P000000000o`000?l000000000o`000000003o
00000080003o00<000000000o`000000503oool00`000000oooo0?ooo`180?ooo`@00000:P3oool2
000000`0oooo00<000000?ooo`3oool06P3oool<00000240oooo1`0000030?ooo`T0000000<00?l0
000000000000100000000`000?l00?l00000000:000000@0oooo1P0000060?ooob<000000P3oool7
00000003003o00000?l0oooo00@0oooo00<00?l00?ooo`000000200000000`3oool000000000000K
000000D0oooo1P00000C0?ooo`T000000P3oool00`00o`00oooo003o00020?ooo`<00?l03@000000
0`000?l00000003o000200000005003o00000000000000000000o`000`000002003o000300000000
0?l0000000P0000000<00?l00000000000000`000003003o00@0000000<00?l00000000000000P00
o`04000000050?ooo`000000000000000000o`00400000000`00o`000000003o000G000000`0oooo
1@000000103oool0000000000000o`07000000T0oooo00<000000?ooo`3oool0703oool002X0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`190?ooo`03000000000?l000000080003o
00<000000?ooo`3oool0o`3ooomE0?ooo`08000000000?l0003o000000000?l000000000o`000002
0000o`03000000000?l0000001@0oooo00<000000?ooo`3oool0B03oool4000002X0oooo0P00000<
0?ooo`030000003oool0oooo01X0oooo3000000Q0?ooo`H000002P3oool300000003003o00000000
oooo0080oooo0P0000000`00o`0000000000000?0?ooo`D000001P3ooolS00000080oooo1`000000
0`00o`00003o0?ooo`040?ooo`03003o003oool0000000P0000000<0oooo0000000000006`00000N
0?ooo`D000001P3oool00`00o`00oooo003o00020?ooo`03003o000000000?l000X000000P3oool0
1`000000003o00000000o`0000000?ooo`00o`000`0000000`00o`00oooo0?ooo`0200000003003o
00000000003o00T0000000<00?l00000000000000`0000001`00o`00000000000000o`00oooo0000
0000o`000`000002003o00030000003oool0oooo00@0oooo00<00000003o000000003`0000000`00
o`00oooo003o00030?oooa@00000103oool7000000030?ooo`000000000000<0000000@0oooo0000
000000000?l01`0000090?ooo`030000003oool0oooo01`0oooo000Z0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool0B@3oool00`000000003o000000020000o`030000003oool0oooo
0?l0ooooE@3oool020000000003o0000o`000000003o000000000?l000000P000?l00`000000003o
0000000D0?ooo`030000003oool0oooo04H0oooo0P0000040?ooo`800000:03oool2000000`0oooo
00<000000?ooo`3oool06P3oool:000002@0oooo1@00000=0?ooo`03003o003oool0oooo00@0oooo
00<00?l00?ooo`3oool03`3oool5000001@0oooo5@0000040?ooo`D0000000<00?l00000o`3oool0
103oool00`00o`00oooo00000008000000030?ooo`000000000001X00000:P3oool020000?l0oooo
003o003oool00?l00?ooo`000000003o0`00000:0?ooo`030000o`3oool0oooo00800?l0103oool0
0`000?l0oooo0?ooo`030?ooo`03000000000?l0000000P0000000<0003o0?ooo`3oool00P3oool4
00000003003o003oool00?l000@0oooo0P00o`080?ooo`04003o003oool0oooo0?ooo`D00000203o
ool00`00o`00oooo003o00030?oooa@0000000<0oooo0000000000004@0000000`00o`0000000000
0005000000T0oooo00<000000?ooo`3oool0703oool002T0oooo0P00000C0?ooo`030000003oool0
oooo04T0oooo00<000000000o`0000000P000?l00`000000oooo0?ooo`3o0?oooeD0oooo00P00000
0000o`000?l000000000o`000000003o00000080003o00<000000000o`000000503oool00`000000
oooo0?ooo`160?ooo`800000103oool2000002P0oooo0P00000<0?ooo`030000003oool0oooo05X0
oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`0a0?ooo`X000002`3oool00`00o`00
003o0?ooo`040?ooo`03003o003oool0000000@000001@3ooolJ000002`0oooo00<0003o0?ooo`3o
ool00P00o`020?ooo`030000o`3oool0oooo00/0oooo00@0003o0?ooo`3oool00?l01@3oool00`00
0?l0oooo0?ooo`030?ooo`03000000000?l00000008000001P3oool00`000?l0oooo0?ooo`060?oo
o`03003o003oool00?l000D0oooo00<00?l00?ooo`3oool01P3oool00`00o`00oooo0?ooo`0>0?oo
o`03003o003oool00?l000<0oooo500000000`3oool000000000000A00000003003o000000000000
00<000002`3oool00`000000oooo0?ooo`0L0?ooo`00;@3oool4000000<0oooo0P0000080?ooo`03
0000003oool0oooo04T0oooo00<000000000o`0000000P000?l00`000000oooo0?ooo`3o0?oooeD0
oooo00P000000000o`000?l000000000o`000000003o00000080003o00<000000000o`000000503o
ool00`000000oooo0?ooo`160?ooo`800000;P3oool2000000`0oooo00<000000?ooo`3oool0FP3o
ool00`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo04L0oooo00<00?l00?ooo`3oool00`3o
ool00`00o`00oooo0?ooo`0@0?ooo`T00000=P3oool00`000?l0oooo0?ooo`02003o0080oooo00<0
003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00@0oooo00<0
003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`060?ooo`03003o003oool00?l000D0oooo00<0
0?l00?ooo`3oool01P3oool00`00o`00oooo0?ooo`0>0?ooo`03003o003oool00?l000X0oooo1`00
00070?oooa<0000000<00?l00000000000000`00000;0?ooo`030000003oool0oooo01`0oooo000Y
0?ooo`<0000000<0oooo0000003oool0103oool010000000oooo0?ooo`0000070?ooo`030000003o
ool0oooo04T0oooo00<000000000o`0000000P000?l00`000000oooo0?ooo`3o0?oooeD0oooo00P0
00000000o`000?l000000000o`000000003o00000080003o00<000000000o`000000503oool00`00
0000oooo0?ooo`160?ooo`800000:P3oool6000000`0oooo0P00001K0?ooo`03003o003oool0oooo
00@0oooo00<00?l00?ooo`3oool0A`3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo
04l0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo
00H0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo
00L0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`060?ooo`03003o003oool0oooo
00h0oooo0P00o`0I0?oooa<0000000<00?l00?ooo`3oool03P3oool00`000000oooo0?ooo`0L0?oo
o`00:03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool000001`3oool4000004P0oooo00<000000000o`0000000P000?l00`000000oooo0?ooo`3o0?oo
oeD0oooo00P000000000o`000?l000000000o`000000003o00000080003o0`00000B0?ooo`<00000
B03oool2000002X0oooo1P00000<0?ooo`030000003oool0oooo05X0oooo00<00?l00?ooo`3oool0
103oool00`00o`00oooo0?ooo`170?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool0
C`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0
1`3oool00`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo00H0oooo00<00?l00?ooo`3oool0
3P3oool2003o01T0oooo1@0000020?ooo``0000000<00?l00?ooo`3oool03P3oool00`000000oooo
0?ooo`0L0?ooo`00:03oool3000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0B@3oool00`000000003o000000020000o`030000
003oool0oooo0?l0ooooE@3oool020000000003o0000o`000000003o000000000?l000000P000?l0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04H0oooo0P00000^0?ooo`800000303oool0
0`000000oooo0?ooo`1J0?ooo`03003o003oool0oooo00@0oooo00<00?l00?ooo`3oool0A`3oool0
0`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo04l0oooo00<0003o0?ooo`3oool0103oool0
0`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`000?l01@3oool0
0`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00L0oooo00<00?l00?ooo`3oool0103oool0
0`00o`00oooo0?ooo`060?ooo`03003o003oool0oooo00h0oooo00<00?l00?ooo`3oool09@3oool5
000000030?ooo`00o`00oooo00l0oooo00<000000?ooo`3oool0703oool002P0oooo00@000000?oo
o`3oool00000103oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0B@3oool00`000000003o000000020000o`030000003oool0oooo0?l0ooooE@3o
ool020000000003o0000o`000000003o000000000?l000000P000?l00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo04H0oooo0P0000040?ooo`800000:03oool2000000`0oooo00<000000?oo
o`3oool0FP3oool00`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo04L0oooo00<00?l00?oo
o`3oool00`3oool00`00o`00oooo0?ooo`1?0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?oo
o`3oool02`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0003o00D0oooo00<0003o0?oo
o`3oool01`3oool00`000?l0oooo0?ooo`070?ooo`03003o003oool0oooo00@0oooo00<00?l00?oo
o`3oool01P3oool00`00o`00oooo0?ooo`0f0?ooo`D0000000<0oooo003o003oool03`3oool00`00
0000oooo0?ooo`0L0?ooo`00:@3oool200000080oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000070?ooo`030000003oool0oooo04T0oooo00<000000000o`0000000P000?l0
0`000000oooo0?ooo`3o0?oooeD0oooo00P000000000o`000?l000000000o`000000003o00000080
003o00<000000?ooo`3oool0503oool00`000000oooo0?ooo`160?ooo`800000103oool2000003H0
oooo00<000000?ooo`3oool0FP3oool00`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo04L0
oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`1?0?ooo`030000o`3oool0oooo00@0
oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0003o00D0
oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0>0?ooo`03003o003oool0oooo00H0
oooo00<00?l00?ooo`3oool0?03oool00`00o`00oooo0?ooo`0>0?ooo`030000003oool0oooo01`0
oooo000^0?ooo`800000103oool2000000P0oooo00<000000?ooo`3oool0B@3oool00`000000003o
000000020000o`030000003oool0oooo0?l0ooooE@3oool020000000003o0000o`000000003o0000
00000?l000000P000?l00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04P0oooo1000000h
0?ooo`030000003oool0oooo05X0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`17
0?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool0C`3oool00`000?l0oooo0?ooo`04
0?ooo`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0000o`05
0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool03P3oool00`00o`00oooo0?ooo`06
0?ooo`03003o003oool0oooo03`0oooo00<00?l00000o`3oool03P3oool00`000000oooo0?ooo`0L
0?ooo`00:03oool3000001<0oooo00<000000?ooo`3oool0B@3oool00`000000003o000000020000
o`030000003oool0oooo0?l0ooooE@3oool020000000003o0000o`000000003o000000000?l00000
0P000?l00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04P0oooo1000000h0?ooo`800000
F`3oool00`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo04L0oooo00<00?l00?ooo`3oool0
0`3oool00`00o`00oooo0?ooo`1?0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0
2`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0003o00D0oooo00<0003o0?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`0>0?ooo`03003o003oool0oooo00H0oooo00<00?l00?ooo`3oool0
?03oool01000o`00oooo0000o`000?l=0?ooo`030000003oool0oooo01`0oooo000[0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0B@3oool00`000000003o000000020000o`030000
003oool0oooo0?l0ooooE@3oool020000000003o0000o`000000003o000000000?l000000P000?l0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04H0oooo1P00000h0?ooo`030000003oool0
oooo05X0oooo00<00?l00000o`000?l0103oool00`00o`00oooo0?ooo`170?ooo`03003o003oool0
oooo00<0oooo00<00?l00?ooo`3oool0C`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0
oooo00/0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0000o`050?ooo`030000o`3oool0
oooo00L0oooo00<0003o0?ooo`3oool03P3oool00`00o`00oooo0?ooo`060?ooo`03003o003oool0
oooo03`0oooo00@00?l00?ooo`3oool0003o3@3oool00`000000oooo0?ooo`0L0?ooo`00:@3oool2
000001<0oooo0`0000190?ooo`03000000000?l000000080003o00<000000?ooo`3oool0o`3ooomE
0?ooo`08000000000?l0003o000000000?l000000000o`0000020000o`030000003oool0oooo01<0
oooo0P0000180?ooo`H00000>03oool00`000000oooo0?ooo`1J0?ooo`03003o00000?l0003o00@0
oooo00<00?l00?ooo`3oool0A`3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo04l0
oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo00D0
oooo00<0003o0?ooo`000?l01@3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00h0
oooo00<00?l00?ooo`3oool01P3oool00`00o`00oooo0?ooo`0l0?ooo`04003o003oool0oooo0000
o`d0oooo00<000000?ooo`3oool0703oool002P0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`190?ooo`03000000000?l000000080003o00<000000?ooo`3oool0o`3ooomE0?ooo`08
000000000?l0003o000000000?l000000000o`0000020000o`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool0B03oool2000003X0oooo00<000000?ooo`3oool0FP3oool00`00o`00003o0000
o`040?ooo`03003o003oool0oooo04L0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?oo
o`1?0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?oo
o`050?ooo`030000o`3oool0003o00D0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?oo
o`020?ooo`030000o`3oool0oooo00T0oooo00<00?l00?ooo`3oool01P3oool00`00o`00oooo0?oo
o`0l0?ooo`04003o003oool0oooo0000o`d0oooo00<000000?ooo`3oool0703oool002T0oooo0`00
000B0?ooo`030000003oool0oooo04T0oooo00<000000000o`0000000P000?l00`000000oooo0?oo
o`3o0?oooeD0oooo00P000000000o`000?l000000000o`000000003o00000080003o00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`180?ooo`800000>P3oool00`000000oooo0?ooo`1J0?oo
o`03003o00000?l0003o00@0oooo00<00?l00?ooo`3oool0A`3oool00`00o`00oooo0?ooo`030?oo
o`03003o003oool0oooo04l0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0;0?oo
o`030000o`3oool0oooo00D0oooo00<0003o0?ooo`000?l01@3oool00`000?l0oooo0?ooo`070?oo
o`040000o`3oool0oooo0?ooo`80003o2`3oool00`00o`00oooo0?ooo`060?ooo`03003o003oool0
oooo03`0oooo00@00?l00?ooo`3oool0003o3@3oool00`000000oooo0?ooo`0L0?ooo`00?P3oool0
0`000000oooo0?ooo`190?ooo`03000000000?l000000080003o00<000000?ooo`3oool0o`3ooomE
0?ooo`08000000000?l0003o000000000?l000000000o`0000020000o`030000003oool0oooo01@0
oooo00<000000?ooo`3oool0B03oool2000003X0oooo00<000000?ooo`3oool0FP3oool00`00o`00
003o0000o`040?ooo`03003o003oool0oooo04L0oooo00<00?l00?ooo`3oool00`3oool00`00o`00
oooo0?ooo`1?0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool02`3oool00`000?l0
oooo0?ooo`050?ooo`030000o`3oool0003o00@0oooo0P000?l90?ooo`040000o`3oool0oooo0?oo
o`80003o2@3oool00`000?l0oooo003o00060?ooo`030000o`3oool00?l003h0oooo00@00?l00?oo
o`3oool0003o3@3oool00`000000oooo0?ooo`0L0?ooo`00?P3oool00`000000oooo0?ooo`190?oo
o`03000000000?l000000080003o00<000000?ooo`3oool0o`3ooomE0?ooo`08000000000?l0003o
000000000?l000000000o`0000020000o`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
B03oool2000003X0oooo00<000000?ooo`3oool0FP3oool00`00o`00oooo0000o`040?ooo`03003o
003oool0oooo04L0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`1?0?ooo`030000
o`3oool0oooo00@0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`050?ooo`040000
o`3oool0003o0000o`<0oooo0P000?l90?ooo`80003o00H0oooo0000o`3oool0003o0?ooo`000?l6
0?ooo`80003o00D0oooo003o00000?l0oooo0000o`020?ooo`80003o00<0oooo003o003oool0?@3o
ool01000o`00oooo0?ooo`000?l=0?ooo`030000003oool0oooo01`0oooo000n0?ooo`030000003o
ool0oooo04T0oooo00<000000000o`0000000P000?l00`000000oooo0?ooo`3o0?oooeD0oooo00P0
00000000o`000?l000000000o`000000003o00000080003o00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`180?ooo`800000>P3oool2000005/0oooo00<00?l00?ooo`000?l0103oool00`00
o`00oooo0?ooo`170?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool0C`3oool00`00
0?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool0103oool00`00
0?l0oooo0?ooo`020?ooo`040000o`3oool0oooo0000o`X0oooo10000?l20?ooo`80003o1P3oool3
0000o`0:0?ooo`00o`00003o0?ooo`000?l0oooo0000o`3oool0003o003o03h0oooo00@00?l00?oo
o`3oool0003o3@3oool00`000000oooo0?ooo`0L0?ooo`00?P3oool00`000000oooo0?ooo`190?oo
o`03000000000?l000000080003o00<000000?ooo`3oool0o`3ooomE0?ooo`08000000000?l0003o
000000000?l000000000o`0000020000o`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
B03oool2000003X0oooo00<000000?ooo`3oool0FP3oool00`00o`00oooo0000o`040?ooo`03003o
003oool0oooo04L0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`1?0?ooo`030000
o`3oool0oooo00@0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`020?ooo`<0003o
1@3oool20000o`/0oooo00<0003o0?ooo`3oool00`3oool010000?l0oooo0000o`000?l30?ooo`06
0000o`3oool0003o0000o`3oool00?l00P3oool00`000?l0oooo0000o`020?ooo`03003o003oool0
oooo03`0oooo00@00?l00?ooo`3oool0003o3@3oool00`000000oooo0?ooo`0L0?ooo`00?P3oool3
000004T0oooo00<000000000o`0000000P000?l00`000000oooo0?ooo`3o0?oooeD0oooo00P00000
0000o`000?l000000000o`000000003o00000080003o00<000000?ooo`3oool04`3oool2000004H0
oooo0P0000020?ooo`8000000P3oool2000003H0oooo00<000000?ooo`3oool0FP3oool00`00o`00
oooo0000o`040?ooo`03003o003oool0oooo04L0oooo00<00?l00?ooo`3oool00`3oool00`00o`00
oooo0?ooo`1?0?ooo`80003o1@3oool00`000?l0oooo0?ooo`0;0?ooo`050000o`3oool0oooo0?oo
o`000?l0203oool20000o`/0oooo00<0003o0?ooo`3oool00`3oool010000?l0oooo0?ooo`000?l3
0?ooo`060000o`3oool0oooo0000o`3oool00?l00`3oool01@000?l0oooo0?ooo`3oool00?l003h0
oooo00@00?l00?ooo`3oool0003o3@3oool00`000000oooo0?ooo`0L0?ooo`00?P3oool00`000000
oooo0?ooo`190?ooo`03000000000?l000000080003o00<000000?ooo`3oool0o`3ooomE0?ooo`08
000000000?l0003o000000000?l000000000o`0000020000o`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool0A03oool200000080oooo0P0000020?ooo`800000=P3oool00`000000oooo0?oo
o`1J0?ooo`03003o003oool0003o00@0oooo00<00?l00?ooo`3oool0A`3oool00`00o`00oooo0?oo
o`030?ooo`03003o003oool0oooo04l0oooo0P000?l50?ooo`030000o`3oool0oooo00`0oooo0P00
0?l00`3oool0003o0?ooo`080?ooo`030000o`3oool0oooo0180oooo00@0003o0?ooo`3oool0003o
0`3oool00`000?l0oooo003o00030?ooo`050000o`3oool0oooo0?ooo`00o`00?P3oool01000o`00
oooo0?ooo`000?l=0?ooo`030000003oool0oooo01`0oooo000n0?ooo`030000003oool0oooo04T0
oooo00<000000000o`0000000P000?l00`000000oooo0?ooo`3o0?oooeD0oooo00P000000000o`00
0?l000000000o`000000003o00000080003o00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`140?ooo`X00000=P3oool00`000000oooo0?ooo`1J0?ooo`03003o003oool0003o00@0oooo00<0
0?l00?ooo`3oool0A`3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo04l0oooo00<0
003o0?ooo`000?l00`3oool20000o`l0oooo0P000?l:0?ooo`030000o`3oool0oooo0180oooo00@0
003o0?ooo`3oool0003o0`3oool00`000?l0oooo003o00070?ooo`03003o003oool0oooo03`0oooo
00@00?l00?ooo`3oool0003o3@3oool00`000000oooo0?ooo`0L0?ooo`00?P3oool00`000000oooo
0?ooo`190?ooo`03000000000?l000000080003o00<000000?ooo`3oool0o`3ooomE0?ooo`080000
00000?l0003o000000000?l000000000o`0000020000o`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool0A03oool:000003H0oooo00<000000?ooo`3oool0FP3oool00`00o`00oooo0000o`04
0?ooo`03003o003oool0oooo04L0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`1A
0?ooo`80003o00@0oooo0000o`3oool0003o403oool00`000?l0oooo0?ooo`0N0?ooo`80003o1P3o
ool00`00o`00oooo0?ooo`050?ooo`03003o003oool0oooo03`0oooo00@00?l00?ooo`3oool0003o
3@3oool00`000000oooo0?ooo`0L0?ooo`00?P3oool00`000000oooo0?ooo`190?ooo`0300000000
0?l000000080003o00<000000?ooo`3oool0o`3ooomE0?ooo`08000000000?l0003o000000000?l0
00000000o`0000020000o`030000003oool0oooo01@0oooo00<000000?ooo`3oool0A`3oool00`00
0000oooo0?ooo`0j0?ooo`800000F`3oool00`00o`00oooo0000o`040?ooo`03003o003oool0oooo
04L0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`1C0?ooo`030000o`3oool0oooo
0380oooo00<0003o0?ooo`3oool01@3oool00`00o`00oooo0?ooo`050?ooo`03003o003oool0oooo
03`0oooo00@00?l00?ooo`3oool0003o3@3oool00`000000oooo0?ooo`0L0?ooo`00?P3oool00`00
0000oooo0?ooo`190?ooo`03000000000?l000000080003o00<000000?ooo`3oool0o`3ooomE0?oo
o`08000000000?l0003o000000000?l000000000o`0000020000o`030000003oool0oooo01@0oooo
00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo05X0oooo
00@00?l00?ooo`3oool0003o0`3oool00`00o`00oooo0?ooo`170?ooo`03003o003oool0oooo00<0
oooo00<00?l00?ooo`3oool0R03oool00`000?l0oooo0?ooo`050?ooo`03003o003oool0oooo00D0
oooo00<00?l00?ooo`3oool0?03oool01000o`00oooo0?ooo`000?l=0?ooo`030000003oool0oooo
01`0oooo000n0?ooo`030000003oool0oooo04T0oooo00<000000000o`0000000P000?l00`000000
oooo0?ooo`3o0?oooeD0oooo00P000000000o`000?l000000000o`000000003o00000080003o00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0FP3oool01000o`00oooo0?ooo`000?l30?ooo`03003o003oool0oooo04L0oooo
00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`2@0?ooo`03003o003oool0oooo00D0oooo
00<00?l00?ooo`3oool0?03oool01000o`00oooo0?ooo`000?l=0?ooo`030000003oool0oooo01`0
oooo000n0?ooo`<00000B@3oool00`000000003o0000000300000?l0ooooE`3oool4000000040000
o`000000003o00000080003o00<000000?ooo`3oool04`3oool2000004/0oooo00<000000?ooo`3o
ool00P3oool8000000H0oooo0P0000080?ooo`P00000103oool6000000`0oooo00<000000?ooo`3o
ool0FP3oool01000o`00oooo0?ooo`000?l30?ooo`03003o003oool0oooo04L0oooo00<00?l00?oo
o`3oool00`3oool00`00o`00oooo0?ooo`2@0?ooo`03003o003oool0oooo00D0oooo00<00?l00?oo
o`3oool0?03oool01000o`00oooo0?ooo`000?l=0?ooo`030000003oool0oooo01`0oooo000n0?oo
o`030000003oool0oooo04T0oooo00<000000000o`000000o`3ooomM0?ooo`05000000000?l00000
0000o`0000000P000?l00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04T0oooo00<00000
0?ooo`3oool00P3oool8000000H0oooo0P0000080?ooo`P00000103oool6000000`0oooo00<00000
0?ooo`3oool0FP3oool01000o`00oooo0?ooo`000?l30?ooo`03003o003oool0oooo04L0oooo00<0
0?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`2@0?ooo`03003o003oool0oooo00D0oooo00<0
0?l00?ooo`3oool0?03oool01000o`00oooo0?ooo`000?l=0?ooo`030000003oool0oooo01`0oooo
000n0?ooo`030000003oool0oooo04T0oooo00<000000000o`000000o`3ooomM0?ooo`0500000000
0?l000000000o`0000000P000?l00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool01@3oool200000180oooo0P00000@0?ooo`8000002P3oool00`000000oooo
0?ooo`1J0?ooo`04003o003oool0oooo0000o`<0oooo00<00?l00?ooo`3oool0A`3oool01000o`00
oooo0?ooo`00o`020?ooo`03003o003oool0oooo0900oooo00<00?l00?ooo`3oool01@3oool00`00
o`00oooo0?ooo`0l0?ooo`04003o003oool0oooo0000o`d0oooo00<000000?ooo`3oool0703oool0
03h0oooo00<000000?ooo`3oool0B@3oool00`000000003o0000003o0?oooed0oooo00D000000000
o`000000003o000000020000o`030000003oool0oooo01@0oooo00<000000?ooo`3oool0BP3oool0
0`000000oooo0?ooo`050?ooo`8000004P3oool200000100oooo0P00000:0?ooo`030000003oool0
oooo05X0oooo00@00?l00?ooo`3oool0003o0`3oool00`00o`00oooo0?ooo`170?ooo`07003o003o
ool0oooo003o003oool00?l00000o`2B0?ooo`03003o003oool0oooo00D0oooo00<00?l00?ooo`3o
ool0?03oool01000o`00oooo0?ooo`000?l=0?ooo`030000003oool0oooo01`0oooo000n0?ooo`03
0000003oool0oooo04T0oooo00<000000000o`000000o`3ooomM0?ooo`05000000000?l000000000
o`0000000P000?l00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04X0oooo00<000000?oo
o`3oool01@3oool2000001@0oooo0P00000>0?ooo`8000002P3oool3000005X0oooo00@00?l00?oo
o`3oool0003o0`3oool00`00o`00oooo0?ooo`170?ooo`07003o003oool00?l0003o003oool00?l0
0000o`2B0?ooo`03003o003oool0oooo00D0oooo00<00?l00?ooo`3oool0?03oool01000o`00oooo
0?ooo`000?l=0?ooo`030000003oool0oooo01`0oooo000n0?ooo`030000003oool0oooo04T0oooo
00<000000000o`000000o`3ooomM0?ooo`05000000000?l000000000o`0000000P000?l00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0103oool2000001@0
oooo0P00000>0?ooo`8000002P3oool00`000000oooo0?ooo`1K0?ooo`800?l000D0003o0?ooo`3o
ool0oooo003o00190?ooo`07003o003oool00?l0003o003oool00?l00000o`2B0?ooo`03003o003o
ool0oooo00D0oooo00<00?l00?ooo`3oool0?03oool4003o00d0oooo00<000000?ooo`3oool0703o
ool003h0oooo00<000000?ooo`3oool0B@3oool00`000000003o0000003o0?oooed0oooo00D00000
0000o`000000003o000000020000o`030000003oool0oooo01@0oooo00<000000?ooo`3oool0B`3o
ool00`000000oooo0?ooo`040?ooo`8000005P3oool2000000H0oooo1P00000<0?ooo`030000003o
ool0oooo05/0oooo0P00o`001@000?l0oooo0?ooo`3oool00?l004T0oooo00L00?l00?ooo`00o`00
0?l00?ooo`00o`00003o0980oooo00<00?l00?ooo`3oool01@3oool00`00o`00oooo0?ooo`0o0?oo
o`03003o003oool0oooo00/0oooo00<000000?ooo`3oool0703oool003h0oooo00<000000?ooo`3o
ool0B@3oool00`000000003o0000003o0?oooed0oooo00D000000000o`000000003o000000020000
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`030?oo
o`8000005P3oool2000000H0oooo1P00000<0?ooo`030000003oool0oooo05/0oooo0P00o`001@00
0?l0oooo0?ooo`3oool00?l004T0oooo00L00?l00?ooo`00o`000?l00?ooo`00o`00003o0980oooo
00<00?l00?ooo`3oool01@3oool00`00o`00oooo0?ooo`0o0?ooo`03003o003oool0oooo00/0oooo
00<000000?ooo`3oool0703oool003h0oooo0`0000190?ooo`<00000o`3ooomM0?ooo`0500000000
0?l000000000o`0000000P000?l00`000000oooo0?ooo`0C0?ooo`800000CP3oool00`000000oooo
0?ooo`030?ooo`800000603oool2000000@0oooo0P00000@0?ooo`030000003oool0oooo05/0oooo
0P00o`001@000?l0oooo0?ooo`3oool00?l004T0oooo00L00?l00?ooo`00o`000?l00?ooo`00o`00
003o0980oooo00<00?l00?ooo`3oool01@3oool00`00o`00oooo0?ooo`0o0?ooo`03003o003oool0
oooo00/0oooo00<000000?ooo`3oool0703oool003h0oooo00<000000?ooo`3oool0o`3ooonY0?oo
o`05000000000?l000000000o`0000000P000?l00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo04@0oooo1P0000030?ooo`030000003oool0oooo0080oooo0P00000H0?ooo`800000103oool2
00000100oooo00<000000?ooo`3oool0F`3oool2003o00050000o`3oool0oooo0?ooo`00o`00B@3o
ool01`00o`00oooo003o0000o`00oooo003o00000?l0TP3oool00`00o`00oooo0?ooo`050?ooo`03
003o003oool0oooo03l0oooo00<00?l00?ooo`3oool02`3oool00`000000oooo0?ooo`0L0?ooo`00
?P3oool00`000000oooo0?ooo`3o0?ooojT0oooo00D000000000o`000000003o000000020000o`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool0A03oool6000000@0oooo1P00000B0?ooo`80
0000103oool2000000@0oooo0P00000@0?ooo`800000G@3oool00`00o`00003o0?ooo`020?ooo`03
003o003oool0oooo04L0oooo00L00?l00?ooo`00o`000?l00?ooo`00o`00003o0980oooo00<00?l0
0?ooo`3oool00`3oool00`00o`00oooo003o00110?ooo`03003o003oool0oooo00/0oooo00<00000
0?ooo`3oool0703oool003h0oooo00<000000?ooo`3oool0o`3ooonY0?ooo`05000000000?l00000
0000o`0000000P000?l00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04H0oooo0P000006
0?ooo`H000004P3oool2000000@0oooo0P0000040?ooo`800000403oool00`000000oooo0?ooo`1L
0?ooo`03003o00000?l0oooo0080oooo00<00?l00?ooo`3oool0A`3oool01`00o`00oooo003o0000
o`00oooo003o00000?l0TP3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool00?l00440oooo
00<00?l00?ooo`3oool02`3oool00`000000oooo0?ooo`0L0?ooo`00?P3oool00`000000oooo0?oo
o`3o0?ooojT0oooo00D000000000o`000000003o000000020000o`030000003oool0oooo01@0oooo
00<000000?ooo`3oool0AP3oool2000000X0oooo0P00000D0?ooo`@000001P3oool8000000X0oooo
00<000000?ooo`3oool0G03oool00`00o`00003o0?ooo`020?ooo`03003o003oool0oooo04L0oooo
00L00?l00?ooo`00o`000?l00?ooo`00o`00003o0980oooo00<00?l00?ooo`3oool00P3oool2003o
00030?ooo`00o`00oooo0400oooo00<00?l00?ooo`3oool02`3oool00`000000oooo0?ooo`0L0?oo
o`00;@3oool400000080oooo0`0000080?ooo`030000003oool0oooo0?l0ooooZ@3oool01@000000
003o000000000?l000000080003o00<000000?ooo`3oool0503oool00`000000oooo0?ooo`160?oo
o`H000001P3oool2000001@0oooo100000060?ooo`P000002P3oool00`000000oooo0?ooo`1L0?oo
o`03003o00000?l0oooo0080oooo00<00?l00?ooo`3oool0A`3oool01`00o`00oooo003o0000o`00
oooo003o00000?l0TP3oool3003o0080oooo0P00o`000`3oool00?l00?ooo`100?ooo`03003o003o
ool0oooo00/0oooo00<000000?ooo`3oool0703oool002d0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0ooooZ@3oool01@000000003o00000000
0?l000000080003o00<000000?ooo`3oool0503oool00`000000oooo0?ooo`160?ooo`H00000>03o
ool00`000000oooo0?ooo`1L0?ooo`03003o00000?l0oooo0080oooo00<00?l00?ooo`3oool0A`3o
ool01`00o`00oooo003o0000o`00oooo003o00000?l0TP3oool2003o00050?ooo`00o`00oooo003o
003oool00P00o`110?ooo`03003o003oool0oooo00/0oooo00<000000?ooo`3oool0703oool002h0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`@00000o`3ooonX0?ooo`05
000000000?l000000000o`0000000P000?l00`000000oooo0?ooo`0B0?ooo`<00000B03oool20000
00@0oooo0P00000f0?ooo`030000003oool0oooo05`0oooo00<00?l00000o`3oool00P3oool00`00
o`00oooo0?ooo`170?ooo`07003o003oool00?l0003o003oool00?l00000o`2B0?ooo`08003o003o
ool0oooo003o003oool00?l00?ooo`00o`120?ooo`03003o003oool0oooo00/0oooo00<000000?oo
o`3oool0703oool002l0oooo00@000000?ooo`3oool0oooo0`0000080?ooo`030000003oool0oooo
0?l0ooooZ@3oool01@000000003o000000000?l000000080003o00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`160?ooo`800000103oool2000003H0oooo00<000000?ooo`3oool0G03oool0
0`00o`00003o0?ooo`020?ooo`03003o003oool0oooo04L0oooo00L00?l00?ooo`00o`000?l00?oo
o`00o`00003o0980oooo00D00?l00?ooo`3oool0oooo003o00020?ooo`03003o003oool0oooo0400
oooo00<00?l00?ooo`3oool02`3oool00`000000oooo0?ooo`0L0?ooo`00<03oool010000000oooo
0?ooo`00000:0?ooo`030000003oool0oooo0?l0ooooZ@3oool01@000000003o000000000?l00000
0080003o00<000000?ooo`3oool0503oool00`000000oooo0?ooo`160?ooo`800000103oool20000
03H0oooo0P00001M0?ooo`03003o00000?l0oooo0080oooo00<00?l00?ooo`3oool0A`3oool01`00
o`00oooo003o0000o`00oooo003o00000?l0UP3oool00`00o`00oooo0?ooo`130?ooo`03003o003o
ool0oooo00/0oooo00<000000?ooo`3oool0703oool002d0oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0?l0ooooZ@3oool01@000000003o0000
00000?l000000080003o00<000000?ooo`3oool0503oool00`000000oooo0?ooo`160?ooo`800000
103oool2000003H0oooo00<000000?ooo`3oool0G03oool00`00o`00003o0?ooo`020?ooo`03003o
003oool0oooo04L0oooo00L00?l00?ooo`00o`000?l00?ooo`00o`00003o0=`0oooo00<00?l00?oo
o`3oool02`3oool00`000000oooo0?ooo`0L0?ooo`00;P3oool2000000<0oooo100000070?ooo`03
0000003oool0oooo0?l0ooooZ@3oool01@000000003o000000000?l000000080003o00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`140?ooo`P00000>03oool00`000000oooo0?ooo`1M0?oo
o`05003o003oool0oooo0?ooo`00o`00B@3oool01`00o`00oooo003o0000o`00oooo003o00000?l0
g03oool00`00o`00oooo0?ooo`0;0?ooo`030000003oool0oooo01`0oooo000n0?ooo`030000003o
ool0oooo0?l0ooooZ@3oool01@000000003o000000000?l000000080003o00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`140?ooo`P00000>03oool00`000000oooo0?ooo`1M0?ooo`05003o
003oool0oooo0?ooo`00o`00B@3oool01`00o`00oooo003o0000o`00oooo003o00000?l0g03oool0
0`00o`00oooo0?ooo`0;0?ooo`030000003oool0oooo01`0oooo000n0?ooo`030000003oool0oooo
0?l0ooooZ@3oool01@000000003o000000000?l000000080003o00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`160?ooo`H00000>03oool00`000000oooo0?ooo`1M0?ooo`05003o003oool0
oooo0?ooo`00o`00B@3oool01`00o`00oooo003o0000o`00oooo003o00000?l0g03oool00`00o`00
oooo0?ooo`0;0?ooo`030000003oool0oooo01`0oooo000n0?ooo`<00000o`3ooonY0?ooo`050000
00000?l000000000o`0000000P000?l00`000000oooo0?ooo`0C0?ooo`800000B03oool6000003P0
oooo00<000000?ooo`3oool0G@3oool01@00o`00003o0?ooo`3oool00?l004T0oooo00L00?l00?oo
o`00o`000?l00?ooo`00o`00003o0=`0oooo00<00?l00?ooo`3oool02`3oool00`000000oooo0?oo
o`0L0?ooo`00?P3oool00`000000oooo0?ooo`3o0?ooojT0oooo00D000000000o`000000003o0000
00020000o`030000003oool0oooo01@0oooo00<000000?ooo`3oool0AP3oool2000000@0oooo0P00
000f0?ooo`800000GP3oool01@00o`00003o0000o`3oool00?l004T0oooo00L00?l00?ooo`00o`00
0?l00?ooo`00o`00003o0=`0oooo00<00?l00?ooo`3oool02`3oool00`000000oooo0?ooo`0L0?oo
o`00?P3oool00`000000oooo0?ooo`3o0?ooojT0oooo00D000000000o`000000003o000000020000
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool0AP3oool2000000@0oooo0P00000f0?oo
o`030000003oool0oooo05d0oooo00D00?l00000o`000?l0003o003o00190?ooo`07003o003oool0
0?l0003o003oool00?l00000o`3L0?ooo`03003o003oool0oooo00/0oooo00<000000?ooo`3oool0
703oool003h0oooo00<000000?ooo`3oool0o`3ooonY0?ooo`05000000000?l000000000o`000000
0P000?l00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04`0oooo0P00000f0?ooo`030000
003oool0oooo05d0oooo00D00?l00000o`000?l0003o003o00190?ooo`07003o003oool00?l0003o
003oool00?l00000o`3L0?ooo`03003o003oool0oooo00/0oooo00<000000?ooo`3oool0703oool0
03h0oooo00<000000?ooo`3oool0o`3ooonY0?ooo`05000000000?l000000000o`0000000P000?l0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04`0oooo0P00000f0?ooo`030000003oool0
oooo05d0oooo00D00?l00000o`000?l0003o003o00190?ooo`07003o003oool00?l0003o003oool0
0?l00000o`3L0?ooo`03003o003oool0oooo00/0oooo00<000000?ooo`3oool0703oool003h0oooo
00<000000?ooo`3oool0o`3ooonY0?ooo`05000000000?l000000000o`0000000P000?l00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo04P0oooo1000000h0?ooo`030000003oool0oooo05d0
oooo00D00?l00000o`000?l0003o003o00190?ooo`07003o003oool00?l0003o003oool00?l00000
o`3L0?ooo`03003o003oool0oooo00/0oooo00<000000?ooo`3oool0703oool003h0oooo00<00000
0?ooo`3oool0o`3ooonY0?ooo`05000000000?l000000000o`0000000P000?l00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo04P0oooo1000000h0?ooo`030000003oool0oooo05d0oooo00D0
0?l00000o`000?l0003o003o00190?ooo`07003o003oool00?l0003o003oool00?l00000o`3L0?oo
o`03003o003oool0oooo00/0oooo00<000000?ooo`3oool0703oool003h0oooo0`00003o0?ooojT0
oooo00@000000000o`000000003o1000000E0?ooo`800000B03oool2000003`0oooo0P00001N0?oo
o`05003o00000?l0oooo0?ooo`00o`00B@3oool01`00o`00oooo003o0000o`00oooo003o00000?l0
g03oool00`00o`00oooo0?ooo`0;0?ooo`030000003oool0oooo01`0oooo000n0?ooo`030000003o
ool0oooo0?l0ooooZ@3oool01@000000003o000000000?l0000001T0oooo00<000000?ooo`3oool0
AP3oool2000003`0oooo00<000000?ooo`3oool0G@3oool01@00o`00003o0?ooo`3oool00?l004T0
oooo00@00?l00?ooo`00o`00003o0P00o`000`000?l0oooo0?ooo`3J0?ooo`03003o003oool0oooo
00/0oooo00<000000?ooo`3oool0703oool003h0oooo00<000000?ooo`3oool0o`3ooonY0?ooo`05
000000000?l000000000o`0000006@3oool00`000000oooo0?ooo`180?ooo`H00000=P3oool00`00
0000oooo0?ooo`1M0?ooo`05003o00000?l0oooo0?ooo`00o`00B@3oool01P00o`00oooo003o003o
ool00?l00000omd0oooo00<00?l00?ooo`3oool02`3oool00`000000oooo0?ooo`0L0?ooo`00?P3o
ool00`000000oooo0?ooo`3o0?ooojT0oooo00D000000000o`000000003o0000000I0?ooo`030000
003oool0oooo04P0oooo1P00000<0?ooo`P000001P3oool2000000P0oooo1P00000<0?ooo`030000
003oool0oooo05d0oooo00D00?l00000o`3oool0oooo003o00190?ooo`06003o003oool00?l00?oo
o`00o`00003og@3oool00`00o`00oooo0?ooo`0;0?ooo`030000003oool0oooo01`0oooo000n0?oo
o`030000003oool0oooo0?l0ooooZ@3oool01@000000003o000000000?l0000001T0oooo00<00000
0?ooo`3oool0B03oool4000000h0oooo200000060?ooo`800000203oool6000000`0oooo00<00000
0?ooo`3oool0G@3oool01@00o`00003o0?ooo`3oool00?l004T0oooo00H00?l00000o`00o`00oooo
003o00000?oM0?ooo`03003o003oool0oooo00/0oooo00<000000?ooo`3oool0703oool003h0oooo
00<000000?ooo`3oool0o`3ooonY0?ooo`05000000000?l000000000o`0000006@3oool00`000000
oooo0?ooo`180?ooo`@000004P3oool2000001P0oooo0P00000:0?ooo`030000003oool0oooo05d0
oooo00D00?l00000o`3oool0oooo003o00190?ooo`05003o00000?l00?l00?ooo`00o`00gP3oool0
0`00o`00oooo0?ooo`0;0?ooo`030000003oool0oooo01`0oooo000n0?ooo`030000003oool0oooo
0?l0ooooZ@3oool01@000000003o000000000?l0000001T0oooo00<000000?ooo`3oool0AP3oool2
000000@0oooo0P00000@0?ooo`800000603oool2000000X0oooo00<000000?ooo`3oool0G@3oool0
1@00o`00oooo0?ooo`3oool00?l004T0oooo0P00o`020?ooo`03003o003oool0oooo0=`0oooo00<0
0?l00?ooo`3oool02`3oool00`000000oooo0?ooo`0L0?ooo`00?P3oool00`000000oooo0?ooo`3o
0?ooojT0oooo00D000000000o`000000003o0000000I0?ooo`030000003oool0oooo04H0oooo0P00
00040?ooo`800000403oool2000001P0oooo0P00000:0?ooo`<00000G@3oool01@00o`00oooo0?oo
o`3oool00?l004T0oooo0P00o`020?ooo`03003o003oool0oooo0=`0oooo00<00?l00?ooo`3oool0
2`3oool00`000000oooo0?ooo`0L0?ooo`00?P3oool300000?l0ooooZ@3oool01@000000003o0000
00000?l0000001P0oooo0P0000180?ooo`8000005P3oool2000001P0oooo0P00000:0?ooo`030000
003oool0oooo05d0oooo00D00?l00?ooo`3oool0oooo003o00190?ooo`800?l00P3oool00`00o`00
oooo0?ooo`3L0?ooo`03003o003oool0oooo00/0oooo00<000000?ooo`3oool0703oool003h0oooo
00<000000?ooo`3oool0o`3ooonY0?ooo`05000000000?l000000000o`0000006@3oool00`000000
oooo0?ooo`160?ooo`8000005P3oool200000180oooo1P00000<0?ooo`030000003oool0oooo05d0
oooo00D00?l00?ooo`3oool0oooo003o00190?ooo`800?l00P3oool00`00o`00oooo0?ooo`3L0?oo
o`03003o003oool0oooo00/0oooo00<000000?ooo`3oool0703oool003h0oooo00<000000?ooo`3o
ool0o`3ooonY0?ooo`05000000000?l000000000o`0000006@3oool00`000000oooo0?ooo`160?oo
o`8000005P3oool200000180oooo1P00000<0?ooo`030000003oool0oooo05d0oooo00D00?l00?oo
o`3oool0oooo003o00190?ooo`800?l00P3oool00`00o`00oooo0?ooo`3L0?ooo`03003o003oool0
oooo00/0oooo00<000000?ooo`3oool0703oool003h0oooo00<000000?ooo`3oool0o`3ooonY0?oo
o`05000000000?l000000000o`0000006@3oool00`000000oooo0?ooo`160?ooo`8000005P3oool2
00000180oooo0P00000@0?ooo`030000003oool0oooo05d0oooo00D00?l00?ooo`3oool0oooo003o
00190?ooo`800?l00P3oool00`00o`00oooo0?ooo`3L0?ooo`03003o003oool0oooo00/0oooo00<0
00000?ooo`3oool0703oool003h0oooo00<000000?ooo`3oool0o`3ooonY0?ooo`05000000000?l0
00000000o`0000006@3oool00`000000oooo0?ooo`160?ooo`800000103oool200000100oooo0P00
000B0?ooo`800000403oool00`000000oooo0?ooo`1M0?ooo`05003o003oool0oooo0?ooo`00o`00
B@3oool2003o0080oooo00<00?l00?ooo`3oool0g03oool00`00o`00oooo0?ooo`0;0?ooo`030000
003oool0oooo01`0oooo000n0?ooo`030000003oool0oooo0?l0ooooZ@3oool01@000000003o0000
00000?l0000001T0oooo00<000000?ooo`3oool0AP3oool2000000@0oooo0P00000<0?ooo`H00000
4P3oool200000100oooo0P00001N0?ooo`05003o003oool0oooo0?ooo`00o`00B@3oool2003o0080
oooo00<00?l00?ooo`3oool0g03oool00`00o`00oooo0?ooo`0;0?ooo`030000003oool0oooo01`0
oooo000n0?ooo`030000003oool0oooo0?l0ooooZ@3oool01@000000003o000000000?l0000001T0
oooo00<000000?ooo`3oool0B03oool4000000h0oooo1P00000B0?ooo`800000403oool00`000000
oooo0?ooo`1M0?ooo`05003o003oool0oooo0?ooo`00o`00B@3oool2003o0080oooo00<00?l00?oo
o`3oool0g03oool00`00o`00003o0?ooo`0;0?ooo`030000003oool0oooo01`0oooo000n0?ooo`<0
0000o`3ooonY0?ooo`<0000000<0003o0000003oool05`3oool2000004X0oooo1000000B0?ooo`80
00004P3oool8000000X0oooo00<000000?ooo`3oool0G@3oool01@00o`00oooo0?ooo`3oool00?l0
04T0oooo0P00o`020?ooo`03003o003oool0oooo0=`0oooo00<00?l00000o`3oool02`3oool00`00
0000oooo0?ooo`0L0?ooo`00?P3oool00`000000oooo0?ooo`3o0?oooj/0oooo00<000000000o`00
00006@3oool00`000000oooo0?ooo`160?ooo`H000004P3oool200000180oooo2000000:0?ooo`03
0000003oool0oooo05d0oooo00D00?l00?ooo`3oool0oooo003o00190?ooo`800?l00P3oool00`00
o`00oooo0?ooo`3L0?ooo`03003o00000?l0oooo00/0oooo00<000000?ooo`3oool0703oool003h0
oooo00<000000?ooo`3oool0o`3ooon[0?ooo`03000000000?l0000001T0oooo00<000000?ooo`3o
ool0AP3oool6000003P0oooo00<000000?ooo`3oool0GP3oool01000o`00oooo0?ooo`00o`190?oo
o`800?l00P3oool00`00o`00oooo0?ooo`3L0?ooo`03003o00000?l0oooo00/0oooo00<000000?oo
o`3oool0703oool003h0oooo00<000000?ooo`3oool0o`3ooon[0?ooo`03000000000?l0000001T0
oooo00<000000?ooo`3oool0B03oool2000003X0oooo00<000000?ooo`3oool0GP3oool01000o`00
oooo0?ooo`00o`190?ooo`800?l00P3oool00`00o`00oooo0?ooo`3L0?ooo`03003o00000?l0oooo
00/0oooo00<000000?ooo`3oool0703oool003h0oooo00<000000?ooo`3oool0o`3ooon[0?ooo`03
000000000?l0000001T0oooo00<000000?ooo`3oool0B03oool2000003X0oooo00<000000?ooo`3o
ool0GP3oool2003o00030?ooo`00o`00oooo04P0oooo0P00o`020?ooo`03003o003oool0oooo0=`0
oooo00<00?l00000o`3oool02`3oool00`000000oooo0?ooo`0L0?ooo`00;P3oool2000000@0oooo
0P0000080?ooo`030000003oool0oooo0?l0ooooZ`3oool00`000000003o0000000I0?ooo`030000
003oool0oooo04P0oooo0P00000j0?ooo`800000G`3oool4003o04T0oooo0P00o`020?ooo`03003o
003oool0oooo0=`0oooo00<00?l00000o`3oool02`3oool00`000000oooo0?ooo`0L0?ooo`00;@3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3o
ool0o`3ooon[0?ooo`03000000000?l0000001T0oooo00<000000?ooo`3oool0B03oool2000003X0
oooo00<000000?ooo`3oool0GP3oool4003o04T0oooo0P00o`020?ooo`03003o003oool0oooo0=`0
oooo00<00?l00000o`3oool02`3oool00`000000oooo0?ooo`0L0?ooo`00<03oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo00D0oooo1000003o0?ooojX0oooo00<000000000o`00
00005`3oool3000004X0oooo0P00000j0?ooo`030000003oool0oooo05h0oooo1000o`190?ooo`80
0?l00P3oool00`00o`00oooo0?ooo`3L0?ooo`03003o00000?l0oooo00/0oooo00<000000?ooo`3o
ool0703oool002h0oooo0P0000030?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3o
ool0o`3ooon[0?ooo`03000000000?l0000001T0oooo00<000000?ooo`3oool0B03oool2000003X0
oooo00<000000?ooo`3oool0GP3oool4003o04T0oooo0P00o`020?ooo`03003o003oool0oooo0=`0
oooo00<00?l00000o`3oool02`3oool00`000000oooo0?ooo`0L0?ooo`00<03oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3ooon[0?ooo`03
000000000?l0000001T0oooo00<000000?ooo`3oool0A03oool200000080oooo0P0000020?ooo`80
0000=P3oool00`000000oooo0?ooo`1N0?ooo`@00?l0B@3oool2003o0080oooo00<00?l00?ooo`3o
ool0g@3oool00`00o`00oooo0?ooo`0:0?ooo`030000003oool0oooo01`0oooo000]0?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`3o0?oo
oj/0oooo00<000000000o`0000006@3oool00`000000oooo0?ooo`140?ooo`8000000P3oool20000
0080oooo0P00000f0?ooo`030000003oool0oooo05h0oooo00@00?l00?ooo`3oool00?l0B@3oool2
003o0080oooo00<00?l00?ooo`3oool0g@3oool00`00o`00oooo0?ooo`0:0?ooo`030000003oool0
oooo01`0oooo000^0?ooo`800000103oool2000000P0oooo00<000000?ooo`3oool0o`3ooon[0?oo
o`03000000000?l0000001T0oooo00<000000?ooo`3oool0A03oool:000003H0oooo0P00001O0?oo
o`04003o003oool0oooo003o04T0oooo0P00o`020?ooo`03003o003oool0oooo0=d0oooo00<00?l0
0?ooo`3oool02P3oool00`000000oooo0?ooo`0L0?ooo`00?P3oool00`000000oooo0?ooo`3o0?oo
oj/0oooo00<000000000o`0000006@3oool00`000000oooo0?ooo`140?ooo`X00000=P3oool00`00
0000oooo0?ooo`1N0?ooo`04003o003oool0oooo003o04T0oooo0P00o`020?ooo`03003o003oool0
oooo0=d0oooo00<00?l00?ooo`3oool02P3oool00`000000oooo0?ooo`0L0?ooo`00?P3oool00`00
0000oooo0?ooo`3o0?oooj/0oooo00<000000000o`0000006@3oool00`000000oooo0?ooo`240?oo
o`030000003oool0oooo05h0oooo00@00?l00?ooo`3oool00?l0B@3oool2003o0>80oooo00<00?l0
0?ooo`3oool02P3oool00`000000oooo0?ooo`0L0?ooo`00?P3oool00`000000oooo0?ooo`3o0?oo
oj/0oooo00<000000000o`0000006@3oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo
05h0oooo00@00?l00?ooo`3oool00?l0B@3oool2003o0>80oooo00<00?l00?ooo`3oool02P3oool0
0`000000oooo0?ooo`0L0?ooo`00?P3oool300000?l0ooooZ`3oool00`000000003o0000000H0?oo
o`800000QP3oool00`000000oooo0?ooo`1N0?ooo`03003o003oool0oooo04X0oooo0P00o`3R0?oo
o`03003o003oool0oooo00X0oooo00<000000?ooo`3oool0703oool003h0oooo00<000000?ooo`3o
ool0o`3ooon[0?ooo`03000000000?l0000001T0oooo00<000000?ooo`3oool0Q03oool00`000000
oooo0?ooo`2[0?ooo`800?l0hP3oool00`00o`00oooo0?ooo`0:0?ooo`030000003oool0oooo01`0
oooo000n0?ooo`030000003oool0oooo0?l0ooooZ`3oool00`000000003o0000000I0?ooo`030000
003oool0oooo08@0oooo00<000000?ooo`3oool0Z`3oool2003o0>80oooo00<00?l00?ooo`3oool0
2P3oool00`000000oooo0?ooo`0L0?ooo`00?P3oool00`000000oooo0?ooo`3o0?oooj/0oooo00<0
00000000o`0000006@3oool00`000000oooo0?ooo`240?ooo`800000[03oool2003o0>80oooo00<0
0?l00?ooo`3oool02P3oool00`000000oooo0?ooo`0L0?ooo`00?P3oool00`000000oooo0?ooo`3o
0?oooj/0oooo00<000000000o`0000006@3oool00`000000oooo0?ooo`240?ooo`030000003oool0
oooo0:`0oooo00<00?l00?ooo`3oool0h03oool00`00o`00oooo0?ooo`0:0?ooo`030000003oool0
oooo01`0oooo000n0?ooo`030000003oool0oooo0?l0ooooZ`3oool00`000000003o0000000I0?oo
o`030000003oool0oooo04h0oooo200000060?ooo`8000002P3oool2000000P0oooo1P00000<0?oo
o`030000003oool0oooo0?l0ooooT03oool00`00o`00oooo0?ooo`0:0?ooo`030000003oool0oooo
01`0oooo000n0?ooo`030000003oool0oooo0?l0ooooZ`3oool00`000000003o0000000I0?ooo`03
0000003oool0oooo04h0oooo200000060?ooo`8000002P3oool2000000P0oooo1P00000<0?ooo`03
0000003oool0oooo0?l0ooooT03oool00`00o`00oooo0?ooo`0:0?ooo`030000003oool0oooo01`0
oooo000n0?ooo`<00000o`3ooon[0?ooo`03000000000?l0000001P0oooo0P00001D0?ooo`800000
503oool2000000h0oooo0P00000:0?ooo`030000003oool0oooo0?l0ooooT03oool00`00o`00oooo
0?ooo`0:0?ooo`030000003oool0oooo01`0oooo000n0?ooo`030000003oool0oooo0?l0ooooZ`3o
ool00`000000003o0000000I0?ooo`030000003oool0oooo0580oooo0P00000D0?ooo`8000003P3o
ool2000000X0oooo00<000000?ooo`3oool0o`3ooon@0?ooo`03003o003oool0oooo00X0oooo00<0
00000?ooo`3oool0703oool003h0oooo00<000000?ooo`3oool0o`3ooon[0?ooo`03000000000?l0
000001T0oooo00<000000?ooo`3oool0DP3oool2000001H0oooo0P00000<0?ooo`8000002P3oool3
00000?l0ooooT03oool00`00o`00oooo0?ooo`0:0?ooo`030000003oool0oooo01`0oooo000n0?oo
o`030000003oool0oooo0?l0ooooZ`3oool00`000000003o0000000I0?ooo`030000003oool0oooo
0580oooo0P00000F0?ooo`800000303oool2000000X0oooo00<000000?ooo`3oool0o`3ooon@0?oo
o`03003o003oool0oooo00X0oooo00<000000?ooo`3oool0703oool003h0oooo00<000000?ooo`3o
ool0o`3ooon[0?ooo`03000000000?l0000001T0oooo00<000000?ooo`3oool0DP3oool2000001H0
oooo0P0000060?ooo`H00000303oool00`000000oooo0?ooo`3o0?oooi00oooo00<00?l00?ooo`3o
ool02P3oool00`000000oooo0?ooo`0L0?ooo`00?P3oool00`000000oooo0?ooo`3o0?oooj/0oooo
00<000000000o`0000006@3oool00`000000oooo0?ooo`1B0?ooo`8000005P3oool2000000H0oooo
1P00000<0?ooo`030000003oool0oooo0?l0ooooT03oool00`00o`00oooo0?ooo`0:0?ooo`030000
003oool0oooo01`0oooo000n0?ooo`030000003oool0oooo0?l0ooooZ`3oool00`000000003o0000
000I0?ooo`030000003oool0oooo0580oooo0P00000H0?ooo`800000103oool200000100oooo00<0
00000?ooo`3oool0o`3ooon@0?ooo`03003o003oool0oooo00X0oooo00<000000?ooo`3oool0703o
ool003h0oooo0`00003o0?oooj/0oooo00<000000000o`000000603oool2000005@0oooo0P00000H
0?ooo`800000103oool200000100oooo00<000000?ooo`3oool0o`3ooon@0?ooo`03003o003oool0
oooo00X0oooo00<000000?ooo`3oool0703oool003h0oooo00<000000?ooo`3oool0o`3ooon[0?oo
o`03000000000?l0000001T0oooo00<000000?ooo`3oool0CP3oool600000180oooo0P0000040?oo
o`800000103oool200000100oooo0P00003o0?oooi40oooo00<00?l00?ooo`3oool02P3oool00`00
0000oooo0?ooo`0L0?ooo`00?P3oool00`000000oooo0?ooo`3o0?oooj/0oooo00<000000000o`00
00006@3oool00`000000oooo0?ooo`1>0?ooo`H000004P3oool2000000@0oooo0P0000040?ooo`80
0000403oool00`000000oooo0?ooo`3o0?oooi00oooo00<00?l00?ooo`3oool02P3oool00`000000
oooo0?ooo`0L0?ooo`00?P3oool00`000000oooo0?ooo`3o0?oooj/0oooo00<000000000o`000000
6@3oool00`000000oooo0?ooo`1B0?ooo`8000004P3oool8000000@0oooo2000000:0?ooo`030000
003oool0oooo0?l0ooooT03oool00`00o`00oooo0?ooo`0:0?ooo`030000003oool0oooo01`0oooo
000n0?ooo`030000003oool0oooo0?l0ooooZ`3oool00`000000003o0000000I0?ooo`030000003o
ool0oooo0580oooo0P00000B0?ooo`P00000103oool8000000X0oooo00<000000?ooo`3oool0o`3o
oon@0?ooo`03003o003oool0oooo00X0oooo00<000000?ooo`3oool0703oool003h0oooo00<00000
0?ooo`3oool0o`3ooon[0?ooo`03000000000?l0000001T0oooo00<000000?ooo`3oool0Q03oool0
0`000000oooo0?ooo`3o0?oooi00oooo00<00?l00?ooo`3oool02P3oool00`000000oooo0?ooo`0L
0?ooo`00?P3oool00`000000oooo0?ooo`3o0?oooj/0oooo00<000000000o`0000006@3oool00`00
0000oooo0?ooo`240?ooo`030000003oool0oooo0?l0ooooT03oool00`00o`00oooo0?ooo`0:0?oo
o`030000003oool0oooo01`0oooo000n0?ooo`<00000o`3ooon[0?ooo`03000000000?l0000001P0
oooo0P0000260?ooo`030000003oool0oooo0?l0ooooT03oool00`00o`00oooo0?ooo`0:0?ooo`03
0000003oool0oooo01`0oooo000n0?ooo`030000003oool0oooo0?l0ooooZ`3oool00`000000003o
0000000I0?ooo`030000003oool0oooo08@0oooo0P00003o0?oooi40oooo00<00?l00?ooo`3oool0
2P3oool00`000000oooo0?ooo`0L0?ooo`00?P3oool00`000000oooo0?ooo`3o0?oooj/0oooo00<0
00000000o`0000006@3oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo0?l0ooooT03o
ool00`00o`00oooo0?ooo`0:0?ooo`030000003oool0oooo01`0oooo000n0?ooo`030000003oool0
oooo0?l0ooooZ`3oool00`000000003o0000000I0?ooo`030000003oool0oooo08@0oooo00<00000
0?ooo`3oool0o`3ooon@0?ooo`03003o003oool0oooo00X0oooo00<000000?ooo`3oool0703oool0
03h0oooo00<000000?ooo`3oool0o`3ooon[0?ooo`03000000000?l0000001T0oooo00<000000?oo
o`3oool0Q03oool00`000000oooo0?ooo`3o0?oooi00oooo00<00?l00?ooo`3oool02P3oool00`00
0000oooo0?ooo`0L0?ooo`00?P3oool00`000000oooo0?ooo`3o0?oooj/0oooo00<000000000o`00
00006@3oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo0?l0ooooT03oool00`00o`00
oooo0?ooo`0:0?ooo`030000003oool0oooo01`0oooo000^0?ooo`8000000`3oool3000000P0oooo
00<000000?ooo`3oool0o`3ooon[0?ooo`03000000000?l0000001T0oooo00<000000?ooo`3oool0
Q03oool00`000000oooo0?ooo`3o0?oooi00oooo00<00?l00?ooo`3oool02P3oool00`000000oooo
0?ooo`0L0?ooo`00;@3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0o`3ooon[0?ooo`03000000000?l0000001T0oooo00<000000?ooo`3oool0
Q03oool200000?l0ooooT@3oool00`00o`00oooo0?ooo`0:0?ooo`030000003oool0oooo01`0oooo
000`0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool400000?l0ooooZP3o
ool00`000000003o0000000G0?ooo`<00000QP3oool00`000000oooo0?ooo`3o0?oooi00oooo00<0
0?l00?ooo`3oool02P3oool00`000000oooo0?ooo`0L0?ooo`00;P3oool2000000<0oooo0`000008
0?ooo`030000003oool0oooo0?l0ooooZ`3oool00`000000003o0000000I0?ooo`030000003oool0
oooo08@0oooo00<000000?ooo`3oool0o`3ooon@0?ooo`03003o003oool0oooo00X0oooo00<00000
0?ooo`3oool0703oool00300oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`3o
0?oooj/0oooo00<000000000o`0000006@3oool00`000000oooo0?ooo`240?ooo`030000003oool0
oooo0?l0ooooT03oool00`00o`00oooo0?ooo`0:0?ooo`030000003oool0oooo01`0oooo000]0?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3o
0?oooj/0oooo00<000000000o`0000006@3oool00`000000oooo0?ooo`240?ooo`030000003oool0
oooo0?l0ooooT03oool00`00o`00oooo0?ooo`0:0?ooo`030000003oool0oooo01`0oooo000^0?oo
o`8000000`3oool4000000L0oooo00<000000?ooo`3oool0o`3ooon[0?ooo`03000000000?l00000
01T0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`3o0?oooi00oooo00<00?l00?oo
o`3oool02P3oool00`000000oooo0?ooo`0L0?ooo`00?P3oool00`000000oooo0?ooo`3o0?oooj/0
oooo00<000000000o`0000006@3oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo0?l0
ooooT03oool00`00o`00oooo0?ooo`0:0?ooo`030000003oool0oooo01`0oooo000n0?ooo`030000
003oool0oooo0?l0ooooZ`3oool00`000000003o0000000I0?ooo`030000003oool0oooo08@0oooo
0P00003o0?oooi40oooo00<00?l00?ooo`3oool02P3oool00`000000oooo0?ooo`0L0?ooo`00?P3o
ool300000?l0ooooZ`3oool00`000000003o0000000H0?ooo`800000QP3oool00`000000oooo0?oo
o`3o0?oooi00oooo00<00?l00?ooo`3oool02P3oool00`000000oooo0?ooo`0L0?ooo`00?P3oool0
0`000000oooo0?ooo`3o0?oooj/0oooo00<000000000o`0000006@3oool00`000000oooo0?ooo`1b
0?ooo`P000002P3oool00`000000oooo0?ooo`3o0?oooi00oooo00<00?l00?ooo`3oool02P3oool0
0`000000oooo0?ooo`0L0?ooo`00?P3oool00`000000oooo0?ooo`3o0?oooj/0oooo00<000000000
o`0000006@3oool00`000000oooo0?ooo`1b0?ooo`P000002P3oool00`000000oooo0?ooo`3o0?oo
oi00oooo00<00?l00?ooo`3oool02P3oool00`000000oooo0?ooo`0L0?ooo`00?P3oool00`000000
oooo0?ooo`3o0?oooj/0oooo00<000000000o`0000006@3oool00`000000oooo0?ooo`1b0?ooo`80
0000403oool00`000000oooo0?ooo`3o0?oooi00oooo00<00?l00?ooo`3oool02P3oool00`000000
oooo0?ooo`0L0?ooo`00?P3oool00`000000oooo0?ooo`3o0?oooj/0oooo00<000000000o`000000
6@3oool00`000000oooo0?ooo`1b0?ooo`800000403oool00`000000oooo0?ooo`3o0?oooi00oooo
00<00?l00?ooo`3oool02P3oool00`000000oooo0?ooo`0L0?ooo`00?P3oool00`000000oooo0?oo
o`3o0?oooj/0oooo00<000000000o`0000006@3oool00`000000oooo0?ooo`1d0?ooo`8000003P3o
oooo000009<0000000<00?l00000000000002`00000N0?ooo`00?P3oool00`000000oooo0?ooo`3o
0?oooj/0oooo00<000000000o`0000006@3oool00`000000oooo0?ooo`1d0?ooo`800000o`3oooo=
0?ooo`00?P3oool300000?l0ooooZ`3oool3000001P0oooo0P00001h0?ooo`800000o`3oooo;0?oo
o`00?P3oool00`000000oooo0?ooo`3o0?ooolL0oooo00<000000?ooo`3oool0MP3oool200000?l0
oooob`3oool003h0oooo00<000000?ooo`3oool0o`3oooo70?ooo`030000003oool0oooo07P0oooo
0P00003o0?ooolT0oooo000n0?ooo`030000003oool0oooo0?l0ooooa`3oool00`000000oooo0?oo
o`1h0?ooo`800000o`3oooo90?ooo`00?P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0
oooo05`0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`1L0?ooo`030000003oool0
oooo05/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`1b0?ooo`800000103oool2
00000?l0oooob@3oool003h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0000007@0oooo0P0000040?ooo`800000o`3oooo90?ooo`00?P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`000000MP3oool400000?l0
oooob`3oool003h0ooooo`00003;000007H0oooo1000003o0?oool/0oooo003o0?ooool0ooooo`3o
oooo0?oooe00oooo003o0?ooool0ooooo`3ooooo0?oooe00oooo003o0?ooool0ooooo`3ooooo0?oo
oe00oooo003o0?ooool0ooooo`3ooooo0?oooe00oooo003o0?ooool0ooooo`3ooooo0?oooe00oooo
003o0?ooool0ooooo`3ooooo0?oooe00oooo003o0?ooool0ooooo`3ooooo0?oooe00oooo0000\
\>"],
  ImageRangeCache->{{{0, 1099}, {322.688, 0}} -> {-0.0524346, -0.0147151, \
0.00191526, 0.00191526}, {{27.375, 524.625}, {315, 7.625}} -> {-0.0423758, \
-5.39782, 0.0021109, 0.137505}, {{574.312, 1071.56}, {315, 7.625}} -> \
{-624.788, -0.384553, 0.942443, 0.00778708}}],

Cell[BoxData[
    \("/afs/cern.ch/user/a/afabich/public/MERIT/PicDisplayAllRuns.eps"\)], \
"Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(rzoom = {11000, 12999};\)\), "\n", 
    \(\(zoom = 
        Select[Transpose[
            Join[{\(Transpose[indexFull]\)[\([1]\)]}, {bufX}, {\(Transpose[
                    indexFull]\)[\([2]\)]}]], 
          rzoom[\([1]\)] \[LessEqual] #[\([3]\)] \[LessEqual] 
              rzoom[\([2]\)] &];\)\), "\[IndentingNewLine]", 
    \(\(prange = 
        Position[\(Transpose[
              indexFull]\)[\([2]\)], _?\((rzoom[\([1]\)] \[LessEqual] # \
\[LessEqual] rzoom[\([2]\)] &)\)];\)\), "\n", 
    \(\(\(prange = 
        Join[First[prange], Last[prange]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Export["\</afs/cern.ch/user/a/afabich/public/MERIT/\
PicDisplayAllRunsZoom.eps\>", \[IndentingNewLine]DisplayTogether[\
\[IndentingNewLine]ListPlot[\[IndentingNewLine]\(Transpose[
              zoom]\)[\([2]\)], \[IndentingNewLine]Axes \[Rule] False, 
          Frame \[Rule] True, 
          FrameTicks \[Rule] {False, True, 
              False, {{0, 0}, {0.5, 3}, {1, 6}, {1.5, 9}}}, 
          PlotJoined \[Rule] False, 
          FrameLabel \[Rule] {"\<run index\>", "\<ratio MCT/PSCT (average \
normalized)\>", "\<\>", \*"\"\<total proton intensity [\!\(10\^12\)]\>\""}\
\[IndentingNewLine]], \
\[IndentingNewLine]MultipleListPlot[\[IndentingNewLine]Take[\(Transpose[
                  result]\)[\([2]\)]/600, 
            prange], \[IndentingNewLine]Take[\(Transpose[result]\)[\([3]\)]/
              600, prange]\[IndentingNewLine], PlotJoined \[Rule] False, 
          SymbolShape \[Rule] PlotSymbol[Triangle], 
          SymbolStyle \[Rule] {RGBColor[1, 0, 0], 
              RGBColor[0, 1, 0]}], \[IndentingNewLine]Show[
          Graphics[\[IndentingNewLine]Join[
              Table[Text[
                  zoom[\([m, 3]\)], {m, 
                    zoom[\([m, 2]\)]}, {0, \(-1\)}, {0, \(-1\)}], {m, 1, 
                  Length[zoom]}], {Text["\<intensity 3\>", {0, 0}, {\(-1\), 
                    0}, TextStyle \[Rule] {FontColor \[Rule] 
                        RGBColor[0, 1, 0]}]}, {Text["\<intensity 2\>", {0, 
                    0.1}, {\(-1\), 0}, 
                  TextStyle \[Rule] {FontColor \[Rule] 
                        RGBColor[1, 0, 0]}]}]\[IndentingNewLine]], 
          hide]\[IndentingNewLine], ImageSize \[Rule] 700], 
      ImageRotated \[Rule] True]\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 700 432.624 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0232288 0.0147151 0.339009 [
[ 0 0 -0.125 0 ]
[.5 -0.0125 -56 -18.25 ]
[.5 -0.0125 56 0 ]
[-0.0125 .01472 -16 -8.84375 ]
[-0.0125 .01472 0 8.84375 ]
[-0.0125 .09947 -52 -8.84375 ]
[-0.0125 .09947 0 8.84375 ]
[-0.0125 .18422 -40 -8.84375 ]
[-0.0125 .18422 0 8.84375 ]
[-0.0125 .26897 -52 -8.84375 ]
[-0.0125 .26897 0 8.84375 ]
[-0.0125 .35372 -16 -8.84375 ]
[-0.0125 .35372 0 8.84375 ]
[-0.0125 .43848 -52 -8.84375 ]
[-0.0125 .43848 0 8.84375 ]
[-0.0125 .52323 -40 -8.84375 ]
[-0.0125 .52323 0 8.84375 ]
[-0.0125 .60798 -52 -8.84375 ]
[-0.0125 .60798 0 8.84375 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -70.8125 -212 ]
[-0.01875 .30902 -52 212 ]
[ 0 .61803 .125 0 ]
[1.0125 .01472 0 -8.84375 ]
[1.0125 .01472 16 8.84375 ]
[1.0125 .18422 0 -8.84375 ]
[1.0125 .18422 16 8.84375 ]
[1.0125 .35372 0 -8.84375 ]
[1.0125 .35372 16 8.84375 ]
[1.0125 .52323 0 -8.84375 ]
[1.0125 .52323 16 8.84375 ]
[ 1 0 .125 0 ]
[1.0125 .30902 16 -173.125 ]
[1.0125 .30902 38.1875 173.125 ]
[.04704 .35836 -8.84375 0 ]
[.04704 .35836 8.84375 64 ]
[.07027 .35661 -8.84375 0 ]
[.07027 .35661 8.84375 64 ]
[.0935 .35955 -8.84375 0 ]
[.0935 .35955 8.84375 64 ]
[.11672 .36663 -8.84375 0 ]
[.11672 .36663 8.84375 64 ]
[.13995 .35565 -8.84375 0 ]
[.13995 .35565 8.84375 64 ]
[.16318 .3536 -8.84375 0 ]
[.16318 .3536 8.84375 64 ]
[.18641 .3705 -8.84375 0 ]
[.18641 .3705 8.84375 64 ]
[.20964 .37186 -8.84375 0 ]
[.20964 .37186 8.84375 64 ]
[.23287 .36257 -8.84375 0 ]
[.23287 .36257 8.84375 64 ]
[.2561 .35784 -8.84375 0 ]
[.2561 .35784 8.84375 64 ]
[.27933 .35634 -8.84375 0 ]
[.27933 .35634 8.84375 64 ]
[.30256 .35541 -8.84375 0 ]
[.30256 .35541 8.84375 64 ]
[.32578 .3686 -8.84375 0 ]
[.32578 .3686 8.84375 64 ]
[.34901 .38327 -8.84375 0 ]
[.34901 .38327 8.84375 64 ]
[.37224 .3685 -8.84375 0 ]
[.37224 .3685 8.84375 64 ]
[.39547 .34952 -8.84375 0 ]
[.39547 .34952 8.84375 64 ]
[.4187 .32951 -8.84375 0 ]
[.4187 .32951 8.84375 64 ]
[.44193 .25194 -8.84375 0 ]
[.44193 .25194 8.84375 64 ]
[.46516 .30065 -8.84375 0 ]
[.46516 .30065 8.84375 64 ]
[.48839 .30774 -8.84375 0 ]
[.48839 .30774 8.84375 64 ]
[.51161 .30868 -8.84375 0 ]
[.51161 .30868 8.84375 64 ]
[.53484 .29918 -8.84375 0 ]
[.53484 .29918 8.84375 64 ]
[.55807 .3049 -8.84375 0 ]
[.55807 .3049 8.84375 64 ]
[.5813 .30496 -8.84375 0 ]
[.5813 .30496 8.84375 64 ]
[.60453 .30498 -8.84375 0 ]
[.60453 .30498 8.84375 64 ]
[.62776 .30105 -8.84375 0 ]
[.62776 .30105 8.84375 64 ]
[.65099 .30053 -8.84375 0 ]
[.65099 .30053 8.84375 64 ]
[.67422 .30422 -8.84375 0 ]
[.67422 .30422 8.84375 64 ]
[.69744 .39688 -8.84375 0 ]
[.69744 .39688 8.84375 64 ]
[.72067 .42534 -8.84375 0 ]
[.72067 .42534 8.84375 64 ]
[.7439 .50437 -8.84375 0 ]
[.7439 .50437 8.84375 64 ]
[.76713 .36802 -8.84375 0 ]
[.76713 .36802 8.84375 64 ]
[.79036 .52572 -8.84375 0 ]
[.79036 .52572 8.84375 64 ]
[.81359 .42461 -8.84375 0 ]
[.81359 .42461 8.84375 64 ]
[.83682 .41263 -8.84375 0 ]
[.83682 .41263 8.84375 64 ]
[.86005 .31171 -8.84375 0 ]
[.86005 .31171 8.84375 64 ]
[.88328 .33649 -8.84375 0 ]
[.88328 .33649 8.84375 64 ]
[.9065 .33749 -8.84375 0 ]
[.9065 .33749 8.84375 64 ]
[.92973 .35249 -8.84375 0 ]
[.92973 .35249 8.84375 64 ]
[.95296 .35664 -8.84375 0 ]
[.95296 .35664 8.84375 64 ]
[.97619 .34227 -8.84375 0 ]
[.97619 .34227 8.84375 64 ]
[.02381 .01472 0 -5.875 ]
[.02381 .01472 83.0625 5.875 ]
[.02381 .04862 0 -5.875 ]
[.02381 .04862 83.0625 5.875 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
gsave
.5 -0.0125 -117 -22.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 18.125 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 18.125 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(run) show
111.000 18.125 moveto
(index) show
171.000 18.125 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -77 -12.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .09947 m
.00625 .09947 L
s
gsave
-0.0125 .09947 -113 -12.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
0 .18422 m
.00625 .18422 L
s
gsave
-0.0125 .18422 -101 -12.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .26897 m
.00625 .26897 L
s
gsave
-0.0125 .26897 -113 -12.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
0 .35372 m
.00625 .35372 L
s
gsave
-0.0125 .35372 -77 -12.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .43848 m
.00625 .43848 L
s
gsave
-0.0125 .43848 -113 -12.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.25) show
1.000 setlinewidth
grestore
0 .52323 m
.00625 .52323 L
s
gsave
-0.0125 .52323 -101 -12.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
0 .60798 m
.00625 .60798 L
s
gsave
-0.0125 .60798 -113 -12.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.75) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03167 m
.00375 .03167 L
s
0 .04862 m
.00375 .04862 L
s
0 .06557 m
.00375 .06557 L
s
0 .08252 m
.00375 .08252 L
s
0 .11642 m
.00375 .11642 L
s
0 .13337 m
.00375 .13337 L
s
0 .15032 m
.00375 .15032 L
s
0 .16727 m
.00375 .16727 L
s
0 .20117 m
.00375 .20117 L
s
0 .21812 m
.00375 .21812 L
s
0 .23507 m
.00375 .23507 L
s
0 .25202 m
.00375 .25202 L
s
0 .28592 m
.00375 .28592 L
s
0 .30287 m
.00375 .30287 L
s
0 .31982 m
.00375 .31982 L
s
0 .33677 m
.00375 .33677 L
s
0 .37067 m
.00375 .37067 L
s
0 .38762 m
.00375 .38762 L
s
0 .40458 m
.00375 .40458 L
s
0 .42153 m
.00375 .42153 L
s
0 .45543 m
.00375 .45543 L
s
0 .47238 m
.00375 .47238 L
s
0 .48933 m
.00375 .48933 L
s
0 .50628 m
.00375 .50628 L
s
0 .54018 m
.00375 .54018 L
s
0 .55713 m
.00375 .55713 L
s
0 .57408 m
.00375 .57408 L
s
0 .59103 m
.00375 .59103 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -334.406 -13.4062 Mabsadd m
1 1 Mabs scale
currentpoint translate
273 13.4062 translate
90 rotate
-273 -13.4062 translate
0 26.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 18.125 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 18.125 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ratio) show
135.000 18.125 moveto
(MCT) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
171.000 18.125 moveto
(\\220) show
183.000 18.125 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(PSCT) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
243.000 18.125 moveto
(H) show
255.000 18.125 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(average) show
351.000 18.125 moveto
(normalized) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
471.000 18.125 moveto
(L) show
483.000 18.125 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
gsave
1.0125 .01472 -61 -12.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.99375 .18422 m
1 .18422 L
s
gsave
1.0125 .18422 -61 -12.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.99375 .35372 m
1 .35372 L
s
gsave
1.0125 .35372 -61 -12.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.99375 .52323 m
1 .52323 L
s
gsave
1.0125 .52323 -61 -12.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9) show
1.000 setlinewidth
grestore
1 0 m
1 .61803 L
s
gsave
1.0125 .30902 -207.031 -15.0938 Mabsadd m
1 1 Mabs scale
currentpoint translate
234.125 15.0938 translate
90 rotate
-234.125 -15.0938 translate
0 30.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 21.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 21.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(total) show
135.000 21.438 moveto
(proton) show
219.000 21.438 moveto
(intensity) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
339.000 21.438 moveto
(@) show
351.000 21.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
375.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
393.250 21.438 moveto
(D) show
405.250 21.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.008 w
.04704 .35836 Mdot
.07027 .35661 Mdot
.0935 .35955 Mdot
.11672 .36663 Mdot
.13995 .35565 Mdot
.16318 .3536 Mdot
.18641 .3705 Mdot
.20964 .37186 Mdot
.23287 .36257 Mdot
.2561 .35784 Mdot
.27933 .35634 Mdot
.30256 .35541 Mdot
.32578 .3686 Mdot
.34901 .38327 Mdot
.37224 .3685 Mdot
.39547 .34952 Mdot
.4187 .32951 Mdot
.44193 .25194 Mdot
.46516 .30065 Mdot
.48839 .30774 Mdot
.51161 .30868 Mdot
.53484 .29918 Mdot
.55807 .3049 Mdot
.5813 .30496 Mdot
.60453 .30498 Mdot
.62776 .30105 Mdot
.65099 .30053 Mdot
.67422 .30422 Mdot
.69744 .39688 Mdot
.72067 .42534 Mdot
.7439 .50437 Mdot
.76713 .36802 Mdot
.79036 .52572 Mdot
.81359 .42461 Mdot
.83682 .41263 Mdot
.86005 .31171 Mdot
.88328 .33649 Mdot
.9065 .33749 Mdot
.92973 .35249 Mdot
.95296 .35664 Mdot
.97619 .34227 Mdot
1 0 0 r
.0001 w
.04704 .08398 0 2.5 Mabsadd m
.04704 .08398 -2.165 -1.25 Mabsadd L
.04704 .08398 2.165 -1.25 Mabsadd L
.04704 .08398 0 2.5 Mabsadd L closepath F
.07027 .36256 0 2.5 Mabsadd m
.07027 .36256 -2.165 -1.25 Mabsadd L
.07027 .36256 2.165 -1.25 Mabsadd L
.07027 .36256 0 2.5 Mabsadd L closepath F
.0935 .3667 0 2.5 Mabsadd m
.0935 .3667 -2.165 -1.25 Mabsadd L
.0935 .3667 2.165 -1.25 Mabsadd L
.0935 .3667 0 2.5 Mabsadd L closepath F
.11672 .07398 0 2.5 Mabsadd m
.11672 .07398 -2.165 -1.25 Mabsadd L
.11672 .07398 2.165 -1.25 Mabsadd L
.11672 .07398 0 2.5 Mabsadd L closepath F
.13995 .21486 0 2.5 Mabsadd m
.13995 .21486 -2.165 -1.25 Mabsadd L
.13995 .21486 2.165 -1.25 Mabsadd L
.13995 .21486 0 2.5 Mabsadd L closepath F
.16318 .22314 0 2.5 Mabsadd m
.16318 .22314 -2.165 -1.25 Mabsadd L
.16318 .22314 2.165 -1.25 Mabsadd L
.16318 .22314 0 2.5 Mabsadd L closepath F
.18641 .0637 0 2.5 Mabsadd m
.18641 .0637 -2.165 -1.25 Mabsadd L
.18641 .0637 2.165 -1.25 Mabsadd L
.18641 .0637 0 2.5 Mabsadd L closepath F
.20964 .06584 0 2.5 Mabsadd m
.20964 .06584 -2.165 -1.25 Mabsadd L
.20964 .06584 2.165 -1.25 Mabsadd L
.20964 .06584 0 2.5 Mabsadd L closepath F
.23287 .05142 0 2.5 Mabsadd m
.23287 .05142 -2.165 -1.25 Mabsadd L
.23287 .05142 2.165 -1.25 Mabsadd L
.23287 .05142 0 2.5 Mabsadd L closepath F
.2561 .06397 0 2.5 Mabsadd m
.2561 .06397 -2.165 -1.25 Mabsadd L
.2561 .06397 2.165 -1.25 Mabsadd L
.2561 .06397 0 2.5 Mabsadd L closepath F
.27933 .049 0 2.5 Mabsadd m
.27933 .049 -2.165 -1.25 Mabsadd L
.27933 .049 2.165 -1.25 Mabsadd L
.27933 .049 0 2.5 Mabsadd L closepath F
.30256 .06659 0 2.5 Mabsadd m
.30256 .06659 -2.165 -1.25 Mabsadd L
.30256 .06659 2.165 -1.25 Mabsadd L
.30256 .06659 0 2.5 Mabsadd L closepath F
.32578 .12965 0 2.5 Mabsadd m
.32578 .12965 -2.165 -1.25 Mabsadd L
.32578 .12965 2.165 -1.25 Mabsadd L
.32578 .12965 0 2.5 Mabsadd L closepath F
.34901 .1342 0 2.5 Mabsadd m
.34901 .1342 -2.165 -1.25 Mabsadd L
.34901 .1342 2.165 -1.25 Mabsadd L
.34901 .1342 0 2.5 Mabsadd L closepath F
.37224 .12441 0 2.5 Mabsadd m
.37224 .12441 -2.165 -1.25 Mabsadd L
.37224 .12441 2.165 -1.25 Mabsadd L
.37224 .12441 0 2.5 Mabsadd L closepath F
.39547 .28526 0 2.5 Mabsadd m
.39547 .28526 -2.165 -1.25 Mabsadd L
.39547 .28526 2.165 -1.25 Mabsadd L
.39547 .28526 0 2.5 Mabsadd L closepath F
.4187 .2894 0 2.5 Mabsadd m
.4187 .2894 -2.165 -1.25 Mabsadd L
.4187 .2894 2.165 -1.25 Mabsadd L
.4187 .2894 0 2.5 Mabsadd L closepath F
.44193 .28526 0 2.5 Mabsadd m
.44193 .28526 -2.165 -1.25 Mabsadd L
.44193 .28526 2.165 -1.25 Mabsadd L
.44193 .28526 0 2.5 Mabsadd L closepath F
.46516 .24109 0 2.5 Mabsadd m
.46516 .24109 -2.165 -1.25 Mabsadd L
.46516 .24109 2.165 -1.25 Mabsadd L
.46516 .24109 0 2.5 Mabsadd L closepath F
.48839 .23557 0 2.5 Mabsadd m
.48839 .23557 -2.165 -1.25 Mabsadd L
.48839 .23557 2.165 -1.25 Mabsadd L
.48839 .23557 0 2.5 Mabsadd L closepath F
.51161 .23557 0 2.5 Mabsadd m
.51161 .23557 -2.165 -1.25 Mabsadd L
.51161 .23557 2.165 -1.25 Mabsadd L
.51161 .23557 0 2.5 Mabsadd L closepath F
.53484 .24109 0 2.5 Mabsadd m
.53484 .24109 -2.165 -1.25 Mabsadd L
.53484 .24109 2.165 -1.25 Mabsadd L
.53484 .24109 0 2.5 Mabsadd L closepath F
.55807 .23971 0 2.5 Mabsadd m
.55807 .23971 -2.165 -1.25 Mabsadd L
.55807 .23971 2.165 -1.25 Mabsadd L
.55807 .23971 0 2.5 Mabsadd L closepath F
.5813 .24385 0 2.5 Mabsadd m
.5813 .24385 -2.165 -1.25 Mabsadd L
.5813 .24385 2.165 -1.25 Mabsadd L
.5813 .24385 0 2.5 Mabsadd L closepath F
.60453 .24247 0 2.5 Mabsadd m
.60453 .24247 -2.165 -1.25 Mabsadd L
.60453 .24247 2.165 -1.25 Mabsadd L
.60453 .24247 0 2.5 Mabsadd L closepath F
.62776 .24247 0 2.5 Mabsadd m
.62776 .24247 -2.165 -1.25 Mabsadd L
.62776 .24247 2.165 -1.25 Mabsadd L
.62776 .24247 0 2.5 Mabsadd L closepath F
.65099 .24937 0 2.5 Mabsadd m
.65099 .24937 -2.165 -1.25 Mabsadd L
.65099 .24937 2.165 -1.25 Mabsadd L
.65099 .24937 0 2.5 Mabsadd L closepath F
.67422 .24661 0 2.5 Mabsadd m
.67422 .24661 -2.165 -1.25 Mabsadd L
.67422 .24661 2.165 -1.25 Mabsadd L
.67422 .24661 0 2.5 Mabsadd L closepath F
.69744 .08019 0 2.5 Mabsadd m
.69744 .08019 -2.165 -1.25 Mabsadd L
.69744 .08019 2.165 -1.25 Mabsadd L
.69744 .08019 0 2.5 Mabsadd L closepath F
.72067 .14309 0 2.5 Mabsadd m
.72067 .14309 -2.165 -1.25 Mabsadd L
.72067 .14309 2.165 -1.25 Mabsadd L
.72067 .14309 0 2.5 Mabsadd L closepath F
.7439 .14861 0 2.5 Mabsadd m
.7439 .14861 -2.165 -1.25 Mabsadd L
.7439 .14861 2.165 -1.25 Mabsadd L
.7439 .14861 0 2.5 Mabsadd L closepath F
.76713 .14309 0 2.5 Mabsadd m
.76713 .14309 -2.165 -1.25 Mabsadd L
.76713 .14309 2.165 -1.25 Mabsadd L
.76713 .14309 0 2.5 Mabsadd L closepath F
.79036 .15413 0 2.5 Mabsadd m
.79036 .15413 -2.165 -1.25 Mabsadd L
.79036 .15413 2.165 -1.25 Mabsadd L
.79036 .15413 0 2.5 Mabsadd L closepath F
.81359 .14033 0 2.5 Mabsadd m
.81359 .14033 -2.165 -1.25 Mabsadd L
.81359 .14033 2.165 -1.25 Mabsadd L
.81359 .14033 0 2.5 Mabsadd L closepath F
.83682 .12627 0 2.5 Mabsadd m
.83682 .12627 -2.165 -1.25 Mabsadd L
.83682 .12627 2.165 -1.25 Mabsadd L
.83682 .12627 0 2.5 Mabsadd L closepath F
.86005 .12544 0 2.5 Mabsadd m
.86005 .12544 -2.165 -1.25 Mabsadd L
.86005 .12544 2.165 -1.25 Mabsadd L
.86005 .12544 0 2.5 Mabsadd L closepath F
.88328 .14309 0 2.5 Mabsadd m
.88328 .14309 -2.165 -1.25 Mabsadd L
.88328 .14309 2.165 -1.25 Mabsadd L
.88328 .14309 0 2.5 Mabsadd L closepath F
.9065 .14585 0 2.5 Mabsadd m
.9065 .14585 -2.165 -1.25 Mabsadd L
.9065 .14585 2.165 -1.25 Mabsadd L
.9065 .14585 0 2.5 Mabsadd L closepath F
.92973 .14172 0 2.5 Mabsadd m
.92973 .14172 -2.165 -1.25 Mabsadd L
.92973 .14172 2.165 -1.25 Mabsadd L
.92973 .14172 0 2.5 Mabsadd L closepath F
.95296 .11696 0 2.5 Mabsadd m
.95296 .11696 -2.165 -1.25 Mabsadd L
.95296 .11696 2.165 -1.25 Mabsadd L
.95296 .11696 0 2.5 Mabsadd L closepath F
.97619 .60274 0 2.5 Mabsadd m
.97619 .60274 -2.165 -1.25 Mabsadd L
.97619 .60274 2.165 -1.25 Mabsadd L
.97619 .60274 0 2.5 Mabsadd L closepath F
0 1 0 r
.04704 .08212 0 2.5 Mabsadd m
.04704 .08212 -2.165 -1.25 Mabsadd L
.04704 .08212 2.165 -1.25 Mabsadd L
.04704 .08212 0 2.5 Mabsadd L closepath F
.07027 .36813 0 2.5 Mabsadd m
.07027 .36813 -2.165 -1.25 Mabsadd L
.07027 .36813 2.165 -1.25 Mabsadd L
.07027 .36813 0 2.5 Mabsadd L closepath F
.0935 .37067 0 2.5 Mabsadd m
.0935 .37067 -2.165 -1.25 Mabsadd L
.0935 .37067 2.165 -1.25 Mabsadd L
.0935 .37067 0 2.5 Mabsadd L closepath F
.11672 .0298 0 2.5 Mabsadd m
.11672 .0298 -2.165 -1.25 Mabsadd L
.11672 .0298 2.165 -1.25 Mabsadd L
.11672 .0298 0 2.5 Mabsadd L closepath F
.13995 .23083 0 2.5 Mabsadd m
.13995 .23083 -2.165 -1.25 Mabsadd L
.13995 .23083 2.165 -1.25 Mabsadd L
.13995 .23083 0 2.5 Mabsadd L closepath F
.16318 .22956 0 2.5 Mabsadd m
.16318 .22956 -2.165 -1.25 Mabsadd L
.16318 .22956 2.165 -1.25 Mabsadd L
.16318 .22956 0 2.5 Mabsadd L closepath F
.18641 .02731 0 2.5 Mabsadd m
.18641 .02731 -2.165 -1.25 Mabsadd L
.18641 .02731 2.165 -1.25 Mabsadd L
.18641 .02731 0 2.5 Mabsadd L closepath F
.20964 .02771 0 2.5 Mabsadd m
.20964 .02771 -2.165 -1.25 Mabsadd L
.20964 .02771 2.165 -1.25 Mabsadd L
.20964 .02771 0 2.5 Mabsadd L closepath F
.23287 .03257 0 2.5 Mabsadd m
.23287 .03257 -2.165 -1.25 Mabsadd L
.23287 .03257 2.165 -1.25 Mabsadd L
.23287 .03257 0 2.5 Mabsadd L closepath F
.2561 .03856 0 2.5 Mabsadd m
.2561 .03856 -2.165 -1.25 Mabsadd L
.2561 .03856 2.165 -1.25 Mabsadd L
.2561 .03856 0 2.5 Mabsadd L closepath F
.27933 .03958 0 2.5 Mabsadd m
.27933 .03958 -2.165 -1.25 Mabsadd L
.27933 .03958 2.165 -1.25 Mabsadd L
.27933 .03958 0 2.5 Mabsadd L closepath F
.30256 .05297 0 2.5 Mabsadd m
.30256 .05297 -2.165 -1.25 Mabsadd L
.30256 .05297 2.165 -1.25 Mabsadd L
.30256 .05297 0 2.5 Mabsadd L closepath F
.32578 .08139 0 2.5 Mabsadd m
.32578 .08139 -2.165 -1.25 Mabsadd L
.32578 .08139 2.165 -1.25 Mabsadd L
.32578 .08139 0 2.5 Mabsadd L closepath F
.34901 .10964 0 2.5 Mabsadd m
.34901 .10964 -2.165 -1.25 Mabsadd L
.34901 .10964 2.165 -1.25 Mabsadd L
.34901 .10964 0 2.5 Mabsadd L closepath F
.37224 .11902 0 2.5 Mabsadd m
.37224 .11902 -2.165 -1.25 Mabsadd L
.37224 .11902 2.165 -1.25 Mabsadd L
.37224 .11902 0 2.5 Mabsadd L closepath F
.39547 .29821 0 2.5 Mabsadd m
.39547 .29821 -2.165 -1.25 Mabsadd L
.39547 .29821 2.165 -1.25 Mabsadd L
.39547 .29821 0 2.5 Mabsadd L closepath F
.4187 .30202 0 2.5 Mabsadd m
.4187 .30202 -2.165 -1.25 Mabsadd L
.4187 .30202 2.165 -1.25 Mabsadd L
.4187 .30202 0 2.5 Mabsadd L closepath F
.44193 .29058 0 2.5 Mabsadd m
.44193 .29058 -2.165 -1.25 Mabsadd L
.44193 .29058 2.165 -1.25 Mabsadd L
.44193 .29058 0 2.5 Mabsadd L closepath F
.46516 .24609 0 2.5 Mabsadd m
.46516 .24609 -2.165 -1.25 Mabsadd L
.46516 .24609 2.165 -1.25 Mabsadd L
.46516 .24609 0 2.5 Mabsadd L closepath F
.48839 .24355 0 2.5 Mabsadd m
.48839 .24355 -2.165 -1.25 Mabsadd L
.48839 .24355 2.165 -1.25 Mabsadd L
.48839 .24355 0 2.5 Mabsadd L closepath F
.51161 .24736 0 2.5 Mabsadd m
.51161 .24736 -2.165 -1.25 Mabsadd L
.51161 .24736 2.165 -1.25 Mabsadd L
.51161 .24736 0 2.5 Mabsadd L closepath F
.53484 .24736 0 2.5 Mabsadd m
.53484 .24736 -2.165 -1.25 Mabsadd L
.53484 .24736 2.165 -1.25 Mabsadd L
.53484 .24736 0 2.5 Mabsadd L closepath F
.55807 .24227 0 2.5 Mabsadd m
.55807 .24227 -2.165 -1.25 Mabsadd L
.55807 .24227 2.165 -1.25 Mabsadd L
.55807 .24227 0 2.5 Mabsadd L closepath F
.5813 .24863 0 2.5 Mabsadd m
.5813 .24863 -2.165 -1.25 Mabsadd L
.5813 .24863 2.165 -1.25 Mabsadd L
.5813 .24863 0 2.5 Mabsadd L closepath F
.60453 .24482 0 2.5 Mabsadd m
.60453 .24482 -2.165 -1.25 Mabsadd L
.60453 .24482 2.165 -1.25 Mabsadd L
.60453 .24482 0 2.5 Mabsadd L closepath F
.62776 .24482 0 2.5 Mabsadd m
.62776 .24482 -2.165 -1.25 Mabsadd L
.62776 .24482 2.165 -1.25 Mabsadd L
.62776 .24482 0 2.5 Mabsadd L closepath F
.65099 .2588 0 2.5 Mabsadd m
.65099 .2588 -2.165 -1.25 Mabsadd L
.65099 .2588 2.165 -1.25 Mabsadd L
.65099 .2588 0 2.5 Mabsadd L closepath F
.67422 .25117 0 2.5 Mabsadd m
.67422 .25117 -2.165 -1.25 Mabsadd L
.67422 .25117 2.165 -1.25 Mabsadd L
.67422 .25117 0 2.5 Mabsadd L closepath F
.69744 .02873 0 2.5 Mabsadd m
.69744 .02873 -2.165 -1.25 Mabsadd L
.69744 .02873 2.165 -1.25 Mabsadd L
.69744 .02873 0 2.5 Mabsadd L closepath F
.72067 .02816 0 2.5 Mabsadd m
.72067 .02816 -2.165 -1.25 Mabsadd L
.72067 .02816 2.165 -1.25 Mabsadd L
.72067 .02816 0 2.5 Mabsadd L closepath F
.7439 .02607 0 2.5 Mabsadd m
.7439 .02607 -2.165 -1.25 Mabsadd L
.7439 .02607 2.165 -1.25 Mabsadd L
.7439 .02607 0 2.5 Mabsadd L closepath F
.76713 .02963 0 2.5 Mabsadd m
.76713 .02963 -2.165 -1.25 Mabsadd L
.76713 .02963 2.165 -1.25 Mabsadd L
.76713 .02963 0 2.5 Mabsadd L closepath F
.79036 .02528 0 2.5 Mabsadd m
.79036 .02528 -2.165 -1.25 Mabsadd L
.79036 .02528 2.165 -1.25 Mabsadd L
.79036 .02528 0 2.5 Mabsadd L closepath F
.81359 .02754 0 2.5 Mabsadd m
.81359 .02754 -2.165 -1.25 Mabsadd L
.81359 .02754 2.165 -1.25 Mabsadd L
.81359 .02754 0 2.5 Mabsadd L closepath F
.83682 .02731 0 2.5 Mabsadd m
.83682 .02731 -2.165 -1.25 Mabsadd L
.83682 .02731 2.165 -1.25 Mabsadd L
.83682 .02731 0 2.5 Mabsadd L closepath F
.86005 .02641 0 2.5 Mabsadd m
.86005 .02641 -2.165 -1.25 Mabsadd L
.86005 .02641 2.165 -1.25 Mabsadd L
.86005 .02641 0 2.5 Mabsadd L closepath F
.88328 .14693 0 2.5 Mabsadd m
.88328 .14693 -2.165 -1.25 Mabsadd L
.88328 .14693 2.165 -1.25 Mabsadd L
.88328 .14693 0 2.5 Mabsadd L closepath F
.9065 .15837 0 2.5 Mabsadd m
.9065 .15837 -2.165 -1.25 Mabsadd L
.9065 .15837 2.165 -1.25 Mabsadd L
.9065 .15837 0 2.5 Mabsadd L closepath F
.92973 .1571 0 2.5 Mabsadd m
.92973 .1571 -2.165 -1.25 Mabsadd L
.92973 .1571 2.165 -1.25 Mabsadd L
.92973 .1571 0 2.5 Mabsadd L closepath F
.95296 .11218 0 2.5 Mabsadd m
.95296 .11218 -2.165 -1.25 Mabsadd L
.95296 .11218 2.165 -1.25 Mabsadd L
.95296 .11218 0 2.5 Mabsadd L closepath F
.97619 .60332 0 2.5 Mabsadd m
.97619 .60332 -2.165 -1.25 Mabsadd L
.97619 .60332 2.165 -1.25 Mabsadd L
.97619 .60332 0 2.5 Mabsadd L closepath F
0 g
gsave
.04704 .35836 -93 19.1562 Mabsadd m
1 1 Mabs scale
currentpoint translate
93 12.8438 translate
270 rotate
-93 -12.8438 translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11001) show
1.000 setlinewidth
grestore
gsave
.07027 .35661 -93 19.1562 Mabsadd m
1 1 Mabs scale
currentpoint translate
93 12.8438 translate
270 rotate
-93 -12.8438 translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11002) show
1.000 setlinewidth
grestore
gsave
.0935 .35955 -93 19.1562 Mabsadd m
1 1 Mabs scale
currentpoint translate
93 12.8438 translate
270 rotate
-93 -12.8438 translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11003) show
1.000 setlinewidth
grestore
gsave
.11672 .36663 -93 19.1562 Mabsadd m
1 1 Mabs scale
currentpoint translate
93 12.8438 translate
270 rotate
-93 -12.8438 translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11017) show
1.000 setlinewidth
grestore
gsave
.13995 .35565 -93 19.1562 Mabsadd m
1 1 Mabs scale
currentpoint translate
93 12.8438 translate
270 rotate
-93 -12.8438 translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11020) show
1.000 setlinewidth
grestore
gsave
.16318 .3536 -93 19.1562 Mabsadd m
1 1 Mabs scale
currentpoint translate
93 12.8438 translate
270 rotate
-93 -12.8438 translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11021) show
1.000 setlinewidth
grestore
gsave
.18641 .3705 -93 19.1562 Mabsadd m
1 1 Mabs scale
currentpoint translate
93 12.8438 translate
270 rotate
-93 -12.8438 translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11023) show
1.000 setlinewidth
grestore
gsave
.20964 .37186 -93 19.1562 Mabsadd m
1 1 Mabs scale
currentpoint translate
93 12.8438 translate
270 rotate
-93 -12.8438 translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11024) show
1.000 setlinewidth
grestore
gsave
.23287 .36257 -93 19.1562 Mabsadd m
1 1 Mabs scale
currentpoint translate
93 12.8438 translate
270 rotate
-93 -12.8438 translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11025) show
1.000 setlinewidth
grestore
gsave
.2561 .35784 -93 19.1562 Mabsadd m
1 1 Mabs scale
currentpoint translate
93 12.8438 translate
270 rotate
-93 -12.8438 translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11026) show
1.000 setlinewidth
grestore
gsave
.27933 .35634 -93 19.1562 Mabsadd m
1 1 Mabs scale
currentpoint translate
93 12.8438 translate
270 rotate
-93 -12.8438 translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11027) show
1.000 setlinewidth
grestore
gsave
.30256 .35541 -93 19.1562 Mabsadd m
1 1 Mabs scale
currentpoint translate
93 12.8438 translate
270 rotate
-93 -12.8438 translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11028) show
1.000 setlinewidth
grestore
gsave
.32578 .3686 -93 19.1562 Mabsadd m
1 1 Mabs scale
currentpoint translate
93 12.8438 translate
270 rotate
-93 -12.8438 translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11029) show
1.000 setlinewidth
grestore
gsave
.34901 .38327 -93 19.1562 Mabsadd m
1 1 Mabs scale
currentpoint translate
93 12.8438 translate
270 rotate
-93 -12.8438 translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11030) show
1.000 setlinewidth
grestore
gsave
.37224 .3685 -93 19.1562 Mabsadd m
1 1 Mabs scale
currentpoint translate
93 12.8438 translate
270 rotate
-93 -12.8438 translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11031) show
1.000 setlinewidth
grestore
gsave
.39547 .34952 -93 19.1562 Mabsadd m
1 1 Mabs scale
currentpoint translate
93 12.8438 translate
270 rotate
-93 -12.8438 translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12001) show
1.000 setlinewidth
grestore
gsave
.4187 .32951 -93 19.1562 Mabsadd m
1 1 Mabs scale
currentpoint translate
93 12.8438 translate
270 rotate
-93 -12.8438 translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12004) show
1.000 setlinewidth
grestore
gsave
.44193 .25194 -93 19.1562 Mabsadd m
1 1 Mabs scale
currentpoint translate
93 12.8438 translate
270 rotate
-93 -12.8438 translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12005) show
1.000 setlinewidth
grestore
gsave
.46516 .30065 -93 19.1562 Mabsadd m
1 1 Mabs scale
currentpoint translate
93 12.8438 translate
270 rotate
-93 -12.8438 translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12006) show
1.000 setlinewidth
grestore
gsave
.48839 .30774 -93 19.1562 Mabsadd m
1 1 Mabs scale
currentpoint translate
93 12.8438 translate
270 rotate
-93 -12.8438 translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12008) show
1.000 setlinewidth
grestore
gsave
.51161 .30868 -93 19.1562 Mabsadd m
1 1 Mabs scale
currentpoint translate
93 12.8438 translate
270 rotate
-93 -12.8438 translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12009) show
1.000 setlinewidth
grestore
gsave
.53484 .29918 -93 19.1562 Mabsadd m
1 1 Mabs scale
currentpoint translate
93 12.8438 translate
270 rotate
-93 -12.8438 translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12010) show
1.000 setlinewidth
grestore
gsave
.55807 .3049 -93 19.1562 Mabsadd m
1 1 Mabs scale
currentpoint translate
93 12.8438 translate
270 rotate
-93 -12.8438 translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12011) show
1.000 setlinewidth
grestore
gsave
.5813 .30496 -93 19.1562 Mabsadd m
1 1 Mabs scale
currentpoint translate
93 12.8438 translate
270 rotate
-93 -12.8438 translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12012) show
1.000 setlinewidth
grestore
gsave
.60453 .30498 -93 19.1562 Mabsadd m
1 1 Mabs scale
currentpoint translate
93 12.8438 translate
270 rotate
-93 -12.8438 translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12013) show
1.000 setlinewidth
grestore
gsave
.62776 .30105 -93 19.1562 Mabsadd m
1 1 Mabs scale
currentpoint translate
93 12.8438 translate
270 rotate
-93 -12.8438 translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12014) show
1.000 setlinewidth
grestore
gsave
.65099 .30053 -93 19.1562 Mabsadd m
1 1 Mabs scale
currentpoint translate
93 12.8438 translate
270 rotate
-93 -12.8438 translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12015) show
1.000 setlinewidth
grestore
gsave
.67422 .30422 -93 19.1562 Mabsadd m
1 1 Mabs scale
currentpoint translate
93 12.8438 translate
270 rotate
-93 -12.8438 translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12016) show
1.000 setlinewidth
grestore
gsave
.69744 .39688 -93 19.1562 Mabsadd m
1 1 Mabs scale
currentpoint translate
93 12.8438 translate
270 rotate
-93 -12.8438 translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12017) show
1.000 setlinewidth
grestore
gsave
.72067 .42534 -93 19.1562 Mabsadd m
1 1 Mabs scale
currentpoint translate
93 12.8438 translate
270 rotate
-93 -12.8438 translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12019) show
1.000 setlinewidth
grestore
gsave
.7439 .50437 -93 19.1562 Mabsadd m
1 1 Mabs scale
currentpoint translate
93 12.8438 translate
270 rotate
-93 -12.8438 translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12020) show
1.000 setlinewidth
grestore
gsave
.76713 .36802 -93 19.1562 Mabsadd m
1 1 Mabs scale
currentpoint translate
93 12.8438 translate
270 rotate
-93 -12.8438 translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12021) show
1.000 setlinewidth
grestore
gsave
.79036 .52572 -93 19.1562 Mabsadd m
1 1 Mabs scale
currentpoint translate
93 12.8438 translate
270 rotate
-93 -12.8438 translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12022) show
1.000 setlinewidth
grestore
gsave
.81359 .42461 -93 19.1562 Mabsadd m
1 1 Mabs scale
currentpoint translate
93 12.8438 translate
270 rotate
-93 -12.8438 translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12023) show
1.000 setlinewidth
grestore
gsave
.83682 .41263 -93 19.1562 Mabsadd m
1 1 Mabs scale
currentpoint translate
93 12.8438 translate
270 rotate
-93 -12.8438 translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12024) show
1.000 setlinewidth
grestore
gsave
.86005 .31171 -93 19.1562 Mabsadd m
1 1 Mabs scale
currentpoint translate
93 12.8438 translate
270 rotate
-93 -12.8438 translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12025) show
1.000 setlinewidth
grestore
gsave
.88328 .33649 -93 19.1562 Mabsadd m
1 1 Mabs scale
currentpoint translate
93 12.8438 translate
270 rotate
-93 -12.8438 translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12026) show
1.000 setlinewidth
grestore
gsave
.9065 .33749 -93 19.1562 Mabsadd m
1 1 Mabs scale
currentpoint translate
93 12.8438 translate
270 rotate
-93 -12.8438 translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12027) show
1.000 setlinewidth
grestore
gsave
.92973 .35249 -93 19.1562 Mabsadd m
1 1 Mabs scale
currentpoint translate
93 12.8438 translate
270 rotate
-93 -12.8438 translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12028) show
1.000 setlinewidth
grestore
gsave
.95296 .35664 -93 19.1562 Mabsadd m
1 1 Mabs scale
currentpoint translate
93 12.8438 translate
270 rotate
-93 -12.8438 translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12030) show
1.000 setlinewidth
grestore
gsave
.97619 .34227 -93 19.1562 Mabsadd m
1 1 Mabs scale
currentpoint translate
93 12.8438 translate
270 rotate
-93 -12.8438 translate
0 25.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12032) show
1.000 setlinewidth
grestore
gsave
.02381 .01472 -61 -9.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 1.000 0.000 setrgbcolor
(intensity) show
134.875 12.875 moveto
(3) show
142.062 12.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.02381 .04862 -61 -9.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(intensity) show
134.875 12.875 moveto
(2) show
142.062 12.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{700, 432.625},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:l0001/2000`400000o`00o`00o`00o`3ooooo
0?oookh0oooo003o0?ooool0oooo_P3oool00?l0ooooo`3ooonn0?ooo`00o`3ooooo0?oookh0oooo
003o0?ooool0oooo_P3oool00?l0ooooo`3ooonn0?ooo`00o`3ooooo0?oookh0oooo000@0?ooo`P0
0000o`3ooooo0?ooojH0oooo000@0?ooo`P00000o`3ooooo0?ooojH0oooo000B0?ooo`800000o`3o
oooo0?ooojX0oooo000B0?ooo`800000o`3ooooo0?ooojX0oooo000B0?ooo`800000o`3ooooo0?oo
ojX0oooo000B0?ooo`800000o`3ooooo0?ooojX0oooo000B0?ooo`800000o`3ooooo0?ooojX0oooo
000B0?ooo`800000o`3ooooo0?ooojX0oooo000@0?ooo`8000000P3oool600000?l0ooooo`3ooonT
0?ooo`00403oool200000080oooo1P00003o0?ooool0ooooY03oool00?l0ooooo`3ooonn0?ooo`00
o`3ooooo0?oookh0oooo000B0?ooo`@000000P3oool200000?l0oooo8P3oool8000000H0oooo1000
00020?ooo`P000000P3oool4000000h0oooo400000020?ooo`@00000103oool400000080oooo0P00
00040?ooo`H000000P3oool400000080oooo1000003o0?oooaX0oooo000B0?ooo`@000000P3oool2
00000?l0oooo8P3oool8000000H0oooo100000020?ooo`P000000P3oool4000000h0oooo40000002
0?ooo`@00000103oool400000080oooo0P0000040?ooo`H000000P3oool400000080oooo1000003o
0?oooaX0oooo000@0?ooo`800000103oool200000?l0oooo9P3oool2000000P0oooo0P0000040?oo
o`800000103oool2000000@0oooo0P00000D0?ooo`8000001P3oool2000000@0oooo0P0000040?oo
o`800000103oool2000000@0oooo0P00000:0?ooo`8000000P3oool200000?l0oooo703oool00100
oooo0P0000040?ooo`800000o`3ooolV0?ooo`800000203oool2000000@0oooo0P0000040?ooo`80
0000103oool2000001@0oooo0P0000060?ooo`800000103oool2000000@0oooo0P0000040?ooo`80
0000103oool2000000X0oooo0P0000020?ooo`800000o`3ooolL0?ooo`004P3oool600000?l0oooo
9P3oool2000000P0oooo0P0000040?ooo`800000103oool2000000@0oooo0P00000D0?ooo`800000
1P3oool2000000@0oooo0P0000040?ooo`800000103oool2000000@0oooo1P0000080?ooo`800000
o`3ooolN0?ooo`004P3oool600000?l0oooo9P3oool2000000P0oooo0P0000040?ooo`800000103o
ool2000000@0oooo0P00000D0?ooo`8000001P3oool2000000@0oooo0P0000040?ooo`800000103o
ool2000000@0oooo1P0000080?ooo`800000o`3ooolN0?ooo`005P3oool200000?l0oooo9P3oool2
000000P0oooo0P0000040?ooo`800000103oool2000000@0oooo0P00000D0?ooo`8000001P3oool2
000000@0oooo0P0000040?ooo`800000103oool2000000@0oooo0P0000040?ooo`800000103oool2
00000080oooo0P00003o0?oooa`0oooo000F0?ooo`800000o`3ooolV0?ooo`800000203oool20000
00@0oooo0P0000040?ooo`800000103oool2000001@0oooo0P0000060?ooo`800000103oool20000
00@0oooo0P0000040?ooo`800000103oool2000000@0oooo0P0000040?ooo`8000000P3oool20000
0?l0oooo703oool00180oooo1000003o0?ooobH0oooo0P0000020?ooo`X000000P3oool400000080
oooo0P0000020?ooo`@00000503oool4000000@0oooo0P0000020?ooo`@00000203oool6000000H0
oooo100000040?ooo`@000000P3oool400000?l0oooo6P3oool00180oooo1000003o0?ooobH0oooo
0P0000020?ooo`X000000P3oool400000080oooo0P0000020?ooo`@00000503oool4000000@0oooo
0P0000020?ooo`@00000203oool6000000H0oooo100000040?ooo`@000000P3oool400000?l0oooo
6P3oool00?l0ooooRP3oool200000?l0oooo<P3oool00?l0ooooRP3oool200000?l0oooo<P3oool0
01@0oooo1000003o0?oooeP0oooo0P00000F0?ooo`@00000o`3ooolb0?ooo`00503oool400000?l0
ooooF03oool2000001H0oooo1000003o0?oooc80oooo000B0?ooo`800000103oool200000?l0oooo
o`3ooonT0?ooo`004P3oool2000000@0oooo0P00003o0?ooool0ooooY03oool00180oooo0P00003o
0?ooool0ooooZP3oool00180oooo0P00003o0?ooool0ooooZP3oool00180oooo0P00003o0?ooool0
ooooZP3oool00180oooo0P00003o0?ooool0ooooZP3oool00100oooo2000000i0?ooool00000o`00
000o000002h0oooo000@0?ooo`P00000>@3oool00`000000oooo0?ooo`3o0?ooool0oooo>`3oool0
0`000000oooo0?ooo`0/0?ooo`004P3oool2000003d0oooo00<000000?ooo`3oool0o`3ooooo0?oo
oc/0oooo00<000000?ooo`3oool0;03oool00180oooo0P00000m0?ooo`030000003oool0oooo04H0
oooo0P00o`3o0?oooo80oooo00<000000?ooo`3oool0;03oool00100oooo2P00000g0?ooo`030000
003oool0oooo04P0oooo00<00?l00?ooo`3oool0o`3oooo_0?ooo`030000003oool0oooo02`0oooo
000@0?ooo`X000009P3oool4000000d0oooo00<000000?ooo`3oool0B03oool00`00o`00oooo0?oo
o`3o0?ooonl0oooo00<000000?ooo`3oool02P3oool4000001h0oooo000D0?ooo`800000:P3oool4
000000d0oooo00<000000?ooo`3oool03P3oool5003o00040?ooo`00o`000?l0003o0080oooo0P00
o`030?ooo`<00?l00`3oool3003o0080oooo0`00o`020?ooo`800?l00P3oool3003o00<0oooo1@00
o`040?ooo`<00?l0103oool00`00o`00oooo0?ooo`0<0?ooo`<00?l0o`3ooooP0?ooo`030000003o
ool0oooo00X0oooo1000000N0?ooo`00503oool2000002P0oooo0P0000040?ooo`8000002`3oool0
0`000000oooo0?ooo`0@0?ooo`03003o003oool0oooo0080oooo00D00?l00?ooo`3oool0oooo003o
00030?ooo`07003o003oool0oooo0?ooo`00o`00oooo003o00030?ooo`04003o003oool0oooo003o
00<0oooo00@00?l00?ooo`3oool00?l00`3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0
oooo00<0oooo00D00?l00?ooo`3oool0oooo003o00020?ooo`<00?l0303oool01@00o`00oooo0?oo
o`3oool00?l00?l0oooog`3oool00`000000oooo0?ooo`080?ooo`800000103oool2000001`0oooo
000D0?ooo`800000:03oool2000000@0oooo0P00000;0?ooo`D000003P3oool00`00o`00oooo0?oo
o`020?ooo`05003o003oool0oooo0?ooo`00o`000`3oool00`00o`00oooo0?ooo`030?ooo`03003o
003oool0oooo00@0oooo00D00?l00?ooo`3oool0oooo003o00060?ooo`03003o003oool0oooo0080
oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`040?ooo`03003o003oool00?l00100
oooo00<00?l00?ooo`3oool0o`3ooooJ0?ooo`@000002P3oool2000000@0oooo0P00000L0?ooo`00
503oool2000002P0oooo0P0000040?ooo`8000002`3oool00`000000oooo0?ooo`0@0?ooo`03003o
003oool0oooo0080oooo00D00?l00?ooo`3oool0oooo003o00030?ooo`03003o003oool0oooo00<0
oooo1@00o`020?ooo`05003o003oool0oooo0?ooo`00o`000`3oool3003o00D0oooo00<00?l00?oo
o`3oool00`3oool00`00o`00oooo0?ooo`030?ooo`05003o003oool0oooo0?ooo`00o`003`3oool0
0`00o`00oooo0?ooo`3o0?ooomd0oooo00<000000?ooo`3oool0203oool2000000@0oooo0P00000J
0?ooo`800000000D0?ooo`800000:03oool2000000@0oooo0P00000;0?ooo`030000003oool0oooo
0100oooo00<00?l00?ooo`3oool00P3oool2003o0080oooo00D00?l00?ooo`3oool0oooo003o0005
0?ooo`05003o003oool0oooo0?ooo`00o`000P3oool2003o0080oooo00@00?l00?ooo`3oool00?l0
0`3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool0
0`3oool01@00o`00oooo0?ooo`3oool00?l000d0oooo0P00o`3o0?ooon00oooo00<000000?ooo`3o
ool0203oool2000000@0oooo0P00000J0?ooo`800000000D0?ooo`800000:03oool2000000@0oooo
0P00000;0?ooo`030000003oool0oooo00h0oooo0`00o`030?ooo`03003o003oool00?l000800?l0
0`3oool5003o00<0oooo0`00o`020?ooo`03003o003oool00?l000800?l0103oool3003o00<0oooo
0`00o`040?ooo`D00?l000D0oooo003o0000o`000?l00?ooo`03003o00h0oooo00<00?l00?ooo`3o
ool0o`3ooooM0?ooo`030000003oool0oooo00P0oooo0P0000040?ooo`8000006P3oool200000000
4P3oool4000002P0oooo0P0000040?ooo`8000002`3oool00`000000oooo0?ooo`0M0?ooo`03003o
003oool0oooo0200oooo00<00?l00?ooo`3oool05`3oool00`00o`00oooo0?ooo`3o0?ooomd0oooo
00<000000?ooo`3oool0203oool2000000@0oooo0P00000J0?ooo`800000000B0?ooo`@00000:03o
ool2000000@0oooo0P00000;0?ooo`030000003oool0oooo01d0oooo00<00?l00?ooo`3oool0803o
ool00`00o`00oooo0?ooo`0C0?ooo`05003o003oool0oooo0?ooo`00o`00o`3ooooO0?ooo`030000
003oool0oooo00P0oooo0P0000040?ooo`8000006P3oool200000000?P3oool2000000@0oooo0P00
000;0?ooo`030000003oool0oooo0100oooo00<00?l00?ooo`3oool09`3oool00`00o`00oooo0?oo
o`0J0?ooo`<00?l0o`3ooomW0?ooo`<00?l0MP3oool00`000000oooo0?ooo`080?ooo`800000103o
ool2000001X0oooo0P00000003h0oooo0P0000040?ooo`8000002`3oool00`000000oooo0?ooo`1W
0?ooo`<00?l02P3oool3003o0?l0oooo;`3oool4003o01L0oooo0P00o`0;0?ooo`@00?l02P3oool3
003o00X0oooo0`00o`1>0?ooo`030000003oool0oooo00P0oooo0P0000040?ooo`800000603oool4
000000004P3oool4000002P0oooo0P0000040?ooo`8000002`3oool00`000000oooo0?ooo`1W0?oo
o`800?l02`3oool2003o0?l0oooo5P3oool3003o00X0oooo1000o`0:0?ooo`800?l06@3oool00`00
o`00oooo0?ooo`0:0?ooo`800?l02`3oool2003o00`0oooo00<00?l00?ooo`3oool0C@3oool00`00
0000oooo0?ooo`080?ooo`800000103oool2000001P0oooo100000000180oooo1000000Z0?ooo`@0
00003@3oool00`000000oooo0?ooo`0o0?ooo`<00?l09P3oool00`00o`00oooo0?ooo`0:0?ooo`03
003o003oool0oooo0?l0oooo503oool2003o00/0oooo0`00o`0H0?ooo`<00?l06@3oool00`00o`00
oooo0?ooo`0:0?ooo`03003o003oool0oooo05X0oooo00<000000?ooo`3oool02P3oool4000001`0
oooo0P0000000100oooo0P0000040?ooo`800000:03oool4000000d0oooo0`0000100?ooo`03003o
003oool0oooo03h0oooo0`00o`3o0?ooo`T0oooo00<00?l00?ooo`3oool02P3oool00`00o`00oooo
0?ooo`0H0?ooo`03003o003oool0oooo0880oooo00<000000?ooo`3oool02P3oool4000001`0oooo
0P0000000100oooo0P0000040?ooo`800000>@3oool00`000000oooo0?ooo`210?ooo`800?l0o`3o
oong0?ooo`030000003oool0oooo02X0oooo0P0000000100oooo0P0000040?ooo`800000>@3oool0
0`000000oooo0?ooo`220?ooo`03003o003oool0oooo0?l0oooo]@3oool00`000000oooo0?ooo`0Z
0?ooo`800000000@0?ooo`800000103oool2000003T0oooo00<000000?ooo`3oool0o`3ooooo0?oo
oc/0oooo00<000000?ooo`3oool0:03oool200000080oooo000@0?ooo`800000103oool2000003T0
oooo00<000000?ooo`3oool0SP3oool4003o00X0oooo0`00o`3o0?oooi/0oooo00<000000?ooo`3o
ool0:03oool200000080oooo000@0?ooo`800000103oool2000003T0oooo00<000000?ooo`3oool0
AP3oool20000odL0oooo0P00o`0;0?ooo`800?l0o`3ooonL0?ooo`030000003oool0oooo02P0oooo
0P0000020?ooo`004P3oool4000003/0oooo00<000000?ooo`3oool0B03oool00`000?l0oooo0?oo
o`1B0?ooo`03003o003oool0oooo0?l0ooooVP3oool00`000000oooo0?ooo`0X0?ooo`8000000P3o
ool00180oooo1000000k0?ooo`030000003oool0oooo04P0oooo00<0003o0?ooo`3oool0o`3oooo_
0?ooo`030000003oool0oooo02P0oooo0P0000020?ooo`00D@3oool00`000000oooo0?ooo`0>0?oo
o`D0003o00@0oooo0000o`000?l0003o0P3oool20000o`<0oooo0`000?l30?ooo`<0003o0P3oool3
0000o`80oooo0P000?l20?ooo`<0003o0`3oool50000o`@0oooo0`000?l40?ooo`030000o`3oool0
oooo00/0oooo1@000?oo0?oooml0oooo00<000000?ooo`3oool0:03oool200000080oooo001A0?oo
o`030000003oool0oooo0100oooo00<0003o0?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0
003o00<0oooo00L0003o0?ooo`3oool0oooo0000o`3oool0003o00<0oooo00@0003o0?ooo`3oool0
003o0`3oool010000?l0oooo0?ooo`000?l30?ooo`030000o`3oool0oooo0080oooo00<0003o0?oo
o`3oool00`3oool01@000?l0oooo0?ooo`3oool0003o0080oooo0`000?l<0?ooo`050000o`3oool0
oooo0?ooo`000?l0o`3ooooO0?ooo`030000003oool0oooo02X0oooo0P0000000540oooo0`00000@
0?ooo`030000o`3oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0000o`030?ooo`030000o`3o
ool0oooo00<0oooo00<0003o0?ooo`3oool0103oool01@000?l0oooo0?ooo`3oool0003o00H0oooo
00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo
00<0003o0?ooo`000?l03@3oool00`000?l0oooo0?ooo`120?ooo`<0003oo`3ooonK0?ooo`030000
003oool0oooo02X0oooo0P0000000540oooo00<000000?ooo`3oool0403oool00`000?l0oooo0?oo
o`020?ooo`050000o`3oool0oooo0?ooo`000?l00`3oool00`000?l0oooo0?ooo`030?ooo`D0003o
0P3oool01@000?l0oooo0?ooo`3oool0003o00<0oooo0`000?l50?ooo`030000o`3oool0oooo00<0
oooo00<0003o0?ooo`3oool00`3oool01@000?l0oooo0?ooo`3oool0003o00d0oooo00<0003o0?oo
o`3oool09P3oool30000oaT0oooo00<0003o0?ooo`3oool0o`3ooonJ0?ooo`030000003oool0oooo
02`0oooo001A0?ooo`030000003oool0oooo0100oooo00<0003o0?ooo`3oool00P3oool20000o`80
oooo00D0003o0?ooo`3oool0oooo0000o`050?ooo`050000o`3oool0oooo0?ooo`000?l00P3oool2
0000o`80oooo00@0003o0?ooo`3oool0003o0`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3o
ool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool01@000?l0oooo0?ooo`3oool0003o00h0oooo
00<0003o0?ooo`3oool09@3oool20000obH0oooo0`00o`3o0?ooohh0oooo00<000000?ooo`3oool0
;03oool00540oooo00<000000?ooo`3oool03P3oool30000o`<0oooo00<0003o0?ooo`000?l00P00
0?l30?ooo`D0003o0`3oool30000o`80oooo00<0003o0?ooo`000?l00P000?l40?ooo`<0003o0`3o
ool30000o`@0oooo1@000?l01@3oool0003o0000o`000?l0oooo00<0003o2P3oool01@000?l0oooo
0?ooo`3oool0003o02L0oooo00<0003o0?ooo`3oool0903oool2003o0?l0ooooS`3oool00`000000
oooo0?ooo`0/0?ooo`00D@3oool00`000000oooo0?ooo`0M0?ooo`030000o`3oool0oooo0200oooo
00<0003o0?ooo`3oool04`3oool01@000?l0oooo0?ooo`3oool0003o04l0oooo00<00?l00?ooo`3o
ool0o`3ooon=0?ooo`030000003oool0oooo02`0oooo001A0?ooo`030000003oool0oooo01d0oooo
00<0003o0?ooo`3oool0803oool00`000?l0oooo0?ooo`0C0?ooo`050000o`3oool0oooo0?ooo`00
0?l0o`3ooooO0?ooo`030000003oool0oooo02X0oooo0P0000000540oooo00<000000?ooo`3oool0
403oool00`000?l0oooo0?ooo`0W0?ooo`030000o`3oool0oooo01X0oooo0`000?oo0?ooon00oooo
00<000000?ooo`3oool0:P3oool200000000D@3oool00`000000oooo0?ooo`3o0?ooool0oooo>`3o
ool00`000000oooo0?ooo`0Z0?ooo`800000001A0?ooo`030000003oool0oooo06L0oooo0`000?lT
0?ooo`@0003oo`3ooonX0?ooo`030000003oool0oooo02X0oooo0P0000000540oooo0`00001W0?oo
o`80003o2`3oool30000oaP0oooo0P000?oo0?ooojT0oooo00<000000?ooo`3oool0:P3oool20000
0000D@3oool00`000000oooo0?ooo`1X0?ooo`030000o`3oool0oooo00T0oooo0P000?lJ0?ooo`03
0000o`3oool0oooo01H0oooo0`000?oo0?ooohh0oooo00<000000?ooo`3oool0:P3oool200000000
D@3oool00`000000oooo0?ooo`1e0?ooo`030000o`3oool0oooo0380oooo00<0003o0?ooo`3oool0
o`3ooon=0?ooo`030000003oool0oooo02P0oooo1000000000h0oooo100000020?ooo`@00000>@3o
ool00`000000oooo0?ooo`3o0?ooool0oooo>`3oool00`000000oooo0?ooo`0X0?ooo`@00000000>
0?ooo`@000000P3oool4000003T0oooo00<000000?ooo`3oool0o`3ooooo0?oooc/0oooo00<00000
0?ooo`3oool0:P3oool2000000003P3oool2000000H0oooo0P00000i0?ooo`030000003oool0oooo
03l0oooo0`000?oo0?ooooP0oooo00<000000?ooo`3oool0:P3oool2000000003P3oool2000000H0
oooo0P00000i0?ooo`030000003oool0oooo03l0oooo0P000?oo0?ooooT0oooo00<000000?ooo`3o
ool0:P3oool2000000003P3oool200000080oooo0P0000020?ooo`800000>@3oool00`000000oooo
0?ooo`100?ooo`030000o`3oool0oooo0?l0oooom`3oool00`000000oooo0?ooo`0Z0?ooo`800000
000>0?ooo`8000000P3oool200000080oooo0P00000i0?ooo`030000003oool0oooo0?l0ooooo`3o
oolk0?ooo`030000003oool0oooo02P0oooo0P0000020?ooo`003P3oool200000080oooo0P000002
0?ooo`800000>@3oool00`000000oooo0?ooo`2f0?ooo`@00?l0d@3oool30000oj/0oooo00<00000
0?ooo`3oool0:03oool200000080oooo000>0?ooo`8000000P3oool200000080oooo0P00000i0?oo
o`<000005`3oool3003o09`0oooo0`00o`3C0?ooo`030000o`3oool0oooo0:X0oooo00<000000?oo
o`3oool0:P3oool2000000003P3oool400000080oooo1000000i0?ooo`030000003oool0oooo01L0
oooo00<0003o003o00000?l0W@3oool00`00o`00oooo0?ooo`3o0?oooh00oooo00<000000?ooo`3o
ool0:P3oool2000000003P3oool400000080oooo1000000i0?ooo`030000003oool0oooo01P0oooo
00<0003o0?ooo`3oool0o`3ooooo0?ooob00oooo00<000000?ooo`3oool0;03oool000h0oooo0P00
00060?ooo`800000>@3oool00`000000oooo0?ooo`3o0?ooool0oooo>`3oool00`000000oooo0?oo
o`0/0?ooo`003P3oool2000000H0oooo0P00000i0?ooo`030000003oool0oooo0?l0ooooo`3ooolk
0?ooo`030000003oool0oooo02X0oooo0P0000000180oooo1000000k0?ooo`030000003oool0oooo
0?l0ooooo`3ooolk0?ooo`030000003oool0oooo02X0oooo0P0000000180oooo100000060?ooo`@0
0000203oool2000000P0oooo200000040?ooo`H000003@3oool00`000000oooo0?ooo`3o0?ooool0
oooo>`3oool00`000000oooo0?ooo`0/0?ooo`00403oool2000000@0oooo0P0000040?ooo`@00000
203oool2000000P0oooo200000040?ooo`H000003@3oool00`000000oooo0?ooo`3o0?ooool0oooo
>`3oool00`000000oooo0?ooo`0/0?ooo`00403oool2000000@0oooo0P0000020?ooo`800000103o
ool200000100oooo0P00000@0?ooo`8000002`3oool00`000000oooo0?ooo`3o0?ooool0oooo>`3o
ool00`000000oooo0?ooo`0X0?ooo`@00000000@0?ooo`800000203oool2000000@0oooo0P00000@
0?ooo`800000403oool2000000/0oooo00<000000?ooo`3oool0o`3ooooo0?oooc/0oooo00<00000
0?ooo`3oool0:03oool400000000403oool2000000P0oooo0P0000040?ooo`8000004P3oool20000
00h0oooo0P00000;0?ooo`D00000o`3ooooo0?ooocT0oooo00<000000?ooo`3oool0;03oool00100
oooo0P0000080?ooo`800000103oool200000180oooo0P00000>0?ooo`8000002`3oool00`000000
oooo0?ooo`3o0?ooool0oooo>`3oool00`000000oooo0?ooo`0/0?ooo`00403oool2000000P0oooo
0P0000040?ooo`800000503oool2000000H0oooo1P00000=0?ooo`030000003oool0oooo0?l0oooo
o`3ooolk0?ooo`030000003oool0oooo02`0oooo000@0?ooo`800000103oool200000080oooo0P00
00040?ooo`800000503oool2000000H0oooo1P00000=0?ooo`030000003oool0oooo0?l0ooooo`3o
oolk0?ooo`030000003oool0oooo02`0oooo000@0?ooo`800000103oool200000080oooo0P000004
0?ooo`8000005P3oool2000000@0oooo0P00000A0?ooo`030000003oool0oooo0?l0ooooo`3ooolk
0?ooo`030000003oool0oooo02`0oooo000B0?ooo`@00000103oool2000000@0oooo0P00000F0?oo
o`800000103oool200000140oooo00<000000?ooo`3oool0a03oool3003o0?l0ooooL`3oool00`00
0000oooo0?ooo`0/0?ooo`004P3oool4000000@0oooo0P0000040?ooo`800000403oool2000000@0
oooo0P0000040?ooo`8000004@3oool00`000000oooo0?ooo`340?ooo`800?l0o`3ooomd0?ooo`03
0000003oool0oooo02`0oooo000@0?ooo`H00000103oool2000000@0oooo0P00000@0?ooo`800000
103oool2000000@0oooo0P00000A0?ooo`030000003oool0oooo0<D0oooo00<00?l00?ooo`3oool0
o`3ooomF0?ooo`<00?l06@3oool00`000000oooo0?ooo`0/0?ooo`00403oool6000000H0oooo1000
000D0?ooo`@000001P3oool8000000/0oooo00<000000?ooo`3oool0o`3ooooo0?oooal0oooo0P00
o`0J0?ooo`030000003oool0oooo02`0oooo000B0?ooo`800000203oool4000001@0oooo10000006
0?ooo`P000002`3oool300000?l0ooooo`3ooolP0?ooo`03003o003oool0oooo01P0oooo00<00000
0?ooo`3oool0;03oool00180oooo0P00000m0?ooo`030000003oool0oooo0?l0ooooo`3ooolO0?oo
o`<0003o6@3oool00`000000oooo0?ooo`0Z0?ooo`800000000B0?ooo`800000?@3oool00`000000
oooo0?ooo`3A0?ooo`<00?l0o`3ooom;0?ooo`030000o`3oool0oooo01P0oooo00<000000?ooo`3o
ool0:P3oool2000000004P3oool2000003d0oooo00<000000?ooo`3oool0dP3oool00`00o`00oooo
0?ooo`3o0?ooofD0oooo00<000000?ooo`3oool0;03oool00180oooo0P00000m0?ooo`030000003o
ool0oooo0?l0ooooo`3ooolk0?ooo`030000003oool0oooo02`0oooo000B0?ooo`800000?@3oool0
0`000000oooo0?ooo`3A0?ooo`<0003oo`3ooolE0?ooo`<0003oCP3oool00`000000oooo0?ooo`0/
0?ooo`003P3oool200000080oooo0P0000020?ooo`800000>@3oool00`000000oooo0?ooo`3A0?oo
o`80003oo`3oool90?ooo`<0003o2P3oool20000odl0oooo00<000000?ooo`3oool0;03oool000h0
oooo0P0000020?ooo`8000000P3oool2000003T0oooo00<000000?ooo`3oool0dP3oool00`000?l0
oooo0?ooo`3o0?ooo`L0oooo0P000?l<0?ooo`030000o`3oool0oooo04d0oooo00<000000?ooo`3o
ool0;03oool000h0oooo2P00000i0?ooo`030000003oool0oooo0;H0oooo10000?oo0?ooob<0oooo
00<0003o0?ooo`3oool0FP3oool00`000000oooo0?ooo`0/0?ooo`003P3oool:000003T0oooo00<0
00000?ooo`3oool0]P3oool30000ool0ooooP@3oool00`000000oooo0?ooo`0V0?ooo`H00000000A
0?ooo`030000003oool0oooo03d0oooo0`00002g0?ooo`030000o`3oool0oooo00X0oooo0`000?oo
0?ooog<0oooo00<000000?ooo`3oool09P3oool6000000004P3oool00`000000oooo0?ooo`0l0?oo
o`030000003oool0oooo0<@0oooo0P000?oo0?ooog@0oooo00<000000?ooo`3oool0:03oool20000
0080oooo000B0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0a@3oool00`000?l0
oooo0?ooo`3o0?ooog80oooo00<000000?ooo`3oool0:03oool200000080oooo000C0?ooo`030000
003oool0oooo03/0oooo00<000000?ooo`3oool0o`3ooooo0?oooc/0oooo00<000000?ooo`3oool0
:03oool4000000004`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0?l0oooocP3o
ool40000ofP0oooo00<000000?ooo`3oool0:03oool400000000503oool00`000000oooo0?ooo`0j
0?ooo`030000003oool0oooo0?l0ooooc`3oool20000od00oooo0`000?lV0?ooo`030000003oool0
oooo02P0oooo0P0000020?ooo`00503oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo
0?l0ooooV@3oool30000oaP0oooo0`000?lI0?ooo`030000o`3oool0oooo02<0oooo0`000?lI0?oo
o`030000o`3oool0oooo02D0oooo00<000000?ooo`3oool0:03oool200000080oooo000D0?ooo`03
0000003oool0oooo03X0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`030000o`3oool0oooo01P0
oooo00<0003o0?ooo`3oool0?`3oool00`000?l0oooo0?ooo`0:0?ooo`<0003o<`3oool00`000000
oooo0?ooo`0X0?ooo`8000000P3oool001D0oooo00<000000?ooo`3oool0>@3oool00`000000oooo
0?ooo`3o0?ooooH0oooo0`00o`0;0?ooo`80003o=03oool00`000000oooo0?ooo`0X0?ooo`800000
0P3oool001D0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`3o0?ooojH0oooo1000
0?m=0?ooo`03003o003oool0oooo00/0oooo00<0003o0?ooo`3oool0<P3oool00`000000oooo0?oo
o`0X0?ooo`8000000P3oool001H0oooo00<000000?ooo`3oool0>03oool300000?l0ooooY`3oool2
0000oi40oooo00<000000?ooo`3oool0:03oool200000080oooo000F0?ooo`030000003oool0oooo
03P0oooo00<000000?ooo`3oool0o`3ooooo0?oooc/0oooo00<000000?ooo`3oool09P3oool20000
0080oooo0P00000000h0oooo1P0000030?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3o
ool0o`3oooo10?ooo`<0003oMP3oool00`000000oooo0?ooo`0V0?ooo`8000000P3oool200000000
3P3oool6000003d0oooo00<000000?ooo`3oool0o`3oooo10?ooo`80003oM`3oool00`000000oooo
0?ooo`0/0?ooo`00403oool2000003l0oooo00<000000?ooo`3oool0o`3oooo20?ooo`030000o`3o
ool0oooo03l0oooo0`00o`0:0?ooo`<00?l09P3oool00`000000oooo0?ooo`0/0?ooo`00403oool2
000003l0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`D0oooo0P00o`0<0?ooo`03003o003oool0
oooo02D0oooo00<000000?ooo`3oool0:03oool400000000403oool6000003/0oooo00<000000?oo
o`3oool0o`3ooooo0?ooo`H0oooo00<00?l00?ooo`3oool0<P3oool00`000000oooo0?ooo`0X0?oo
o`@00000000@0?ooo`H00000>`3oool00`000000oooo0?ooo`3o0?ooool0oooo>`3oool00`000000
oooo0?ooo`0Z0?ooo`800000000@0?ooo`800000103oool2000003T0oooo00<000000?ooo`3oool0
o`3ooooo0?oooc/0oooo00<000000?ooo`3oool0:P3oool200000000403oool2000000@0oooo0P00
000i0?ooo`030000003oool0oooo0?l0ooooo`3ooolk0?ooo`030000003oool0oooo02X0oooo0P00
00000100oooo0P0000040?ooo`800000>@3oool300000?l0ooooo`3ooolk0?ooo`030000003oool0
oooo02X0oooo0P0000000100oooo0P0000040?ooo`800000>@3oool00`000000oooo0?ooo`3o0?oo
ool0oooo>`3oool00`000000oooo0?ooo`0Z0?ooo`800000000>0?ooo`P00000>`3oool00`000000
oooo0?ooo`3o0?ooool0oooo>`3oool00`000000oooo0?ooo`0Z0?ooo`800000000>0?ooo`P00000
>`3oool00`000000oooo0?ooo`3o0?ooool0oooo>`3oool00`000000oooo0?ooo`0X0?ooo`800000
0P3oool00100oooo1P00000k0?ooo`030000003oool0oooo0?l0ooooo`3ooolk0?ooo`030000003o
ool0oooo02P0oooo0P0000020?ooo`00403oool6000003/0oooo00<000000?ooo`3oool0o`3ooooo
0?oooc/0oooo00<000000?ooo`3oool0;03oool00100oooo0P0000040?ooo`800000403oool40000
00P0oooo0P0000080?ooo`H000003@3oool00`000000oooo0?ooo`3o0?ooool0oooo>`3oool00`00
0000oooo0?ooo`0:0?ooo`@000007P3oool00100oooo0P0000040?ooo`800000403oool4000000P0
oooo0P0000080?ooo`H000003@3oool00`000000oooo0?ooo`3o0?ooool0oooo>`3oool00`000000
oooo0?ooo`0:0?ooo`@00000703oool2000000005P3oool2000000h0oooo0P0000040?ooo`800000
5P3oool2000000/0oooo00<000000?ooo`3oool0o`3ooooo0?oooc/0oooo00<000000?ooo`3oool0
203oool2000000@0oooo0P00000J0?ooo`800000000F0?ooo`8000003P3oool2000000@0oooo0P00
000F0?ooo`8000002`3oool500000?l0ooooo`3ooolf0?ooo`@000002P3oool2000000@0oooo0P00
000H0?ooo`8000000P3oool00180oooo1000000@0?ooo`800000103oool2000001H0oooo0P00000;
0?ooo`030000003oool0oooo0?l0ooooo`3ooolk0?ooo`030000003oool0oooo00h0oooo0P00000H
0?ooo`8000000P3oool00180oooo1000000@0?ooo`800000103oool2000001H0oooo0P00000;0?oo
o`030000003oool0oooo0?l0ooooo`3ooolk0?ooo`030000003oool0oooo00h0oooo0P00000H0?oo
o`8000000P3oool00100oooo0P00000D0?ooo`800000103oool200000100oooo1P00000=0?ooo`03
0000003oool0oooo0?l0ooooo`3ooolk0?ooo`030000003oool0oooo00X0oooo1000000J0?ooo`80
00000P3oool00100oooo0P00000D0?ooo`800000103oool200000100oooo1P00000=0?ooo`030000
003oool0oooo0?l0ooooo`3ooolk0?ooo`030000003oool0oooo00X0oooo1000000J0?ooo`800000
0P3oool00180oooo1P00000>0?ooo`800000103oool200000100oooo0P00000A0?ooo`030000003o
ool0oooo0?l0ooooo`3ooolk0?ooo`030000003oool0oooo00h0oooo0P00000H0?ooo`8000000P3o
ool00180oooo1P00000>0?ooo`800000103oool200000100oooo0P00000A0?ooo`030000003oool0
oooo0?l0ooooo`3ooolk0?ooo`030000003oool0oooo00h0oooo0P00000J0?ooo`800000000B0?oo
o`@00000403oool2000000@0oooo0P00000@0?ooo`8000004@3oool00`000000oooo0?ooo`3o0?oo
ool0oooo>`3oool00`000000oooo0?ooo`080?ooo`800000103oool2000001X0oooo0P0000000180
oooo1000000@0?ooo`800000103oool200000100oooo0P00000A0?ooo`030000003oool0oooo0?l0
ooooo`3ooolk0?ooo`030000003oool0oooo00P0oooo0P0000040?ooo`800000703oool00100oooo
0P0000040?ooo`800000403oool400000180oooo2000000;0?ooo`030000003oool0oooo0?l0oooo
o`3ooolk0?ooo`030000003oool0oooo00X0oooo1000000N0?ooo`00403oool2000000@0oooo0P00
000@0?ooo`@000004P3oool8000000/0oooo0`00003o0?ooool0oooo>`3oool00`000000oooo0?oo
o`0:0?ooo`@000007P3oool00100oooo0P00000o0?ooo`030000003oool0oooo0?l0ooooo`3ooolk
0?ooo`030000003oool0oooo02`0oooo000@0?ooo`800000?`3oool00`000000oooo0?ooo`3o0?oo
ool0oooo>`3oool00`000000oooo0?ooo`0Z0?ooo`800000000@0?ooo`800000?`3oool00`000000
oooo0?ooo`3o0?ooool0oooo>`3oool00`000000oooo0?ooo`0Z0?ooo`800000000@0?ooo`800000
?`3oool00`000000oooo0?ooo`3o0?ooool0oooo>`3oool00`000000oooo0?ooo`0Z0?ooo`800000
000@0?ooo`800000103oool2000003T0oooo00<000000?ooo`3oool0o`3ooooo0?oooc/0oooo00<0
00000?ooo`3oool0:P3oool200000000403oool2000000@0oooo0P00000i0?ooo`030000003oool0
oooo0?l0ooooo`3ooolk0?ooo`030000003oool0oooo02X0oooo0P0000000180oooo1000000k0?oo
o`030000003oool0oooo0?l0ooooo`3ooolk0?ooo`030000003oool0oooo02X0oooo0P0000000180
oooo1000000k0?ooo`030000003oool0oooo04`0oooo0`000?oo0?ooon/0oooo00<000000?ooo`3o
ool0:03oool400000000403oool6000003/0oooo00<000000?ooo`3oool0C@3oool00`000?l0oooo
0?ooo`3o0?ooonX0oooo00<000000?ooo`3oool0:03oool400000000403oool6000003/0oooo0`00
003o0?ooool0oooo>`3oool00`000000oooo0?ooo`0Z0?ooo`800000000B0?ooo`800000?@3oool0
0`000000oooo0?ooo`3o0?ooool0oooo>`3oool00`000000oooo0?ooo`0Z0?ooo`800000000B0?oo
o`800000?@3oool00`000000oooo0?ooo`1I0?ooo`@0003oo`3ooooM0?ooo`030000003oool0oooo
02X0oooo0P0000000180oooo0P00000m0?ooo`030000003oool0oooo05T0oooo0`000?oo0?ooomh0
oooo00<000000?ooo`3oool0:P3oool2000000004P3oool2000003d0oooo00<000000?ooo`3oool0
FP3oool00`000?l0oooo0?ooo`3o0?ooomd0oooo00<000000?ooo`3oool0:03oool200000080oooo
000B0?ooo`800000?@3oool00`000000oooo0?ooo`3o0?ooool0oooo>`3oool00`000000oooo0?oo
o`0X0?ooo`8000000P3oool00180oooo0P00000m0?ooo`030000003oool0oooo05T0oooo1000o`3o
0?ooomd0oooo00<000000?ooo`3oool0:03oool200000080oooo000>0?ooo`8000000P3oool20000
0080oooo0P00000i0?ooo`030000003oool0oooo04`0oooo0`00o`0:0?ooo`<00?l0o`3ooooN0?oo
o`030000003oool0oooo02P0oooo0P0000020?ooo`003P3oool200000080oooo0P0000020?ooo`80
0000>@3oool00`000000oooo0?ooo`1=0?ooo`03003o003oool0oooo00X0oooo00<00?l00?ooo`3o
ool0o`3ooooM0?ooo`030000003oool0oooo02P0oooo0P0000020?ooo`003P3oool:000003T0oooo
0`00003o0?oooa@0oooo10000?l:0?ooo`<0003oo`3ooolF0?ooo`030000003oool0oooo02P0oooo
0P0000020?ooo`003P3oool:000003T0oooo00<000000?ooo`3oool0o`3ooolD0?ooo`<0003o2`3o
ool20000ool0oooo5`3oool00`000000oooo0?ooo`0Z0?ooo`800000001A0?ooo`030000003oool0
oooo0?l0oooo5@3oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo0?l0oooo5@3oool0
0`000000oooo0?ooo`0Z0?ooo`800000001A0?ooo`030000003oool0oooo0?l0oooo?03oool30000
oo/0oooo00<000000?ooo`3oool0;03oool00540oooo00<000000?ooo`3oool0o`3oool70?ooo`<0
003o9@3oool30000o`X0oooo0`00o`0H0?ooo`<0003o2P3oool30000om<0oooo00<000000?ooo`3o
ool0;03oool00540oooo00<000000?ooo`3oool0o`3oool80?ooo`030000o`3oool0oooo00T0oooo
1000o`0H0?ooo`030000o`3oool0oooo00T0oooo0P00o`0;0?ooo`@0003o2P3oool20000o`/0oooo
0P000?oD0?ooo`030000003oool0oooo02H0oooo1P0000000540oooo00<000000?ooo`3oool0o`3o
ool70?ooo`<00?l02P3oool3003o02H0oooo00<00?l00?ooo`3oool02P3oool20000o`/0oooo0`00
o`0:0?ooo`<00?l0d`3oool00`000000oooo0?ooo`0V0?ooo`H00000001A0?ooo`030000003oool0
oooo0?l0oooo1`3oool2003o00`0oooo00<00?l00?ooo`3oool02P3oool3003o00X0oooo0`00o`0I
0?ooo`030000o`3oool0oooo00X0oooo00<00?l00?ooo`3oool02P3oool00`00o`00oooo0?ooo`0G
0?ooo`<0003o^03oool00`000000oooo0?ooo`0X0?ooo`8000000P3oool00540oooo00<000000?oo
o`3oool0o`3oool80?ooo`03003o003oool0oooo01L0oooo0P00o`0;0?ooo`800?l0603oool4003o
02@0oooo10000?l;0?ooo`030000o`3oool0oooo0;L0oooo00<000000?ooo`3oool0:03oool20000
0080oooo001A0?ooo`030000003oool0oooo0?T0oooo0`00000V0?ooo`03003o003oool0oooo00X0
oooo00<00?l00?ooo`3oool05`3oool2003o02D0oooo0`000?l;0?ooo`<00?l0^03oool00`000000
oooo0?ooo`0X0?ooo`8000000P3oool001L0oooo00<000000?ooo`3oool0=`3oool300000?P0oooo
1000001>0?ooo`03003o003oool0oooo02@0oooo00<0003o0?ooo`3oool02P3oool2003o0;T0oooo
00<000000?ooo`3oool0:03oool200000080oooo000F0?ooo`030000003oool0oooo03P0oooo00<0
00000?ooo`3oool0n@3oool3000008<0oooo00<00?l00?ooo`3oool0]`3oool00`000000oooo0?oo
o`0X0?ooo`8000000P3oool001H0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`3j
0?ooo`030000003oool0oooo0?l0oooo?@3oool00`000000oooo0?ooo`0X0?ooo`8000000P3oool0
01D0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`3o0?ooool0oooo>`3oool00`00
0000oooo0?ooo`0V0?ooo`8000000P3oool2000000005@3oool00`000000oooo0?ooo`0i0?ooo`03
0000003oool0oooo0?l0ooooL@3oool3003o0<H0oooo00<000000?ooo`3oool09P3oool200000080
oooo0P00000001@0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`3o0?ooog80oooo
00<00?l00?ooo`3oool0a@3oool00`000000oooo0?ooo`0/0?ooo`00503oool00`000000oooo0?oo
o`050?ooo`@00000203oool2000000X0oooo0P0000080?ooo`H000003@3oool00`000000oooo0?oo
o`3o0?ooool0oooo>`3oool00`000000oooo0?ooo`0/0?ooo`00503oool00`000000oooo0?ooo`05
0?ooo`@00000203oool2000000X0oooo0P0000080?ooo`H000003@3oool00`000000oooo0?ooo`3o
0?ooool0oooo>`3oool00`000000oooo0?ooo`0/0?ooo`00503oool00`000000oooo0?ooo`030?oo
o`800000103oool200000180oooo0P00000>0?ooo`8000002`3oool00`000000oooo0?ooo`3o0?oo
ool0oooo>`3oool00`000000oooo0?ooo`0/0?ooo`00503oool00`000000oooo0?ooo`030?ooo`80
0000103oool200000180oooo0P00000>0?ooo`8000002`3oool00`000000oooo0?ooo`3o0?ooool0
oooo>`3oool00`000000oooo0?ooo`0/0?ooo`00503oool00`000000oooo0?ooo`030?ooo`800000
103oool2000001@0oooo0P00000<0?ooo`8000002`3oool500000?l0ooooo`3oooli0?ooo`030000
003oool0oooo02`0oooo000D0?ooo`030000003oool0oooo00<0oooo0P0000040?ooo`800000503o
ool2000000`0oooo0P00000;0?ooo`030000003oool0oooo0?l0ooooo`3ooolk0?ooo`030000003o
ool0oooo02`0oooo000E0?ooo`030000003oool0oooo0080oooo0P0000040?ooo`800000503oool2
000000H0oooo1P00000=0?ooo`030000003oool0oooo0?l0ooooo`3ooolk0?ooo`030000003oool0
oooo02`0oooo000E0?ooo`030000003oool0oooo0080oooo0P0000040?ooo`800000503oool20000
00H0oooo1P00000=0?ooo`030000003oool0oooo0?l0ooooo`3ooolk0?ooo`030000003oool0oooo
02`0oooo000F0?ooo`040000003oool0oooo0?ooo`800000103oool2000001H0oooo0P0000040?oo
o`8000004@3oool00`000000oooo0?ooo`3o0?ooool0oooo>`3oool00`000000oooo0?ooo`0/0?oo
o`005P3oool010000000oooo0?ooo`3oool2000000@0oooo0P00000F0?ooo`800000103oool20000
0140oooo00<000000?ooo`3oool0m`3oool600000?l0oooo?@3oool00`000000oooo0?ooo`0/0?oo
o`004P3oool4000000030?ooo`000000000000<00000103oool200000100oooo0P0000040?ooo`80
0000103oool200000140oooo00<000000?ooo`3oool0m`3oool600000?l0oooo?@3oool00`000000
oooo0?ooo`0/0?ooo`004P3oool400000080oooo100000040?ooo`800000403oool2000000@0oooo
0P0000040?ooo`8000004@3oool00`000000oooo0?ooo`3m0?ooo`800000o`3ooolk0?ooo`030000
003oool0oooo02`0oooo000@0?ooo`800000103oool2000000@0oooo1000000B0?ooo`P00000103o
ool8000000/0oooo00<000000?ooo`3oool0o@3oool200000?l0oooo>`3oool00`000000oooo0?oo
o`0/0?ooo`00403oool2000000@0oooo0P0000040?ooo`@000004P3oool8000000@0oooo2000000;
0?ooo`<00000gP3oool30000oaP0oooo0`000?l00`3oool000000000003o0?oooc/0oooo00<00000
0?ooo`3oool0:03oool4000000004P3oool6000003T0oooo00<000000?ooo`3oool0gP3oool20000
oaT0oooo0P000?l20?ooo`800000o`3ooolk0?ooo`030000003oool0oooo02P0oooo100000000180
oooo1P00000i0?ooo`030000003oool0oooo0=l0oooo00<0003o0?ooo`3oool02@3oool40000o`P0
oooo1P00003o0?ooocd0oooo00<000000?ooo`3oool0;03oool001H0oooo0P00000i0?ooo`030000
003oool0oooo0>`0oooo0P000?l90?ooo`H00000o`3ooolm0?ooo`030000003oool0oooo02`0oooo
000F0?ooo`800000>@3oool00`000000oooo0?ooo`3]0?ooo`030000o`3oool0oooo00L0oooo0P00
0002003o0?l0oooo?`3oool00`000000oooo0?ooo`0/0?ooo`004P3oool4000003/0oooo00<00000
0?ooo`3oool0m`3oool2000000030?ooo`00o`00oooo0?l0oooo?P3oool00`000000oooo0?ooo`0/
0?ooo`004P3oool4000003/0oooo00<000000?ooo`3oool0m`3oool200000?l0oooo@@3oool00`00
0000oooo0?ooo`0/0?ooo`00D@3oool00`000000oooo0?ooo`3N0?ooo`<00?l05P3oool2000003D0
oooo0`00003o0?ooo`T0oooo00<000000?ooo`3oool0;03oool00540oooo00<000000?ooo`3oool0
gP3oool2003o01L0oooo200000070?ooo`<00000903oool400000380oooo0`00000;0?ooo`<00000
a@3oool00`000000oooo0?ooo`0Z0?ooo`800000000D0?ooo`800000>`3oool00`000000oooo0?oo
o`3O0?ooo`03003o003oool0oooo00T0oooo1000o`080?ooo`P000001P3oool4000002D0oooo0`00
000a0?ooo`@000002P3oool400000<D0oooo00<000000?ooo`3oool0:P3oool200000000503oool2
000003/0oooo0`00003/0?ooo`800?l02@3oool2000000@0oooo0P0000070?ooo`<000009P3oool0
0`000000oooo0?ooo`0:0?ooo`<000002P3oool3000000X0oooo0`00000:0?ooo`<000002`3oool3
000000X0oooo0`00002h0?ooo`030000003oool0oooo02`0oooo000B0?ooo`8000000P3oool20000
03T0oooo00<000000?ooo`3oool0k@3oool00`00o`00oooo0?ooo`070?ooo`800000103oool20000
00P0oooo00<000000?ooo`3oool0<@3oool4000000T0oooo100000090?ooo`@000002`3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00P0oooo1000002h0?ooo`030000003oool0oooo
02`0oooo000B0?ooo`8000000P3oool2000003T0oooo00<000000?ooo`3oool0m`3oool2000000@0
oooo0P00000E0?ooo`<000002P3oool3000001P0oooo0`00000:0?ooo`<000002P3oool3000002D0
oooo0`00002h0?ooo`030000003oool0oooo02H0oooo1P0000000180oooo0P0000020?ooo`800000
>@3oool00`000000oooo0?ooo`3g0?ooo`800000103oool2000001@0oooo100000090?ooo`@00000
6@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo02H0oooo1P0000000180oooo0P00
00020?ooo`800000>@3oool00`000000oooo0?ooo`3g0?ooo`800000103oool2000001D0oooo0`00
000:0?ooo`<00000a03oool3000004h0oooo00<000000?ooo`3oool0:03oool200000080oooo000@
0?ooo`8000001P3oool2000003L0oooo00<000000?ooo`3oool0m`3oool2000000@0oooo0P00000F
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0`P3oool4000004h0oooo00<00000
0?ooo`3oool0:03oool200000080oooo000@0?ooo`8000001P3oool2000003L0oooo00<000000?oo
o`3oool0m`3oool2000000@0oooo0P00003Y0?ooo`<00000CP3oool00`000000oooo0?ooo`0X0?oo
o`8000000P3oool000h0oooo100000040?ooo`@00000=`3oool00`000000oooo0?ooo`3g0?ooo`80
0000103oool200000>X0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0X0?ooo`80
00000P3oool000h0oooo100000040?ooo`@00000=`3oool00`000000oooo0?ooo`3g0?ooo`800000
103oool200000?l0oooo>`3oool00`000000oooo0?ooo`0X0?ooo`8000000P3oool00540oooo00<0
00000?ooo`3oool0m`3oool2000000@0oooo0P00003o0?oooc/0oooo00<000000?ooo`3oool0:03o
ool200000080oooo001A0?ooo`<00000n@3oool400000?l0oooo?@3oool00`000000oooo0?ooo`0V
0?ooo`8000000P3oool2000000004P3oool6000003T0oooo00<000000?ooo`3oool0n@3oool40000
0?l0oooo?@3oool00`000000oooo0?ooo`0V0?ooo`8000000P3oool2000000004P3oool6000003T0
oooo00<000000?ooo`3oool0m`3oool2000000@0oooo0P00003o0?oooc/0oooo00<000000?ooo`3o
ool0;03oool00100oooo0P00000o0?ooo`030000003oool0oooo0?L0oooo0P0000040?ooo`800000
;`3oool400000?l0oooo203oool00`000000oooo0?ooo`0/0?ooo`00403oool2000003l0oooo00<0
00000?ooo`3oool0k03oool3000000P0oooo0P0000040?ooo`8000001`3oool4000002@0oooo1000
000c0?ooo`800000203oool600000<@0oooo00<000000?ooo`3oool0;03oool00100oooo1P00000k
0?ooo`030000003oool0oooo0>/0oooo100000080?ooo`800000103oool2000000L0oooo1000000R
0?ooo`800000103oool200000340oooo0P0000080?ooo`H00000a03oool00`000000oooo0?ooo`0/
0?ooo`00403oool6000003/0oooo00<000000?ooo`3oool0k03oool3000000P0oooo0P0000040?oo
o`8000001@3oool2000000@0oooo0P00000P0?ooo`800000103oool2000000H0oooo200000050?oo
o`P000001`3oool4000000/0oooo0P00000>0?ooo`8000001`3oool400000;L0oooo00<000000?oo
o`3oool0:P3oool200000000403oool2000000@0oooo0P00000i0?ooo`030000003oool0oooo0>d0
oooo00<000000?ooo`3oool01`3oool2000000@0oooo0P0000050?ooo`800000103oool200000200
oooo0P0000040?ooo`8000001P3oool8000000D0oooo200000070?ooo`@000002`3oool2000000h0
oooo0P0000070?ooo`@00000]`3oool00`000000oooo0?ooo`0Z0?ooo`800000000@0?ooo`800000
103oool2000003T0oooo00<000000?ooo`3oool0m`3oool2000000@0oooo0P0000050?ooo`800000
103oool2000000P0oooo1000000D0?ooo`800000103oool2000000X0oooo0P0000070?ooo`800000
2`3oool2000000@0oooo0P0000030?ooo`X00000303oool2000000D0oooo0P0000040?ooo`800000
LP3oool300000400oooo00<000000?ooo`3oool0:P3oool2000000004P3oool4000003/0oooo00<0
00000?ooo`3oool0m`3oool2000000@0oooo0P0000050?ooo`800000103oool2000000P0oooo1000
00070?ooo`H000001`3oool2000000@0oooo0P00000:0?ooo`8000001`3oool2000000/0oooo0P00
00040?ooo`8000000`3oool:000000`0oooo0P0000050?ooo`800000103oool200000740oooo1000
000:0?ooo`<00000<`3oool00`000000oooo0?ooo`0Z0?ooo`800000000B0?ooo`@00000>`3oool3
00000?L0oooo0P0000040?ooo`8000001@3oool6000000P0oooo0P0000040?ooo`8000001@3oool6
000000L0oooo0P0000040?ooo`8000002P3oool2000000T0oooo0P00000?0?ooo`8000000`3oool2
000000@0oooo0P0000080?ooo`H000001`3oool2000000@0oooo0P00001R0?ooo`H000002P3oool3
000000T0oooo1000000c0?ooo`030000003oool0oooo02X0oooo0P0000000540oooo00<000000?oo
o`3oool0m`3oool2000000@0oooo0P0000050?ooo`H00000203oool2000000@0oooo0P00000;0?oo
o`8000001@3oool2000000@0oooo0P00000:0?ooo`8000002@3oool2000000l0oooo0P0000030?oo
o`800000103oool2000000P0oooo1P0000070?ooo`800000103oool200000680oooo1P00000;0?oo
o`030000003oool0oooo00T0oooo0`00000U0?ooo`<000002`3oool00`000000oooo0?ooo`0Z0?oo
o`800000001A0?ooo`030000003oool0oooo0?L0oooo200000050?ooo`800000303oool2000000@0
oooo0P00000;0?ooo`8000001@3oool2000000@0oooo0P00000:0?ooo`8000002`3oool2000000T0
oooo100000070?ooo`8000000P3oool2000000P0oooo0P00000;0?ooo`H00000JP3oool2000001H0
oooo00<000000?ooo`3oool08`3oool4000000/0oooo00<000000?ooo`3oool0:03oool400000000
403oool8000003T0oooo00<000000?ooo`3oool0m`3oool8000000D0oooo0P00000<0?ooo`800000
103oool2000000/0oooo0P0000050?ooo`800000103oool2000000X0oooo0P00000;0?ooo`800000
2@3oool4000000L0oooo0P0000020?ooo`800000203oool2000000/0oooo1P00001Z0?ooo`800000
?@3oool3000000/0oooo00<000000?ooo`3oool0:03oool400000000403oool8000003T0oooo00<0
00000?ooo`3oool0m`3oool2000000/0oooo0P00000>0?ooo`@000003@3oool2000000D0oooo0P00
00040?ooo`8000002P3oool2000000d0oooo0P00000;0?ooo`8000001`3oool4000000P0oooo0P00
000;0?ooo`800000KP3oool2000003h0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0Z0?ooo`800000000B0?ooo`800000?@3oool00`000000oooo0?ooo`3g0?ooo`8000002`3oool2
000000h0oooo100000090?ooo`H000001@3oool8000000X0oooo0P00000=0?ooo`8000002`3oool2
000000L0oooo100000080?ooo`8000002`3oool2000006h0oooo0P00001;0?ooo`030000003oool0
oooo02X0oooo0P0000000180oooo0P00000Z0?ooo`P000002`3oool00`000000oooo0?ooo`3O0?oo
o`<000005`3oool2000000/0oooo1P0000060?ooo`800000103oool2000000L0oooo1P0000050?oo
o`P000001P3oool6000000L0oooo0P0000040?ooo`8000001@3oool2000000@0oooo0P0000050?oo
o`P000001P3oool8000000D0oooo0P00001X0?ooo`H00000C@3oool00`000000oooo0?ooo`0:0?oo
o`@00000703oool2000000004P3oool2000002X0oooo2000000;0?ooo`030000003oool0oooo0=h0
oooo1000000G0?ooo`8000002`3oool6000000H0oooo0P0000040?ooo`8000001@3oool2000000@0
oooo0P0000090?ooo`800000203oool6000000L0oooo0P0000040?ooo`8000001@3oool2000000@0
oooo0P0000050?ooo`P000001P3oool8000000D0oooo0P00001X0?ooo`H00000903oool3000002H0
oooo00<000000?ooo`3oool02P3oool4000001`0oooo0P0000000180oooo0P00000^0?ooo`800000
3@3oool00`000000oooo0?ooo`1J0?ooo`<00000PP3oool3000001T0oooo0P0000070?ooo`800000
103oool2000000H0oooo0P0000040?ooo`8000001@3oool2000000@0oooo0P0000090?ooo`800000
203oool8000000D0oooo200000050?ooo`P000002@3oool2000000`0oooo0P0000070?ooo`P00000
HP3oool2000002L0oooo1000000V0?ooo`030000003oool0oooo00P0oooo0P0000040?ooo`800000
603oool200000080oooo000B0?ooo`800000;P3oool2000000d0oooo1@00001:0?ooo`<000002P3o
ool4000004`0oooo0`00000d0?ooo`030000003oool0oooo01P0oooo0P0000070?ooo`800000103o
ool2000000H0oooo0P0000040?ooo`8000001@3oool2000000@0oooo0P0000090?ooo`800000203o
ool8000000D0oooo200000050?ooo`P000002@3oool2000000`0oooo0P0000070?ooo`P00000HP3o
ool2000002P0oooo0`00000S0?ooo`@000002P3oool2000000@0oooo0P00000H0?ooo`8000000P3o
ool00180oooo0P00000^0?ooo`8000003@3oool00`000000oooo0?ooo`0T0?ooo`<00000903oool4
000000/0oooo0`00000b0?ooo`<000002P3oool3000000T0oooo100000120?ooo`8000003@3oool2
000000D0oooo0P0000040?ooo`800000203oool4000000L0oooo0P0000040?ooo`8000002@3oool2
000000`0oooo0P00000;0?ooo`8000002`3oool2000000/0oooo0P00000<0?ooo`8000002`3oool2
000006@0oooo0P00000Y0?ooo`030000003oool0oooo00T0oooo0`00000I0?ooo`030000003oool0
oooo00P0oooo0P0000040?ooo`800000603oool400000000403oool200000080oooo1P00000X0?oo
o`8000003@3oool00`000000oooo0?ooo`0G0?ooo`<000002@3oool4000000/0oooo0`00000G0?oo
o`<00000303oool00`000000oooo0?ooo`0`0?ooo`@000002@3oool4000000X0oooo0`0000120?oo
o`8000003@3oool2000000D0oooo0P0000040?ooo`800000203oool4000000T0oooo1000000;0?oo
o`800000303oool2000000/0oooo0P00000;0?ooo`8000002`3oool2000000`0oooo0P00000;0?oo
o`800000I03oool2000003@0oooo1000000I0?ooo`030000003oool0oooo00P0oooo0P0000040?oo
o`800000603oool400000000403oool200000080oooo1P00000X0?ooo`8000003@3oool00`000000
oooo0?ooo`0F0?ooo`@000002P3oool3000000X0oooo1000000H0?ooo`030000003oool0oooo03l0
oooo0`00000:0?ooo`<000002`3oool00`000000oooo0?ooo`110?ooo`8000001`3oool2000000@0
oooo0P0000050?ooo`800000103oool2000000H0oooo0P0000040?ooo`8000001`3oool4000000/0
oooo0P00000<0?ooo`8000002`3oool2000000/0oooo0P00000;0?ooo`800000303oool2000000/0
oooo0P00001T0?ooo`P00000;`3oool3000001T0oooo00<000000?ooo`3oool0203oool6000001X0
oooo0P0000020?ooo`00@P3oool2000000d0oooo00<000000?ooo`3oool05`3oool3000000/0oooo
00<000000?ooo`3oool02P3oool3000004d0oooo0`00000;0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0CP3oool2000000L0oooo0P0000040?ooo`8000001@3oool2000000@0oooo
0P0000060?ooo`800000103oool2000000D0oooo0P0000040?ooo`8000002@3oool2000000`0oooo
0P00000;0?ooo`8000002`3oool2000000/0oooo0P00000<0?ooo`8000002`3oool2000006@0oooo
2000000`0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0203oool6000001X0oooo
0P0000020?ooo`00@P3oool2000000d0oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`090?ooo`<0003o303oool00`000000oooo0?ooo`1;0?ooo`@00000H`3oool:000000D0oooo2000
00050?ooo`800000103oool2000000H0oooo0P0000040?ooo`8000001@3oool2000000@0oooo0P00
00090?ooo`800000303oool2000000/0oooo0P00000;0?ooo`8000002`3oool2000000`0oooo0P00
000;0?ooo`800000I03oool2000000h0oooo1000000o0?ooo`030000003oool0oooo00P0oooo0P00
000P0?ooo`800000000B0?ooo`@000000P3oool2000002P0oooo0P00000=0?ooo`030000003oool0
oooo02@0oooo0P000?lI0?ooo`<00000@03oool3000006<0oooo2P0000050?ooo`P000001@3oool2
000000@0oooo0P0000060?ooo`800000103oool2000000D0oooo0P0000040?ooo`8000001@3oool6
000000`0oooo0P00000;0?ooo`8000002`3oool2000000/0oooo0P00000<0?ooo`8000002`3oool2
000006@0oooo0P00000>0?ooo`@000002@3oool2000003@0oooo00<000000?ooo`3oool0203oool2
00000200oooo0P0000000180oooo100000020?ooo`800000903oool6000000d0oooo00<000000?oo
o`3oool09@3oool00`000?l0oooo0?ooo`090?ooo`@0003o2@3oool400000440oooo00<000000?oo
o`3oool0B`3oool3000001@0oooo0P0000040?ooo`8000002`3oool2000000L0oooo0P0000040?oo
o`8000001P3oool2000000@0oooo0P0000050?ooo`800000103oool2000000D0oooo1P00000<0?oo
o`8000002`3oool2000000/0oooo0P0000070?ooo`H00000203oool6000000/0oooo0P00000a0?oo
o`<00000<P3oool2000000X0oooo0P0000040?ooo`8000001`3oool2000003@0oooo00<000000?oo
o`3oool0203oool200000280oooo000@0?ooo`800000103oool2000002H0oooo1P00000=0?ooo`03
0000003oool0oooo02@0oooo0`00o`0;0?ooo`80003o2`3oool3000007D0oooo0`00000F0?ooo`@0
0000503oool2000000@0oooo0P00000;0?ooo`8000001`3oool2000000@0oooo0P0000060?ooo`80
0000103oool2000000D0oooo0P0000040?ooo`8000001`3oool4000000`0oooo0P00000;0?ooo`80
00002`3oool2000000L0oooo1P0000080?ooo`H000002`3oool200000300oooo1000000b0?ooo`80
00002P3oool2000000@0oooo0P0000070?ooo`800000=03oool00`000000oooo0?ooo`080?ooo`80
00008P3oool00100oooo0P0000040?ooo`800000:P3oool2000000d0oooo00<000000?ooo`3oool0
903oool2003o00d0oooo00<0003o0?ooo`3oool02P3oool00`000000oooo0?ooo`0T0?ooo`<00000
2P3oool3000003l0oooo1000000G0?ooo`<000005P3oool200000080oooo0P00000;0?ooo`800000
2@3oool4000000P0oooo0P0000040?ooo`8000001@3oool2000000@0oooo0P0000070?ooo`@00000
203oool6000000L0oooo1P0000070?ooo`H000002@3oool4000000X0oooo100000070?ooo`H00000
<@3oool3000003@0oooo0P0000080?ooo`800000103oool2000000L0oooo0P00000T0?ooo`P00000
203oool00`000000oooo0?ooo`0:0?ooo`H000005P3oool6000000004P3oool6000002X0oooo0P00
000=0?ooo`<000009@3oool00`00o`00oooo0?ooo`090?ooo`@00?l0<@3oool4000000T0oooo1000
00100?ooo`<00000603oool00`000000oooo0?ooo`0E0?ooo`8000000P3oool2000000/0oooo0P00
00090?ooo`@00000203oool2000000@0oooo0P0000050?ooo`800000103oool2000000D0oooo0P00
00040?ooo`8000001P3oool6000000L0oooo1P0000070?ooo`H000002@3oool4000000X0oooo1000
00070?ooo`H00000<P3oool00`000000oooo0?ooo`0c0?ooo`800000203oool2000000@0oooo0P00
00090?ooo`8000008P3oool8000000P0oooo00<000000?ooo`3oool02P3oool6000001H0oooo1P00
00000180oooo1P00000i0?ooo`030000003oool0oooo0380oooo0P00o`0c0?ooo`<000002P3oool3
00000440oooo00<000000?ooo`3oool0<@3oool4000000/0oooo0P0000070?ooo`800000103oool2
000000H0oooo0P0000040?ooo`8000001@3oool2000000@0oooo0P0000050?ooo`800000103oool2
000000P0oooo100000090?ooo`@000002@3oool4000000L0oooo0P0000040?ooo`8000001P3oool2
000000@0oooo0P0000070?ooo`@00000JP3oool2000000H0oooo1P00000;0?ooo`8000008P3oool2
000000h0oooo00<000000?ooo`3oool0:03oool200000080oooo000F0?ooo`800000>@3oool00`00
0000oooo0?ooo`1X0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0M03oool40000
00/0oooo0P0000070?ooo`800000103oool2000000H0oooo0P0000040?ooo`8000001@3oool20000
00@0oooo0P0000050?ooo`800000103oool2000000P0oooo100000090?ooo`@000002@3oool40000
00L0oooo0P0000040?ooo`8000001P3oool2000000@0oooo0P0000070?ooo`@00000JP3oool20000
00H0oooo1P00000;0?ooo`8000008P3oool2000000h0oooo00<000000?ooo`3oool0:03oool20000
0080oooo000F0?ooo`800000>@3oool00`000000oooo0?ooo`3L0?ooo`P00000203oool4000000/0
oooo0P0000070?ooo`800000103oool2000000P0oooo100000070?ooo`800000103oool2000000D0
oooo0P0000040?ooo`8000001P3oool2000000@0oooo0P0000050?ooo`800000103oool2000000D0
oooo0P0000040?ooo`8000001@3oool2000000@0oooo0P0000060?ooo`800000103oool2000000D0
oooo0P0000040?ooo`800000HP3oool2000000@0oooo0P0000060?ooo`8000003`3oool2000002@0
oooo0P00000<0?ooo`030000003oool0oooo02P0oooo0P0000020?ooo`00403oool6000003/0oooo
00<000000?ooo`3oool0g03oool8000000P0oooo1000000;0?ooo`8000001`3oool2000000@0oooo
0P0000080?ooo`@000002@3oool4000000L0oooo0P0000040?ooo`8000001P3oool2000000@0oooo
0P0000050?ooo`800000103oool2000000D0oooo0P0000040?ooo`8000001@3oool2000000@0oooo
0P0000060?ooo`800000103oool2000000D0oooo0P0000040?ooo`800000HP3oool2000000@0oooo
0P0000060?ooo`8000004@3oool200000280oooo0P00000<0?ooo`030000003oool0oooo02P0oooo
0P0000020?ooo`00403oool6000003/0oooo00<000000?ooo`3oool0F03oool800000800oooo0P00
00080?ooo`800000103oool2000000D0oooo1P0000070?ooo`800000103oool2000000H0oooo0P00
00040?ooo`8000001`3oool4000000L0oooo0P0000040?ooo`8000001P3oool2000000@0oooo0P00
00050?ooo`800000103oool2000000D0oooo0P0000040?ooo`8000001@3oool2000000@0oooo0P00
00060?ooo`800000103oool2000000D0oooo0P0000040?ooo`800000I03oool4000000P0oooo0P00
000A0?ooo`8000001`3oool4000001T0oooo0P00000:0?ooo`030000003oool0oooo02P0oooo0P00
00020?ooo`005P3oool2000003T0oooo00<000000?ooo`3oool0C03oool4000000P0oooo20000019
0?ooo`@000005`3oool3000001T0oooo0P0000080?ooo`800000103oool2000000D0oooo1P000007
0?ooo`800000103oool2000000H0oooo0P0000040?ooo`8000001@3oool2000000@0oooo0P000005
0?ooo`800000103oool2000000H0oooo0P0000040?ooo`8000001@3oool2000000@0oooo0P000005
0?ooo`800000103oool2000000D0oooo0P0000040?ooo`8000001P3oool2000000@0oooo0P000005
0?ooo`800000103oool2000006@0oooo100000080?ooo`8000002`3oool2000000@0oooo0P000007
0?ooo`@000006@3oool2000000X0oooo00<000000?ooo`3oool0:03oool200000080oooo000F0?oo
o`800000>@3oool00`000000oooo0?ooo`0R0?ooo`P000008P3oool4000000`0oooo0P00000n0?oo
o`8000002`3oool4000001H0oooo1000000I0?ooo`800000203oool2000000@0oooo0P0000090?oo
o`8000001`3oool2000000@0oooo0P0000060?ooo`800000103oool2000000D0oooo0P0000040?oo
o`8000001@3oool2000000@0oooo0P0000060?ooo`800000103oool2000000D0oooo0P0000040?oo
o`8000001@3oool2000000@0oooo0P0000050?ooo`800000103oool2000000H0oooo0P0000040?oo
o`8000001@3oool2000000@0oooo0P00001R0?ooo`800000103oool2000000H0oooo200000050?oo
o`800000103oool2000000D0oooo0P0000040?ooo`8000001`3oool4000000h0oooo0P0000080?oo
o`030000003oool0oooo02H0oooo0P0000020?ooo`800000000B0?ooo`H00000>@3oool00`000000
oooo0?ooo`0E0?ooo`P000001@3oool800000200oooo0P0000040?ooo`8000002P3oool200000340
oooo100000090?ooo`8000002@3oool2000000@0oooo0P00000E0?ooo`<000006@3oool2000000P0
oooo0P0000040?ooo`8000002@3oool2000000L0oooo0P0000040?ooo`8000001P3oool2000000@0
oooo0P0000050?ooo`800000103oool2000000D0oooo0P0000040?ooo`8000001P3oool2000000@0
oooo0P0000050?ooo`800000103oool2000000D0oooo0P0000040?ooo`8000001@3oool2000000@0
oooo0P0000060?ooo`800000103oool2000000D0oooo0P0000040?ooo`800000HP3oool2000000@0
oooo0P0000060?ooo`P000001@3oool8000000D0oooo0P0000040?ooo`8000001`3oool4000000h0
oooo0P0000080?ooo`030000003oool0oooo02H0oooo0P0000020?ooo`800000000B0?ooo`H00000
>@3oool00`000000oooo0?ooo`0E0?ooo`P000001@3oool2000000h0oooo1000000D0?ooo`800000
103oool2000000X0oooo0P00000a0?ooo`@000002@3oool2000000T0oooo0P0000040?ooo`800000
5P3oool00`000000oooo0?ooo`0H0?ooo`800000203oool2000000@0oooo0P00000B0?ooo`800000
103oool2000000H0oooo0P0000040?ooo`8000001@3oool2000000@0oooo0P0000050?ooo`800000
103oool2000000H0oooo0P0000040?ooo`8000001@3oool2000000@0oooo0P0000050?ooo`800000
103oool2000000D0oooo0P0000040?ooo`8000001P3oool2000000@0oooo0P0000050?ooo`800000
103oool200000680oooo0P0000040?ooo`8000001P3oool2000000/0oooo200000050?ooo`800000
103oool2000000D0oooo0P0000040?ooo`8000001P3oool2000000@0oooo0P0000080?ooo`030000
003oool0oooo02`0oooo000@0?ooo`800000103oool2000003T0oooo0`00000I0?ooo`8000001`3o
ool2000000h0oooo1000000D0?ooo`800000103oool2000000X0oooo0P00000Q0?ooo`H00000203o
ool2000000@0oooo0P0000070?ooo`8000002@3oool2000000@0oooo0P00000a0?ooo`800000203o
ool2000000@0oooo0P00000B0?ooo`800000103oool2000000H0oooo0P0000040?ooo`8000001@3o
ool2000000@0oooo0P0000050?ooo`P000001P3oool2000000@0oooo0P0000050?ooo`800000103o
ool2000000D0oooo0P0000040?ooo`8000001@3oool2000000@0oooo0P0000060?ooo`800000103o
ool2000000D0oooo0P0000040?ooo`800000HP3oool2000000@0oooo0P0000060?ooo`8000002`3o
ool2000000/0oooo0P0000040?ooo`8000001@3oool2000000@0oooo0P0000060?ooo`800000103o
ool2000000P0oooo00<000000?ooo`3oool0;03oool00100oooo0P0000040?ooo`800000>@3oool0
0`000000oooo0?ooo`0I0?ooo`8000002@3oool2000000X0oooo0P0000040?ooo`8000004P3oool2
000000@0oooo0P00000:0?ooo`8000008@3oool6000000P0oooo0P0000040?ooo`8000002@3oool2
000000L0oooo0P0000040?ooo`800000<@3oool2000000P0oooo0P0000040?ooo`8000004P3oool8
000000H0oooo0P0000040?ooo`8000001@3oool2000000@0oooo0P0000050?ooo`P000001P3oool2
000000@0oooo0P0000050?ooo`800000103oool2000000D0oooo0P0000040?ooo`8000001@3oool8
000000H0oooo200000050?ooo`800000103oool200000680oooo0P0000040?ooo`800000203oool2
000000T0oooo0P00000=0?ooo`@000001`3oool2000000@0oooo0P0000080?ooo`@000002P3oool0
0`000000oooo0?ooo`0X0?ooo`@00000000@0?ooo`800000103oool2000003T0oooo00<000000?oo
o`3oool06@3oool2000000T0oooo0P00000:0?ooo`800000103oool200000180oooo0P0000040?oo
o`8000002P3oool2000002L0oooo0P0000060?ooo`800000103oool2000000T0oooo0P0000090?oo
o`@00000<`3oool2000000P0oooo0P0000040?ooo`8000004P3oool8000000H0oooo0P0000040?oo
o`8000001@3oool2000000@0oooo0P0000050?ooo`800000303oool2000000@0oooo0P0000050?oo
o`800000103oool2000000D0oooo0P0000040?ooo`8000001@3oool8000000H0oooo200000050?oo
o`800000103oool200000680oooo0P0000040?ooo`800000203oool2000000/0oooo0P00000;0?oo
o`@000001`3oool2000000@0oooo0P0000080?ooo`@000002P3oool00`000000oooo0?ooo`0X0?oo
o`@00000000@0?ooo`800000103oool2000003T0oooo00<000000?ooo`3oool06@3oool2000000/0
oooo0P00000>0?ooo`8000001`3oool2000000T0oooo0P0000040?ooo`8000002P3oool2000002L0
oooo0P0000060?ooo`800000103oool2000000T0oooo0P0000090?ooo`@00000;`3oool6000000P0
oooo0P0000040?ooo`8000004P3oool2000000`0oooo0P0000040?ooo`8000001@3oool2000000@0
oooo0P0000050?ooo`800000303oool8000000D0oooo200000050?ooo`P000001@3oool2000000`0
oooo0P00000;0?ooo`P00000;@3oool8000002d0oooo0P0000040?ooo`8000002P3oool2000000T0
oooo0P0000090?ooo`800000103oool2000000D0oooo0P0000040?ooo`8000001P3oool2000000@0
oooo0P0000080?ooo`030000003oool0oooo02`0oooo000@0?ooo`800000103oool2000003T0oooo
00<000000?ooo`3oool06@3oool2000000/0oooo0P00000>0?ooo`8000001`3oool2000000T0oooo
0P0000040?ooo`8000002P3oool2000002L0oooo0P0000060?ooo`H000002`3oool2000000L0oooo
0P0000040?ooo`8000001P3oool6000001@0oooo200000050?ooo`H00000203oool2000000@0oooo
0P00000B0?ooo`800000303oool2000000@0oooo0P0000050?ooo`800000103oool2000000L0oooo
0P00000:0?ooo`P000001@3oool8000000D0oooo200000050?ooo`800000303oool2000000/0oooo
200000070?ooo`<000008`3oool8000002d0oooo0P0000040?ooo`8000002P3oool2000000/0oooo
0P0000070?ooo`800000103oool2000000D0oooo0P0000040?ooo`8000001P3oool2000000@0oooo
0P0000080?ooo`030000003oool0oooo02`0oooo000@0?ooo`800000103oool2000003T0oooo00<0
00000?ooo`3oool06@3oool2000000d0oooo0P0000080?ooo`@000002@3oool2000000T0oooo0P00
00040?ooo`8000001P3oool6000000T0oooo1000000J0?ooo`8000001P3oool6000000d0oooo0P00
00050?ooo`800000103oool2000000H0oooo1P00000D0?ooo`P000001`3oool4000000X0oooo1000
000F0?ooo`8000002P3oool8000000D0oooo0P0000040?ooo`8000001`3oool2000000X0oooo0P00
000;0?ooo`8000002`3oool2000000d0oooo0P00000<0?ooo`8000002@3oool2000000`0oooo1000
000W0?ooo`800000;`3oool2000000@0oooo0P00000<0?ooo`8000002@3oool2000000L0oooo0P00
00040?ooo`8000001@3oool2000000@0oooo0P00000<0?ooo`800000203oool00`000000oooo0?oo
o`0Z0?ooo`800000000B0?ooo`@000000P3oool2000003L0oooo00<000000?ooo`3oool06@3oool2
000000d0oooo0P0000080?ooo`@000002@3oool2000000T0oooo0P0000040?ooo`8000001P3oool6
000000T0oooo1000000;0?ooo`8000001`3oool6000000P0oooo0P00000A0?ooo`8000001@3oool2
000000@0oooo0P00000<0?ooo`8000005P3oool2000000T0oooo1000000:0?ooo`@000005P3oool2
000000X0oooo200000050?ooo`P000002@3oool2000000P0oooo0P00000;0?ooo`8000002`3oool2
000000d0oooo0P00000<0?ooo`8000002@3oool2000000d0oooo0`00000W0?ooo`800000;`3oool2
000000@0oooo0P00000<0?ooo`8000002`3oool2000000D0oooo0P0000040?ooo`8000001@3oool2
000000@0oooo0P00000<0?ooo`800000203oool00`000000oooo0?ooo`0Z0?ooo`800000000B0?oo
o`@000000P3oool2000003L0oooo00<000000?ooo`3oool06@3oool2000000L0oooo0P0000040?oo
o`800000303oool2000000T0oooo0P0000070?ooo`800000103oool2000000H0oooo200000050?oo
o`800000103oool2000000T0oooo0P0000070?ooo`H00000203oool2000000/0oooo0P0000040?oo
o`8000001@3oool2000000@0oooo0P00000<0?ooo`8000005P3oool2000000L0oooo0P0000040?oo
o`8000001P3oool2000000@0oooo0P00000F0?ooo`800000203oool2000000/0oooo200000090?oo
o`8000002P3oool2000000/0oooo0P00000;0?ooo`8000003@3oool2000000`0oooo0P0000090?oo
o`800000303oool00`000000oooo0?ooo`0V0?ooo`800000;`3oool8000000H0oooo0P0000040?oo
o`8000002`3oool2000000D0oooo200000050?ooo`800000103oool2000000P0oooo1000000:0?oo
o`030000003oool0oooo02P0oooo0P0000020?ooo`00D@3oool00`000000oooo0?ooo`0E0?ooo`H0
00001`3oool2000000@0oooo0P00000<0?ooo`8000002@3oool2000000L0oooo200000060?ooo`P0
00001@3oool2000000@0oooo0P0000090?ooo`8000001`3oool2000000`0oooo0P00000;0?ooo`80
0000103oool2000000D0oooo2000000<0?ooo`8000005P3oool2000000L0oooo0P0000040?ooo`80
00001P3oool2000000@0oooo0P00000F0?ooo`800000203oool2000000/0oooo0P00000A0?ooo`80
0000203oool2000000/0oooo0P00000;0?ooo`8000003@3oool2000000`0oooo0P0000090?ooo`80
0000=@3oool2000002l0oooo200000060?ooo`800000103oool2000000D0oooo0P0000040?ooo`80
00001@3oool8000000D0oooo0P0000040?ooo`800000203oool4000000X0oooo00<000000?ooo`3o
ool0:03oool200000080oooo001A0?ooo`<000005@3oool6000000T0oooo100000080?ooo`800000
103oool2000000T0oooo0P0000070?ooo`P000001P3oool200000140oooo0P0000090?ooo`800000
1`3oool2000000`0oooo0P00000;0?ooo`P000001@3oool8000000`0oooo0P00000F0?ooo`800000
1`3oool2000000@0oooo0P0000060?ooo`800000103oool2000001P0oooo0P0000080?ooo`800000
2@3oool200000140oooo0P00000:0?ooo`8000002`3oool2000000/0oooo0P00000=0?ooo`800000
303oool2000000T0oooo0P00000c0?ooo`800000;`3oool2000000h0oooo100000070?ooo`800000
103oool2000000D0oooo0P00000=0?ooo`@000003P3oool2000000P0oooo00<000000?ooo`3oool0
:P3oool2000000004P3oool6000003T0oooo00<000000?ooo`3oool05`3oool4000000T0oooo1000
00080?ooo`800000103oool2000000T0oooo0P0000070?ooo`800000303oool200000140oooo0P00
00030?ooo`X000001@3oool2000000`0oooo200000050?ooo`P000001@3oool2000000h0oooo1P00
000F0?ooo`8000001`3oool2000000@0oooo0P0000060?ooo`800000103oool2000001P0oooo0P00
00080?ooo`8000002`3oool2000000T0oooo0P0000040?ooo`8000002P3oool2000000/0oooo0P00
000;0?ooo`8000003@3oool2000000`0oooo0P0000090?ooo`800000<`3oool2000002l0oooo0P00
000>0?ooo`@000002@3oool4000000L0oooo0P00000=0?ooo`@000003P3oool2000000P0oooo00<0
00000?ooo`3oool0:P3oool2000000004P3oool6000003T0oooo00<000000?ooo`3oool05`3oool4
000000L0oooo0P0000040?ooo`800000203oool4000000d0oooo0P0000050?ooo`8000003P3oool2
000000/0oooo100000050?ooo`X000001@3oool2000000`0oooo200000050?ooo`8000002`3oool2
000000h0oooo1P00000F0?ooo`8000001`3oool2000000@0oooo0P0000060?ooo`800000103oool2
00000180oooo0P0000040?ooo`8000002P3oool2000000T0oooo0P0000090?ooo`800000103oool2
000000`0oooo0P00000;0?ooo`8000002`3oool2000000D0oooo0P0000040?ooo`8000001P3oool2
000000@0oooo0P00000;0?ooo`800000<@3oool200000340oooo0P00000:0?ooo`800000103oool2
000000L0oooo100000090?ooo`8000002@3oool2000000@0oooo0P0000060?ooo`800000103oool2
000000P0oooo00<000000?ooo`3oool0;03oool00100oooo0P00000o0?ooo`030000003oool0oooo
01D0oooo0P0000040?ooo`8000001@3oool2000000@0oooo0P0000080?ooo`@000003@3oool20000
00L0oooo0P00000<0?ooo`8000002`3oool4000000D0oooo0P0000040?ooo`8000001`3oool80000
00H0oooo0P00000;0?ooo`8000003@3oool2000000X0oooo0P0000040?ooo`8000001`3oool40000
00/0oooo0P0000070?ooo`800000103oool2000000H0oooo0P0000040?ooo`8000004P3oool20000
00@0oooo0P00000:0?ooo`8000002`3oool2000000L0oooo2000000<0?ooo`8000002`3oool20000
00/0oooo0P0000050?ooo`800000103oool2000000H0oooo0P0000040?ooo`8000002`3oool20000
0340oooo0P00000a0?ooo`8000002P3oool2000000@0oooo0P0000050?ooo`800000103oool20000
00L0oooo0P0000090?ooo`800000103oool2000000H0oooo0P0000040?ooo`800000203oool00`00
0000oooo0?ooo`0/0?ooo`00403oool2000003l0oooo00<000000?ooo`3oool05@3oool2000000@0
oooo0P0000050?ooo`800000103oool2000000H0oooo0P0000040?ooo`8000001@3oool2000000@0
oooo0P0000070?ooo`8000003P3oool2000000d0oooo0P0000030?ooo`800000103oool2000000L0
oooo200000060?ooo`8000003@3oool2000000/0oooo0P00000:0?ooo`800000103oool2000000L0
oooo1000000;0?ooo`8000001`3oool2000000@0oooo0P0000060?ooo`800000103oool200000180
oooo2000000<0?ooo`8000002@3oool2000000L0oooo200000060?ooo`800000103oool2000000D0
oooo0P0000040?ooo`8000001@3oool2000000@0oooo0P0000050?ooo`P000001P3oool8000000D0
oooo0P0000040?ooo`800000;@3oool6000002@0oooo0`00000<0?ooo`800000203oool2000000@0
oooo0P0000050?ooo`800000103oool2000000T0oooo0P00000=0?ooo`800000203oool4000000X0
oooo00<000000?ooo`3oool0:03oool400000000403oool6000003/0oooo00<000000?ooo`3oool0
5@3oool2000000@0oooo0P0000050?ooo`800000103oool2000000H0oooo0P0000040?ooo`800000
1@3oool2000000@0oooo0P0000090?ooo`800000303oool2000000d0oooo0P0000050?ooo`800000
0P3oool2000000L0oooo0P00000>0?ooo`8000002`3oool2000000d0oooo0P0000080?ooo`800000
103oool2000000D0oooo0P0000040?ooo`8000001@3oool6000000L0oooo0P0000040?ooo`800000
1P3oool2000000@0oooo0P00000B0?ooo`P00000303oool2000000/0oooo0P0000090?ooo`800000
203oool2000000@0oooo0P0000050?ooo`800000103oool2000000D0oooo0P0000040?ooo`800000
1@3oool8000000H0oooo200000050?ooo`800000103oool2000002d0oooo1P00000S0?ooo`@00000
303oool2000000P0oooo0P0000040?ooo`8000001@3oool2000000@0oooo0P0000090?ooo`800000
3@3oool2000000P0oooo1000000:0?ooo`030000003oool0oooo02P0oooo100000000100oooo1P00
000k0?ooo`030000003oool0oooo01D0oooo0P0000040?ooo`8000001@3oool2000000@0oooo0P00
00060?ooo`800000103oool2000000D0oooo200000090?ooo`8000003P3oool2000000D0oooo0P00
00040?ooo`8000001@3oool200000080oooo0P0000070?ooo`8000003P3oool2000000d0oooo0P00
000;0?ooo`800000203oool2000000@0oooo0P0000050?ooo`800000103oool2000000D0oooo1P00
00070?ooo`800000103oool2000000H0oooo0P0000040?ooo`8000005P3oool2000000P0oooo0P00
00040?ooo`8000002`3oool2000000T0oooo0P0000080?ooo`P000001@3oool8000000D0oooo2000
00090?ooo`800000303oool2000000L0oooo2000000]0?ooo`P000008P3oool3000000h0oooo0P00
00060?ooo`800000103oool2000000D0oooo0P0000040?ooo`8000002`3oool2000000L0oooo1000
00080?ooo`800000103oool2000000P0oooo00<000000?ooo`3oool0;03oool00100oooo0P000004
0?ooo`800000>@3oool00`000000oooo0?ooo`0E0?ooo`800000103oool2000000D0oooo0P000004
0?ooo`8000001P3oool2000000@0oooo0P0000050?ooo`P000002`3oool2000000`0oooo0P000005
0?ooo`800000103oool2000000L0oooo100000090?ooo`8000003P3oool2000000/0oooo0P00000=
0?ooo`8000001P3oool8000000D0oooo0P0000040?ooo`8000001`3oool4000000L0oooo0P000004
0?ooo`8000001P3oool2000000@0oooo0P00000F0?ooo`800000203oool2000000@0oooo0P000005
0?ooo`800000103oool2000000T0oooo0P0000080?ooo`P000001@3oool8000000D0oooo20000009
0?ooo`800000303oool2000000L0oooo2000000]0?ooo`P000008`3oool00`000000oooo0?ooo`0=
0?ooo`8000001P3oool2000000@0oooo0P0000050?ooo`800000103oool2000000/0oooo0P000007
0?ooo`@00000203oool2000000@0oooo0P0000080?ooo`030000003oool0oooo02`0oooo000@0?oo
o`800000103oool2000003T0oooo00<000000?ooo`3oool05@3oool2000000@0oooo0P0000050?oo
o`800000103oool2000000H0oooo0P0000040?ooo`8000002@3oool2000000d0oooo0P0000060?oo
o`800000103oool2000000D0oooo200000070?ooo`@000002@3oool2000000h0oooo0P00000=0?oo
o`8000002`3oool2000000H0oooo200000050?ooo`800000103oool2000000L0oooo100000090?oo
o`@00000203oool8000001H0oooo0P0000080?ooo`P000001@3oool2000000@0oooo0P0000090?oo
o`800000303oool2000000/0oooo0P00000;0?ooo`8000002`3oool2000000`0oooo0P00000;0?oo
o`800000;`3oool2000003<0oooo0P0000040?ooo`8000001P3oool2000000@0oooo0P0000050?oo
o`800000103oool2000000D0oooo0P0000040?ooo`8000002`3oool2000000H0oooo0P0000040?oo
o`800000203oool00`000000oooo0?ooo`0/0?ooo`004P3oool4000003/0oooo00<000000?ooo`3o
ool05@3oool2000000@0oooo0P0000050?ooo`800000103oool2000000H0oooo0P0000040?ooo`80
00002@3oool2000000L0oooo0P0000040?ooo`8000001P3oool2000000@0oooo0P0000050?ooo`P0
00001@3oool8000000T0oooo0P00000>0?ooo`8000002`3oool2000000D0oooo0P0000040?ooo`80
00001P3oool2000000/0oooo0P0000040?ooo`8000001@3oool2000000@0oooo0P0000070?ooo`@0
0000203oool8000001H0oooo0P0000080?ooo`P000001@3oool8000000T0oooo0P00000<0?ooo`80
00002`3oool2000000/0oooo0P00000;0?ooo`800000303oool2000000/0oooo0P00000_0?ooo`80
0000<`3oool2000000@0oooo0P0000060?ooo`800000103oool2000000D0oooo0P0000040?ooo`80
00001@3oool2000000@0oooo0P00000;0?ooo`8000001P3oool2000000@0oooo0P0000080?ooo`03
0000003oool0oooo02`0oooo000B0?ooo`@00000>`3oool3000001D0oooo0P0000040?ooo`800000
1@3oool2000000@0oooo0P0000060?ooo`800000103oool2000000T0oooo0P0000070?ooo`800000
103oool2000000P0oooo100000070?ooo`8000002`3oool8000000T0oooo0P00000>0?ooo`800000
1@3oool2000000@0oooo0P0000050?ooo`800000103oool2000000H0oooo0P00000;0?ooo`800000
103oool2000000D0oooo0P0000040?ooo`8000001@3oool2000000@0oooo0P0000060?ooo`800000
703oool2000000`0oooo0P0000070?ooo`P000002@3oool2000000`0oooo0P00000;0?ooo`800000
2`3oool2000000/0oooo0P00000<0?ooo`8000002`3oool200000340oooo0P00000a0?ooo`P00000
1P3oool2000000@0oooo0P0000050?ooo`800000103oool2000000L0oooo100000070?ooo`800000
103oool2000000H0oooo0P0000040?ooo`800000203oool00`000000oooo0?ooo`0/0?ooo`00D@3o
ool00`000000oooo0?ooo`0E0?ooo`800000103oool2000000D0oooo0P0000040?ooo`8000001P3o
ool2000000@0oooo0P0000090?ooo`8000002@3oool4000000X0oooo100000070?ooo`8000002`3o
ool200000140oooo0P0000060?ooo`800000103oool2000000D0oooo0P0000040?ooo`8000001`3o
ool4000000X0oooo0P0000090?ooo`800000103oool2000000/0oooo0P0000050?ooo`800000103o
ool2000000H0oooo0P00000L0?ooo`800000303oool2000000/0oooo0P00000;0?ooo`800000303o
ool2000000/0oooo0P00000;0?ooo`8000002`3oool2000000`0oooo0P00000;0?ooo`8000002@3o
ool2000000`0oooo0`00000G0?ooo`8000006@3oool3000001D0oooo200000060?ooo`800000103o
ool2000000D0oooo0P0000040?ooo`8000001`3oool4000000L0oooo0P0000040?ooo`8000001P3o
ool2000000@0oooo0P0000080?ooo`030000003oool0oooo02`0oooo001A0?ooo`030000003oool0
oooo01D0oooo0P0000040?ooo`8000001`3oool4000000P0oooo0P0000040?ooo`8000002@3oool2
000000T0oooo100000080?ooo`800000103oool2000000L0oooo0P0000090?ooo`8000004@3oool2
000000H0oooo0P0000040?ooo`8000001`3oool4000000T0oooo1000000:0?ooo`8000002@3oool2
000000@0oooo0P00000;0?ooo`8000001@3oool2000000@0oooo0P0000080?ooo`8000006P3oool2
000000`0oooo0P00000;0?ooo`8000002`3oool2000000`0oooo0P00000;0?ooo`8000002`3oool2
000000/0oooo0P00000<0?ooo`8000002`3oool2000000T0oooo0P00000;0?ooo`@000006@3oool2
000001H0oooo1000000I0?ooo`800000203oool8000000D0oooo0P0000040?ooo`8000001@3oool2
000000@0oooo0P0000070?ooo`@00000203oool2000000@0oooo0P0000080?ooo`030000003oool0
oooo02X0oooo0P0000000540oooo00<000000?ooo`3oool05`3oool4000000T0oooo100000080?oo
o`800000103oool2000000T0oooo0P0000070?ooo`800000103oool2000000H0oooo0P0000040?oo
o`8000001`3oool2000000/0oooo0P0000090?ooo`800000103oool2000000P0oooo100000090?oo
o`@000001`3oool2000000@0oooo0P00000:0?ooo`8000001`3oool2000000@0oooo0P0000070?oo
o`@000001`3oool2000000@0oooo0P0000080?ooo`8000006P3oool2000000`0oooo0P00000;0?oo
o`8000001`3oool6000000`0oooo0P00000;0?ooo`8000002`3oool2000000/0oooo0P00000<0?oo
o`8000002`3oool2000000T0oooo0P00000<0?ooo`<000006@3oool2000001L0oooo0`00000I0?oo
o`800000203oool8000000D0oooo200000050?ooo`800000103oool2000000L0oooo100000080?oo
o`800000103oool2000000P0oooo00<000000?ooo`3oool0:P3oool200000000D@3oool00`000000
oooo0?ooo`0G0?ooo`@000001`3oool2000000@0oooo0P0000080?ooo`@000002`3oool2000000L0
oooo0P0000040?ooo`8000001P3oool2000000@0oooo0P0000090?ooo`8000002@3oool2000000T0
oooo0P0000040?ooo`800000203oool4000000L0oooo0P0000040?ooo`8000001@3oool2000000@0
oooo0P00000:0?ooo`8000001`3oool2000000@0oooo0P0000070?ooo`@000001`3oool2000000@0
oooo0P00000:0?ooo`800000503oool6000000`0oooo0P00000;0?ooo`8000001`3oool6000000`0
oooo0P00000;0?ooo`8000002`3oool2000000L0oooo1P0000080?ooo`H000002`3oool2000000T0
oooo0P00000=0?ooo`030000003oool0oooo01X0oooo0P00000F0?ooo`030000003oool0oooo01P0
oooo0P0000080?ooo`8000002`3oool8000000D0oooo0P0000040?ooo`8000001@3oool2000000@0
oooo0P0000060?ooo`800000103oool2000000P0oooo00<000000?ooo`3oool0;03oool00540oooo
00<000000?ooo`3oool05@3oool2000000@0oooo0P0000050?ooo`800000103oool2000000P0oooo
1000000;0?ooo`8000001`3oool2000000@0oooo0P0000060?ooo`800000103oool2000000T0oooo
0P00000;0?ooo`8000002@3oool4000000P0oooo0P0000040?ooo`8000001@3oool2000000@0oooo
0P0000050?ooo`800000103oool2000000`0oooo0P0000070?ooo`@000003@3oool2000000D0oooo
0P0000040?ooo`8000002P3oool2000001@0oooo1P00000<0?ooo`8000002`3oool2000000/0oooo
0P00000<0?ooo`8000002`3oool2000000/0oooo0P0000070?ooo`H00000203oool6000000/0oooo
0P00000;0?ooo`800000:03oool200000340oooo0P0000080?ooo`8000002`3oool2000000/0oooo
0P0000040?ooo`8000001@3oool2000000@0oooo0P0000060?ooo`800000103oool2000000P0oooo
00<000000?ooo`3oool0;03oool001X0oooo200000060?ooo`800000203oool8000000@0oooo1P00
000=0?ooo`030000003oool0oooo01D0oooo0P0000040?ooo`8000001@3oool2000000@0oooo0P00
00060?ooo`800000103oool2000000D0oooo1P0000070?ooo`800000103oool2000000H0oooo0P00
00040?ooo`8000002`3oool2000000T0oooo0P0000090?ooo`@00000203oool2000000@0oooo0P00
00050?ooo`800000103oool2000000D0oooo0P0000040?ooo`800000303oool2000000L0oooo1000
000=0?ooo`8000001@3oool2000000@0oooo0P00000<0?ooo`8000005P3oool2000000`0oooo0P00
000;0?ooo`8000002`3oool2000000P0oooo1P0000070?ooo`H000001`3oool6000000/0oooo0P00
000<0?ooo`8000001`3oool6000000/0oooo0P00000R0?ooo`800000103oool200000340oooo0P00
000:0?ooo`8000002@3oool2000000/0oooo0P0000040?ooo`8000001@3oool2000000@0oooo0P00
00060?ooo`P00000203oool00`000000oooo0?ooo`0/0?ooo`006P3oool8000000H0oooo0P000008
0?ooo`P00000103oool6000000d0oooo00<000000?ooo`3oool05@3oool2000000@0oooo0P000005
0?ooo`800000103oool2000000H0oooo0P0000040?ooo`8000001@3oool6000000L0oooo0P000004
0?ooo`8000001P3oool2000000@0oooo0P00000;0?ooo`8000002`3oool2000000D0oooo0P000004
0?ooo`8000001P3oool2000000@0oooo0P0000050?ooo`800000103oool2000000D0oooo0P000004
0?ooo`8000001P3oool2000000@0oooo0P0000050?ooo`800000103oool2000000D0oooo0P000004
0?ooo`8000001@3oool2000000@0oooo0P00000<0?ooo`8000005P3oool2000000`0oooo0P00000;
0?ooo`8000005@3oool6000000L0oooo1P0000070?ooo`H000002`3oool2000000`0oooo0P000007
0?ooo`H000002`3oool200000280oooo0P0000040?ooo`800000<@3oool2000000X0oooo0P00000;
0?ooo`8000002@3oool2000000@0oooo0P0000050?ooo`800000103oool2000000H0oooo20000008
0?ooo`030000003oool0oooo02`0oooo000N0?ooo`8000004P3oool200000100oooo0P00000;0?oo
o`030000003oool0oooo01D0oooo0P0000040?ooo`8000001@3oool2000000@0oooo0P0000060?oo
o`800000103oool2000000L0oooo100000070?ooo`800000103oool2000000H0oooo0P0000040?oo
o`8000001@3oool2000000@0oooo0P00000;0?ooo`8000001@3oool2000000@0oooo0P0000060?oo
o`800000103oool2000000D0oooo0P0000040?ooo`8000001@3oool2000000@0oooo0P0000060?oo
o`800000103oool2000000D0oooo0P0000040?ooo`8000001@3oool2000000@0oooo0P0000050?oo
o`800000103oool2000000H0oooo0P0000040?ooo`800000803oool6000000/0oooo0P00000I0?oo
o`8000002`3oool2000000/0oooo0P00000V0?ooo`8000002`3oool2000002@0oooo1000000c0?oo
o`800000303oool2000000T0oooo0P0000090?ooo`800000103oool2000000D0oooo0P0000040?oo
o`8000001P3oool2000000h0oooo00<000000?ooo`3oool0:P3oool2000000007P3oool200000180
oooo0P00000@0?ooo`8000002`3oool00`000000oooo0?ooo`0E0?ooo`800000103oool2000000D0
oooo0P0000040?ooo`8000001P3oool2000000@0oooo0P0000070?ooo`@000001`3oool2000000@0
oooo0P0000060?ooo`800000103oool2000000D0oooo0P0000040?ooo`8000001@3oool2000000@0
oooo0P0000050?ooo`800000103oool2000000H0oooo0P0000040?ooo`8000001@3oool2000000@0
oooo0P0000050?ooo`800000103oool2000000P0oooo1000000=0?ooo`8000001`3oool4000000L0
oooo0P0000040?ooo`8000001P3oool2000000@0oooo0P00000P0?ooo`H000001`3oool6000001T0
oooo0P00000;0?ooo`8000002`3oool2000002H0oooo0P00000=0?ooo`8000008P3oool4000003<0
oooo0P00000<0?ooo`8000002`3oool2000000L0oooo0P0000040?ooo`8000001@3oool2000000@0
oooo0P0000060?ooo`8000003P3oool00`000000oooo0?ooo`0Z0?ooo`800000000N0?ooo`800000
503oool2000000h0oooo0P00000;0?ooo`D000004`3oool2000000@0oooo0P0000050?ooo`800000
103oool2000000H0oooo0P0000040?ooo`8000001@3oool2000000@0oooo0P0000050?ooo`800000
103oool2000000H0oooo0P0000040?ooo`8000001`3oool4000000L0oooo0P0000040?ooo`800000
1@3oool2000000@0oooo0P0000060?ooo`800000103oool2000000D0oooo0P0000040?ooo`800000
1@3oool2000000@0oooo0P0000080?ooo`@000003@3oool2000000L0oooo100000070?ooo`P00000
1P3oool8000002@0oooo0P0000070?ooo`H00000JP3oool200000200oooo0P0000040?ooo`800000
903oool2000000L0oooo1P00000>0?ooo`8000002@3oool2000000L0oooo0P0000040?ooo`800000
1@3oool2000000@0oooo0P0000080?ooo`800000303oool00`000000oooo0?ooo`0Z0?ooo`800000
000N0?ooo`800000503oool2000000h0oooo0P00000;0?ooo`030000003oool0oooo01D0oooo0P00
00040?ooo`8000001@3oool2000000@0oooo0P0000060?ooo`800000103oool2000000D0oooo0P00
00040?ooo`8000001@3oool2000000@0oooo0P0000060?ooo`800000103oool2000000L0oooo1000
00090?ooo`@000001`3oool2000000@0oooo0P0000060?ooo`800000103oool2000000D0oooo0P00
00040?ooo`8000001@3oool2000000@0oooo0P0000060?ooo`800000103oool2000000L0oooo1000
00070?ooo`800000103oool2000000D0oooo200000060?ooo`P00000903oool2000000/0oooo0P00
001T0?ooo`800000103oool200000200oooo0P0000040?ooo`800000903oool2000000L0oooo1P00
000>0?ooo`8000002`3oool2000000D0oooo0P0000040?ooo`8000001@3oool2000000@0oooo0P00
00080?ooo`800000303oool00`000000oooo0?ooo`0Z0?ooo`800000000N0?ooo`8000005P3oool2
000000H0oooo1P00000=0?ooo`030000003oool0oooo01D0oooo0P0000040?ooo`8000001@3oool2
000000@0oooo0P0000060?ooo`800000103oool2000000D0oooo0P0000040?ooo`8000001@3oool2
000000@0oooo0P0000060?ooo`P000001@3oool2000000@0oooo0P0000070?ooo`@000001`3oool2
000000@0oooo0P0000060?ooo`800000103oool2000000D0oooo0P0000040?ooo`8000001@3oool2
000000@0oooo0P0000060?ooo`800000103oool2000000L0oooo100000070?ooo`800000103oool2
000000D0oooo0P00000@0?ooo`800000<`3oool2000006@0oooo0P0000040?ooo`800000803oool2
000000@0oooo0P00000T0?ooo`8000002`3oool2000000P0oooo0P0000040?ooo`8000002`3oool2
000000D0oooo200000050?ooo`800000103oool2000000X0oooo0P00000:0?ooo`030000003oool0
oooo02X0oooo0P00000001h0oooo0P00000F0?ooo`8000001P3oool6000000d0oooo00<000000?oo
o`3oool05@3oool2000000@0oooo0P0000050?ooo`800000103oool2000000H0oooo0P0000040?oo
o`8000001@3oool2000000@0oooo0P0000050?ooo`P000001P3oool8000000D0oooo0P0000040?oo
o`8000001@3oool2000000@0oooo0P0000050?ooo`800000103oool2000000H0oooo0P0000040?oo
o`8000001@3oool2000000@0oooo0P0000050?ooo`P000001P3oool2000000@0oooo0P00000;0?oo
o`8000001@3oool2000000@0oooo0P0000050?ooo`800000403oool2000009T0oooo2000000P0?oo
o`800000103oool2000002@0oooo0P00000;0?ooo`800000203oool2000000@0oooo0P0000050?oo
o`800000103oool2000000D0oooo200000050?ooo`800000103oool2000000X0oooo0P00000:0?oo
o`030000003oool0oooo02X0oooo0P00000001h0oooo0P00000H0?ooo`800000103oool200000140
oooo00<000000?ooo`3oool05@3oool2000000@0oooo0P0000050?ooo`P000001P3oool2000000@0
oooo0P0000050?ooo`800000103oool2000000D0oooo2000000:0?ooo`8000001`3oool2000000@0
oooo0P0000050?ooo`800000103oool2000000D0oooo0P0000040?ooo`8000001P3oool2000000@0
oooo0P0000050?ooo`P000001@3oool8000000H0oooo0P0000040?ooo`8000002`3oool2000000D0
oooo0P0000040?ooo`8000001`3oool2000000h0oooo0P00002I0?ooo`P00000803oool2000000@0
oooo0P00000N0?ooo`X000004`3oool8000000D0oooo0P0000040?ooo`8000001@3oool2000000/0
oooo2000000<0?ooo`800000203oool00`000000oooo0?ooo`0V0?ooo`H00000000>0?ooo`H00000
0P3oool4000000@0oooo0P00000H0?ooo`800000103oool200000140oooo00<000000?ooo`3oool0
5@3oool8000000D0oooo200000060?ooo`800000103oool2000000D0oooo0P0000040?ooo`800000
2@3oool2000000`0oooo0P0000070?ooo`800000103oool2000000D0oooo0P0000040?ooo`800000
1@3oool2000000@0oooo0P0000060?ooo`P000001@3oool8000000T0oooo0P0000080?ooo`800000
103oool2000000D0oooo0P0000040?ooo`8000001@3oool2000000@0oooo0P0000070?ooo`800000
3P3oool2000009d0oooo0P00000R0?ooo`800000103oool2000001h0oooo2P00000C0?ooo`P00000
1@3oool8000000D0oooo0P00000;0?ooo`P00000303oool2000000P0oooo00<000000?ooo`3oool0
9P3oool6000000003P3oool600000080oooo2P00000B0?ooo`800000103oool2000000@0oooo0P00
000A0?ooo`030000003oool0oooo01D0oooo200000090?ooo`800000203oool8000000D0oooo0P00
00040?ooo`8000002@3oool2000000`0oooo0P0000070?ooo`800000103oool2000000D0oooo0P00
00040?ooo`8000001@3oool2000000@0oooo0P0000060?ooo`P000002@3oool2000000/0oooo0P00
00080?ooo`800000103oool2000000D0oooo0P0000040?ooo`8000001@3oool2000000@0oooo0P00
00090?ooo`800000303oool2000009d0oooo0P00000R0?ooo`800000103oool2000001h0oooo0P00
00040?ooo`8000006@3oool2000000L0oooo200000070?ooo`8000002@3oool2000000`0oooo0P00
00040?ooo`800000203oool00`000000oooo0?ooo`0Z0?ooo`800000000@0?ooo`800000103oool2
00000080oooo1P00000B0?ooo`800000103oool2000000@0oooo0P00000A0?ooo`030000003oool0
oooo01T0oooo0P00000;0?ooo`800000203oool8000000D0oooo0P0000040?ooo`8000002@3oool2
000000`0oooo0P0000070?ooo`800000103oool2000000D0oooo0P0000040?ooo`8000001@3oool8
000000X0oooo0P00000;0?ooo`8000002`3oool2000000P0oooo0P0000040?ooo`8000001`3oool4
000000L0oooo0P0000040?ooo`8000002@3oool2000000`0oooo0P00002M0?ooo`800000203oool6
000001@0oooo0P0000040?ooo`8000005@3oool4000000D0oooo0P0000040?ooo`8000006@3oool2
000000/0oooo0P0000090?ooo`8000002@3oool2000000`0oooo0P0000040?ooo`800000203oool0
0`000000oooo0?ooo`0Z0?ooo`800000000@0?ooo`800000103oool2000000H0oooo0P00000D0?oo
o`@000001P3oool8000000/0oooo00<000000?ooo`3oool06@3oool2000000/0oooo0P00000<0?oo
o`8000001`3oool2000000@0oooo0P0000090?ooo`800000303oool2000000L0oooo0P0000040?oo
o`8000001@3oool2000000@0oooo0P0000050?ooo`P000002P3oool2000000/0oooo0P00000;0?oo
o`800000203oool2000000@0oooo0P0000070?ooo`@000001`3oool2000000@0oooo0P00000;0?oo
o`8000002P3oool2000009d0oooo0P0000080?ooo`H00000503oool2000000@0oooo0P00000E0?oo
o`@000001`3oool200000080oooo0P00000I0?ooo`8000002`3oool2000000/0oooo0P0000090?oo
o`8000002P3oool8000000P0oooo00<000000?ooo`3oool0:P3oool200000000403oool2000000@0
oooo0P0000060?ooo`800000503oool4000000H0oooo2000000;0?ooo`<000006@3oool2000000/0
oooo0P00000<0?ooo`8000001`3oool2000000@0oooo0P0000090?ooo`800000303oool2000000L0
oooo0P0000040?ooo`8000001@3oool2000000@0oooo0P0000090?ooo`800000303oool2000000/0
oooo0P00000;0?ooo`800000203oool2000000@0oooo0P0000050?ooo`800000103oool2000000D0
oooo0P0000040?ooo`8000002`3oool2000000X0oooo0P00002M0?ooo`8000003P3oool200000180
oooo0P0000040?ooo`8000004`3oool2000000@0oooo0P0000050?ooo`8000000P3oool2000001T0
oooo0P00000;0?ooo`8000002`3oool2000000T0oooo0P00000:0?ooo`P00000203oool00`000000
oooo0?ooo`0Z0?ooo`800000000@0?ooo`800000103oool2000003T0oooo00<000000?ooo`3oool0
6@3oool2000000/0oooo0P00000<0?ooo`8000001`3oool8000000T0oooo0P00000<0?ooo`800000
1`3oool2000000@0oooo0P0000050?ooo`800000103oool2000000T0oooo0P00000<0?ooo`800000
2`3oool2000000/0oooo0P0000080?ooo`800000103oool2000000D0oooo0P0000040?ooo`800000
1@3oool2000000@0oooo0P0000050?ooo`800000103oool2000000H0oooo1P00002M0?ooo`800000
3P3oool200000180oooo2000000C0?ooo`800000103oool2000000L0oooo1000000I0?ooo`800000
2`3oool2000000d0oooo0P0000090?ooo`800000303oool2000000X0oooo00<000000?ooo`3oool0
:03oool200000080oooo000@0?ooo`800000103oool2000003T0oooo00<000000?ooo`3oool06@3o
ool2000000/0oooo0P00000<0?ooo`8000001`3oool8000000T0oooo0P00000<0?ooo`8000001`3o
ool2000000@0oooo0P0000050?ooo`800000103oool2000000T0oooo0P00000<0?ooo`8000002`3o
ool2000000/0oooo0P0000080?ooo`P000001@3oool2000000@0oooo0P0000050?ooo`P000001@3o
ool2000000@0oooo0P0000060?ooo`H00000W@3oool2000000h0oooo0P00000B0?ooo`P000006@3o
ool2000000L0oooo1000000I0?ooo`8000002`3oool2000000d0oooo0P0000090?ooo`800000303o
ool2000000X0oooo00<000000?ooo`3oool0:03oool200000080oooo000@0?ooo`800000103oool2
000003T0oooo00<000000?ooo`3oool06@3oool2000000/0oooo0P00000<0?ooo`8000002`3oool2
000000/0oooo0P0000080?ooo`H000001`3oool8000000D0oooo0P0000040?ooo`8000002@3oool2
000000`0oooo0P00000;0?ooo`8000002`3oool2000000P0oooo200000050?ooo`800000103oool2
000000D0oooo200000060?ooo`P000002@3oool2000009d0oooo0P00000>0?ooo`8000004P3oool2
000001l0oooo0P0000050?ooo`P000005`3oool2000000/0oooo0P0000070?ooo`800000103oool2
000000/0oooo0P00000:0?ooo`8000002P3oool00`000000oooo0?ooo`0X0?ooo`8000000P3oool0
00h0oooo0P0000020?ooo`@00000>`3oool00`000000oooo0?ooo`0I0?ooo`8000002`3oool20000
00`0oooo0P00000;0?ooo`8000001`3oool6000000P0oooo1P0000070?ooo`P000001@3oool80000
00T0oooo0P00000<0?ooo`8000002`3oool2000000L0oooo1P00000<0?ooo`8000001`3oool20000
00@0oooo0P0000090?ooo`800000203oool8000000T0oooo0P00002I0?ooo`H000002P3oool60000
0180oooo0P00000K0?ooo`@000001`3oool8000001L0oooo0P00000;0?ooo`8000001`3oool20000
00@0oooo0P00000;0?ooo`8000002P3oool2000000X0oooo00<000000?ooo`3oool0:03oool20000
0080oooo000>0?ooo`8000000P3oool4000003/0oooo00<000000?ooo`3oool06@3oool2000000L0
oooo1P00000<0?ooo`8000002`3oool2000000L0oooo1P0000080?ooo`P000002@3oool2000000L0
oooo200000090?ooo`800000303oool2000000L0oooo1P0000070?ooo`H00000303oool2000000L0
oooo0P0000040?ooo`8000002@3oool2000000`0oooo0P00002V0?ooo`H000002P3oool6000001@0
oooo0P00000I0?ooo`@000001`3oool2000001T0oooo1P00000;0?ooo`8000001`3oool8000000D0
oooo0P0000040?ooo`8000002P3oool2000000X0oooo00<000000?ooo`3oool0:03oool200000080
oooo001A0?ooo`030000003oool0oooo01D0oooo1P0000070?ooo`H00000303oool2000000/0oooo
0P0000070?ooo`P000001P3oool8000000T0oooo0P00000;0?ooo`8000002`3oool2000000P0oooo
1P0000070?ooo`H000001`3oool8000000X0oooo0P0000070?ooo`800000103oool2000000T0oooo
0P00000<0?ooo`800000Z03oool4000000P0oooo0P0000040?ooo`800000503oool2000001d0oooo
0P0000050?ooo`8000006@3oool6000000L0oooo1P0000070?ooo`P000001@3oool2000000@0oooo
0P00000:0?ooo`8000002P3oool00`000000oooo0?ooo`0X0?ooo`8000000P3oool00540oooo00<0
00000?ooo`3oool05@3oool6000000L0oooo200000060?ooo`H000002`3oool2000000L0oooo2000
000:0?ooo`8000002`3oool2000000/0oooo0P00000;0?ooo`800000203oool6000000L0oooo2000
00050?ooo`P000002P3oool2000000L0oooo0P0000040?ooo`8000002@3oool2000000`0oooo0P00
002X0?ooo`@00000203oool2000000@0oooo0P00000F0?ooo`8000006`3oool2000000L0oooo0P00
000K0?ooo`8000001`3oool6000000/0oooo0P0000070?ooo`P000002P3oool2000000X0oooo00<0
00000?ooo`3oool09P3oool400000080oooo000B0?ooo`@00000>`3oool00`000000oooo0?ooo`0E
0?ooo`P000001@3oool8000000H0oooo1P00000;0?ooo`8000002`3oool2000000`0oooo0P00000;
0?ooo`8000002`3oool2000000L0oooo1P0000080?ooo`P000001@3oool8000000T0oooo0P00000<
0?ooo`8000001`3oool2000000@0oooo0P0000090?ooo`800000303oool200000:H0oooo0P000004
0?ooo`8000001P3oool2000000@0oooo0P00000F0?ooo`8000005@3oool2000000@0oooo0P000007
0?ooo`8000006`3oool2000000/0oooo0P00000;0?ooo`8000001`3oool8000000X0oooo0P00000:
0?ooo`030000003oool0oooo02H0oooo100000020?ooo`004P3oool4000003/0oooo00<000000?oo
o`3oool05@3oool8000000T0oooo0P0000080?ooo`P000002@3oool2000000/0oooo0P00000<0?oo
o`8000002`3oool2000000/0oooo0P0000070?ooo`H00000203oool8000000T0oooo0P00000;0?oo
o`800000303oool2000000L0oooo0P0000040?ooo`8000002@3oool2000000`0oooo0P00002V0?oo
o`800000103oool2000000H0oooo0P0000040?ooo`800000603oool2000001<0oooo0P0000040?oo
o`8000002@3oool2000002H0oooo0P00000;0?ooo`8000002`3oool2000000P0oooo1P00000:0?oo
o`030000003oool0oooo02`0oooo000@0?ooo`800000103oool2000003T0oooo0`00000I0?ooo`80
00002`3oool2000000P0oooo200000090?ooo`8000002`3oool2000000`0oooo0P00000;0?ooo`80
00002`3oool2000000P0oooo200000090?ooo`8000002`3oool2000000/0oooo0P00000<0?ooo`80
00001`3oool8000000T0oooo0P00000<0?ooo`800000YP3oool2000000@0oooo0P0000060?ooo`P0
0000603oool2000001<0oooo200000090?ooo`800000<`3oool2000000/0oooo0P0000080?ooo`H0
00002P3oool00`000000oooo0?ooo`0/0?ooo`00403oool2000000@0oooo0P00000i0?ooo`030000
003oool0oooo01T0oooo0P00000;0?ooo`800000303oool2000000L0oooo1P00000;0?ooo`800000
303oool2000000/0oooo0P00000;0?ooo`800000203oool8000000T0oooo0P00000;0?ooo`800000
2`3oool2000000`0oooo0P0000070?ooo`P000002@3oool2000000`0oooo0P00002V0?ooo`800000
103oool2000000H0oooo2000000B0?ooo`800000103oool2000001<0oooo2000000;0?ooo`800000
<@3oool2000000/0oooo0P00000<0?ooo`8000002P3oool00`000000oooo0?ooo`0/0?ooo`00403o
ool2000000@0oooo0P00000i0?ooo`030000003oool0oooo01T0oooo0P00000;0?ooo`800000303o
ool2000000L0oooo1P00000;0?ooo`800000303oool2000000/0oooo0P00000;0?ooo`800000303o
ool2000000/0oooo0P00000;0?ooo`8000002`3oool2000000P0oooo1P00000;0?ooo`8000001`3o
ool6000000`0oooo0P00002V0?ooo`800000103oool2000000X0oooo0P00000D0?ooo`800000103o
ool2000001<0oooo0P00000A0?ooo`800000<@3oool2000000/0oooo0P00000<0?ooo`8000002P3o
ool00`000000oooo0?ooo`0/0?ooo`00403oool2000000@0oooo0P00000i0?ooo`030000003oool0
oooo01T0oooo0P00000;0?ooo`800000303oool2000000L0oooo200000090?ooo`800000303oool2
000000L0oooo1P00000;0?ooo`800000303oool2000000/0oooo0P00000;0?ooo`8000002`3oool2
000000P0oooo1P00000;0?ooo`8000001`3oool6000000P0oooo1P00002V0?ooo`800000103oool2
000000X0oooo0P00000D0?ooo`P000004`3oool2000000/0oooo0P0000040?ooo`800000<@3oool2
000000/0oooo0P00000H0?ooo`030000003oool0oooo02`0oooo000@0?ooo`800000103oool20000
03T0oooo00<000000?ooo`3oool06@3oool2000000/0oooo0P00000<0?ooo`8000001`3oool80000
00T0oooo0P00000<0?ooo`8000001`3oool6000000L0oooo1P00000<0?ooo`8000002`3oool20000
00/0oooo0P00000;0?ooo`800000203oool8000000T0oooo0P0000070?ooo`P000001P3oool60000
0:H0oooo0P0000040?ooo`8000002P3oool2000001@0oooo2000000E0?ooo`8000002@3oool20000
00@0oooo0P00000a0?ooo`8000002`3oool2000001P0oooo00<000000?ooo`3oool0;03oool00100
oooo0P0000040?ooo`800000>@3oool00`000000oooo0?ooo`0I0?ooo`8000002`3oool2000000`0
oooo0P00000;0?ooo`8000002`3oool2000000P0oooo1P0000070?ooo`P000001@3oool6000000`0
oooo0P00000;0?ooo`8000002`3oool2000000/0oooo0P0000080?ooo`P000002@3oool2000000L0
oooo2000000:0?ooo`800000YP3oool2000000@0oooo0P00000:0?ooo`800000603oool2000001L0
oooo0P00000;0?ooo`@00000;`3oool6000000/0oooo0P00000H0?ooo`030000003oool0oooo02`0
oooo000B0?ooo`@00000>`3oool00`000000oooo0?ooo`0I0?ooo`8000002`3oool2000000`0oooo
0P00000;0?ooo`8000001`3oool6000000P0oooo1P0000070?ooo`P000001@3oool8000000X0oooo
0P00000;0?ooo`8000002`3oool2000000L0oooo1P00000<0?ooo`8000002`3oool2000000/0oooo
0P00000<0?ooo`800000YP3oool2000000@0oooo0P00000:0?ooo`800000603oool2000001T0oooo
0P0000090?ooo`@00000;`3oool6000000/0oooo0P00000H0?ooo`030000003oool0oooo02`0oooo
000B0?ooo`@00000>`3oool00`000000oooo0?ooo`0I0?ooo`8000001`3oool6000000`0oooo0P00
000;0?ooo`8000001`3oool6000000`0oooo0P00000;0?ooo`8000001`3oool8000000X0oooo0P00
000;0?ooo`8000001`3oool6000000L0oooo1P00000<0?ooo`8000002`3oool2000000/0oooo0P00
002d0?ooo`800000103oool2000000X0oooo0P00000H0?ooo`8000006@3oool2000000L0oooo0P00
00040?ooo`800000<@3oool2000000L0oooo1P00000H0?ooo`030000003oool0oooo02`0oooo001A
0?ooo`030000003oool0oooo01D0oooo1P0000070?ooo`H00000303oool2000000/0oooo0P00000;
0?ooo`800000303oool2000000/0oooo0P00000;0?ooo`800000303oool2000000L0oooo1P000007
0?ooo`H000002`3oool2000000`0oooo0P00000;0?ooo`8000002`3oool200000;@0oooo2000000:
0?ooo`800000603oool2000001/0oooo0P0000050?ooo`800000103oool200000340oooo0P000007
0?ooo`H00000603oool00`000000oooo0?ooo`0/0?ooo`00D@3oool00`000000oooo0?ooo`0E0?oo
o`H000002`3oool2000000P0oooo1P00000;0?ooo`8000002`3oool2000001T0oooo0P00000;0?oo
o`800000303oool2000000L0oooo1P00000;0?ooo`8000002`3oool2000000`0oooo0P00000;0?oo
o`8000002`3oool200000;@0oooo2000000:0?ooo`800000603oool2000001/0oooo0P0000050?oo
o`800000103oool2000003h0oooo0P00000H0?ooo`030000003oool0oooo02`0oooo000@0?ooo`P0
0000>@3oool3000001T0oooo0P00000;0?ooo`800000203oool6000000/0oooo0P00000V0?ooo`80
00002`3oool2000000P0oooo1P00000;0?ooo`8000002`3oool2000001T0oooo0P0000070?ooo`H0
00002`3oool200000;@0oooo0P00000<0?ooo`H00000603oool2000001D0oooo0P0000040?ooo`80
00001@3oool2000000@0oooo0P00000n0?ooo`800000603oool00`000000oooo0?ooo`0/0?ooo`00
403oool8000003T0oooo00<000000?ooo`3oool06@3oool2000001T0oooo0P00000;0?ooo`800000
9P3oool2000000/0oooo0P0000080?ooo`H000002`3oool2000002H0oooo0P0000070?ooo`H00000
2`3oool200000;@0oooo0P00000<0?ooo`H00000603oool2000001D0oooo0P0000040?ooo`800000
1@3oool2000000@0oooo0P00001H0?ooo`030000003oool0oooo02`0oooo000B0?ooo`800000?@3o
ool00`000000oooo0?ooo`0d0?ooo`8000002`3oool2000002H0oooo0P00000;0?ooo`800000303o
ool2000003<0oooo0P0000070?ooo`P000002@3oool200000;H0oooo0P00000<0?ooo`@00000603o
ool2000001L0oooo100000070?ooo`800000103oool2000005P0oooo00<000000?ooo`3oool0;03o
ool00180oooo0P00000m0?ooo`030000003oool0oooo03d0oooo1P00000V0?ooo`8000002`3oool2
000000`0oooo0P00000c0?ooo`8000001`3oool8000000T0oooo0P00002f0?ooo`800000303oool4
000001@0oooo1P00000G0?ooo`@000001`3oool2000000@0oooo0P00001H0?ooo`030000003oool0
oooo02`0oooo000B0?ooo`800000?@3oool00`000000oooo0?ooo`0m0?ooo`H000009P3oool20000
00/0oooo0P00000m0?ooo`H000002`3oool2000000L0oooo1P00002h0?ooo`800000203oool20000
00@0oooo0P00000B0?ooo`H000005@3oool2000000@0oooo0P0000050?ooo`800000103oool20000
05P0oooo00<000000?ooo`3oool0;03oool00180oooo0P00000m0?ooo`030000003oool0oooo0440
oooo0P00000R0?ooo`H000002`3oool2000003d0oooo1P00000;0?ooo`8000001`3oool600000;P0
oooo0P0000080?ooo`800000103oool2000001H0oooo0P00000E0?ooo`800000103oool2000000D0
oooo0P0000040?ooo`800000F03oool00`000000oooo0?ooo`0/0?ooo`004P3oool2000003d0oooo
00<000000?ooo`3oool0@@3oool200000280oooo1P0000070?ooo`H00000@@3oool2000000/0oooo
0P00000;0?ooo`800000^P3oool2000000H0oooo0P0000040?ooo`8000005P3oool2000001D0oooo
0P0000040?ooo`8000001@3oool2000000@0oooo0P00001H0?ooo`030000003oool0oooo02`0oooo
000B0?ooo`800000?@3oool00`000000oooo0?ooo`1Y0?ooo`8000001`3oool600000440oooo0P00
000;0?ooo`8000002`3oool200000;X0oooo0P0000060?ooo`800000103oool2000000L0oooo0`00
000S0?ooo`800000103oool2000000D0oooo2000001H0?ooo`030000003oool0oooo02`0oooo000@
0?ooo`8000000P3oool6000003L0oooo00<000000?ooo`3oool0J@3oool2000000/0oooo0P00001>
0?ooo`800000`@3oool2000000@0oooo0P0000060?ooo`800000103oool2000000H0oooo1000000S
0?ooo`800000103oool2000000D0oooo2000001H0?ooo`030000003oool0oooo02`0oooo000@0?oo
o`8000000P3oool6000003L0oooo00<000000?ooo`3oool0MP3oool2000004h0oooo0P0000310?oo
o`800000103oool2000000H0oooo0P0000040?ooo`8000001`3oool3000002<0oooo0P0000040?oo
o`8000001@3oool2000005h0oooo00<000000?ooo`3oool0;03oool00540oooo0`0000360?ooo`80
0000`@3oool8000000H0oooo0P0000040?ooo`800000203oool00`000000oooo0?ooo`0R0?ooo`80
0000103oool2000000D0oooo0P00001N0?ooo`030000003oool0oooo02`0oooo001A0?ooo`030000
003oool0oooo0<H0oooo0P0000310?ooo`P000001P3oool2000000@0oooo0P00000]0?ooo`800000
103oool2000000L0oooo0P00001L0?ooo`030000003oool0oooo02`0oooo000>0?ooo`8000000P3o
ool200000080oooo1000000g0?ooo`030000003oool0oooo0<80oooo1P0000350?ooo`800000203o
ool2000000@0oooo0P00000]0?ooo`800000103oool2000000L0oooo0P00001L0?ooo`030000003o
ool0oooo02`0oooo000>0?ooo`8000000P3oool200000080oooo1000000g0?ooo`030000003oool0
oooo0<80oooo1P0000350?ooo`800000203oool2000000@0oooo0P00000]0?ooo`800000103oool2
000000T0oooo0P00001J0?ooo`030000003oool0oooo02`0oooo000>0?ooo`8000000P3oool20000
0080oooo0P00000i0?ooo`030000003oool0oooo0<H0oooo0P0000350?ooo`800000203oool80000
02d0oooo200000090?ooo`800000FP3oool00`000000oooo0?ooo`0/0?ooo`003P3oool200000080
oooo0P0000020?ooo`800000>@3oool00`000000oooo0?ooo`360?ooo`800000a@3oool2000000P0
oooo2000000]0?ooo`P000002`3oool2000005P0oooo00<000000?ooo`3oool0:03oool400000000
3P3oool200000080oooo0P0000020?ooo`8000003P3oool8000000H0oooo0P0000080?ooo`H00000
3@3oool00`000000oooo0?ooo`3o0?ooohh0oooo0P0000080?ooo`800000<`3oool200000140oooo
0P00001H0?ooo`030000003oool0oooo00P0oooo1P00000J0?ooo`@00000000>0?ooo`8000000P3o
ool200000080oooo0P00000>0?ooo`P000001P3oool2000000P0oooo1P00000=0?ooo`030000003o
ool0oooo0?l0ooooSP3oool2000000P0oooo0P00000c0?ooo`8000002`3oool2000000@0oooo0P00
001H0?ooo`030000003oool0oooo00P0oooo1P00000N0?ooo`003P3oool200000080oooo0P000002
0?ooo`8000004P3oool2000001P0oooo0P00000;0?ooo`030000003oool0oooo0?l0ooooSP3oool2
000000X0oooo0P00000c0?ooo`8000002@3oool2000000@0oooo0P00001H0?ooo`030000003oool0
oooo00h0oooo0P00000L0?ooo`003P3oool200000080oooo0P0000020?ooo`8000004P3oool20000
01P0oooo0P00000;0?ooo`D00000o`3ooon<0?ooo`8000002P3oool2000002D0oooo0`00000;0?oo
o`8000002@3oool8000005D0oooo1000000@0?ooo`800000703oool000h0oooo100000020?ooo`80
0000503oool2000001P0oooo0P00000;0?ooo`030000003oool0oooo0?l0ooooRP3oool6000000`0
oooo0P00000R0?ooo`@000003@3oool2000000L0oooo2000001H0?ooo`030000003oool0oooo00h0
oooo0P00000L0?ooo`003P3oool400000080oooo0P00000D0?ooo`800000603oool2000000/0oooo
00<000000?ooo`3oool0o`3ooon:0?ooo`H00000303oool2000002<0oooo0`00000=0?ooo`800000
2`3oool2000005X0oooo00<000000?ooo`3oool03P3oool2000001`0oooo000Z0?ooo`8000004P3o
ool6000000d0oooo00<000000?ooo`3oool0o`3ooon>0?ooo`8000003P3oool200000280oooo00<0
00000?ooo`3oool03P3oool2000000T0oooo0P00001J0?ooo`030000003oool0oooo00X0oooo1P00
000L0?ooo`00:P3oool200000180oooo1P00000=0?ooo`030000003oool0oooo0?l0ooooSP3oool2
000000h0oooo0P0000070?ooo`@00000:03oool2000000T0oooo0P00001J0?ooo`030000003oool0
oooo00X0oooo1P00000L0?ooo`004P3oool400000080oooo0P00000@0?ooo`8000004P3oool20000
0140oooo00<000000?ooo`3oool0o`3ooonH0?ooo`800000103oool2000000L0oooo1000000R0?oo
o`800000103oool2000000T0oooo0P00001J0?ooo`030000003oool0oooo00P0oooo0P0000040?oo
o`800000703oool00180oooo100000020?ooo`800000403oool200000180oooo0P00000A0?ooo`03
0000003oool0oooo0?l0ooooV03oool2000000@0oooo0P0000050?ooo`800000103oool200000200
oooo0P0000040?ooo`8000002@3oool2000005X0oooo00<000000?ooo`3oool0203oool2000000@0
oooo0P00000H0?ooo`@00000000@0?ooo`800000103oool2000000h0oooo1P00000B0?ooo`800000
4@3oool00`000000oooo0?ooo`3o0?oooiP0oooo200000050?ooo`800000103oool200000200oooo
200000090?ooo`800000FP3oool00`000000oooo0?ooo`080?ooo`800000103oool2000001P0oooo
100000000100oooo0P0000040?ooo`8000003P3oool600000180oooo0P00000A0?ooo`030000003o
ool0oooo0?l0ooooV03oool8000000D0oooo0P0000040?ooo`800000803oool8000000T0oooo0P00
001J0?ooo`030000003oool0oooo00P0oooo0P0000040?ooo`8000006P3oool2000000004P3oool6
00000180oooo0P00000B0?ooo`P000002`3oool00`000000oooo0?ooo`3o0?oooi`0oooo0P000007
0?ooo`800000103oool2000002@0oooo0P00000;0?ooo`800000FP3oool00`000000oooo0?ooo`0:
0?ooo`@00000703oool2000000004P3oool600000180oooo0P00000B0?ooo`P000002`3oool30000
0?l0ooooW03oool2000000L0oooo0P0000040?ooo`800000903oool2000000L0oooo1P00001J0?oo
o`030000003oool0oooo00X0oooo1000000J0?ooo`8000000P3oool001H0oooo0P00000i0?ooo`03
0000003oool0oooo0?l0ooooW03oool2000000L0oooo0P0000040?ooo`800000903oool2000000L0
oooo1P00001J0?ooo`030000003oool0oooo02P0oooo0P0000020?ooo`005P3oool2000003T0oooo
00<000000?ooo`3oool0o`3ooonL0?ooo`8000001`3oool2000000@0oooo0P00000T0?ooo`800000
2`3oool2000005X0oooo00<000000?ooo`3oool0:03oool200000080oooo000B0?ooo`@00000>`3o
ool00`000000oooo0?ooo`3o0?oooi`0oooo0P0000070?ooo`800000103oool2000002@0oooo0P00
000;0?ooo`800000FP3oool00`000000oooo0?ooo`0X0?ooo`8000000P3oool00180oooo1000000k
0?ooo`030000003oool0oooo0?l0ooooW03oool2000000L0oooo0P0000040?ooo`800000903oool2
000006L0oooo00<000000?ooo`3oool0:03oool200000080oooo001A0?ooo`030000003oool0oooo
0?l0ooooW03oool2000000L0oooo0P0000040?ooo`800000903oool2000006L0oooo00<000000?oo
o`3oool0:03oool200000080oooo001A0?ooo`030000003oool0oooo0?l0ooooW03oool2000000L0
oooo2000000T0?ooo`800000I`3oool00`000000oooo0?ooo`0X0?ooo`8000000P3oool00100oooo
2P00000g0?ooo`030000003oool0oooo0?l0ooooV03oool6000000L0oooo2000000B0?ooo`P00000
1P3oool6000006L0oooo00<000000?ooo`3oool0:03oool200000080oooo000@0?ooo`X00000=`3o
ool00`000000oooo0?ooo`3o0?oooiP0oooo1P0000070?ooo`800000603oool8000000H0oooo1P00
001W0?ooo`030000003oool0oooo02P0oooo0P0000020?ooo`00503oool2000003/0oooo00<00000
0?ooo`3oool0o`3ooonL0?ooo`8000001`3oool2000001P0oooo0P00000@0?ooo`800000I`3oool0
0`000000oooo0?ooo`0X0?ooo`8000000P3oool001@0oooo0P00000k0?ooo`<00000o`3ooonL0?oo
o`8000002@3oool2000001H0oooo0P00000@0?ooo`800000I`3oool00`000000oooo0?ooo`0O0?oo
o`D000001P3oool200000000503oool2000003/0oooo00<000000?ooo`3oool0o`3ooonW0?ooo`80
0000603oool2000007L0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`060?ooo`80
0000000D0?ooo`800000>`3oool00`000000oooo0?ooo`3o0?ooojT0oooo0P00000F0?ooo`800000
M`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00P0oooo000D0?ooo`800000>`3o
ool00`000000oooo0?ooo`3o0?ooojT0oooo0P00000H0?ooo`800000M@3oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo00P0oooo000D0?ooo`800000>`3oool00`000000oooo0?ooo`3o
0?oooj/0oooo0P00000F0?ooo`800000M@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo00P0oooo000D0?ooo`800000>`3oool00`000000oooo0?ooo`3o0?oooj/0oooo0P00000H0?oo
o`800000L`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00P0oooo000D0?ooo`80
0000>`3oool00`000000oooo0?ooo`3o0?ooojD0oooo0P0000040?ooo`800000603oool2000007<0
oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`080?ooo`00503oool2000003/0oooo
00<000000?ooo`3oool0o`3ooonU0?ooo`800000103oool200000180oooo0P0000040?ooo`800000
L`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0000000X0oooo000D0?ooo`800000>`3o
ool00`000000oooo0?ooo`3o0?ooojL0oooo1000000D0?ooo`800000103oool2000007<0oooo00<0
00000?ooo`3oool0803oool2000000X0oooo000@0?ooo`X00000=`3oool300000?l0ooooY`3oool4
000001@0oooo2000001c0?ooo`030000003oool0oooo01l0oooo1P0000070?ooo`00403oool:0000
03L0oooo00<000000?ooo`3oool0o`3ooonU0?ooo`800000103oool200000180oooo2000001c0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?oo
o`00503oool2000003/0oooo00<000000?ooo`3oool0o`3ooonU0?ooo`800000103oool200000180
oooo0P00001i0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool02@3oool001@0oooo
0P00000k0?ooo`030000003oool0oooo0?l0ooooY@3oool2000000@0oooo0P00000B0?ooo`800000
N@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00P0oooo000D0?ooo`800000>`3o
ool00`000000oooo0?ooo`3o0?ooojD0oooo0P0000040?ooo`800000503oool2000007L0oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`00503oool2000003/0oooo00<00000
0?ooo`3oool0o`3ooonU0?ooo`800000103oool2000001@0oooo0P00001g0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool0103oool200000000503oool2000003/0oooo00<000000?oo
o`3oool0o`3ooonU0?ooo`800000103oool2000001H0oooo0P00001e0?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool01@3oool001@0oooo0P00000k0?ooo`030000003oool0oooo0?l0
ooooY@3oool2000000@0oooo0P00000F0?ooo`800000M@3oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00180oooo1000000k0?ooo`030000
003oool0oooo0?l0ooooY@3oool2000000@0oooo0P00000H0?ooo`800000L`3oool00`000000oooo
0?ooo`0O0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00180oooo1000
000k0?ooo`030000003oool0oooo0?l0ooooY@3oool2000000@0oooo0P00000H0?ooo`800000L`3o
ool00`000000oooo0?ooo`0P0?ooo`@00000203oool00540oooo0`00003o0?ooojD0oooo0P000004
0?ooo`8000004P3oool2000000@0oooo0P00001c0?ooo`030000003oool0oooo02`0oooo001A0?oo
o`030000003oool0oooo0?l0ooooY@3oool800000180oooo0P0000040?ooo`800000L`3oool00`00
0000oooo0?ooo`0/0?ooo`00403oool8000003T0oooo00<000000?ooo`3oool0o`3ooonU0?ooo`P0
0000503oool4000007D0oooo00<000000?ooo`3oool0;03oool00100oooo2000000i0?ooo`030000
003oool0oooo0?l0ooooY@3oool2000001X0oooo1000001e0?ooo`030000003oool0oooo02`0oooo
000@0?ooo`800000103oool2000003T0oooo00<000000?ooo`3oool0o`3ooonU0?ooo`800000603o
ool2000000@0oooo0P00001c0?ooo`030000003oool0oooo02`0oooo000@0?ooo`800000103oool2
000003T0oooo00<000000?ooo`3oool0o`3ooonW0?ooo`8000005P3oool2000000@0oooo0P00001c
0?ooo`030000003oool0oooo02`0oooo000B0?ooo`8000001P3oool8000000H0oooo0P00000:0?oo
o`800000203oool6000000d0oooo00<000000?ooo`3oool0o`3ooonW0?ooo`8000005P3oool20000
00@0oooo0P00001T0?ooo`@0003o2`3oool00`000000oooo0?ooo`0/0?ooo`004P3oool2000000H0
oooo200000060?ooo`8000002P3oool2000000P0oooo1P00000=0?ooo`030000003oool0oooo0?l0
ooooZ@3oool2000001@0oooo0P0000040?ooo`800000I03oool4003o00/0oooo00<000000?ooo`3o
ool0;03oool001@0oooo0P0000080?ooo`800000503oool2000000h0oooo0P00000;0?ooo`030000
003oool0oooo0?l0ooooZ@3oool2000001@0oooo0P0000040?ooo`800000I@3oool2003o00`0oooo
00<000000?ooo`3oool0;03oool001@0oooo0P0000080?ooo`800000503oool2000000h0oooo0P00
000;0?ooo`030000003oool0oooo0?l0ooooZ`3oool200000180oooo0P0000040?ooo`800000IP3o
ool00`00o`00oooo0?ooo`0:0?ooo`030000003oool0oooo02`0oooo000@0?ooo`P000001P3oool2
000001H0oooo0P00000<0?ooo`8000002`3oool500000?l0ooooZ@3oool200000180oooo0P000004
0?ooo`800000L`3oool00`000000oooo0?ooo`0/0?ooo`00403oool8000000H0oooo0P00000F0?oo
o`800000303oool2000000/0oooo00<000000?ooo`3oool0o`3ooonU0?ooo`800000103oool20000
0180oooo0P0000040?ooo`800000L`3oool00`000000oooo0?ooo`0Z0?ooo`800000000N0?ooo`80
00005P3oool2000000H0oooo1P00000=0?ooo`030000003oool0oooo0?l0ooooY@3oool2000000@0
oooo0P00000B0?ooo`800000103oool2000007<0oooo00<000000?ooo`3oool0;03oool001h0oooo
0P00000F0?ooo`8000001P3oool6000000d0oooo00<000000?ooo`3oool0o`3ooonU0?ooo`P00000
4P3oool2000000@0oooo0P00001c0?ooo`030000003oool0oooo02`0oooo000B0?ooo`H000001P3o
ool2000001P0oooo0P0000040?ooo`8000004@3oool00`000000oooo0?ooo`3o0?ooojD0oooo2000
000B0?ooo`P00000L`3oool00`000000oooo0?ooo`0/0?ooo`004P3oool6000000H0oooo0P00000H
0?ooo`800000103oool200000140ooooo`00003o000003l00000;P3oool00100oooo0P0000080?oo
o`H000004P3oool2000000@0oooo0P0000040?ooo`800000o`3ooonm0?ooo`800000503oool20000
0:P0oooo000@0?ooo`800000203oool600000180oooo0P0000040?ooo`800000103oool200000?l0
oooo_@3oool2000001@0oooo0P00002X0?ooo`00403oool6000000P0oooo0P00000B0?ooo`P00000
103oool800000?l0oooo]`3oool2000001H0oooo0P00002V0?ooo`00403oool6000000P0oooo0P00
000B0?ooo`P00000103oool800000?l0oooo]`3oool2000001H0oooo0P00002V0?ooo`00403oool2
000000@0oooo0P00003o0?ooonD0oooo0P00000H0?ooo`800000Y03oool00100oooo0P0000040?oo
o`800000o`3ooooU0?ooo`800000603oool200000:@0oooo000B0?ooo`@00000o`3ooooW0?ooo`80
00006P3oool200000:80oooo000B0?ooo`@00000o`3ooooS0?ooo`H000006P3oool200000:80oooo
003o0?ooooT0oooo1P00000D0?ooo`800000103oool200000:80oooo003o0?ooood0oooo0P00000D
0?ooo`800000103oool200000:80oooo000B0?ooo`@000000P3oool200000?l0ooooh`3oool20000
01@0oooo2000002R0?ooo`004P3oool400000080oooo0P00003o0?ooooT0oooo2000002R0?ooo`00
403oool2000000@0oooo0P00003o0?ooool0oooo0P00002T0?ooo`00403oool2000000@0oooo0P00
003o0?ooool0oooo0P00002T0?ooo`00403oool2000000@0oooo0P00003o0?ooool0oooo0P00002T
0?ooo`00403oool2000000@0oooo0P00003o0?ooool0oooo0P00002T0?ooo`00403oool2000000@0
oooo0P00003o0?ooool0oooo0P00002T0?ooo`00403oool2000000@0oooo0P00003o0?ooool0oooo
0P00002T0?ooo`004P3oool600000?l0ooooo`3oool200000:@0oooo000B0?ooo`H00000o`3ooooo
0?ooo`800000Y03oool00180oooo00@000000?ooo`3oool0oooo0P00003o0?oooo/0oooo1P00002T
0?ooo`004`3oool00`000000oooo0?ooo`0200000?l0oooon`3oool600000:@0oooo000C0?ooo`D0
0000o`3ooooo0?ooo`800000Y03oool001@0oooo1000003o0?ooool0oooo0P00002T0?ooo`00503o
ool00`000000oooo0?ooo`3o0?ooool0ooooY`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo
0?ooojL0oooo000D0?ooo`030000003oool0oooo0?l0ooooo`3ooonW0?ooo`00503oool00`000000
oooo0?ooo`3o0?ooool0ooooY`3oool001@0oooo00<000000?ooo`3oool0o`3ooooo0?ooojL0oooo
000D0?ooo`030000003oool0oooo0?l0ooooo`3ooonW0?ooo`004`3oool00`000000oooo0?ooo`3o
0?ooool0ooooZ03oool001<0oooo00<000000?ooo`3oool0o`3ooooo0?ooojP0oooo000B0?ooo`03
0000003oool0oooo0?l0ooooo`3ooonY0?ooo`004P3oool00`000000oooo0?ooo`3o0?ooool0oooo
Z@3oool00?l0ooooo`3ooonn0?ooo`00o`3ooooo0?oookh0oooo003o0?ooool0oooo_P3oool00?l0
ooooo`3ooonn0?ooo`00o`3ooooo0?oookh0oooo0000\
\>"],
  ImageRangeCache->{{{0, 699}, {431.625, 0}} -> {-7.16084, -0.244576, \
0.0752471, 0.00515591}}],

Cell[BoxData[
    \("/afs/cern.ch/user/a/afabich/public/MERIT/PicDisplayAllRunsZoom.eps"\)],\
 "Output"]
}, Open  ]]
},
FrontEndVersion->"5.2 for X",
ScreenRectangle->{{0, 1280}, {0, 1005}},
WindowSize->{1255, 877},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
ShowSelection->True
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 531, 8, 139, "Input"],
Cell[2310, 63, 66, 1, 27, "Output"],
Cell[2379, 66, 76, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2492, 72, 557, 12, 123, "Input"],
Cell[3052, 86, 62, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3151, 92, 1098, 20, 139, "Input"],
Cell[4252, 114, 163, 2, 27, "Output"],
Cell[4418, 118, 97, 2, 27, "Output"]
}, Open  ]],
Cell[4530, 123, 415, 10, 43, "Input"],
Cell[4948, 135, 627, 13, 91, "Input"],

Cell[CellGroupData[{
Cell[5600, 152, 710, 16, 123, "Input"],
Cell[6313, 170, 214, 3, 27, "Output"]
}, Open  ]],
Cell[6542, 176, 729, 14, 91, "Input"],

Cell[CellGroupData[{
Cell[7296, 194, 1340, 21, 219, "Input"],
Cell[8639, 217, 350020, 9479, 332, 146931, 6969, "GraphicsData", \
"PostScript", "Graphics"],
Cell[358662, 9698, 100, 2, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[358799, 9705, 2349, 44, 365, "Input"],
Cell[361151, 9751, 175235, 4141, 441, 77977, 2937, "GraphicsData", \
"PostScript", "Graphics"],
Cell[536389, 13894, 104, 2, 27, "Output"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

